--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET lock_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SET check_function_bodies = false;
SET client_min_messages = warning;

--
-- Name: core; Type: SCHEMA; Schema: -; Owner: core
--

CREATE SCHEMA core;


ALTER SCHEMA core OWNER TO core;

--
-- Name: extra; Type: SCHEMA; Schema: -; Owner: extra
--

CREATE SCHEMA extra;


ALTER SCHEMA extra OWNER TO extra;

--
-- Name: history; Type: SCHEMA; Schema: -; Owner: core
--

CREATE SCHEMA history;


ALTER SCHEMA history OWNER TO core;

--
-- Name: plpgsql; Type: EXTENSION; Schema: -; Owner: 
--

CREATE EXTENSION IF NOT EXISTS plpgsql WITH SCHEMA pg_catalog;


--
-- Name: EXTENSION plpgsql; Type: COMMENT; Schema: -; Owner: 
--

COMMENT ON EXTENSION plpgsql IS 'PL/pgSQL procedural language';


--
-- Name: uuid-ossp; Type: EXTENSION; Schema: -; Owner: 
--

CREATE EXTENSION IF NOT EXISTS "uuid-ossp" WITH SCHEMA public;


--
-- Name: EXTENSION "uuid-ossp"; Type: COMMENT; Schema: -; Owner: 
--

COMMENT ON EXTENSION "uuid-ossp" IS 'generate universally unique identifiers (UUIDs)';


SET search_path = core, pg_catalog;

--
-- Name: AllPersonnel_DoDelete(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "AllPersonnel_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	username character varying(255);
BEGIN
	username := CURRENT_USER;

	IF core."Personnel_Delete"(OLD.id, username) THEN
		RETURN OLD;
	END IF;

	RETURN NULL;
END;
$$;


ALTER FUNCTION core."AllPersonnel_DoDelete"() OWNER TO core;

--
-- Name: AllPersonnel_DoInsert(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "AllPersonnel_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF NEW.id IS NULL THEN
		NEW.id := uuid_generate_v4();
	END IF;
	
	IF NEW.created IS NULL THEN
		NEW.created := CURRENT_TIMESTAMP;
	END IF;
	
	IF NEW.created_by IS NULL THEN
		NEW.created_by := CURRENT_USER;
	END IF;

	INSERT INTO core."Personnel" (
		id,
		name_last,
		name_first,
		user_level,
		days_to_log,
		apb_type_id,
		apb_zone_id,
		apb_violations,
		created,
		created_by,
		updated,
		updated_by)
	VALUES (
		NEW.id,
		NEW.name_last,
		NEW.name_first,
		NEW.user_level,
		NEW.days_to_log,
		NEW.apb_type_id,
		NEW.apb_zone_id,
		NEW.apb_violations,
		NEW.created,
		NEW.created_by,
		NEW.updated,
		NEW.updated_by);

	RETURN NEW;
END;
$$;


ALTER FUNCTION core."AllPersonnel_DoInsert"() OWNER TO core;

--
-- Name: AllPersonnel_DoUpdate(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "AllPersonnel_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.id := OLD.id;

	IF NEW.updated IS NULL THEN
		NEW.updated := CURRENT_TIMESTAMP;
	END IF;

	IF NEW.updated_by IS NULL THEN
		NEW.updated_by := CURRENT_USER;
	END IF;

	UPDATE core."Personnel" SET
		name_last = NEW.name_last,
		name_first = NEW.name_first,
		user_level = NEW.user_level,
		days_to_log = NEW.days_to_log,
		apb_type_id = NEW.apb_type_id,
		apb_zone_id = NEW.apb_zone_id,
		apb_violations = NEW.apb_violations,
		updated = NEW.updated,
		updated_by = NEW.updated_by
	WHERE id = OLD.id 
		AND deleted IS NULL;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION core."AllPersonnel_DoUpdate"() OWNER TO core;

--
-- Name: CanSwitchToSingleId(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "CanSwitchToSingleId"() RETURNS boolean
    LANGUAGE sql
    AS $$
SELECT NOT EXISTS (
	SELECT count(*) AS count
	FROM core."Personnel" AS cp
	LEFT JOIN core."Token" AS ct ON cp.id = ct.personnel_id AND ct.type_id = 1 AND ct.deleted IS NULL
	WHERE cp.deleted IS NULL
	GROUP BY cp.id
	HAVING count(*) <> 1
);
$$;


ALTER FUNCTION core."CanSwitchToSingleId"() OWNER TO core;

--
-- Name: CardToken_DoDelete(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "CardToken_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	username character varying(255);
BEGIN
	username := CURRENT_USER;

	IF core."Token_Delete"(OLD.token_id, username) THEN
		RETURN OLD;
	END IF;

	RETURN NULL;
END;
$$;


ALTER FUNCTION core."CardToken_DoDelete"() OWNER TO core;

--
-- Name: CardToken_DoInsert(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "CardToken_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	token_type_id smallint;
BEGIN
	IF NEW.token_id IS NULL THEN
		NEW.token_id := uuid_generate_v4();
	END IF;

	token_type_id := 1;

	IF NEW.site_code IS NULL THEN
		NEW.site_code := 0;
	END IF;

	IF NEW.card_format IS NULL THEN
		NEW.card_format := 26;
	END IF;

	IF NEW.activate_date IS NULL THEN
		NEW.activate_date := CURRENT_DATE;
	END IF;

	IF NEW.deactivate_date IS NULL THEN
		NEW.deactivate_date := CURRENT_DATE + '1 year'::interval;
	END IF;

	IF NEW.lost IS NULL THEN
		NEW.lost := false;
	END IF;

	IF NEW.created IS NULL THEN
		NEW.created := CURRENT_TIMESTAMP;
	END IF;

	IF NEW.created_by IS NULL THEN
		NEW.created_by := CURRENT_USER;
	END IF;

	INSERT INTO core."Token" (
		id,
		type_id,
		user_level,
		personnel_id,
		badge_id,
		lost,
		last_read,
		last_reader,
		last_read_status,
		created,
		created_by,
		updated,
		updated_by,
		downloaded,
		downloaded_by,
		download_required)
	VALUES (
		NEW.token_id,
		token_type_id,
		NEW.user_level,
		NEW.personnel_id,
		NEW.badge_id,
		NEW.lost,
		NEW.last_read,
		NEW.last_reader,
		NEW.last_read_status,
		NEW.created,
		NEW.created_by,
		NEW.updated,
		NEW.updated_by,
		NEW.downloaded,
		NEW.downloaded_by,
		NEW.download_required);

	INSERT INTO core."Card" (
		token_id,
		card_number,
		site_code,
		card_format,
		card_type,
		pin_number,
		card_valid,
		activate_date,
		deactivate_date,
		secondary_expiration_date,
		expire_days,
		action_point_id,
		threat_level,
		auto_disable,
		grant_long_access_time,
		escort_visitor_capable,
		access_cost_override_capable,
		event_lock_override_capable,
		building_passback_exemption,
		parking_passback_exemption,
		card_holder_groups,
		activation_group,
		on_access_output,
		compass_command_group,
		low_battery)
	VALUES (
		NEW.token_id,
		NEW.card_number,
		NEW.site_code,
		NEW.card_format,
		NEW.card_type,
		NEW.pin_number,
		NEW.card_valid,
		NEW.activate_date,
		NEW.deactivate_date,
		NEW.secondary_expiration_date,
		NEW.expire_days,
		NEW.action_point_id,
		NEW.threat_level,
		NEW.auto_disable,
		NEW.grant_long_access_time,
		NEW.escort_visitor_capable,
		NEW.access_cost_override_capable,
		NEW.event_lock_override_capable,
		NEW.building_passback_exemption,
		NEW.parking_passback_exemption,
		NEW.card_holder_groups,
		NEW.activation_group,
		NEW.on_access_output,
		NEW.compass_command_group,
		NEW.low_battery);

	RETURN NEW;
END;
$$;


ALTER FUNCTION core."CardToken_DoInsert"() OWNER TO core;

--
-- Name: CardToken_DoUpdate(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "CardToken_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.token_id := OLD.token_id;

	IF NEW.updated IS NULL THEN
		NEW.updated := CURRENT_TIMESTAMP;
	END IF;

	IF NEW.updated_by IS NULL THEN
		NEW.updated_by := CURRENT_USER;
	END IF;

	UPDATE core."Token" SET
		user_level = NEW.user_level,
		personnel_id = NEW.personnel_id,
		badge_id = NEW.badge_id,
		lost = NEW.lost,
		last_read = NEW.last_read,
		last_reader = NEW.last_reader,
		last_read_status = NEW.last_read_status,
		updated = NEW.updated,
		updated_by = NEW.updated_by,
		downloaded = NEW.downloaded,
		downloaded_by = NEW.downloaded_by,
		download_required = NEW.download_required
	WHERE id = OLD.token_id
		AND deleted IS NULL;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	UPDATE core."Card" SET 
		card_number = NEW.card_number,
		site_code = NEW.site_code,
		card_format = NEW.card_format,
		card_type = NEW.card_type,
		pin_number = NEW.pin_number,
		card_valid = NEW.card_valid,
		activate_date = NEW.activate_date,
		deactivate_date = NEW.deactivate_date,
		secondary_expiration_date = NEW.secondary_expiration_date,
		expire_days = NEW.expire_days,
		action_point_id = NEW.action_point_id,
		threat_level = NEW.threat_level,
		auto_disable = NEW.auto_disable,
		grant_long_access_time = NEW.grant_long_access_time,
		escort_visitor_capable = NEW.escort_visitor_capable,
		access_cost_override_capable = NEW.access_cost_override_capable,
		event_lock_override_capable = NEW.event_lock_override_capable,
		building_passback_exemption = NEW.building_passback_exemption,
		parking_passback_exemption = NEW.parking_passback_exemption,
		card_holder_groups = NEW.card_holder_groups,
		activation_group = NEW.activation_group,
		on_access_output = NEW.on_access_output,
		compass_command_group = NEW.compass_command_group,
		low_battery = NEW.low_battery
	WHERE token_id = OLD.token_id;

	RETURN NEW;
END;
$$;


ALTER FUNCTION core."CardToken_DoUpdate"() OWNER TO core;

--
-- Name: Personnel_Delete(uuid, character varying); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "Personnel_Delete"(personnel_id uuid, username character varying) RETURNS boolean
    LANGUAGE plpgsql
    AS $_$
DECLARE
	delete_personnel_id ALIAS FOR $1;
	result boolean := false;
	deleted_ts timestamp with time zone;
	deleted_token_id uuid := NULL;
	rec RECORD;
BEGIN
	IF username IS NULL THEN
		username := CURRENT_USER;
	END IF;

	deleted_ts := CURRENT_TIMESTAMP;

	FOR rec in select name_first, name_last, name_middle, assigned_to, card_number, site_code, card_format, room 
	FROM extra."MultiCard" where extra."MultiCard".personnel_id = delete_personnel_id
	LOOP
	IF rec.card_number <= 256 and rec.site_code = 0 and rec.card_format = 26 THEN
	Insert into history."AccutechTagChange" (
				change_time, 
				event, 
				card_number,
				name_first,
				name_last,
				name_middle,
				assigned_to, 
				updated_by,
				room) 
				VALUES (
				NOW(),
				5037,
				rec.card_number,
				rec.name_first,
				rec.name_last,
				rec.name_middle,
				rec.assigned_to,
				username,
				rec.room);
	END IF;
	END LOOP;
	
	WITH deletedTokens AS (
		UPDATE core."Token" AS token SET
			deleted = deleted_ts,
			deleted_by = username
		WHERE token.personnel_id = delete_personnel_id AND token.deleted IS NULL
		RETURNING token.id
	)
	UPDATE core."Card" AS card SET
		deleted = deleted_ts
	WHERE card.token_id IN (SELECT id FROM deletedTokens);

	UPDATE core."Personnel" AS personnel SET
		deleted = deleted_ts,
		deleted_by = username
	WHERE personnel.id = delete_personnel_id AND personnel.deleted IS NULL;

	IF FOUND THEN
		result := true;
	END IF;
	
	RETURN result;
END;
$_$;


ALTER FUNCTION core."Personnel_Delete"(personnel_id uuid, username character varying) OWNER TO core;

--
-- Name: Token_Delete(uuid, character varying); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "Token_Delete"(token_id uuid, username character varying) RETURNS boolean
    LANGUAGE plpgsql
    AS $_$
DECLARE
	result boolean := false;
	deleted_ts timestamp with time zone;
	deleted_token_id uuid := NULL;
BEGIN
	IF username IS NULL THEN
		username := CURRENT_USER;
	END IF;

	deleted_ts := CURRENT_TIMESTAMP;

	UPDATE core."Token" AS token SET
		deleted = deleted_ts,
		deleted_by = username
	WHERE token.id = $1 AND token.deleted IS NULL
	RETURNING token.id INTO deleted_token_id;

	IF deleted_token_id IS NOT NULL THEN
		result := true;
		UPDATE core."Card" AS card SET
			deleted = deleted_ts
		WHERE card.token_id = deleted_token_id;
	END IF;

	RETURN result;
END;
$_$;


ALTER FUNCTION core."Token_Delete"(token_id uuid, username character varying) OWNER TO core;

--
-- Name: datediff(character varying, timestamp without time zone, timestamp without time zone); Type: FUNCTION; Schema: core; Owner: postgres
--

CREATE FUNCTION datediff(units character varying, start_t timestamp without time zone, end_t timestamp without time zone) RETURNS integer
    LANGUAGE plpgsql
    AS $$
   DECLARE
     diff_interval INTERVAL; 
     diff INT = 0;
     years_diff INT = 0;
   BEGIN
     IF units IN ('yy', 'yyyy', 'year', 'mm', 'm', 'month') THEN
       years_diff = DATE_PART('year', end_t) - DATE_PART('year', start_t);
 
       IF units IN ('yy', 'yyyy', 'year') THEN
         -- SQL Server does not count full years passed (only difference between year parts)
         RETURN years_diff;
       ELSE
         -- If end month is less than start month it will subtracted
         RETURN years_diff * 12 + (DATE_PART('month', end_t) - DATE_PART('month', start_t)); 
       END IF;
     END IF;
 
     -- Minus operator returns interval 'DDD days HH:MI:SS'  
     diff_interval = end_t - start_t;
 
     diff = diff + DATE_PART('day', diff_interval);
 
     IF units IN ('wk', 'ww', 'week') THEN
       diff = diff/7;
       RETURN diff;
     END IF;
 
     IF units IN ('dd', 'd', 'day') THEN
       RETURN diff;
     END IF;
 
     diff = diff * 24 + DATE_PART('hour', diff_interval); 
 
     IF units IN ('hh', 'hour') THEN
        RETURN diff;
     END IF;
 
     diff = diff * 60 + DATE_PART('minute', diff_interval);
 
     IF units IN ('mi', 'n', 'minute') THEN
        RETURN diff;
     END IF;
 
     diff = diff * 60 + DATE_PART('second', diff_interval);
 
     RETURN diff;
   END;
   $$;


ALTER FUNCTION core.datediff(units character varying, start_t timestamp without time zone, end_t timestamp without time zone) OWNER TO postgres;

SET search_path = extra, pg_catalog;

--
-- Name: AllAccessSet_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllAccessSet_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."AccessSet"
	WHERE id = OLD.id;

	IF FOUND THEN
		extra_found := true;
	END IF;

	IF OLD.notes_id IS NOT NULL THEN
		DELETE FROM extra."Notes" WHERE id = OLD.notes_id;
	END IF;
	
	DELETE FROM core."AccessSet"
	WHERE id = OLD.id;

	IF NOT FOUND AND NOT extra_found THEN
		RETURN NULL;
	END IF;
	
	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."AllAccessSet_DoDelete"() OWNER TO extra;

--
-- Name: AllAccessSet_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllAccessSet_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF NEW.id IS NULL THEN
		NEW.id := uuid_generate_v4();
	END IF;

	INSERT INTO core."AccessSet" (
		id,
		name,
		user_level,
		download_required)
	VALUES (
		NEW.id,
		NEW.name,
		NEW.user_level,
		NEW.download_required);

	NEW.notes_id := extra."Notes_InsertOrUpdate"(NEW.notes_id, NEW.notes);

	INSERT INTO extra."AccessSet" (
		id,
		notes_id)
	VALUES (
		NEW.id,
		NEW.notes_id);

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllAccessSet_DoInsert"() OWNER TO extra;

--
-- Name: AllAccessSet_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllAccessSet_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.id := OLD.id;

	UPDATE core."AccessSet" SET
		name = NEW.name,
		user_level = NEW.user_level,
		download_required = NEW.download_required
	WHERE id = OLD.id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	NEW.notes_id := extra."Notes_Update"(OLD.notes_id, NEW.notes_id, NEW.notes);

	UPDATE extra."AccessSet" SET
		notes_id = NEW.notes_id
	WHERE id = OLD.id;

	IF NOT FOUND THEN
		INSERT INTO extra."AccessSet" (
			id,
			notes_id)
		VALUES (
			NEW.id,
			NEW.notes_id);
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllAccessSet_DoUpdate"() OWNER TO extra;

--
-- Name: AllPersonnel_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllPersonnel_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."Personnel"
	WHERE id = OLD.id;

	IF FOUND THEN
		extra_found := true;
	END IF;

	IF OLD.notes_id IS NOT NULL THEN
		DELETE FROM extra."Notes" WHERE id = OLD.notes_id;
	END IF;

	IF OLD.photo_id IS NOT NULL THEN
		DELETE FROM extra."Blob" WHERE id = OLD.photo_id;
	END IF;

	IF OLD.signature_id IS NOT NULL THEN
		DELETE FROM extra."Blob" WHERE id = OLD.signature_id;
	END IF;

	IF OLD.fingerprint_id IS NOT NULL THEN
		DELETE FROM extra."Blob" WHERE id = OLD.fingerprint_id;
	END IF;

	DELETE FROM core."AllPersonnel"
	WHERE id = OLD.id;

	IF NOT FOUND AND NOT extra_found THEN
		RETURN NULL;
	END IF;

	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."AllPersonnel_DoDelete"() OWNER TO extra;

--
-- Name: AllPersonnel_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllPersonnel_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF NEW.id IS NULL THEN
		NEW.id := uuid_generate_v4();
	END IF;

	INSERT INTO core."AllPersonnel" (
		id,
		name_last,
		name_first,
		user_level,
		days_to_log,
		apb_type_id,
		apb_zone_id,
		apb_violations,
		created,
		created_by,
		updated,
		updated_by)
	VALUES (
		NEW.id,
		NEW.name_last,
		NEW.name_first,
		NEW.user_level,
		NEW.days_to_log,
		NEW.apb_type_id,
		NEW.apb_zone_id,
		NEW.apb_violations,
		NEW.created,
		NEW.created_by,
		NEW.updated,
		NEW.updated_by);

	NEW.notes_id := extra."Notes_InsertOrUpdate"(NEW.notes_id, NEW.notes);
	NEW.photo_id := extra."Blob_InsertOrUpdate"(NEW.photo_id, NEW.photo_type, NEW.photo);
	NEW.signature_id := extra."Blob_InsertOrUpdate"(NEW.signature_id, NEW.signature_type, NEW.signature);
	NEW.fingerprint_id := extra."Blob_InsertOrUpdate"(NEW.fingerprint_id, NEW.fingerprint_type, NEW.fingerprint);

	INSERT INTO extra."Personnel" (
		id,
		name_middle,
		name_prefix,
		name_suffix,
		company,
		department,
		job_title,
		email,
		phone_work,
		phone_work_ext,
		phone_mobile,
		phone_home,
		address,
		city,
		state_or_prov,
		postal_code,
		country,
		notes_id,
		photo_id,
		signature_id,
		fingerprint_id,
		room,
		assigned_to,
		admission_date)
	VALUES (
		NEW.id,
		NEW.name_middle,
		NEW.name_prefix,
		NEW.name_suffix,
		NEW.company,
		NEW.department,
		NEW.job_title,
		NEW.email,
		NEW.phone_work,
		NEW.phone_work_ext,
		NEW.phone_mobile,
		NEW.phone_home,
		NEW.address,
		NEW.city,
		NEW.state_or_prov,
		NEW.postal_code,
		NEW.country,
		NEW.notes_id,
		NEW.photo_id,
		NEW.signature_id,
		NEW.fingerprint_id,
		NEW.room,
		NEW.assigned_to,
		NEW.admission_date);

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllPersonnel_DoInsert"() OWNER TO extra;

--
-- Name: AllPersonnel_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllPersonnel_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.id := OLD.id;

	UPDATE core."AllPersonnel" SET
		name_last = NEW.name_last,
		name_first = NEW.name_first,
		user_level = NEW.user_level,
		days_to_log = NEW.days_to_log,
		apb_type_id = NEW.apb_type_id,
		apb_zone_id = NEW.apb_zone_id,
		apb_violations = NEW.apb_violations,
		updated = NEW.updated,
		updated_by = NEW.updated_by
	WHERE id = OLD.id;
	
	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	NEW.notes_id := extra."Notes_Update"(OLD.notes_id, NEW.notes_id, NEW.notes);
	NEW.photo_id := extra."Blob_Update"(OLD.photo_id, NEW.photo_id, NEW.photo_type, NEW.photo);
	NEW.signature_id := extra."Blob_Update"(OLD.signature_id, NEW.signature_id, NEW.signature_type, NEW.signature);
	NEW.fingerprint_id := extra."Blob_Update"(OLD.fingerprint_id, NEW.fingerprint_id, NEW.fingerprint_type, NEW.fingerprint);

	UPDATE extra."Personnel" SET
		name_middle = NEW.name_middle,
		name_prefix = NEW.name_prefix,
		name_suffix = NEW.name_suffix,
		company = NEW.company,
		department = NEW.department,
		job_title = NEW.job_title,
		email = NEW.email,
		phone_work = NEW.phone_work,
		phone_work_ext = NEW.phone_work_ext,
		phone_mobile = NEW.phone_mobile,
		phone_home = NEW.phone_home,
		address = NEW.address,
		city = NEW.city,
		state_or_prov = NEW.state_or_prov,
		postal_code = NEW.postal_code,
		country = NEW.country,
		notes_id = NEW.notes_id,
		photo_id = NEW.photo_id,
		signature_id = NEW.signature_id,
		fingerprint_id = NEW.fingerprint_id,
		room = NEW.room,
		assigned_to = NEW.assigned_to,
		admission_date = NEW.admission_date
	WHERE id = OLD.id;

	IF NOT FOUND THEN
		INSERT INTO extra."Personnel" (
			id,
			name_middle,
			name_prefix,
			name_suffix,
			company,
			department,
			job_title,
			email,
			phone_work,
			phone_work_ext,
			phone_mobile,
			phone_home,
			address,
			city,
			state_or_prov,
			postal_code,
			country,
			notes_id,
			photo_id,
			signature_id,
			fingerprint_id,
			room,
			assigned_to,
			admission_date)
		VALUES (
			NEW.id,
			NEW.name_middle,
			NEW.name_prefix,
			NEW.name_suffix,
			NEW.company,
			NEW.department,
			NEW.job_title,
			NEW.email,
			NEW.phone_work,
			NEW.phone_work_ext,
			NEW.phone_mobile,
			NEW.phone_home,
			NEW.address,
			NEW.city,
			NEW.state_or_prov,
			NEW.postal_code,
			NEW.country,
			NEW.notes_id,
			NEW.photo_id,
			NEW.signature_id,
			NEW.fingerprint_id,
			NEW.room,
			NEW.assigned_to,
			NEW.admission_date);
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllPersonnel_DoUpdate"() OWNER TO extra;

--
-- Name: AllVehicle_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllVehicle_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."Vehicle"
	WHERE id = OLD.id;

	IF FOUND THEN
		extra_found := true;
	END IF;

	IF OLD.notes_id IS NOT NULL THEN
		DELETE FROM extra."Notes" WHERE id = OLD.notes_id;
	END IF;
	
	DELETE FROM core."Vehicle"
	WHERE id = OLD.id;

	IF NOT FOUND AND NOT extra_found THEN
		RETURN NULL;
	END IF;
	
	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."AllVehicle_DoDelete"() OWNER TO extra;

--
-- Name: AllVehicle_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllVehicle_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF NEW.id IS NULL THEN
		NEW.id := uuid_generate_v4();
	END IF;

	INSERT INTO core."Vehicle" (
		id,
		personnel_id,
		make,
		model,
		color,
		accent_color,
		state_or_prov,
		tag,
		sticker,
		year)
	VALUES (
		NEW.id,
		NEW.personnel_id,
		NEW.make,
		NEW.model,
		NEW.color,
		NEW.accent_color,
		NEW.state_or_prov,
		NEW.tag,
		NEW.sticker,
		NEW.year);

	NEW.notes_id := extra."Notes_InsertOrUpdate"(NEW.notes_id, NEW.notes);

	INSERT INTO extra."Vehicle" (
		id,
		notes_id)
	VALUES (
		NEW.id,
		NEW.notes_id);

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllVehicle_DoInsert"() OWNER TO extra;

--
-- Name: AllVehicle_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllVehicle_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.id := OLD.id;

	UPDATE core."Vehicle" SET
		personnel_id = NEW.personnel_id,
		make = NEW.make,
		model = NEW.model,
		color = NEW.color,
		accent_color = NEW.accent_color,
		state_or_prov = NEW.state_or_prov,
		tag = NEW.tag,
		sticker = NEW.sticker,
		year = NEW.year
	WHERE id = OLD.id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	NEW.notes_id := extra."Notes_Update"(OLD.notes_id, NEW.notes_id, NEW.notes);

	UPDATE extra."Vehicle" SET
		notes_id = NEW.notes_id
	WHERE id = OLD.id;

	IF NOT FOUND THEN
		INSERT INTO extra."Vehicle" (
			id,
			notes_id)
		VALUES (
			NEW.id,
			NEW.notes_id);
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllVehicle_DoUpdate"() OWNER TO extra;

--
-- Name: Blob_InsertOrUpdate(uuid, character varying, bytea); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "Blob_InsertOrUpdate"(id uuid, mime_type character varying, bytes bytea) RETURNS uuid
    LANGUAGE plpgsql
    AS $$
DECLARE
	new_id ALIAS FOR id;
	new_mime_type ALIAS FOR mime_type;
	new_bytes ALIAS FOR bytes;
	new_blob RECORD;
	new_blob_type RECORD;
	new_type_id smallint;
BEGIN
	IF bytes IS NULL THEN
		RETURN NULL;
	END IF;
	
	IF new_mime_type IS NULL THEN
		new_type_id := NULL;
	ELSE
		SELECT btype.id INTO new_blob_type
		FROM core."BlobType" btype
		WHERE btype.mime_type = new_mime_type;

		new_type_id := new_blob_type.id;

		IF new_type_id IS NULL THEN
			INSERT INTO core."BlobType" (mime_type)
			VALUES (new_mime_type)
			RETURNING core."BlobType".id INTO new_blob_type;

			new_type_id := new_blob_type.id;
		END IF;
	END IF;
	
	IF id IS NULL THEN
		id := uuid_generate_v4();

		INSERT INTO extra."Blob" (id, type_id, bytes)
		VALUES (new_id, new_type_id, new_bytes)
		RETURNING extra."Blob".id INTO new_blob;
	ELSE
		UPDATE extra."Blob" blob
		SET
			type_id = new_type_id,
			bytes = new_bytes
		WHERE blob.id = new_id
		RETURNING blob.id INTO new_blob;

		IF NOT FOUND THEN
			INSERT INTO extra."Blob" (id, type_id, bytes)
			VALUES (id, new_type_id, bytes)
			RETURNING extra."Blob".id INTO new_blob;
		END IF;
	END IF;
	
	RETURN new_blob.id;
END;
$$;


ALTER FUNCTION extra."Blob_InsertOrUpdate"(id uuid, mime_type character varying, bytes bytea) OWNER TO extra;

--
-- Name: Blob_Update(uuid, uuid, character varying, bytea); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "Blob_Update"(old_id uuid, new_id uuid, mime_type character varying, bytes bytea) RETURNS uuid
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF bytes IS NULL THEN
		IF old_id IS NOT NULL THEN
			DELETE FROM extra."Blob" WHERE id = old_id;
		END IF;
		new_id := NULL;
	ELSE
		IF old_id IS NOT NULL THEN
			IF new_id IS NULL THEN
				new_id := old_id;
			ELSIF new_id <> old_id THEN
				DELETE FROM extra."Blob" WHERE id = old_id;
			END IF;
		END IF;
		new_id := extra."Blob_InsertOrUpdate"(new_id, mime_type, bytes);
	END IF;
	
	RETURN new_id;
END;
$$;


ALTER FUNCTION extra."Blob_Update"(old_id uuid, new_id uuid, mime_type character varying, bytes bytea) OWNER TO extra;

--
-- Name: CardToken_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "CardToken_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."Card"
	WHERE token_id = OLD.token_id;

	IF FOUND THEN
		extra_found := true;
	END IF;
	
	DELETE FROM core."CardToken"
	WHERE token_id = OLD.token_id;

	IF NOT FOUND AND NOT extra_found THEN
		RETURN NULL;
	END IF;
	
	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."CardToken_DoDelete"() OWNER TO extra;

--
-- Name: CardToken_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "CardToken_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	core_inserted RECORD;
BEGIN
	INSERT INTO core."CardToken" (
		token_id,
		card_number,
		site_code,
		card_format,
		card_type,
		pin_number,
		card_valid,
		activate_date,
		deactivate_date,
		secondary_expiration_date,
		expire_days,
		action_point_id,
		threat_level,
		auto_disable,
		grant_long_access_time,
		escort_visitor_capable,
		access_cost_override_capable,
		event_lock_override_capable,
		building_passback_exemption,
		parking_passback_exemption,
		card_holder_groups,
		activation_group,
		on_access_output,
		compass_command_group,
		user_level,
		personnel_id,
		badge_id,
		lost,
		last_read,
		last_reader,
		last_read_status,
		created,
		created_by,
		updated,
		updated_by,
		downloaded,
		downloaded_by,
		download_required,
		low_battery)
	VALUES (
		NEW.token_id,
		NEW.card_number,
		NEW.site_code,
		NEW.card_format,
		NEW.card_type,
		NEW.pin_number,
		NEW.card_valid,
		NEW.activate_date,
		NEW.deactivate_date,
		NEW.secondary_expiration_date,
		NEW.expire_days,
		NEW.action_point_id,
		NEW.threat_level,
		NEW.auto_disable,
		NEW.grant_long_access_time,
		NEW.escort_visitor_capable,
		NEW.access_cost_override_capable,
		NEW.event_lock_override_capable,
		NEW.building_passback_exemption,
		NEW.parking_passback_exemption,
		NEW.card_holder_groups,
		NEW.activation_group,
		NEW.on_access_output,
		NEW.compass_command_group,
		NEW.user_level,
		NEW.personnel_id,
		NEW.badge_id,
		NEW.lost,
		NEW.last_read,
		NEW.last_reader,
		NEW.last_read_status,
		NEW.created,
		NEW.created_by,
		NEW.updated,
		NEW.updated_by,
		NEW.downloaded,
		NEW.downloaded_by,
		NEW.download_required,
		NEW.low_battery)
	RETURNING token_id INTO STRICT core_inserted;
	
	IF NOT FOUND OR core_inserted.token_id IS NULL THEN
		RETURN NULL;
	END IF;

	NEW.token_id := core_inserted.token_id;

	INSERT INTO extra."Card" (
		token_id,
		card_emboss_num,
		card_label)
	VALUES (
		core_inserted.token_id,
		NEW.card_emboss_num,
		NEW.card_label);

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."CardToken_DoInsert"() OWNER TO extra;

--
-- Name: CardToken_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "CardToken_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.token_id := OLD.token_id;

	UPDATE core."CardToken" SET
		card_number = NEW.card_number,
		site_code = NEW.site_code,
		card_format = NEW.card_format,
		card_type = NEW.card_type,
		pin_number = NEW.pin_number,
		card_valid = NEW.card_valid,
		activate_date = NEW.activate_date,
		deactivate_date = NEW.deactivate_date,
		secondary_expiration_date = NEW.secondary_expiration_date,
		expire_days = NEW.expire_days,
		action_point_id = NEW.action_point_id,
		threat_level = NEW.threat_level,
		auto_disable = NEW.auto_disable,
		grant_long_access_time = NEW.grant_long_access_time,
		escort_visitor_capable = NEW.escort_visitor_capable,
		access_cost_override_capable = NEW.access_cost_override_capable,
		event_lock_override_capable = NEW.event_lock_override_capable,
		building_passback_exemption = NEW.building_passback_exemption,
		parking_passback_exemption = NEW.parking_passback_exemption,
		card_holder_groups = NEW.card_holder_groups,
		activation_group = NEW.activation_group,
		on_access_output = NEW.on_access_output,
		compass_command_group = NEW.compass_command_group,
		user_level = NEW.user_level,
		personnel_id = NEW.personnel_id,
		badge_id = NEW.badge_id,
		lost = NEW.lost,
		last_read = NEW.last_read,
		last_reader = NEW.last_reader,
		last_read_status = NEW.last_read_status,
		created = NEW.created,
		created_by = NEW.created_by,
		updated = NEW.updated,
		updated_by = NEW.updated_by,
		downloaded = NEW.downloaded,
		downloaded_by = NEW.downloaded_by,
		download_required = NEW.download_required,
		low_battery = NEW.low_battery
	WHERE token_id = OLD.token_id;
	
	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	UPDATE extra."Card" SET
		card_emboss_num = NEW.card_emboss_num,
		card_label = NEW.card_label
	WHERE token_id = OLD.token_id;

	IF NOT FOUND THEN
		INSERT INTO extra."Card" (
			token_id,
			card_emboss_num,
			card_label)
		VALUES (
			NEW.token_id,
			NEW.card_emboss_num,
			NEW.card_label);
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."CardToken_DoUpdate"() OWNER TO extra;

--
-- Name: MultiCard_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "MultiCard_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."CardToken"
	WHERE token_id = OLD.token_id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."MultiCard_DoDelete"() OWNER TO extra;

--
-- Name: MultiCard_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "MultiCard_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	new_card RECORD;
	new_personnel RECORD;
	old_personnel RECORD;
	is_new_personnel BOOLEAN;
BEGIN
	is_new_personnel := true;

	IF NEW.personnel_id IS NOT NULL THEN
		SELECT personnel.id INTO old_personnel
		FROM core."Personnel" personnel
		WHERE personnel.id = NEW.personnel_id;

		IF FOUND THEN
			is_new_personnel := false;
		END IF;
	END IF;

	IF is_new_personnel THEN
		INSERT INTO extra."AllPersonnel" (
			id,
			name_last,
			name_first,
			name_middle,
			name_prefix,
			name_suffix,
			company,
			department,
			job_title,
			email,
			phone_work,
			phone_work_ext,
			phone_mobile,
			phone_home,
			address,
			city,
			state_or_prov,
			postal_code,
			country,
			notes_id,
			notes,
			photo_id,
			photo,
			photo_type,
			signature_id,
			signature,
			signature_type,
			fingerprint_id,
			fingerprint,
			fingerprint_type,
			user_level,
			days_to_log,
			apb_type_id,
			apb_zone_id,
			apb_violations,
			created,
			created_by,
			updated,
			updated_by,
			room,
			assigned_to,
			admission_date)
		VALUES (
			NEW.personnel_id,
			NEW.name_last,
			NEW.name_first,
			NEW.name_middle,
			NEW.name_prefix,
			NEW.name_suffix,
			NEW.company,
			NEW.department,
			NEW.job_title,
			NEW.email,
			NEW.phone_work,
			NEW.phone_work_ext,
			NEW.phone_mobile,
			NEW.phone_home,
			NEW.address,
			NEW.city,
			NEW.state_or_prov,
			NEW.postal_code,
			NEW.country,
			NEW.notes_id,
			NEW.notes,
			NEW.photo_id,
			NEW.photo,
			NEW.photo_type,
			NEW.signature_id,
			NEW.signature,
			NEW.signature_type,
			NEW.fingerprint_id,
			NEW.fingerprint,
			NEW.fingerprint_type,
			NEW.personnel_user_level,
			NEW.days_to_log,
			NEW.apb_type_id,
			NEW.apb_zone_id,
			NEW.apb_violations,
			NEW.personnel_created,
			NEW.personnel_created_by,
			NEW.personnel_updated,
			NEW.personnel_updated_by,
			NEW.room,
			NEW.assigned_to,
			NEW.admission_date)
			RETURNING id INTO STRICT new_personnel;

		IF NOT FOUND OR new_personnel.id IS NULL THEN
			RETURN NULL;
		END IF;

		NEW.personnel_id := new_personnel.id;
	ELSE
		NEW.personnel_id := OLD.personnel_id;

		UPDATE extra."AllPersonnel" personnel SET
			name_last = NEW.name_last,
			name_first = NEW.name_first,
			name_middle = NEW.name_middle,
			name_prefix = NEW.name_prefix,
			name_suffix = NEW.name_suffix,
			company = NEW.company,
			department = NEW.department,
			job_title = NEW.job_title,
			email = NEW.email,
			phone_work = NEW.phone_work,
			phone_work_ext = NEW.phone_work_ext,
			phone_mobile = NEW.phone_mobile,
			phone_home = NEW.phone_home,
			address = NEW.address,
			city = NEW.city,
			state_or_prov = NEW.state_or_prov,
			postal_code = NEW.postal_code,
			country = NEW.country,
			notes_id = NEW.notes_id,
			notes = NEW.notes,
			photo_id = NEW.photo_id,
			photo = NEW.photo,
			photo_type = NEW.photo_type,
			signature_id = NEW.signature_id,
			signature = NEW.signature,
			signature_type = NEW.signature_type,
			fingerprint_id = NEW.fingerprint_id,
			fingerprint = NEW.fingerprint,
			fingerprint_type = NEW.fingerprint_type,
			user_level = NEW.personnel_user_level,
			days_to_log = NEW.days_to_log,
			apb_type_id = NEW.apb_type_id,
			apb_zone_id = NEW.apb_zone_id,
			apb_violations = NEW.apb_violations,
			created = NEW.personnel_created,
			created_by = NEW.personnel_created_by,
			updated = NEW.personnel_updated,
			updated_by = NEW.personnel_updated_by,
			room = NEW.room,
			assigned_to = NEW.assigned_to,
			admission_date = NEW.admission_date
		WHERE id = OLD.personnel_id;

		IF NOT FOUND THEN
			RETURN NULL;
		END IF;
	END IF;

	INSERT INTO extra."CardToken" (
		token_id,
		personnel_id,
		card_number,
		site_code,
		card_format,
		card_type,
		card_emboss_num,
		card_label,
		pin_number,
		card_valid,
		activate_date,
		deactivate_date,
		secondary_expiration_date,
		expire_days,
		action_point_id,
		threat_level,
		auto_disable,
		grant_long_access_time,
		escort_visitor_capable,
		access_cost_override_capable,
		event_lock_override_capable,
		building_passback_exemption,
		parking_passback_exemption,
		card_holder_groups,
		activation_group,
		on_access_output,
		compass_command_group,
		user_level,
		badge_id,
		lost,
		last_read,
		last_reader,
		last_read_status,
		created,
		created_by,
		updated,
		updated_by,
		downloaded,
		downloaded_by,
		download_required,
		low_battery)
	VALUES (
		NEW.token_id,
		NEW.personnel_id,
		NEW.card_number,
		NEW.site_code,
		NEW.card_format,
		NEW.card_type,
		NEW.card_emboss_num,
		NEW.card_label,
		NEW.pin_number,
		NEW.card_valid,
		NEW.activate_date,
		NEW.deactivate_date,
		NEW.secondary_expiration_date,
		NEW.expire_days,
		NEW.action_point_id,
		NEW.threat_level,
		NEW.auto_disable,
		NEW.grant_long_access_time,
		NEW.escort_visitor_capable,
		NEW.access_cost_override_capable,
		NEW.event_lock_override_capable,
		NEW.building_passback_exemption,
		NEW.parking_passback_exemption,
		NEW.card_holder_groups,
		NEW.activation_group,
		NEW.on_access_output,
		NEW.compass_command_group,
		NEW.card_user_level,
		NEW.badge_id,
		NEW.lost,
		NEW.last_read,
		NEW.last_reader,
		NEW.last_read_status,
		NEW.card_created,
		NEW.card_created_by,
		NEW.card_updated,
		NEW.card_updated_by,
		NEW.downloaded,
		NEW.downloaded_by,
		NEW.download_required,
		NEW.low_battery)
	RETURNING token_id INTO STRICT new_card;

	IF NOT FOUND OR new_card.token_id IS NULL THEN
		RETURN NULL;
	END IF;

	NEW.token_id := new_card.token_id;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."MultiCard_DoInsert"() OWNER TO extra;

--
-- Name: MultiCard_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "MultiCard_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.token_id := OLD.token_id;
	NEW.personnel_id := OLD.personnel_id;

	UPDATE extra."AllPersonnel" personnel SET
		name_last = NEW.name_last,
		name_first = NEW.name_first,
		name_middle = NEW.name_middle,
		name_prefix = NEW.name_prefix,
		name_suffix = NEW.name_suffix,
		company = NEW.company,
		department = NEW.department,
		job_title = NEW.job_title,
		email = NEW.email,
		phone_work = NEW.phone_work,
		phone_work_ext = NEW.phone_work_ext,
		phone_mobile = NEW.phone_mobile,
		phone_home = NEW.phone_home,
		address = NEW.address,
		city = NEW.city,
		state_or_prov = NEW.state_or_prov,
		postal_code = NEW.postal_code,
		country = NEW.country,
		notes_id = NEW.notes_id,
		notes = NEW.notes,
		photo_id = NEW.photo_id,
		photo = NEW.photo,
		photo_type = NEW.photo_type,
		signature_id = NEW.signature_id,
		signature = NEW.signature,
		signature_type = NEW.signature_type,
		fingerprint_id = NEW.fingerprint_id,
		fingerprint = NEW.fingerprint,
		fingerprint_type = NEW.fingerprint_type,
		user_level = NEW.personnel_user_level,
		days_to_log = NEW.days_to_log,
		apb_type_id = NEW.apb_type_id,
		apb_zone_id = NEW.apb_zone_id,
		apb_violations = NEW.apb_violations,
		created = NEW.personnel_created,
		created_by = NEW.personnel_created_by,
		updated = NEW.personnel_updated,
		updated_by = NEW.personnel_updated_by,
		room = NEW.room,
		assigned_to = NEW.assigned_to,
		admission_date = NEW.admission_date
	WHERE id = OLD.personnel_id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	UPDATE extra."CardToken" card SET
		card_number = NEW.card_number,
		site_code = NEW.site_code,
		card_format = NEW.card_format,
		card_type = NEW.card_type,
		card_emboss_num = NEW.card_emboss_num,
		card_label = NEW.card_label,
		pin_number = NEW.pin_number,
		card_valid = NEW.card_valid,
		activate_date = NEW.activate_date,
		deactivate_date = NEW.deactivate_date,
		secondary_expiration_date = NEW.secondary_expiration_date,
		expire_days = NEW.expire_days,
		action_point_id = NEW.action_point_id,
		threat_level = NEW.threat_level,
		auto_disable = NEW.auto_disable,
		grant_long_access_time = NEW.grant_long_access_time,
		escort_visitor_capable = NEW.escort_visitor_capable,
		access_cost_override_capable = NEW.access_cost_override_capable,
		event_lock_override_capable = NEW.event_lock_override_capable,
		building_passback_exemption = NEW.building_passback_exemption,
		parking_passback_exemption = NEW.parking_passback_exemption,
		card_holder_groups = NEW.card_holder_groups,
		activation_group = NEW.activation_group,
		on_access_output = NEW.on_access_output,
		compass_command_group = NEW.compass_command_group,
		user_level = NEW.card_user_level,
		badge_id = NEW.badge_id,
		lost = NEW.lost,
		last_read = NEW.last_read,
		last_reader = NEW.last_reader,
		last_read_status = NEW.last_read_status,
		created = NEW.card_created,
		created_by = NEW.card_created_by,
		updated = NEW.card_updated,
		updated_by = NEW.card_updated_by,
		downloaded = NEW.downloaded,
		downloaded_by = NEW.downloaded_by,
		download_required = NEW.download_required,
		low_battery = NEW.low_battery
	WHERE token_id = OLD.token_id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."MultiCard_DoUpdate"() OWNER TO extra;

--
-- Name: Notes_InsertOrUpdate(uuid, text); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "Notes_InsertOrUpdate"(id uuid, text text) RETURNS uuid
    LANGUAGE plpgsql
    AS $$
DECLARE
	new_note RECORD;
	new_id ALIAS FOR id;
	new_text ALIAS FOR text;
BEGIN
	IF text IS NULL THEN
		RETURN NULL;
	END IF;
	
	IF new_id IS NULL THEN
		new_id := uuid_generate_v4();

		INSERT INTO extra."Notes" (id, text)
		VALUES (new_id, new_text)
		RETURNING extra."Notes".id INTO new_note;
	ELSE
		UPDATE extra."Notes" notes
		SET text = new_text
		WHERE notes.id = new_id
		RETURNING notes.id INTO new_note;

		IF NOT FOUND THEN
			INSERT INTO extra."Notes" (id, text)
			VALUES (new_id, new_text)
			RETURNING extra."Notes".id INTO new_note;
		END IF;
	END IF;
	
	RETURN new_note.id;
END;
$$;


ALTER FUNCTION extra."Notes_InsertOrUpdate"(id uuid, text text) OWNER TO extra;

--
-- Name: Notes_Update(uuid, uuid, text); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "Notes_Update"(old_id uuid, new_id uuid, text text) RETURNS uuid
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF text IS NULL THEN
		IF old_id IS NOT NULL THEN
			DELETE FROM extra."Notes" WHERE id = old_id;
		END IF;
		new_id := NULL;
	ELSE
		IF old_id IS NOT NULL THEN
			IF new_id IS NULL THEN
				new_id := old_id;
			ELSIF new_id <> old_id THEN
				DELETE FROM extra."Notes" WHERE id = old_id;
			END IF;
		END IF;
		new_id := extra."Notes_InsertOrUpdate"(new_id, text);
	END IF;
	
	RETURN new_id;
END;
$$;


ALTER FUNCTION extra."Notes_Update"(old_id uuid, new_id uuid, text text) OWNER TO extra;

--
-- Name: SingleCard_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "SingleCard_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."CardToken"
	WHERE token_id = OLD.token_id;

	IF FOUND THEN
		extra_found := true;
	END IF;
	
	DELETE FROM extra."AllPersonnel"
	WHERE id = OLD.personnel_id;

	IF NOT FOUND AND NOT extra_found THEN
		RETURN NULL;
	END IF;
	
	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."SingleCard_DoDelete"() OWNER TO extra;

--
-- Name: SingleCard_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "SingleCard_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	new_card RECORD;
	new_personnel RECORD;
	old_personnel RECORD;
BEGIN
	IF NEW.personnel_id IS NOT NULL THEN
		SELECT personnel.id INTO old_personnel
		FROM core."Personnel" personnel
		WHERE personnel.id = NEW.personnel_id;
		
		IF FOUND THEN
			RAISE EXCEPTION 'An existing record exists with personnel ID: %', NEW.personnel_id
				USING ERRCODE = 'integrity_constraint_violation';
		END IF;
	END IF;

	INSERT INTO extra."AllPersonnel" (
		id,
		name_last,
		name_first,
		name_middle,
		name_prefix,
		name_suffix,
		company,
		department,
		job_title,
		email,
		phone_work,
		phone_work_ext,
		phone_mobile,
		phone_home,
		address,
		city,
		state_or_prov,
		postal_code,
		country,
		notes_id,
		notes,
		photo_id,
		photo,
		photo_type,
		signature_id,
		signature,
		signature_type,
		fingerprint_id,
		fingerprint,
		fingerprint_type,
		user_level,
		days_to_log,
		apb_type_id,
		apb_zone_id,
		apb_violations,
		created,
		created_by,
		updated,
		updated_by,
		room,
		assigned_to,
		admission_date)
	VALUES (
		NEW.personnel_id,
		NEW.name_last,
		NEW.name_first,
		NEW.name_middle,
		NEW.name_prefix,
		NEW.name_suffix,
		NEW.company,
		NEW.department,
		NEW.job_title,
		NEW.email,
		NEW.phone_work,
		NEW.phone_work_ext,
		NEW.phone_mobile,
		NEW.phone_home,
		NEW.address,
		NEW.city,
		NEW.state_or_prov,
		NEW.postal_code,
		NEW.country,
		NEW.notes_id,
		NEW.notes,
		NEW.photo_id,
		NEW.photo,
		NEW.photo_type,
		NEW.signature_id,
		NEW.signature,
		NEW.signature_type,
		NEW.fingerprint_id,
		NEW.fingerprint,
		NEW.fingerprint_type,
		NEW.personnel_user_level,
		NEW.days_to_log,
		NEW.apb_type_id,
		NEW.apb_zone_id,
		NEW.apb_violations,
		NEW.personnel_created,
		NEW.personnel_created_by,
		NEW.personnel_updated,
		NEW.personnel_updated_by,
		NEW.room,
		NEW.assigned_to,
		NEW.admission_date)
	RETURNING id INTO STRICT new_personnel;

	IF NOT FOUND OR new_personnel.id IS NULL THEN
		RETURN NULL;
	END IF;
	
	NEW.personnel_id := new_personnel.id;

	INSERT INTO extra."CardToken" (
		token_id,
		personnel_id,
		card_number,
		site_code,
		card_format,
		card_type,
		card_emboss_num,
		card_label,
		pin_number,
		card_valid,
		activate_date,
		deactivate_date,
		secondary_expiration_date,
		expire_days,
		action_point_id,
		threat_level,
		auto_disable,
		grant_long_access_time,
		escort_visitor_capable,
		access_cost_override_capable,
		event_lock_override_capable,
		building_passback_exemption,
		parking_passback_exemption,
		card_holder_groups,
		activation_group,
		on_access_output,
		compass_command_group,
		user_level,
		badge_id,
		lost,
		last_read,
		last_reader,
		last_read_status,
		created,
		created_by,
		updated,
		updated_by,
		downloaded,
		downloaded_by,
		download_required,
		low_battery)
	VALUES (
		NEW.token_id,
		NEW.personnel_id,
		NEW.card_number,
		NEW.site_code,
		NEW.card_format,
		NEW.card_type,
		NEW.card_emboss_num,
		NEW.card_label,
		NEW.pin_number,
		NEW.card_valid,
		NEW.activate_date,
		NEW.deactivate_date,
		NEW.secondary_expiration_date,
		NEW.expire_days,
		NEW.action_point_id,
		NEW.threat_level,
		NEW.auto_disable,
		NEW.grant_long_access_time,
		NEW.escort_visitor_capable,
		NEW.access_cost_override_capable,
		NEW.event_lock_override_capable,
		NEW.building_passback_exemption,
		NEW.parking_passback_exemption,
		NEW.card_holder_groups,
		NEW.activation_group,
		NEW.on_access_output,
		NEW.compass_command_group,
		NEW.card_user_level,
		NEW.badge_id,
		NEW.lost,
		NEW.last_read,
		NEW.last_reader,
		NEW.last_read_status,
		NEW.card_created,
		NEW.card_created_by,
		NEW.card_updated,
		NEW.card_updated_by,
		NEW.downloaded,
		NEW.downloaded_by,
		NEW.download_required,
		NEW.low_battery)
	RETURNING token_id INTO STRICT new_card;
	
	IF NOT FOUND OR new_card.token_id IS NULL THEN
		RETURN NULL;
	END IF;
	IF NEW.card_number <= 256 and NEW.site_code = 0 and NEW.card_format = 26 THEN
				
				Insert into history."AccutechTagChange" (
				change_time, 
				event, 
				card_number, 
				name_first, 
				name_last, 
				name_middle, 
				assigned_to, 
				updated_by,
				room) 
				VALUES (
				NOW(),
				5036,
				NEW.card_number,
				NEW.name_first,
				NEW.name_last,
				NEW.name_middle,
				NEW.assigned_to,
				NEW.personnel_created_by,
				NEW.room);
	END IF;	
	NEW.token_id := new_card.token_id;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."SingleCard_DoInsert"() OWNER TO extra;

--
-- Name: SingleCard_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "SingleCard_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	d_change_type smallint;
BEGIN
	NEW.token_id := OLD.token_id;
	NEW.personnel_id := OLD.personnel_id;

	UPDATE extra."AllPersonnel" personnel SET
		name_last = NEW.name_last,
		name_first = NEW.name_first,
		name_middle = NEW.name_middle,
		name_prefix = NEW.name_prefix,
		name_suffix = NEW.name_suffix,
		company = NEW.company,
		department = NEW.department,
		job_title = NEW.job_title,
		email = NEW.email,
		phone_work = NEW.phone_work,
		phone_work_ext = NEW.phone_work_ext,
		phone_mobile = NEW.phone_mobile,
		phone_home = NEW.phone_home,
		address = NEW.address,
		city = NEW.city,
		state_or_prov = NEW.state_or_prov,
		postal_code = NEW.postal_code,
		country = NEW.country,
		notes_id = NEW.notes_id,
		notes = NEW.notes,
		photo_id = NEW.photo_id,
		photo = NEW.photo,
		photo_type = NEW.photo_type,
		signature_id = NEW.signature_id,
		signature = NEW.signature,
		signature_type = NEW.signature_type,
		fingerprint_id = NEW.fingerprint_id,
		fingerprint = NEW.fingerprint,
		fingerprint_type = NEW.fingerprint_type,
		user_level = NEW.personnel_user_level,
		days_to_log = NEW.days_to_log,
		apb_type_id = NEW.apb_type_id,
		apb_zone_id = NEW.apb_zone_id,
		apb_violations = NEW.apb_violations,
		created = NEW.personnel_created,
		created_by = NEW.personnel_created_by,
		updated = NEW.personnel_updated,
		updated_by = NEW.personnel_updated_by,
		room = NEW.room,
		assigned_to = NEW.assigned_to,
		admission_date = NEW.admission_date
	WHERE id = OLD.personnel_id;
	
	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	UPDATE extra."CardToken" card SET
		card_number = NEW.card_number,
		site_code = NEW.site_code,
		card_format = NEW.card_format,
		card_type = NEW.card_type,
		card_emboss_num = NEW.card_emboss_num,
		card_label = NEW.card_label,
		pin_number = NEW.pin_number,
		card_valid = NEW.card_valid,
		activate_date = NEW.activate_date,
		deactivate_date = NEW.deactivate_date,
		secondary_expiration_date = NEW.secondary_expiration_date,
		expire_days = NEW.expire_days,
		action_point_id = NEW.action_point_id,
		threat_level = NEW.threat_level,
		auto_disable = NEW.auto_disable,
		grant_long_access_time = NEW.grant_long_access_time,
		escort_visitor_capable = NEW.escort_visitor_capable,
		access_cost_override_capable = NEW.access_cost_override_capable,
		event_lock_override_capable = NEW.event_lock_override_capable,
		building_passback_exemption = NEW.building_passback_exemption,
		parking_passback_exemption = NEW.parking_passback_exemption,
		card_holder_groups = NEW.card_holder_groups,
		activation_group = NEW.activation_group,
		on_access_output = NEW.on_access_output,
		compass_command_group = NEW.compass_command_group,
		user_level = NEW.card_user_level,
		badge_id = NEW.badge_id,
		lost = NEW.lost,
		last_read = NEW.last_read,
		last_reader = NEW.last_reader,
		last_read_status = NEW.last_read_status,
		created = NEW.card_created,
		created_by = NEW.card_created_by,
		updated = NEW.card_updated,
		updated_by = NEW.card_updated_by,
		downloaded = NEW.downloaded,
		downloaded_by = NEW.downloaded_by,
		download_required = NEW.download_required,
		low_battery = NEW.low_battery
	WHERE token_id = OLD.token_id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;
		d_change_type := 5039; --Owner Edited
		IF OLD.name_last = 'Unassigned' THEN
		d_change_type := 5038; --Admitted
		END IF;
		IF NEW.name_last = 'Unassigned' THEN
		d_change_type := 5041; --Discharged
		END IF;
		IF NEW.assigned_to >= 100 THEN--Tag is being re-assigned
			IF d_change_type = 5038 THEN --The tag is being admitted after being discharged, Discharge with assigned_to >=100 are ignored
				d_change_type := 5040; --Reassigned
				Insert into history."AccutechTagChange" (
				change_time, 
				event, 
				card_number, 
				name_first, 
				name_last, 
				name_middle, 
				assigned_to, 
				updated_by,
				room) 
				VALUES (
				NOW(),
				d_change_type,
				NEW.card_number,
				NEW.name_first,
				NEW.name_last,
				NEW.name_middle,
				NEW.assigned_to - 100,
				NEW.personnel_updated_by,
				NEW.room);
			END IF;
		ELSE
			Insert into history."AccutechTagChange" (
			change_time, 
			event, 
			card_number, 
			name_first, 
			name_last, 
			name_middle, 
			assigned_to, 
			updated_by,
			room) 
			VALUES (
			NOW(),
			d_change_type,
			NEW.card_number,
			NEW.name_first,
			NEW.name_last,
			NEW.name_middle,
			NEW.assigned_to,
			NEW.personnel_updated_by,
			NEW.room);		
		END IF;
	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."SingleCard_DoUpdate"() OWNER TO extra;

SET search_path = history, pg_catalog;

--
-- Name: Activity_Insert_Statistics(); Type: FUNCTION; Schema: history; Owner: core
--

CREATE FUNCTION "Activity_Insert_Statistics"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	t_activity RECORD;
	new_stats RECORD;
	l_active timestamp with time zone;
BEGIN
		IF NEW.event_type_id = 2 THEN
		SELECT id INTO t_activity
		FROM history."Activity_Statistics" stats
		WHERE stats.point_id = NEW.point_id and stats.cleared_time IS NULL and stats.acked_time IS NULL;
		END IF;		
		IF NEW.event_type_id = 1 THEN
		SELECT id INTO t_activity
		FROM history."Activity_Statistics" stats
		WHERE stats.point_id = NEW.point_id and stats.card_number = NEW.card_number and stats.cleared_time IS NULL and stats.acked_time IS NULL;
		END IF;
		IF NEW.event_type_id = 6 THEN
		SELECT id INTO t_activity 
		FROM history."Activity_Statistics" stats
		WHERE stats.point_id = NEW.point_id and stats.cleared_time IS NULL and stats.acked_time IS NULL;
		END IF;
		
	IF t_activity.id IS NULL THEN
		IF NEW.event_type_id = 2 and NEW.state = 1 THEN
		NEW.id := uuid_generate_v4();
		INSERT INTO history."Activity_Statistics" (
			id,event_type_id, rtu_id, rtu_name, point_id, point_name, state, status, card_number, site_code, card_format, 
					card_holder_name, computer, "user", user_comments, token_id, active_time, inactive_time, acked_time, cleared_time, last_active, total_active, active_count)
		VALUES (
			NEW.id,NEW.event_type_id, NEW.rtu_id, NEW.rtu_Name, NEW.point_id, NEW.point_name,null, null, NEW.card_number, NEW.site_code,	NEW.card_format,
					 NEW.card_Holder_name, NEW.computer, NEW.user, NEW.user_comments, NEW.token_id, NEW."time", NULL, NULL, NULL, NEW."time", 0,1);
		SELECT id INTO t_activity
		FROM history."Activity_Statistics" stats
		WHERE stats.point_id = NEW.point_id and stats.cleared_time IS NULL and stats.acked_time IS NULL;
		END IF;
		
		IF NEW.event_type_id = 1 THEN
		NEW.id := uuid_generate_v4();
		INSERT INTO history."Activity_Statistics" (
			id,event_type_id, rtu_id, rtu_name, point_id, point_name, state, status, card_number, site_code, card_format, 
					card_holder_name, computer, "user", user_comments, token_id, active_time, inactive_time, acked_time, cleared_time, last_active, total_active, active_count)
		VALUES (
			NEW.id,NEW.event_type_id, NEW.rtu_id, NEW.rtu_Name, NEW.point_id, NEW.point_name,null, null, NEW.card_number, NEW.site_code,	NEW.card_format,
					 NEW.card_Holder_name, NEW.computer, NEW.user, NEW.user_comments, NEW.token_id, NEW."time", NEW."time", NULL, NULL, NEW."time", 0,1);
		SELECT id INTO t_activity
		FROM history."Activity_Statistics" stats
		WHERE stats.point_id = NEW.point_id and stats.cleared_time IS NULL and stats.acked_time IS NULL;
		END IF;
		
	END IF;
	IF NOT FOUND OR t_activity.id IS NULL THEN
		RETURN NULL;
	END IF;
	IF NEW.state = 0 and NEW.event_type_id = 2 THEN
		IF NEW.user_comments IS NULL THEN
		select last_active INTO l_active from history."Activity_Statistics" where id = t_activity.id;
		Update history."Activity_Statistics" set inactive_time = NEW."time", total_active = total_active + datediff('second', l_active::timestamp(0), NEW."time"::timestamp(0)) where id = t_activity.id;
		END IF;
		IF NEW.user_comments IS NOT NULL THEN
		select last_active INTO l_active from history."Activity_Statistics" where id = t_activity.id;
		Update history."Activity_Statistics" set inactive_time = NEW."time", total_active = total_active + datediff('second', l_active::timestamp(0), NEW."time"::timestamp(0)), user_comments = 'Auto Cleared', "user" = 'System' where id = t_activity.id;
		END IF;
	END IF;
	
	IF NEW.state = 1 and NEW.event_type_id = 2 THEN
		Update history."Activity_Statistics" set last_active = NEW."time", active_count = active_count + 1 where id = t_activity.id;
	END IF;
	
	IF NEW.event_type_id = 6 and NEW.status ilike 'Acked' THEN
		Update history."Activity_Statistics" set acked_time = NEW."time", "user" = NEW."user" where id = t_activity.id;
		Update history."Activity_Statistics" set inactive_time = NEW."time" where inactive_time IS NULL;
	END IF;
	
	IF NEW.event_type_id = 6 and NEW.status ilike 'Cleared' THEN
		Update history."Activity_Statistics" set cleared_time = NEW."time", "user" = NEW."user" where id = t_activity.id;
		Update history."Activity_Statistics" set inactive_time = NEW."time" where inactive_time IS NULL;
	END IF;


	

	RETURN NEW;
END;
$$;


ALTER FUNCTION history."Activity_Insert_Statistics"() OWNER TO core;

SET search_path = core, pg_catalog;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: AccessEntry; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "AccessEntry" (
    id integer NOT NULL,
    name character varying(50)
);


ALTER TABLE "AccessEntry" OWNER TO core;

--
-- Name: AccessSet; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "AccessSet" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    name character varying(50),
    user_level integer,
    download_required boolean
);


ALTER TABLE "AccessSet" OWNER TO core;

--
-- Name: AccessSetsToAccessEntries; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "AccessSetsToAccessEntries" (
    access_set_id uuid NOT NULL,
    access_entry_id integer NOT NULL
);


ALTER TABLE "AccessSetsToAccessEntries" OWNER TO core;

--
-- Name: AccessSetsToTokens; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "AccessSetsToTokens" (
    access_set_id uuid NOT NULL,
    token_id uuid NOT NULL
);


ALTER TABLE "AccessSetsToTokens" OWNER TO core;

--
-- Name: Personnel; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Personnel" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    name_last character varying(50),
    name_first character varying(50),
    user_level integer,
    days_to_log smallint,
    apb_type_id smallint,
    apb_zone_id integer,
    apb_violations smallint,
    created timestamp with time zone DEFAULT now(),
    created_by character varying(255) DEFAULT "current_user"(),
    updated timestamp with time zone,
    updated_by character varying(255),
    deleted timestamp with time zone,
    deleted_by character varying(255)
);


ALTER TABLE "Personnel" OWNER TO core;

--
-- Name: COLUMN "Personnel".apb_type_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Personnel".apb_type_id IS 'Anti-passback type id';


--
-- Name: COLUMN "Personnel".apb_zone_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Personnel".apb_zone_id IS 'Anti-passback zone id';


--
-- Name: COLUMN "Personnel".apb_violations; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Personnel".apb_violations IS 'Anti-passback zone violation count';


--
-- Name: AllPersonnel; Type: VIEW; Schema: core; Owner: core
--

CREATE VIEW "AllPersonnel" AS
 SELECT personnel.id,
    personnel.name_last,
    personnel.name_first,
    personnel.user_level,
    personnel.days_to_log,
    personnel.apb_type_id,
    personnel.apb_zone_id,
    personnel.apb_violations,
    personnel.created,
    personnel.created_by,
    personnel.updated,
    personnel.updated_by
   FROM "Personnel" personnel
  WHERE (personnel.deleted IS NULL);


ALTER TABLE "AllPersonnel" OWNER TO core;

--
-- Name: COLUMN "AllPersonnel".apb_type_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "AllPersonnel".apb_type_id IS 'Anti-passback type id';


--
-- Name: COLUMN "AllPersonnel".apb_zone_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "AllPersonnel".apb_zone_id IS 'Anti-passback zone id';


--
-- Name: COLUMN "AllPersonnel".apb_violations; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "AllPersonnel".apb_violations IS 'Anti-passback zone violation count';


--
-- Name: AlterTableInformation; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "AlterTableInformation" (
    id integer NOT NULL,
    tabletobealtered character varying(50) NOT NULL,
    ordertoalter integer NOT NULL,
    qryschema character varying(50) NOT NULL,
    qrytable character varying(50) NOT NULL,
    viewname character varying(50),
    functionname character varying(50),
    viewaliasname character varying(50),
    returnfield1 character varying(50) NOT NULL,
    returnfield2 character varying(50),
    returnfield3 character varying(50),
    wherefield character varying(50),
    internalfunctiontableorviewname character varying(50)
);


ALTER TABLE "AlterTableInformation" OWNER TO core;

--
-- Name: AlterTableInformation_id_seq; Type: SEQUENCE; Schema: core; Owner: core
--

CREATE SEQUENCE "AlterTableInformation_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "AlterTableInformation_id_seq" OWNER TO core;

--
-- Name: AlterTableInformation_id_seq; Type: SEQUENCE OWNED BY; Schema: core; Owner: core
--

ALTER SEQUENCE "AlterTableInformation_id_seq" OWNED BY "AlterTableInformation".id;


--
-- Name: BlobType; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "BlobType" (
    id smallint NOT NULL,
    name character varying(50),
    abbrev character varying(10),
    mime_type character varying(50)
);


ALTER TABLE "BlobType" OWNER TO core;

--
-- Name: BlobType_id_seq; Type: SEQUENCE; Schema: core; Owner: core
--

CREATE SEQUENCE "BlobType_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "BlobType_id_seq" OWNER TO core;

--
-- Name: BlobType_id_seq; Type: SEQUENCE OWNED BY; Schema: core; Owner: core
--

ALTER SEQUENCE "BlobType_id_seq" OWNED BY "BlobType".id;


--
-- Name: Card; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Card" (
    token_id uuid NOT NULL,
    card_number bigint NOT NULL,
    site_code bigint DEFAULT 0 NOT NULL,
    card_format smallint DEFAULT 26 NOT NULL,
    card_type smallint,
    pin_number character varying(50),
    card_valid boolean,
    activate_date date DEFAULT (now())::date,
    deactivate_date date DEFAULT ((now() + '1 year'::interval))::date,
    secondary_expiration_date date,
    expire_days smallint,
    action_point_id integer,
    threat_level smallint,
    auto_disable boolean,
    grant_long_access_time boolean,
    escort_visitor_capable boolean,
    access_cost_override_capable boolean,
    event_lock_override_capable boolean,
    building_passback_exemption boolean,
    parking_passback_exemption boolean,
    card_holder_groups smallint,
    activation_group smallint,
    on_access_output smallint,
    compass_command_group smallint,
    deleted timestamp with time zone,
    low_battery boolean DEFAULT false
);


ALTER TABLE "Card" OWNER TO core;

--
-- Name: COLUMN "Card".activate_date; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Card".activate_date IS 'Activate card on date';


--
-- Name: COLUMN "Card".deactivate_date; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Card".deactivate_date IS 'Deactivate card on date';


--
-- Name: COLUMN "Card".expire_days; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Card".expire_days IS 'Card expires after days unused';


--
-- Name: COLUMN "Card".action_point_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Card".action_point_id IS 'Action point to trigger in project';


--
-- Name: Token; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Token" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    type_id smallint,
    user_level integer,
    personnel_id uuid,
    badge_id integer,
    lost boolean DEFAULT false NOT NULL,
    last_read timestamp with time zone,
    last_reader character varying(255),
    last_read_status character varying(255),
    created timestamp with time zone DEFAULT now(),
    created_by character varying(255) DEFAULT "current_user"(),
    updated timestamp with time zone,
    updated_by character varying(255),
    deleted timestamp with time zone,
    deleted_by character varying(255),
    downloaded timestamp with time zone,
    downloaded_by character varying(255),
    download_required boolean
);


ALTER TABLE "Token" OWNER TO core;

--
-- Name: COLUMN "Token".badge_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Token".badge_id IS 'Tree node id for badge template';


--
-- Name: CardDownload; Type: VIEW; Schema: core; Owner: core
--

CREATE VIEW "CardDownload" AS
 SELECT card.token_id,
    token.personnel_id,
    personnel.name_last,
    personnel.name_first,
    card.card_number,
    card.site_code,
    card.card_format,
    card.card_type,
    card.pin_number,
    card.card_valid,
    card.activate_date,
    card.deactivate_date,
    card.expire_days,
    card.secondary_expiration_date,
    card.action_point_id,
    card.threat_level,
    card.auto_disable,
    card.grant_long_access_time,
    card.escort_visitor_capable,
    card.access_cost_override_capable,
    card.event_lock_override_capable,
    card.building_passback_exemption,
    card.parking_passback_exemption,
    card.card_holder_groups,
    card.activation_group,
    card.on_access_output,
    card.compass_command_group,
    personnel.apb_type_id,
    personnel.apb_zone_id,
    personnel.apb_violations,
    token.lost,
    token.downloaded,
    token.downloaded_by,
    token.download_required,
    card.low_battery
   FROM (("Card" card
     JOIN "Token" token ON ((card.token_id = token.id)))
     JOIN "Personnel" personnel ON ((token.personnel_id = personnel.id)))
  WHERE (token.deleted IS NULL);


ALTER TABLE "CardDownload" OWNER TO core;

--
-- Name: CardToken; Type: VIEW; Schema: core; Owner: core
--

CREATE VIEW "CardToken" AS
 SELECT card.token_id,
    card.card_number,
    card.site_code,
    card.card_format,
    card.card_type,
    card.pin_number,
    card.card_valid,
    card.activate_date,
    card.deactivate_date,
    card.secondary_expiration_date,
    card.expire_days,
    card.action_point_id,
    card.threat_level,
    card.auto_disable,
    card.grant_long_access_time,
    card.escort_visitor_capable,
    card.access_cost_override_capable,
    card.event_lock_override_capable,
    card.building_passback_exemption,
    card.parking_passback_exemption,
    card.card_holder_groups,
    card.activation_group,
    card.on_access_output,
    card.compass_command_group,
    token.user_level,
    token.personnel_id,
    token.badge_id,
    token.lost,
    token.last_read,
    token.last_reader,
    token.last_read_status,
    token.created,
    token.created_by,
    token.updated,
    token.updated_by,
    token.downloaded,
    token.downloaded_by,
    token.download_required,
    card.low_battery
   FROM ("Card" card
     JOIN "Token" token ON ((card.token_id = token.id)))
  WHERE (token.deleted IS NULL);


ALTER TABLE "CardToken" OWNER TO core;

--
-- Name: Parameter; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Parameter" (
    id bigint NOT NULL,
    name character varying(255) NOT NULL,
    value text
);


ALTER TABLE "Parameter" OWNER TO core;

--
-- Name: Parameter_id_seq; Type: SEQUENCE; Schema: core; Owner: core
--

CREATE SEQUENCE "Parameter_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "Parameter_id_seq" OWNER TO core;

--
-- Name: Parameter_id_seq; Type: SEQUENCE OWNED BY; Schema: core; Owner: core
--

ALTER SEQUENCE "Parameter_id_seq" OWNED BY "Parameter".id;


--
-- Name: PersonnelTokenCounts; Type: VIEW; Schema: core; Owner: core
--

CREATE VIEW "PersonnelTokenCounts" AS
 SELECT personnel.id AS personnel_id,
    token.type_id,
    count(token.id) AS count
   FROM ("Personnel" personnel
     LEFT JOIN "Token" token ON (((personnel.id = token.personnel_id) AND (token.deleted IS NULL))))
  WHERE (personnel.deleted IS NULL)
  GROUP BY personnel.id, token.type_id;


ALTER TABLE "PersonnelTokenCounts" OWNER TO core;

--
-- Name: PersonnelWithSingleCard; Type: VIEW; Schema: core; Owner: core
--

CREATE VIEW "PersonnelWithSingleCard" AS
 SELECT personnel.id AS personnel_id
   FROM ("Personnel" personnel
     LEFT JOIN "Token" token ON ((((personnel.id = token.personnel_id) AND (token.type_id = 1)) AND (token.deleted IS NULL))))
  WHERE (personnel.deleted IS NULL)
  GROUP BY personnel.id
 HAVING (count(token.id) = 1);


ALTER TABLE "PersonnelWithSingleCard" OWNER TO core;

--
-- Name: Reader; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Reader" (
    id integer NOT NULL,
    name character varying(50),
    is_zone boolean DEFAULT false NOT NULL,
    is_muster_zone boolean DEFAULT false NOT NULL
);


ALTER TABLE "Reader" OWNER TO core;

--
-- Name: ReadersToAccessEntries; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "ReadersToAccessEntries" (
    reader_id integer NOT NULL,
    access_entry_id integer NOT NULL
);


ALTER TABLE "ReadersToAccessEntries" OWNER TO core;

--
-- Name: RfidTag; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "RfidTag" (
    token_id uuid NOT NULL,
    tag_number numeric(39,0) NOT NULL
);


ALTER TABLE "RfidTag" OWNER TO core;

--
-- Name: ScheduledEvent; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "ScheduledEvent" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    start timestamp with time zone,
    stop timestamp with time zone,
    event_id integer,
    active boolean DEFAULT false NOT NULL
);


ALTER TABLE "ScheduledEvent" OWNER TO core;

--
-- Name: SystemInformation; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "SystemInformation" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    created timestamp with time zone DEFAULT now(),
    computer_id integer,
    computer_name character varying(50)
);


ALTER TABLE "SystemInformation" OWNER TO core;

--
-- Name: SystemInformationItem; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "SystemInformationItem" (
    sysinfo_id uuid NOT NULL,
    item_id integer NOT NULL,
    "group" character varying(255),
    name character varying(255),
    value text,
    kind character varying(255),
    key text,
    description text
);


ALTER TABLE "SystemInformationItem" OWNER TO core;

--
-- Name: TokenType; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "TokenType" (
    id smallint NOT NULL,
    name character varying(50) NOT NULL,
    table_name character varying(63)
);


ALTER TABLE "TokenType" OWNER TO core;

--
-- Name: TokenType_id_seq; Type: SEQUENCE; Schema: core; Owner: core
--

CREATE SEQUENCE "TokenType_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "TokenType_id_seq" OWNER TO core;

--
-- Name: TokenType_id_seq; Type: SEQUENCE OWNED BY; Schema: core; Owner: core
--

ALTER SEQUENCE "TokenType_id_seq" OWNED BY "TokenType".id;


--
-- Name: Vehicle; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Vehicle" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    personnel_id uuid,
    make character varying(50),
    model character varying(50),
    color character varying(50),
    accent_color character varying(50),
    state_or_prov character varying(50),
    tag character varying(50),
    sticker character varying(50),
    year smallint
);


ALTER TABLE "Vehicle" OWNER TO core;

SET search_path = extra, pg_catalog;

--
-- Name: AccessSet; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "AccessSet" (
    id uuid NOT NULL,
    notes_id uuid
);


ALTER TABLE "AccessSet" OWNER TO extra;

--
-- Name: Notes; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "Notes" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    text text
);


ALTER TABLE "Notes" OWNER TO extra;

--
-- Name: AllAccessSet; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "AllAccessSet" AS
 SELECT core.id,
    core.name,
    core.user_level,
    core.download_required,
    extra.notes_id,
    notes.text AS notes
   FROM ((core."AccessSet" core
     LEFT JOIN "AccessSet" extra ON ((core.id = extra.id)))
     LEFT JOIN "Notes" notes ON ((extra.notes_id = notes.id)));


ALTER TABLE "AllAccessSet" OWNER TO extra;

--
-- Name: Blob; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "Blob" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    type_id smallint,
    bytes bytea
);


ALTER TABLE "Blob" OWNER TO extra;

--
-- Name: Personnel; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "Personnel" (
    id uuid NOT NULL,
    name_middle character varying(50),
    name_prefix character varying(30),
    name_suffix character varying(30),
    company character varying(50),
    department character varying(50),
    job_title character varying(50),
    email character varying(255),
    phone_work character varying(30),
    phone_work_ext character varying(20),
    phone_mobile character varying(30),
    phone_home character varying(30),
    address character varying(150),
    city character varying(50),
    state_or_prov character varying(50),
    postal_code character varying(20),
    country character varying(50),
    notes_id uuid,
    photo_id uuid,
    signature_id uuid,
    fingerprint_id uuid,
    room character varying(50),
    assigned_to smallint,
    admission_date timestamp without time zone
);


ALTER TABLE "Personnel" OWNER TO extra;

--
-- Name: AllPersonnel; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "AllPersonnel" AS
 SELECT core.id,
    core.name_last,
    core.name_first,
    extra.name_middle,
    extra.name_prefix,
    extra.name_suffix,
    extra.company,
    extra.department,
    extra.job_title,
    extra.email,
    extra.phone_work,
    extra.phone_work_ext,
    extra.phone_mobile,
    extra.phone_home,
    extra.address,
    extra.city,
    extra.state_or_prov,
    extra.postal_code,
    extra.country,
    extra.notes_id,
    notes.text AS notes,
    extra.photo_id,
    photo.bytes AS photo,
    photo_type.mime_type AS photo_type,
    extra.signature_id,
    signature.bytes AS signature,
    signature_type.mime_type AS signature_type,
    extra.fingerprint_id,
    fingerprint.bytes AS fingerprint,
    fingerprint_type.mime_type AS fingerprint_type,
    core.user_level,
    core.days_to_log,
    core.apb_type_id,
    core.apb_zone_id,
    core.apb_violations,
    core.created,
    core.created_by,
    core.updated,
    core.updated_by,
    extra.room,
    extra.assigned_to,
    extra.admission_date
   FROM ((((((((core."AllPersonnel" core
     LEFT JOIN "Personnel" extra ON ((core.id = extra.id)))
     LEFT JOIN "Notes" notes ON ((extra.notes_id = notes.id)))
     LEFT JOIN "Blob" photo ON ((extra.photo_id = photo.id)))
     LEFT JOIN core."BlobType" photo_type ON ((photo.type_id = photo_type.id)))
     LEFT JOIN "Blob" signature ON ((extra.signature_id = signature.id)))
     LEFT JOIN core."BlobType" signature_type ON ((signature.type_id = signature_type.id)))
     LEFT JOIN "Blob" fingerprint ON ((extra.fingerprint_id = fingerprint.id)))
     LEFT JOIN core."BlobType" fingerprint_type ON ((fingerprint.type_id = fingerprint_type.id)));


ALTER TABLE "AllPersonnel" OWNER TO extra;

--
-- Name: Vehicle; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "Vehicle" (
    id uuid NOT NULL,
    notes_id uuid
);


ALTER TABLE "Vehicle" OWNER TO extra;

--
-- Name: AllVehicle; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "AllVehicle" AS
 SELECT core.id,
    core.personnel_id,
    core.make,
    core.model,
    core.color,
    core.accent_color,
    core.state_or_prov,
    core.tag,
    core.sticker,
    core.year,
    extra.notes_id,
    notes.text AS notes
   FROM ((core."Vehicle" core
     LEFT JOIN "Vehicle" extra ON ((core.id = extra.id)))
     LEFT JOIN "Notes" notes ON ((extra.notes_id = notes.id)));


ALTER TABLE "AllVehicle" OWNER TO extra;

--
-- Name: Card; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "Card" (
    token_id uuid NOT NULL,
    card_emboss_num character varying(50),
    card_label character varying(50)
);


ALTER TABLE "Card" OWNER TO extra;

--
-- Name: CardToken; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "CardToken" AS
 SELECT core.token_id,
    core.card_number,
    core.site_code,
    core.card_format,
    core.card_type,
    extra.card_emboss_num,
    extra.card_label,
    core.pin_number,
    core.card_valid,
    core.activate_date,
    core.deactivate_date,
    core.secondary_expiration_date,
    core.expire_days,
    core.action_point_id,
    core.threat_level,
    core.auto_disable,
    core.grant_long_access_time,
    core.escort_visitor_capable,
    core.access_cost_override_capable,
    core.event_lock_override_capable,
    core.building_passback_exemption,
    core.parking_passback_exemption,
    core.card_holder_groups,
    core.activation_group,
    core.on_access_output,
    core.compass_command_group,
    core.user_level,
    core.personnel_id,
    core.badge_id,
    core.lost,
    core.last_read,
    core.last_reader,
    core.last_read_status,
    core.created,
    core.created_by,
    core.updated,
    core.updated_by,
    core.downloaded,
    core.downloaded_by,
    core.download_required,
    core.low_battery
   FROM (core."CardToken" core
     LEFT JOIN "Card" extra ON ((core.token_id = extra.token_id)));


ALTER TABLE "CardToken" OWNER TO extra;

--
-- Name: MultiCard; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "MultiCard" AS
 SELECT card.token_id,
    card.personnel_id,
    card.card_number,
    card.site_code,
    card.card_format,
    card.card_type,
    card.card_emboss_num,
    card.card_label,
    card.pin_number,
    card.card_valid,
    card.activate_date,
    card.deactivate_date,
    card.secondary_expiration_date,
    card.expire_days,
    card.action_point_id,
    card.threat_level,
    card.auto_disable,
    card.grant_long_access_time,
    card.escort_visitor_capable,
    card.access_cost_override_capable,
    card.event_lock_override_capable,
    card.building_passback_exemption,
    card.parking_passback_exemption,
    card.card_holder_groups,
    card.activation_group,
    card.on_access_output,
    card.compass_command_group,
    card.user_level AS card_user_level,
    card.badge_id,
    card.lost,
    card.last_read,
    card.last_reader,
    card.last_read_status,
    card.created AS card_created,
    card.created_by AS card_created_by,
    card.updated AS card_updated,
    card.updated_by AS card_updated_by,
    card.downloaded,
    card.downloaded_by,
    card.download_required,
    personnel.name_last,
    personnel.name_first,
    personnel.name_middle,
    personnel.name_prefix,
    personnel.name_suffix,
    personnel.company,
    personnel.department,
    personnel.job_title,
    personnel.email,
    personnel.phone_work,
    personnel.phone_work_ext,
    personnel.phone_mobile,
    personnel.phone_home,
    personnel.address,
    personnel.city,
    personnel.state_or_prov,
    personnel.postal_code,
    personnel.country,
    personnel.notes_id,
    personnel.notes,
    personnel.photo_id,
    personnel.photo,
    personnel.photo_type,
    personnel.signature_id,
    personnel.signature,
    personnel.signature_type,
    personnel.fingerprint_id,
    personnel.fingerprint,
    personnel.fingerprint_type,
    personnel.user_level AS personnel_user_level,
    personnel.days_to_log,
    personnel.apb_type_id,
    personnel.apb_zone_id,
    personnel.apb_violations,
    personnel.created AS personnel_created,
    personnel.created_by AS personnel_created_by,
    personnel.updated AS personnel_updated,
    personnel.updated_by AS personnel_updated_by,
    personnel.room,
    personnel.assigned_to,
    personnel.admission_date,
    card.low_battery
   FROM ("CardToken" card
     LEFT JOIN "AllPersonnel" personnel ON ((personnel.id = card.personnel_id)));


ALTER TABLE "MultiCard" OWNER TO extra;

--
-- Name: SingleCard; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "SingleCard" AS
 SELECT card.token_id,
    card.personnel_id,
    card.card_number,
    card.site_code,
    card.card_format,
    card.card_type,
    card.card_emboss_num,
    card.card_label,
    card.pin_number,
    card.card_valid,
    card.activate_date,
    card.deactivate_date,
    card.secondary_expiration_date,
    card.expire_days,
    card.action_point_id,
    card.threat_level,
    card.auto_disable,
    card.grant_long_access_time,
    card.escort_visitor_capable,
    card.access_cost_override_capable,
    card.event_lock_override_capable,
    card.building_passback_exemption,
    card.parking_passback_exemption,
    card.card_holder_groups,
    card.activation_group,
    card.on_access_output,
    card.compass_command_group,
    card.user_level AS card_user_level,
    card.badge_id,
    card.lost,
    card.last_read,
    card.last_reader,
    card.last_read_status,
    card.created AS card_created,
    card.created_by AS card_created_by,
    card.updated AS card_updated,
    card.updated_by AS card_updated_by,
    card.downloaded,
    card.downloaded_by,
    card.download_required,
    personnel.name_last,
    personnel.name_first,
    personnel.name_middle,
    personnel.name_prefix,
    personnel.name_suffix,
    personnel.company,
    personnel.department,
    personnel.job_title,
    personnel.email,
    personnel.phone_work,
    personnel.phone_work_ext,
    personnel.phone_mobile,
    personnel.phone_home,
    personnel.address,
    personnel.city,
    personnel.state_or_prov,
    personnel.postal_code,
    personnel.country,
    personnel.notes_id,
    personnel.notes,
    personnel.photo_id,
    personnel.photo,
    personnel.photo_type,
    personnel.signature_id,
    personnel.signature,
    personnel.signature_type,
    personnel.fingerprint_id,
    personnel.fingerprint,
    personnel.fingerprint_type,
    personnel.user_level AS personnel_user_level,
    personnel.days_to_log,
    personnel.apb_type_id,
    personnel.apb_zone_id,
    personnel.apb_violations,
    personnel.created AS personnel_created,
    personnel.created_by AS personnel_created_by,
    personnel.updated AS personnel_updated,
    personnel.updated_by AS personnel_updated_by,
    personnel.room,
    personnel.assigned_to,
    personnel.admission_date,
    card.low_battery
   FROM ((core."PersonnelWithSingleCard" singles
     LEFT JOIN "CardToken" card ON ((card.personnel_id = singles.personnel_id)))
     LEFT JOIN "AllPersonnel" personnel ON ((personnel.id = singles.personnel_id)));


ALTER TABLE "SingleCard" OWNER TO extra;

SET search_path = history, pg_catalog;

--
-- Name: AccutechTagChange; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "AccutechTagChange" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    change_time timestamp with time zone DEFAULT now() NOT NULL,
    event smallint NOT NULL,
    card_number bigint NOT NULL,
    name_first character varying(50),
    name_last character varying(50),
    name_middle character varying(50),
    assigned_to smallint,
    updated_by character varying(255),
    room character varying(50)
);


ALTER TABLE "AccutechTagChange" OWNER TO core;

--
-- Name: Activity; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "Activity" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    "time" timestamp with time zone DEFAULT now() NOT NULL,
    event_type_id smallint,
    rtu_id integer,
    rtu_name character varying(100),
    point_id integer,
    point_name character varying(100),
    state smallint,
    status character varying(255),
    card_number bigint,
    site_code bigint,
    card_format smallint,
    card_holder_name character varying(100),
    computer character varying(100),
    "user" character varying(100),
    user_comments text,
    token_id uuid
);


ALTER TABLE "Activity" OWNER TO core;

--
-- Name: Activity_Statistics; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "Activity_Statistics" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    event_type_id smallint,
    rtu_id integer,
    rtu_name character varying(100),
    point_id integer,
    point_name character varying(100),
    state smallint,
    status character varying(255),
    card_number bigint,
    site_code bigint,
    card_format smallint,
    card_holder_name character varying(100),
    computer character varying(100),
    "user" character varying(100),
    user_comments text,
    token_id uuid,
    active_time timestamp with time zone,
    inactive_time timestamp with time zone,
    acked_time timestamp with time zone,
    cleared_time timestamp with time zone,
    last_active timestamp with time zone,
    total_active bigint,
    active_count bigint
);


ALTER TABLE "Activity_Statistics" OWNER TO core;

--
-- Name: ChangeType; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "ChangeType" (
    id smallint NOT NULL,
    name character varying(50) NOT NULL
);


ALTER TABLE "ChangeType" OWNER TO core;

--
-- Name: ChangeType_id_seq; Type: SEQUENCE; Schema: history; Owner: core
--

CREATE SEQUENCE "ChangeType_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "ChangeType_id_seq" OWNER TO core;

--
-- Name: ChangeType_id_seq; Type: SEQUENCE OWNED BY; Schema: history; Owner: core
--

ALTER SEQUENCE "ChangeType_id_seq" OWNED BY "ChangeType".id;


--
-- Name: EventType; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "EventType" (
    id smallint NOT NULL,
    name character varying(50) NOT NULL
);


ALTER TABLE "EventType" OWNER TO core;

--
-- Name: EventType_id_seq; Type: SEQUENCE; Schema: history; Owner: core
--

CREATE SEQUENCE "EventType_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "EventType_id_seq" OWNER TO core;

--
-- Name: EventType_id_seq; Type: SEQUENCE OWNED BY; Schema: history; Owner: core
--

ALTER SEQUENCE "EventType_id_seq" OWNED BY "EventType".id;


--
-- Name: ProjectChange; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "ProjectChange" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    "time" timestamp with time zone DEFAULT now() NOT NULL,
    change_type_id smallint,
    name character varying(100),
    computer character varying(100),
    "user" character varying(100),
    old_data bytea,
    new_data bytea
);


ALTER TABLE "ProjectChange" OWNER TO core;

SET search_path = core, pg_catalog;

--
-- Name: created; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AllPersonnel" ALTER COLUMN created SET DEFAULT now();


--
-- Name: id; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AlterTableInformation" ALTER COLUMN id SET DEFAULT nextval('"AlterTableInformation_id_seq"'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "BlobType" ALTER COLUMN id SET DEFAULT nextval('"BlobType_id_seq"'::regclass);


--
-- Name: low_battery; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "CardDownload" ALTER COLUMN low_battery SET DEFAULT false;


--
-- Name: low_battery; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "CardToken" ALTER COLUMN low_battery SET DEFAULT false;


--
-- Name: id; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "Parameter" ALTER COLUMN id SET DEFAULT nextval('"Parameter_id_seq"'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "TokenType" ALTER COLUMN id SET DEFAULT nextval('"TokenType_id_seq"'::regclass);


SET search_path = extra, pg_catalog;

--
-- Name: low_battery; Type: DEFAULT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "CardToken" ALTER COLUMN low_battery SET DEFAULT false;


--
-- Name: low_battery; Type: DEFAULT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "MultiCard" ALTER COLUMN low_battery SET DEFAULT false;


--
-- Name: low_battery; Type: DEFAULT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "SingleCard" ALTER COLUMN low_battery SET DEFAULT false;


SET search_path = history, pg_catalog;

--
-- Name: id; Type: DEFAULT; Schema: history; Owner: core
--

ALTER TABLE ONLY "ChangeType" ALTER COLUMN id SET DEFAULT nextval('"ChangeType_id_seq"'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: history; Owner: core
--

ALTER TABLE ONLY "EventType" ALTER COLUMN id SET DEFAULT nextval('"EventType_id_seq"'::regclass);


SET search_path = core, pg_catalog;

--
-- Data for Name: AccessEntry; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "AccessEntry" (id, name) FROM stdin;
\.


--
-- Data for Name: AccessSet; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "AccessSet" (id, name, user_level, download_required) FROM stdin;
\.


--
-- Data for Name: AccessSetsToAccessEntries; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "AccessSetsToAccessEntries" (access_set_id, access_entry_id) FROM stdin;
\.


--
-- Data for Name: AccessSetsToTokens; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "AccessSetsToTokens" (access_set_id, token_id) FROM stdin;
\.


--
-- Data for Name: AlterTableInformation; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "AlterTableInformation" (id, tabletobealtered, ordertoalter, qryschema, qrytable, viewname, functionname, viewaliasname, returnfield1, returnfield2, returnfield3, wherefield, internalfunctiontableorviewname) FROM stdin;
1	Card	1	information_schema	views	CardToken	\N	extra	table_schema	table_name	view_definition	table_name	\N
2	Card	3	information_schema	views	MultiCard	\N	card	table_schema	table_name	view_definition	table_name	\N
3	Card	2	information_schema	views	SingleCard	\N	card	table_schema	table_name	view_definition	table_name	\N
4	Card	4	pg_catalog	pg_proc	\N	CardToken_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
5	Card	5	pg_catalog	pg_proc	\N	CardToken_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
6	Card	6	pg_catalog	pg_proc	\N	MultiCard_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
7	Card	7	pg_catalog	pg_proc	\N	MultiCard_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
8	Card	8	pg_catalog	pg_proc	\N	SingleCard_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
9	Card	9	pg_catalog	pg_proc	\N	SingleCard_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
10	Personnel	1	information_schema	views	AllPersonnel	\N	extra	table_schema	table_name	view_definition	table_name	\N
11	Personnel	2	information_schema	views	MultiCard	\N	personnel	table_schema	table_name	view_definition	table_name	\N
12	Personnel	3	information_schema	views	SingleCard	\N	personnel	table_schema	table_name	view_definition	table_name	\N
13	Personnel	4	pg_catalog	pg_proc	\N	AllPersonnel_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	Personnel
14	Personnel	5	pg_catalog	pg_proc	\N	AllPersonnel_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	Personnel
15	Personnel	6	pg_catalog	pg_proc	\N	MultiCard_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	AllPersonnel
16	Personnel	7	pg_catalog	pg_proc	\N	MultiCard_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	AllPersonnel
17	Personnel	8	pg_catalog	pg_proc	\N	SingleCard_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	AllPersonnel
18	Personnel	9	pg_catalog	pg_proc	\N	SingleCard_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	AllPersonnel
19	Vehicle	1	information_schema	views	AllVehicle	\N	extra	table_schema	table_name	view_definition	table_name	\N
20	Vehicle	2	pg_catalog	pg_proc	\N	AllVehicle_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	Vehicle
21	Vehicle	3	pg_catalog	pg_proc	\N	AllVehicle_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	Vehicle
\.


--
-- Name: AlterTableInformation_id_seq; Type: SEQUENCE SET; Schema: core; Owner: core
--

SELECT pg_catalog.setval('"AlterTableInformation_id_seq"', 21, true);


--
-- Data for Name: BlobType; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "BlobType" (id, name, abbrev, mime_type) FROM stdin;
0	Binary Data	BIN	application/octet-stream
1	Plain Text	TXT	text/plain
2	Comma-separated Values	CSV	text/csv
3	Rich Text Format	RTF	text/rtf
4	HyperText Markup Language	HTML	text/html
5	Cascading Style Sheets	CSS	text/css
6	JavaScript	JS	application/javascript
7	Portable Document Format	PDF	application/pdf
8	PostScript	PS	application/postscript
9	Extensible Markup Language	XML	application/xml
10	Bitmap Image	BMP	image/bmp
11	GIF Image	GIF	image/gif
12	JPEG Image	JPEG	image/jpeg
13	PNG Image	PNG	image/png
14	SVG Image	SVG	image/svg+xml
15	µ-Law (G.711) Audio	ULAW	audio/basic
16	AIFF Audio	AIFF	audio/aiff
17	MP3/MP2/MPEG Audio	MP3	audio/mpeg
18	MP4 Audio	MP4	audio/mp4
19	Ogg Vorbis Audio	OGG	audio/ogg
20	WAV/WAVE Audio	WAV	audio/vnd.wave
\.


--
-- Name: BlobType_id_seq; Type: SEQUENCE SET; Schema: core; Owner: core
--

SELECT pg_catalog.setval('"BlobType_id_seq"', 21, true);


--
-- Data for Name: Card; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Card" (token_id, card_number, site_code, card_format, card_type, pin_number, card_valid, activate_date, deactivate_date, secondary_expiration_date, expire_days, action_point_id, threat_level, auto_disable, grant_long_access_time, escort_visitor_capable, access_cost_override_capable, event_lock_override_capable, building_passback_exemption, parking_passback_exemption, card_holder_groups, activation_group, on_access_output, compass_command_group, deleted, low_battery) FROM stdin;
\.


--
-- Data for Name: Parameter; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Parameter" (id, name, value) FROM stdin;
1	db_version	4.0.0.0
2	product_version	4.0.29.22
\.


--
-- Name: Parameter_id_seq; Type: SEQUENCE SET; Schema: core; Owner: core
--

SELECT pg_catalog.setval('"Parameter_id_seq"', 2, true);


--
-- Data for Name: Personnel; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Personnel" (id, name_last, name_first, user_level, days_to_log, apb_type_id, apb_zone_id, apb_violations, created, created_by, updated, updated_by, deleted, deleted_by) FROM stdin;
\.


--
-- Data for Name: Reader; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Reader" (id, name, is_zone, is_muster_zone) FROM stdin;
\.


--
-- Data for Name: ReadersToAccessEntries; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "ReadersToAccessEntries" (reader_id, access_entry_id) FROM stdin;
\.


--
-- Data for Name: RfidTag; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "RfidTag" (token_id, tag_number) FROM stdin;
\.


--
-- Data for Name: ScheduledEvent; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "ScheduledEvent" (id, start, stop, event_id, active) FROM stdin;
\.


--
-- Data for Name: SystemInformation; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "SystemInformation" (id, created, computer_id, computer_name) FROM stdin;
\.


--
-- Data for Name: SystemInformationItem; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "SystemInformationItem" (sysinfo_id, item_id, "group", name, value, kind, key, description) FROM stdin;
\.


--
-- Data for Name: Token; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Token" (id, type_id, user_level, personnel_id, badge_id, lost, last_read, last_reader, last_read_status, created, created_by, updated, updated_by, deleted, deleted_by, downloaded, downloaded_by, download_required) FROM stdin;
\.


--
-- Data for Name: TokenType; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "TokenType" (id, name, table_name) FROM stdin;
1	Access Card	Card
2	RFID Tag	RfidTag
\.


--
-- Name: TokenType_id_seq; Type: SEQUENCE SET; Schema: core; Owner: core
--

SELECT pg_catalog.setval('"TokenType_id_seq"', 3, true);


--
-- Data for Name: Vehicle; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Vehicle" (id, personnel_id, make, model, color, accent_color, state_or_prov, tag, sticker, year) FROM stdin;
\.


SET search_path = extra, pg_catalog;

--
-- Data for Name: AccessSet; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "AccessSet" (id, notes_id) FROM stdin;
\.


--
-- Data for Name: Blob; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "Blob" (id, type_id, bytes) FROM stdin;
\.


--
-- Data for Name: Card; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "Card" (token_id, card_emboss_num, card_label) FROM stdin;
\.


--
-- Data for Name: Notes; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "Notes" (id, text) FROM stdin;
\.


--
-- Data for Name: Personnel; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "Personnel" (id, name_middle, name_prefix, name_suffix, company, department, job_title, email, phone_work, phone_work_ext, phone_mobile, phone_home, address, city, state_or_prov, postal_code, country, notes_id, photo_id, signature_id, fingerprint_id, room, assigned_to, admission_date) FROM stdin;
\.


--
-- Data for Name: Vehicle; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "Vehicle" (id, notes_id) FROM stdin;
\.


SET search_path = history, pg_catalog;

--
-- Data for Name: AccutechTagChange; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "AccutechTagChange" (id, change_time, event, card_number, name_first, name_last, name_middle, assigned_to, updated_by, room) FROM stdin;
\.


--
-- Data for Name: Activity; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "Activity" (id, "time", event_type_id, rtu_id, rtu_name, point_id, point_name, state, status, card_number, site_code, card_format, card_holder_name, computer, "user", user_comments, token_id) FROM stdin;
\.


--
-- Data for Name: Activity_Statistics; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "Activity_Statistics" (id, event_type_id, rtu_id, rtu_name, point_id, point_name, state, status, card_number, site_code, card_format, card_holder_name, computer, "user", user_comments, token_id, active_time, inactive_time, acked_time, cleared_time, last_active, total_active, active_count) FROM stdin;
\.


--
-- Data for Name: ChangeType; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "ChangeType" (id, name) FROM stdin;
1	Node Add
2	Node Modify
3	Node Delete
4	Card Add
5	Card Modify
6	Card Delete
7	Personnel Add
8	Personnel Modify
9	Personnel Delete
10	Access Set Add
11	Access Set Modify
12	Access Set Delete
\.


--
-- Name: ChangeType_id_seq; Type: SEQUENCE SET; Schema: history; Owner: core
--

SELECT pg_catalog.setval('"ChangeType_id_seq"', 9, true);


--
-- Data for Name: EventType; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "EventType" (id, name) FROM stdin;
1	Card
2	I/O
3	Exception
4	Download
5	Client
6	Alarm
\.


--
-- Name: EventType_id_seq; Type: SEQUENCE SET; Schema: history; Owner: core
--

SELECT pg_catalog.setval('"EventType_id_seq"', 5, true);


--
-- Data for Name: ProjectChange; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "ProjectChange" (id, "time", change_type_id, name, computer, "user", old_data, new_data) FROM stdin;
\.


SET search_path = core, pg_catalog;

--
-- Name: AccessEntry_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AccessEntry"
    ADD CONSTRAINT "AccessEntry_pkey" PRIMARY KEY (id);


--
-- Name: AccessSet_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AccessSet"
    ADD CONSTRAINT "AccessSet_pkey" PRIMARY KEY (id);


--
-- Name: AccessSetsToAccessEntries_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AccessSetsToAccessEntries"
    ADD CONSTRAINT "AccessSetsToAccessEntries_pkey" PRIMARY KEY (access_set_id, access_entry_id);


--
-- Name: AccessSetsToTokens_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AccessSetsToTokens"
    ADD CONSTRAINT "AccessSetsToTokens_pkey" PRIMARY KEY (access_set_id, token_id);


--
-- Name: AlterTableInformation_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AlterTableInformation"
    ADD CONSTRAINT "AlterTableInformation_pkey" PRIMARY KEY (id);


--
-- Name: BlobType_abbrev_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "BlobType"
    ADD CONSTRAINT "BlobType_abbrev_key" UNIQUE (abbrev);


--
-- Name: BlobType_mime_type_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "BlobType"
    ADD CONSTRAINT "BlobType_mime_type_key" UNIQUE (mime_type);


--
-- Name: BlobType_name_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "BlobType"
    ADD CONSTRAINT "BlobType_name_key" UNIQUE (name);


--
-- Name: BlobType_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "BlobType"
    ADD CONSTRAINT "BlobType_pkey" PRIMARY KEY (id);

ALTER TABLE "BlobType" CLUSTER ON "BlobType_pkey";


--
-- Name: Card_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Card"
    ADD CONSTRAINT "Card_pkey" PRIMARY KEY (token_id);


--
-- Name: Parameter_name_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Parameter"
    ADD CONSTRAINT "Parameter_name_key" UNIQUE (name);


--
-- Name: Parameter_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Parameter"
    ADD CONSTRAINT "Parameter_pkey" PRIMARY KEY (id);


--
-- Name: Personnel_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_pkey" PRIMARY KEY (id);


--
-- Name: Reader_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Reader"
    ADD CONSTRAINT "Reader_pkey" PRIMARY KEY (id);


--
-- Name: ReadersToAccessEntries_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "ReadersToAccessEntries"
    ADD CONSTRAINT "ReadersToAccessEntries_pkey" PRIMARY KEY (reader_id, access_entry_id);


--
-- Name: RfidTag_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "RfidTag"
    ADD CONSTRAINT "RfidTag_pkey" PRIMARY KEY (token_id);


--
-- Name: RfidTag_tag_number_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "RfidTag"
    ADD CONSTRAINT "RfidTag_tag_number_key" UNIQUE (tag_number);


--
-- Name: ScheduledEvent_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "ScheduledEvent"
    ADD CONSTRAINT "ScheduledEvent_pkey" PRIMARY KEY (id);


--
-- Name: SystemInformationItem_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "SystemInformationItem"
    ADD CONSTRAINT "SystemInformationItem_pkey" PRIMARY KEY (sysinfo_id, item_id);


--
-- Name: SystemInformation_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "SystemInformation"
    ADD CONSTRAINT "SystemInformation_pkey" PRIMARY KEY (id);


--
-- Name: TokenType_name_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "TokenType"
    ADD CONSTRAINT "TokenType_name_key" UNIQUE (name);


--
-- Name: TokenType_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "TokenType"
    ADD CONSTRAINT "TokenType_pkey" PRIMARY KEY (id);

ALTER TABLE "TokenType" CLUSTER ON "TokenType_pkey";


--
-- Name: TokenType_table_name_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "TokenType"
    ADD CONSTRAINT "TokenType_table_name_key" UNIQUE (table_name);


--
-- Name: Token_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Token"
    ADD CONSTRAINT "Token_pkey" PRIMARY KEY (id);


--
-- Name: Vehicle_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Vehicle"
    ADD CONSTRAINT "Vehicle_pkey" PRIMARY KEY (id);


SET search_path = extra, pg_catalog;

--
-- Name: AccessSet_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "AccessSet"
    ADD CONSTRAINT "AccessSet_pkey" PRIMARY KEY (id);


--
-- Name: Blob_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "Blob"
    ADD CONSTRAINT "Blob_pkey" PRIMARY KEY (id);


--
-- Name: Card_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "Card"
    ADD CONSTRAINT "Card_pkey" PRIMARY KEY (token_id);


--
-- Name: Notes_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "Notes"
    ADD CONSTRAINT "Notes_pkey" PRIMARY KEY (id);


--
-- Name: Personnel_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_pkey" PRIMARY KEY (id);


--
-- Name: Vehicle_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "Vehicle"
    ADD CONSTRAINT "Vehicle_pkey" PRIMARY KEY (id);


SET search_path = history, pg_catalog;

--
-- Name: Activity_Statistics_pkey; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Activity_Statistics"
    ADD CONSTRAINT "Activity_Statistics_pkey" PRIMARY KEY (id);


--
-- Name: Activity_pkey; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Activity"
    ADD CONSTRAINT "Activity_pkey" PRIMARY KEY (id);


--
-- Name: ChangeType_name_key; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "ChangeType"
    ADD CONSTRAINT "ChangeType_name_key" UNIQUE (name);


--
-- Name: ChangeType_pkey; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "ChangeType"
    ADD CONSTRAINT "ChangeType_pkey" PRIMARY KEY (id);


--
-- Name: EventType_name_key; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "EventType"
    ADD CONSTRAINT "EventType_name_key" UNIQUE (name);


--
-- Name: EventType_pkey; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "EventType"
    ADD CONSTRAINT "EventType_pkey" PRIMARY KEY (id);


--
-- Name: ProjectChange_pkey; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "ProjectChange"
    ADD CONSTRAINT "ProjectChange_pkey" PRIMARY KEY (id);


--
-- Name: pk_history.AccutechTagChange; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AccutechTagChange"
    ADD CONSTRAINT "pk_history.AccutechTagChange" PRIMARY KEY (id);


SET search_path = core, pg_catalog;

--
-- Name: AccessSetsToAccessEntries_access_entry_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "AccessSetsToAccessEntries_access_entry_id_idx" ON "AccessSetsToAccessEntries" USING btree (access_entry_id);


--
-- Name: AccessSetsToAccessEntries_access_set_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "AccessSetsToAccessEntries_access_set_id_idx" ON "AccessSetsToAccessEntries" USING btree (access_set_id);


--
-- Name: AccessSetsToTokens_access_set_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "AccessSetsToTokens_access_set_id_idx" ON "AccessSetsToTokens" USING btree (access_set_id);


--
-- Name: AccessSetsToTokens_token_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "AccessSetsToTokens_token_id_idx" ON "AccessSetsToTokens" USING btree (token_id);


--
-- Name: Card_unique_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE UNIQUE INDEX "Card_unique_idx" ON "Card" USING btree (card_number, site_code, card_format) WHERE (deleted IS NULL);


--
-- Name: Personnel_existing_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE UNIQUE INDEX "Personnel_existing_idx" ON "Personnel" USING btree (id) WHERE (deleted IS NULL);


--
-- Name: ReadersToAccessEntries_access_entry_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "ReadersToAccessEntries_access_entry_id_idx" ON "ReadersToAccessEntries" USING btree (access_entry_id);


--
-- Name: ReadersToAccessEntries_reader_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "ReadersToAccessEntries_reader_id_idx" ON "ReadersToAccessEntries" USING btree (reader_id);


--
-- Name: Token_existing_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE UNIQUE INDEX "Token_existing_idx" ON "Token" USING btree (id) WHERE (deleted IS NULL);


--
-- Name: Token_personnel_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "Token_personnel_id_idx" ON "Token" USING btree (personnel_id) WHERE (deleted IS NULL);


--
-- Name: Token_type_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "Token_type_id_idx" ON "Token" USING btree (type_id);


SET search_path = extra, pg_catalog;

--
-- Name: AccessSet_notes_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "AccessSet_notes_id_idx" ON "AccessSet" USING btree (notes_id);


--
-- Name: Blob_blob_type_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Blob_blob_type_id_idx" ON "Blob" USING btree (type_id);


--
-- Name: Personnel_fingerprint_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Personnel_fingerprint_id_idx" ON "Personnel" USING btree (fingerprint_id);


--
-- Name: Personnel_notes_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Personnel_notes_id_idx" ON "Personnel" USING btree (notes_id);


--
-- Name: Personnel_photo_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Personnel_photo_id_idx" ON "Personnel" USING btree (photo_id);


--
-- Name: Personnel_signature_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Personnel_signature_id_idx" ON "Personnel" USING btree (signature_id);


--
-- Name: Vehicle_notes_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Vehicle_notes_id_idx" ON "Vehicle" USING btree (notes_id);


SET search_path = history, pg_catalog;

--
-- Name: Activity_event_type_id_idx; Type: INDEX; Schema: history; Owner: core; Tablespace: 
--

CREATE INDEX "Activity_event_type_id_idx" ON "Activity" USING btree (event_type_id);


--
-- Name: Activity_time_idx; Type: INDEX; Schema: history; Owner: core; Tablespace: 
--

CREATE INDEX "Activity_time_idx" ON "Activity" USING btree ("time");


--
-- Name: ProjectChange_change_type_id_idx; Type: INDEX; Schema: history; Owner: core; Tablespace: 
--

CREATE INDEX "ProjectChange_change_type_id_idx" ON "ProjectChange" USING btree (change_type_id);


--
-- Name: ProjectChange_time_idx; Type: INDEX; Schema: history; Owner: core; Tablespace: 
--

CREATE INDEX "ProjectChange_time_idx" ON "ProjectChange" USING btree ("time");


SET search_path = core, pg_catalog;

--
-- Name: AllPersonnel_trigger_delete; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "AllPersonnel_trigger_delete" INSTEAD OF DELETE ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoDelete"();


--
-- Name: AllPersonnel_trigger_insert; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "AllPersonnel_trigger_insert" INSTEAD OF INSERT ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoInsert"();


--
-- Name: AllPersonnel_trigger_update; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "AllPersonnel_trigger_update" INSTEAD OF UPDATE ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoUpdate"();


--
-- Name: CardToken_trigger_delete; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "CardToken_trigger_delete" INSTEAD OF DELETE ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoDelete"();


--
-- Name: CardToken_trigger_insert; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "CardToken_trigger_insert" INSTEAD OF INSERT ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoInsert"();


--
-- Name: CardToken_trigger_update; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "CardToken_trigger_update" INSTEAD OF UPDATE ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoUpdate"();


SET search_path = extra, pg_catalog;

--
-- Name: AllAccessSet_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllAccessSet_trigger_delete" INSTEAD OF DELETE ON "AllAccessSet" FOR EACH ROW EXECUTE PROCEDURE "AllAccessSet_DoDelete"();


--
-- Name: AllAccessSet_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllAccessSet_trigger_insert" INSTEAD OF INSERT ON "AllAccessSet" FOR EACH ROW EXECUTE PROCEDURE "AllAccessSet_DoInsert"();


--
-- Name: AllAccessSet_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllAccessSet_trigger_update" INSTEAD OF UPDATE ON "AllAccessSet" FOR EACH ROW EXECUTE PROCEDURE "AllAccessSet_DoUpdate"();


--
-- Name: AllPersonnel_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllPersonnel_trigger_delete" INSTEAD OF DELETE ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoDelete"();


--
-- Name: AllPersonnel_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllPersonnel_trigger_insert" INSTEAD OF INSERT ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoInsert"();


--
-- Name: AllPersonnel_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllPersonnel_trigger_update" INSTEAD OF UPDATE ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoUpdate"();


--
-- Name: AllVehicle_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllVehicle_trigger_delete" INSTEAD OF DELETE ON "AllVehicle" FOR EACH ROW EXECUTE PROCEDURE "AllVehicle_DoDelete"();


--
-- Name: AllVehicle_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllVehicle_trigger_insert" INSTEAD OF INSERT ON "AllVehicle" FOR EACH ROW EXECUTE PROCEDURE "AllVehicle_DoInsert"();


--
-- Name: AllVehicle_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllVehicle_trigger_update" INSTEAD OF UPDATE ON "AllVehicle" FOR EACH ROW EXECUTE PROCEDURE "AllVehicle_DoUpdate"();


--
-- Name: CardToken_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "CardToken_trigger_delete" INSTEAD OF DELETE ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoDelete"();


--
-- Name: CardToken_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "CardToken_trigger_insert" INSTEAD OF INSERT ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoInsert"();


--
-- Name: CardToken_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "CardToken_trigger_update" INSTEAD OF UPDATE ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoUpdate"();


--
-- Name: MultiCard_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "MultiCard_trigger_delete" INSTEAD OF DELETE ON "MultiCard" FOR EACH ROW EXECUTE PROCEDURE "MultiCard_DoDelete"();


--
-- Name: MultiCard_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "MultiCard_trigger_insert" INSTEAD OF INSERT ON "MultiCard" FOR EACH ROW EXECUTE PROCEDURE "MultiCard_DoInsert"();


--
-- Name: MultiCard_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "MultiCard_trigger_update" INSTEAD OF UPDATE ON "MultiCard" FOR EACH ROW EXECUTE PROCEDURE "MultiCard_DoUpdate"();


--
-- Name: SingleCard_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "SingleCard_trigger_delete" INSTEAD OF DELETE ON "SingleCard" FOR EACH ROW EXECUTE PROCEDURE "SingleCard_DoDelete"();


--
-- Name: SingleCard_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "SingleCard_trigger_insert" INSTEAD OF INSERT ON "SingleCard" FOR EACH ROW EXECUTE PROCEDURE "SingleCard_DoInsert"();


--
-- Name: SingleCard_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "SingleCard_trigger_update" INSTEAD OF UPDATE ON "SingleCard" FOR EACH ROW EXECUTE PROCEDURE "SingleCard_DoUpdate"();


SET search_path = history, pg_catalog;

--
-- Name: Activity_trigger_insert; Type: TRIGGER; Schema: history; Owner: core
--

CREATE TRIGGER "Activity_trigger_insert" AFTER INSERT ON "Activity" FOR EACH ROW EXECUTE PROCEDURE "Activity_Insert_Statistics"();


SET search_path = core, pg_catalog;

--
-- Name: AccessSetsToAccessEntries_access_entry_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AccessSetsToAccessEntries"
    ADD CONSTRAINT "AccessSetsToAccessEntries_access_entry_id_fkey" FOREIGN KEY (access_entry_id) REFERENCES "AccessEntry"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: AccessSetsToAccessEntries_access_set_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AccessSetsToAccessEntries"
    ADD CONSTRAINT "AccessSetsToAccessEntries_access_set_id_fkey" FOREIGN KEY (access_set_id) REFERENCES "AccessSet"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: AccessSetsToTokens_access_set_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AccessSetsToTokens"
    ADD CONSTRAINT "AccessSetsToTokens_access_set_id_fkey" FOREIGN KEY (access_set_id) REFERENCES "AccessSet"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: AccessSetsToTokens_token_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AccessSetsToTokens"
    ADD CONSTRAINT "AccessSetsToTokens_token_id_fkey" FOREIGN KEY (token_id) REFERENCES "Token"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: Card_token_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "Card"
    ADD CONSTRAINT "Card_token_id_fkey" FOREIGN KEY (token_id) REFERENCES "Token"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: ReadersToAccessEntries_access_entry_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "ReadersToAccessEntries"
    ADD CONSTRAINT "ReadersToAccessEntries_access_entry_id_fkey" FOREIGN KEY (access_entry_id) REFERENCES "AccessEntry"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: ReadersToAccessEntries_reader_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "ReadersToAccessEntries"
    ADD CONSTRAINT "ReadersToAccessEntries_reader_id_fkey" FOREIGN KEY (reader_id) REFERENCES "Reader"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: RfidTag_token_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "RfidTag"
    ADD CONSTRAINT "RfidTag_token_id_fkey" FOREIGN KEY (token_id) REFERENCES "Token"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: SystemInformationItem_sysinfo_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "SystemInformationItem"
    ADD CONSTRAINT "SystemInformationItem_sysinfo_id_fkey" FOREIGN KEY (sysinfo_id) REFERENCES "SystemInformation"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: Token_personnel_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "Token"
    ADD CONSTRAINT "Token_personnel_id_fkey" FOREIGN KEY (personnel_id) REFERENCES "Personnel"(id) ON UPDATE CASCADE DEFERRABLE INITIALLY DEFERRED;


--
-- Name: Token_type_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "Token"
    ADD CONSTRAINT "Token_type_id_fkey" FOREIGN KEY (type_id) REFERENCES "TokenType"(id);


--
-- Name: Vehicle_personnel_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "Vehicle"
    ADD CONSTRAINT "Vehicle_personnel_id_fkey" FOREIGN KEY (personnel_id) REFERENCES "Personnel"(id) ON UPDATE CASCADE ON DELETE CASCADE;


SET search_path = extra, pg_catalog;

--
-- Name: AccessSet_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "AccessSet"
    ADD CONSTRAINT "AccessSet_id_fkey" FOREIGN KEY (id) REFERENCES core."AccessSet"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: AccessSet_notes_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "AccessSet"
    ADD CONSTRAINT "AccessSet_notes_id_fkey" FOREIGN KEY (notes_id) REFERENCES "Notes"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Blob_blob_type_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Blob"
    ADD CONSTRAINT "Blob_blob_type_id_fkey" FOREIGN KEY (type_id) REFERENCES core."BlobType"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Card_token_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Card"
    ADD CONSTRAINT "Card_token_id_fkey" FOREIGN KEY (token_id) REFERENCES core."Card"(token_id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: Personnel_fingerprint_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_fingerprint_id_fkey" FOREIGN KEY (fingerprint_id) REFERENCES "Blob"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Personnel_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_id_fkey" FOREIGN KEY (id) REFERENCES core."Personnel"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: Personnel_notes_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_notes_id_fkey" FOREIGN KEY (notes_id) REFERENCES "Notes"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Personnel_photo_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_photo_id_fkey" FOREIGN KEY (photo_id) REFERENCES "Blob"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Personnel_signature_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_signature_id_fkey" FOREIGN KEY (signature_id) REFERENCES "Blob"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Vehicle_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Vehicle"
    ADD CONSTRAINT "Vehicle_id_fkey" FOREIGN KEY (id) REFERENCES core."Vehicle"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: Vehicle_notes_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Vehicle"
    ADD CONSTRAINT "Vehicle_notes_id_fkey" FOREIGN KEY (notes_id) REFERENCES "Notes"(id) ON UPDATE CASCADE ON DELETE SET NULL;


SET search_path = history, pg_catalog;

--
-- Name: Activity_event_type_id_fkey; Type: FK CONSTRAINT; Schema: history; Owner: core
--

ALTER TABLE ONLY "Activity"
    ADD CONSTRAINT "Activity_event_type_id_fkey" FOREIGN KEY (event_type_id) REFERENCES "EventType"(id);


--
-- Name: ProjectChange_change_type_id_fkey; Type: FK CONSTRAINT; Schema: history; Owner: core
--

ALTER TABLE ONLY "ProjectChange"
    ADD CONSTRAINT "ProjectChange_change_type_id_fkey" FOREIGN KEY (change_type_id) REFERENCES "ChangeType"(id);


--
-- Name: core; Type: ACL; Schema: -; Owner: core
--

REVOKE ALL ON SCHEMA core FROM PUBLIC;
REVOKE ALL ON SCHEMA core FROM core;
GRANT ALL ON SCHEMA core TO core;
GRANT USAGE ON SCHEMA core TO extra WITH GRANT OPTION;


--
-- Name: extra; Type: ACL; Schema: -; Owner: extra
--

REVOKE ALL ON SCHEMA extra FROM PUBLIC;
REVOKE ALL ON SCHEMA extra FROM extra;
GRANT ALL ON SCHEMA extra TO extra;
GRANT ALL ON SCHEMA extra TO core WITH GRANT OPTION;


--
-- Name: history; Type: ACL; Schema: -; Owner: core
--

REVOKE ALL ON SCHEMA history FROM PUBLIC;
REVOKE ALL ON SCHEMA history FROM core;
GRANT ALL ON SCHEMA history TO core;


--
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM postgres;
GRANT ALL ON SCHEMA public TO postgres;
GRANT ALL ON SCHEMA public TO PUBLIC;


SET search_path = core, pg_catalog;

--
-- Name: AllPersonnel_DoDelete(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "AllPersonnel_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllPersonnel_DoDelete"() FROM core;
GRANT ALL ON FUNCTION "AllPersonnel_DoDelete"() TO core;
GRANT ALL ON FUNCTION "AllPersonnel_DoDelete"() TO extra;


--
-- Name: AllPersonnel_DoInsert(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "AllPersonnel_DoInsert"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllPersonnel_DoInsert"() FROM core;
GRANT ALL ON FUNCTION "AllPersonnel_DoInsert"() TO core;
GRANT ALL ON FUNCTION "AllPersonnel_DoInsert"() TO extra;


--
-- Name: AllPersonnel_DoUpdate(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "AllPersonnel_DoUpdate"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllPersonnel_DoUpdate"() FROM core;
GRANT ALL ON FUNCTION "AllPersonnel_DoUpdate"() TO core;
GRANT ALL ON FUNCTION "AllPersonnel_DoUpdate"() TO extra;


--
-- Name: CanSwitchToSingleId(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "CanSwitchToSingleId"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CanSwitchToSingleId"() FROM core;
GRANT ALL ON FUNCTION "CanSwitchToSingleId"() TO core;
GRANT ALL ON FUNCTION "CanSwitchToSingleId"() TO extra;


--
-- Name: CardToken_DoDelete(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "CardToken_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoDelete"() FROM core;
GRANT ALL ON FUNCTION "CardToken_DoDelete"() TO core;


--
-- Name: CardToken_DoInsert(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "CardToken_DoInsert"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoInsert"() FROM core;
GRANT ALL ON FUNCTION "CardToken_DoInsert"() TO core;
GRANT ALL ON FUNCTION "CardToken_DoInsert"() TO extra;


--
-- Name: CardToken_DoUpdate(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "CardToken_DoUpdate"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoUpdate"() FROM core;
GRANT ALL ON FUNCTION "CardToken_DoUpdate"() TO core;
GRANT ALL ON FUNCTION "CardToken_DoUpdate"() TO extra;


--
-- Name: Personnel_Delete(uuid, character varying); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "Personnel_Delete"(personnel_id uuid, username character varying) FROM PUBLIC;
REVOKE ALL ON FUNCTION "Personnel_Delete"(personnel_id uuid, username character varying) FROM core;
GRANT ALL ON FUNCTION "Personnel_Delete"(personnel_id uuid, username character varying) TO core;
GRANT ALL ON FUNCTION "Personnel_Delete"(personnel_id uuid, username character varying) TO extra;


--
-- Name: Token_Delete(uuid, character varying); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "Token_Delete"(token_id uuid, username character varying) FROM PUBLIC;
REVOKE ALL ON FUNCTION "Token_Delete"(token_id uuid, username character varying) FROM core;
GRANT ALL ON FUNCTION "Token_Delete"(token_id uuid, username character varying) TO core;
GRANT ALL ON FUNCTION "Token_Delete"(token_id uuid, username character varying) TO extra;


SET search_path = extra, pg_catalog;

--
-- Name: AllAccessSet_DoDelete(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "AllAccessSet_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllAccessSet_DoDelete"() FROM extra;
GRANT ALL ON FUNCTION "AllAccessSet_DoDelete"() TO extra;
GRANT ALL ON FUNCTION "AllAccessSet_DoDelete"() TO core;


--
-- Name: AllVehicle_DoDelete(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "AllVehicle_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllVehicle_DoDelete"() FROM extra;
GRANT ALL ON FUNCTION "AllVehicle_DoDelete"() TO extra;
GRANT ALL ON FUNCTION "AllVehicle_DoDelete"() TO core;


--
-- Name: CardToken_DoDelete(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "CardToken_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoDelete"() FROM extra;
GRANT ALL ON FUNCTION "CardToken_DoDelete"() TO extra;
GRANT ALL ON FUNCTION "CardToken_DoDelete"() TO core;


--
-- Name: CardToken_DoInsert(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "CardToken_DoInsert"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoInsert"() FROM extra;
GRANT ALL ON FUNCTION "CardToken_DoInsert"() TO extra;
GRANT ALL ON FUNCTION "CardToken_DoInsert"() TO core;


--
-- Name: CardToken_DoUpdate(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "CardToken_DoUpdate"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoUpdate"() FROM extra;
GRANT ALL ON FUNCTION "CardToken_DoUpdate"() TO extra;
GRANT ALL ON FUNCTION "CardToken_DoUpdate"() TO core;


--
-- Name: MultiCard_DoDelete(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "MultiCard_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "MultiCard_DoDelete"() FROM extra;
GRANT ALL ON FUNCTION "MultiCard_DoDelete"() TO extra;
GRANT ALL ON FUNCTION "MultiCard_DoDelete"() TO core;


--
-- Name: MultiCard_DoInsert(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "MultiCard_DoInsert"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "MultiCard_DoInsert"() FROM extra;
GRANT ALL ON FUNCTION "MultiCard_DoInsert"() TO extra;
GRANT ALL ON FUNCTION "MultiCard_DoInsert"() TO core;


--
-- Name: MultiCard_DoUpdate(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "MultiCard_DoUpdate"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "MultiCard_DoUpdate"() FROM extra;
GRANT ALL ON FUNCTION "MultiCard_DoUpdate"() TO extra;
GRANT ALL ON FUNCTION "MultiCard_DoUpdate"() TO core;


--
-- Name: SingleCard_DoDelete(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "SingleCard_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "SingleCard_DoDelete"() FROM extra;
GRANT ALL ON FUNCTION "SingleCard_DoDelete"() TO extra;
GRANT ALL ON FUNCTION "SingleCard_DoDelete"() TO core;


--
-- Name: SingleCard_DoInsert(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "SingleCard_DoInsert"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "SingleCard_DoInsert"() FROM extra;
GRANT ALL ON FUNCTION "SingleCard_DoInsert"() TO extra;
GRANT ALL ON FUNCTION "SingleCard_DoInsert"() TO core;


--
-- Name: SingleCard_DoUpdate(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "SingleCard_DoUpdate"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "SingleCard_DoUpdate"() FROM extra;
GRANT ALL ON FUNCTION "SingleCard_DoUpdate"() TO extra;
GRANT ALL ON FUNCTION "SingleCard_DoUpdate"() TO core;


SET search_path = history, pg_catalog;

--
-- Name: Activity_Insert_Statistics(); Type: ACL; Schema: history; Owner: core
--

REVOKE ALL ON FUNCTION "Activity_Insert_Statistics"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "Activity_Insert_Statistics"() FROM core;
GRANT ALL ON FUNCTION "Activity_Insert_Statistics"() TO core;
GRANT ALL ON FUNCTION "Activity_Insert_Statistics"() TO extra;


SET search_path = core, pg_catalog;

--
-- Name: AccessEntry; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "AccessEntry" FROM PUBLIC;
REVOKE ALL ON TABLE "AccessEntry" FROM core;
GRANT ALL ON TABLE "AccessEntry" TO core;


--
-- Name: AccessSet; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "AccessSet" FROM PUBLIC;
REVOKE ALL ON TABLE "AccessSet" FROM core;
GRANT ALL ON TABLE "AccessSet" TO core;
GRANT SELECT,INSERT,REFERENCES,DELETE,TRIGGER,UPDATE ON TABLE "AccessSet" TO extra WITH GRANT OPTION;


--
-- Name: AccessSetsToAccessEntries; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "AccessSetsToAccessEntries" FROM PUBLIC;
REVOKE ALL ON TABLE "AccessSetsToAccessEntries" FROM core;
GRANT ALL ON TABLE "AccessSetsToAccessEntries" TO core;


--
-- Name: AccessSetsToTokens; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "AccessSetsToTokens" FROM PUBLIC;
REVOKE ALL ON TABLE "AccessSetsToTokens" FROM core;
GRANT ALL ON TABLE "AccessSetsToTokens" TO core;


--
-- Name: Personnel; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL ON TABLE "Personnel" FROM core;
GRANT ALL ON TABLE "Personnel" TO core;


--
-- Name: Personnel.id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(id) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(id) ON TABLE "Personnel" FROM core;
GRANT SELECT(id),REFERENCES(id) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.name_last; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(name_last) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(name_last) ON TABLE "Personnel" FROM core;
GRANT SELECT(name_last) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.name_first; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(name_first) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(name_first) ON TABLE "Personnel" FROM core;
GRANT SELECT(name_first) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.user_level; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(user_level) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(user_level) ON TABLE "Personnel" FROM core;
GRANT SELECT(user_level) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.days_to_log; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(days_to_log) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(days_to_log) ON TABLE "Personnel" FROM core;
GRANT SELECT(days_to_log) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.apb_type_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(apb_type_id) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(apb_type_id) ON TABLE "Personnel" FROM core;
GRANT SELECT(apb_type_id) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.apb_zone_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(apb_zone_id) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(apb_zone_id) ON TABLE "Personnel" FROM core;
GRANT SELECT(apb_zone_id) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.apb_violations; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(apb_violations) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(apb_violations) ON TABLE "Personnel" FROM core;
GRANT SELECT(apb_violations) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.created; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(created) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(created) ON TABLE "Personnel" FROM core;
GRANT SELECT(created) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.created_by; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(created_by) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(created_by) ON TABLE "Personnel" FROM core;
GRANT SELECT(created_by) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.updated; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(updated) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(updated) ON TABLE "Personnel" FROM core;
GRANT SELECT(updated) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.updated_by; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(updated_by) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(updated_by) ON TABLE "Personnel" FROM core;
GRANT SELECT(updated_by) ON TABLE "Personnel" TO extra;


--
-- Name: AllPersonnel; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "AllPersonnel" FROM PUBLIC;
REVOKE ALL ON TABLE "AllPersonnel" FROM core;
GRANT ALL ON TABLE "AllPersonnel" TO core;
GRANT SELECT,INSERT,REFERENCES,DELETE,UPDATE ON TABLE "AllPersonnel" TO extra WITH GRANT OPTION;


--
-- Name: BlobType; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "BlobType" FROM PUBLIC;
REVOKE ALL ON TABLE "BlobType" FROM core;
GRANT ALL ON TABLE "BlobType" TO core;
GRANT SELECT,REFERENCES ON TABLE "BlobType" TO extra WITH GRANT OPTION;


--
-- Name: Card; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "Card" FROM PUBLIC;
REVOKE ALL ON TABLE "Card" FROM core;
GRANT ALL ON TABLE "Card" TO core;


--
-- Name: Card.token_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(token_id) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(token_id) ON TABLE "Card" FROM core;
GRANT SELECT(token_id),REFERENCES(token_id) ON TABLE "Card" TO extra;


--
-- Name: Card.card_number; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(card_number) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(card_number) ON TABLE "Card" FROM core;
GRANT SELECT(card_number) ON TABLE "Card" TO extra;


--
-- Name: Card.site_code; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(site_code) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(site_code) ON TABLE "Card" FROM core;
GRANT SELECT(site_code) ON TABLE "Card" TO extra;


--
-- Name: Card.card_format; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(card_format) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(card_format) ON TABLE "Card" FROM core;
GRANT SELECT(card_format) ON TABLE "Card" TO extra;


--
-- Name: Card.card_type; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(card_type) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(card_type) ON TABLE "Card" FROM core;
GRANT SELECT(card_type) ON TABLE "Card" TO extra;


--
-- Name: Card.pin_number; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(pin_number) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(pin_number) ON TABLE "Card" FROM core;
GRANT SELECT(pin_number) ON TABLE "Card" TO extra;


--
-- Name: Card.card_valid; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(card_valid) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(card_valid) ON TABLE "Card" FROM core;
GRANT SELECT(card_valid) ON TABLE "Card" TO extra;


--
-- Name: Card.activate_date; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(activate_date) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(activate_date) ON TABLE "Card" FROM core;
GRANT SELECT(activate_date) ON TABLE "Card" TO extra;


--
-- Name: Card.deactivate_date; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(deactivate_date) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(deactivate_date) ON TABLE "Card" FROM core;
GRANT SELECT(deactivate_date) ON TABLE "Card" TO extra;


--
-- Name: Card.secondary_expiration_date; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(secondary_expiration_date) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(secondary_expiration_date) ON TABLE "Card" FROM core;
GRANT SELECT(secondary_expiration_date) ON TABLE "Card" TO extra;


--
-- Name: Card.expire_days; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(expire_days) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(expire_days) ON TABLE "Card" FROM core;
GRANT SELECT(expire_days) ON TABLE "Card" TO extra;


--
-- Name: Card.action_point_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(action_point_id) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(action_point_id) ON TABLE "Card" FROM core;
GRANT SELECT(action_point_id) ON TABLE "Card" TO extra;


--
-- Name: Card.threat_level; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(threat_level) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(threat_level) ON TABLE "Card" FROM core;
GRANT SELECT(threat_level) ON TABLE "Card" TO extra;


--
-- Name: Card.auto_disable; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(auto_disable) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(auto_disable) ON TABLE "Card" FROM core;
GRANT SELECT(auto_disable) ON TABLE "Card" TO extra;


--
-- Name: Card.grant_long_access_time; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(grant_long_access_time) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(grant_long_access_time) ON TABLE "Card" FROM core;
GRANT SELECT(grant_long_access_time) ON TABLE "Card" TO extra;


--
-- Name: Card.escort_visitor_capable; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(escort_visitor_capable) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(escort_visitor_capable) ON TABLE "Card" FROM core;
GRANT SELECT(escort_visitor_capable) ON TABLE "Card" TO extra;


--
-- Name: Card.access_cost_override_capable; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(access_cost_override_capable) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(access_cost_override_capable) ON TABLE "Card" FROM core;
GRANT SELECT(access_cost_override_capable) ON TABLE "Card" TO extra;


--
-- Name: Card.event_lock_override_capable; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(event_lock_override_capable) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(event_lock_override_capable) ON TABLE "Card" FROM core;
GRANT SELECT(event_lock_override_capable) ON TABLE "Card" TO extra;


--
-- Name: Card.building_passback_exemption; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(building_passback_exemption) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(building_passback_exemption) ON TABLE "Card" FROM core;
GRANT SELECT(building_passback_exemption) ON TABLE "Card" TO extra;


--
-- Name: Card.parking_passback_exemption; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(parking_passback_exemption) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(parking_passback_exemption) ON TABLE "Card" FROM core;
GRANT SELECT(parking_passback_exemption) ON TABLE "Card" TO extra;


--
-- Name: Card.card_holder_groups; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(card_holder_groups) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(card_holder_groups) ON TABLE "Card" FROM core;
GRANT SELECT(card_holder_groups) ON TABLE "Card" TO extra;


--
-- Name: Card.activation_group; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(activation_group) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(activation_group) ON TABLE "Card" FROM core;
GRANT SELECT(activation_group) ON TABLE "Card" TO extra;


--
-- Name: Card.on_access_output; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(on_access_output) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(on_access_output) ON TABLE "Card" FROM core;
GRANT SELECT(on_access_output) ON TABLE "Card" TO extra;


--
-- Name: Card.compass_command_group; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(compass_command_group) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(compass_command_group) ON TABLE "Card" FROM core;
GRANT SELECT(compass_command_group) ON TABLE "Card" TO extra;


--
-- Name: Card.low_battery; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(low_battery) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(low_battery) ON TABLE "Card" FROM core;
GRANT REFERENCES(low_battery) ON TABLE "Card" TO extra;


--
-- Name: Token; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "Token" FROM PUBLIC;
REVOKE ALL ON TABLE "Token" FROM core;
GRANT ALL ON TABLE "Token" TO core;


--
-- Name: Token.id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(id) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(id) ON TABLE "Token" FROM core;
GRANT SELECT(id),REFERENCES(id) ON TABLE "Token" TO extra;


--
-- Name: Token.user_level; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(user_level) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(user_level) ON TABLE "Token" FROM core;
GRANT SELECT(user_level) ON TABLE "Token" TO extra;


--
-- Name: Token.personnel_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(personnel_id) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(personnel_id) ON TABLE "Token" FROM core;
GRANT SELECT(personnel_id) ON TABLE "Token" TO extra;


--
-- Name: Token.badge_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(badge_id) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(badge_id) ON TABLE "Token" FROM core;
GRANT SELECT(badge_id) ON TABLE "Token" TO extra;


--
-- Name: Token.lost; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(lost) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(lost) ON TABLE "Token" FROM core;
GRANT SELECT(lost) ON TABLE "Token" TO extra;


--
-- Name: Token.last_read; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(last_read) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(last_read) ON TABLE "Token" FROM core;
GRANT SELECT(last_read) ON TABLE "Token" TO extra;


--
-- Name: Token.last_reader; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(last_reader) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(last_reader) ON TABLE "Token" FROM core;
GRANT SELECT(last_reader) ON TABLE "Token" TO extra;


--
-- Name: Token.last_read_status; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(last_read_status) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(last_read_status) ON TABLE "Token" FROM core;
GRANT SELECT(last_read_status) ON TABLE "Token" TO extra;


--
-- Name: Token.created; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(created) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(created) ON TABLE "Token" FROM core;
GRANT SELECT(created) ON TABLE "Token" TO extra;


--
-- Name: Token.created_by; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(created_by) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(created_by) ON TABLE "Token" FROM core;
GRANT SELECT(created_by) ON TABLE "Token" TO extra;


--
-- Name: Token.updated; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(updated) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(updated) ON TABLE "Token" FROM core;
GRANT SELECT(updated) ON TABLE "Token" TO extra;


--
-- Name: Token.updated_by; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(updated_by) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(updated_by) ON TABLE "Token" FROM core;
GRANT SELECT(updated_by) ON TABLE "Token" TO extra;


--
-- Name: Token.download_required; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(download_required) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(download_required) ON TABLE "Token" FROM core;
GRANT SELECT(download_required) ON TABLE "Token" TO extra WITH GRANT OPTION;


--
-- Name: CardDownload; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "CardDownload" FROM PUBLIC;
REVOKE ALL ON TABLE "CardDownload" FROM core;
GRANT ALL ON TABLE "CardDownload" TO core;


--
-- Name: CardToken; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "CardToken" FROM PUBLIC;
REVOKE ALL ON TABLE "CardToken" FROM core;
GRANT ALL ON TABLE "CardToken" TO core;
GRANT SELECT,INSERT,REFERENCES,DELETE,UPDATE ON TABLE "CardToken" TO extra WITH GRANT OPTION;


--
-- Name: PersonnelTokenCounts; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "PersonnelTokenCounts" FROM PUBLIC;
REVOKE ALL ON TABLE "PersonnelTokenCounts" FROM core;
GRANT ALL ON TABLE "PersonnelTokenCounts" TO core;
GRANT SELECT,INSERT,REFERENCES,DELETE,UPDATE ON TABLE "PersonnelTokenCounts" TO extra WITH GRANT OPTION;


--
-- Name: PersonnelWithSingleCard; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "PersonnelWithSingleCard" FROM PUBLIC;
REVOKE ALL ON TABLE "PersonnelWithSingleCard" FROM core;
GRANT ALL ON TABLE "PersonnelWithSingleCard" TO core;
GRANT SELECT,INSERT,REFERENCES,DELETE,UPDATE ON TABLE "PersonnelWithSingleCard" TO extra WITH GRANT OPTION;


--
-- Name: RfidTag; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "RfidTag" FROM PUBLIC;
REVOKE ALL ON TABLE "RfidTag" FROM core;
GRANT ALL ON TABLE "RfidTag" TO core;


--
-- Name: RfidTag.token_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(token_id) ON TABLE "RfidTag" FROM PUBLIC;
REVOKE ALL(token_id) ON TABLE "RfidTag" FROM core;
GRANT SELECT(token_id),REFERENCES(token_id) ON TABLE "RfidTag" TO extra;


--
-- Name: RfidTag.tag_number; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(tag_number) ON TABLE "RfidTag" FROM PUBLIC;
REVOKE ALL(tag_number) ON TABLE "RfidTag" FROM core;
GRANT SELECT(tag_number) ON TABLE "RfidTag" TO extra;


--
-- Name: TokenType; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "TokenType" FROM PUBLIC;
REVOKE ALL ON TABLE "TokenType" FROM core;
GRANT ALL ON TABLE "TokenType" TO core;
GRANT SELECT,REFERENCES ON TABLE "TokenType" TO extra WITH GRANT OPTION;


--
-- Name: TokenType_id_seq; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON SEQUENCE "TokenType_id_seq" FROM PUBLIC;
REVOKE ALL ON SEQUENCE "TokenType_id_seq" FROM core;
GRANT ALL ON SEQUENCE "TokenType_id_seq" TO core;


--
-- PostgreSQL database dump complete
--

