--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET lock_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SET check_function_bodies = false;
SET client_min_messages = warning;

--
-- Name: core; Type: SCHEMA; Schema: -; Owner: core
--

CREATE SCHEMA core;


ALTER SCHEMA core OWNER TO core;

--
-- Name: extra; Type: SCHEMA; Schema: -; Owner: extra
--

CREATE SCHEMA extra;


ALTER SCHEMA extra OWNER TO extra;

--
-- Name: history; Type: SCHEMA; Schema: -; Owner: core
--

CREATE SCHEMA history;


ALTER SCHEMA history OWNER TO core;

--
-- Name: plpgsql; Type: EXTENSION; Schema: -; Owner: 
--

CREATE EXTENSION IF NOT EXISTS plpgsql WITH SCHEMA pg_catalog;


--
-- Name: EXTENSION plpgsql; Type: COMMENT; Schema: -; Owner: 
--

COMMENT ON EXTENSION plpgsql IS 'PL/pgSQL procedural language';


--
-- Name: uuid-ossp; Type: EXTENSION; Schema: -; Owner: 
--

CREATE EXTENSION IF NOT EXISTS "uuid-ossp" WITH SCHEMA public;


--
-- Name: EXTENSION "uuid-ossp"; Type: COMMENT; Schema: -; Owner: 
--

COMMENT ON EXTENSION "uuid-ossp" IS 'generate universally unique identifiers (UUIDs)';


SET search_path = core, pg_catalog;

--
-- Name: AllPersonnel_DoDelete(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "AllPersonnel_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	username character varying(255);
BEGIN
	username := CURRENT_USER;

	IF core."Personnel_Delete"(OLD.id, username) THEN
		RETURN OLD;
	END IF;

	RETURN NULL;
END;
$$;


ALTER FUNCTION core."AllPersonnel_DoDelete"() OWNER TO core;

--
-- Name: AllPersonnel_DoInsert(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "AllPersonnel_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF NEW.id IS NULL THEN
		NEW.id := uuid_generate_v4();
	END IF;
	
	IF NEW.created IS NULL THEN
		NEW.created := CURRENT_TIMESTAMP;
	END IF;
	
	IF NEW.created_by IS NULL THEN
		NEW.created_by := CURRENT_USER;
	END IF;

	INSERT INTO core."Personnel" (
		id,
		name_last,
		name_first,
		user_level,
		days_to_log,
		apb_type_id,
		apb_zone_id,
		apb_violations,
		created,
		created_by,
		updated,
		updated_by)
	VALUES (
		NEW.id,
		NEW.name_last,
		NEW.name_first,
		NEW.user_level,
		NEW.days_to_log,
		NEW.apb_type_id,
		NEW.apb_zone_id,
		NEW.apb_violations,
		NEW.created,
		NEW.created_by,
		NEW.updated,
		NEW.updated_by);

	RETURN NEW;
END;
$$;


ALTER FUNCTION core."AllPersonnel_DoInsert"() OWNER TO core;

--
-- Name: AllPersonnel_DoUpdate(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "AllPersonnel_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.id := OLD.id;

	IF NEW.updated IS NULL THEN
		NEW.updated := CURRENT_TIMESTAMP;
	END IF;

	IF NEW.updated_by IS NULL THEN
		NEW.updated_by := CURRENT_USER;
	END IF;

	UPDATE core."Personnel" SET
		name_last = NEW.name_last,
		name_first = NEW.name_first,
		user_level = NEW.user_level,
		days_to_log = NEW.days_to_log,
		apb_type_id = NEW.apb_type_id,
		apb_zone_id = NEW.apb_zone_id,
		apb_violations = NEW.apb_violations,
		updated = NEW.updated,
		updated_by = NEW.updated_by
	WHERE id = OLD.id 
		AND deleted IS NULL;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION core."AllPersonnel_DoUpdate"() OWNER TO core;

--
-- Name: CanSwitchToSingleId(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "CanSwitchToSingleId"() RETURNS boolean
    LANGUAGE sql
    AS $$
SELECT NOT EXISTS (
	SELECT count(*) AS count
	FROM core."Personnel" AS cp
	LEFT JOIN core."Token" AS ct ON cp.id = ct.personnel_id AND ct.type_id = 1 AND ct.deleted IS NULL
	WHERE cp.deleted IS NULL
	GROUP BY cp.id
	HAVING count(*) <> 1
);
$$;


ALTER FUNCTION core."CanSwitchToSingleId"() OWNER TO core;

--
-- Name: CardToken_DoDelete(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "CardToken_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	username character varying(255);
BEGIN
	username := CURRENT_USER;

	IF core."Token_Delete"(OLD.token_id, username) THEN
		RETURN OLD;
	END IF;

	RETURN NULL;
END;
$$;


ALTER FUNCTION core."CardToken_DoDelete"() OWNER TO core;

--
-- Name: CardToken_DoInsert(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "CardToken_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	token_type_id smallint;
BEGIN
	IF NEW.token_id IS NULL THEN
		NEW.token_id := uuid_generate_v4();
	END IF;

	token_type_id := 1;

	IF NEW.site_code IS NULL THEN
		NEW.site_code := 0;
	END IF;

	IF NEW.card_format IS NULL THEN
		NEW.card_format := 26;
	END IF;

	IF NEW.activate_date IS NULL THEN
		NEW.activate_date := CURRENT_DATE;
	END IF;

	IF NEW.deactivate_date IS NULL THEN
		NEW.deactivate_date := CURRENT_DATE + '1 year'::interval;
	END IF;

	IF NEW.lost IS NULL THEN
		NEW.lost := false;
	END IF;

	IF NEW.created IS NULL THEN
		NEW.created := CURRENT_TIMESTAMP;
	END IF;

	IF NEW.created_by IS NULL THEN
		NEW.created_by := CURRENT_USER;
	END IF;

	INSERT INTO core."Token" (
		id,
		type_id,
		user_level,
		personnel_id,
		badge_id,
		lost,
		last_read,
		last_reader,
		last_read_status,
		created,
		created_by,
		updated,
		updated_by,
		downloaded,
		downloaded_by,
		download_required)
	VALUES (
		NEW.token_id,
		token_type_id,
		NEW.user_level,
		NEW.personnel_id,
		NEW.badge_id,
		NEW.lost,
		NEW.last_read,
		NEW.last_reader,
		NEW.last_read_status,
		NEW.created,
		NEW.created_by,
		NEW.updated,
		NEW.updated_by,
		NEW.downloaded,
		NEW.downloaded_by,
		NEW.download_required);

	INSERT INTO core."Card" (
		token_id,
		card_number,
		site_code,
		card_format,
		card_type,
		pin_number,
		card_valid,
		activate_date,
		deactivate_date,
		secondary_expiration_date,
		expire_days,
		action_point_id,
		threat_level,
		auto_disable,
		grant_long_access_time,
		escort_visitor_capable,
		access_cost_override_capable,
		event_lock_override_capable,
		building_passback_exemption,
		parking_passback_exemption,
		card_holder_groups,
		activation_group,
		on_access_output,
		compass_command_group,
		low_battery)
	VALUES (
		NEW.token_id,
		NEW.card_number,
		NEW.site_code,
		NEW.card_format,
		NEW.card_type,
		NEW.pin_number,
		NEW.card_valid,
		NEW.activate_date,
		NEW.deactivate_date,
		NEW.secondary_expiration_date,
		NEW.expire_days,
		NEW.action_point_id,
		NEW.threat_level,
		NEW.auto_disable,
		NEW.grant_long_access_time,
		NEW.escort_visitor_capable,
		NEW.access_cost_override_capable,
		NEW.event_lock_override_capable,
		NEW.building_passback_exemption,
		NEW.parking_passback_exemption,
		NEW.card_holder_groups,
		NEW.activation_group,
		NEW.on_access_output,
		NEW.compass_command_group,
		NEW.low_battery);

	RETURN NEW;
END;
$$;


ALTER FUNCTION core."CardToken_DoInsert"() OWNER TO core;

--
-- Name: CardToken_DoUpdate(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "CardToken_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.token_id := OLD.token_id;

	IF NEW.updated IS NULL THEN
		NEW.updated := CURRENT_TIMESTAMP;
	END IF;

	IF NEW.updated_by IS NULL THEN
		NEW.updated_by := CURRENT_USER;
	END IF;

	UPDATE core."Token" SET
		user_level = NEW.user_level,
		personnel_id = NEW.personnel_id,
		badge_id = NEW.badge_id,
		lost = NEW.lost,
		last_read = NEW.last_read,
		last_reader = NEW.last_reader,
		last_read_status = NEW.last_read_status,
		updated = NEW.updated,
		updated_by = NEW.updated_by,
		downloaded = NEW.downloaded,
		downloaded_by = NEW.downloaded_by,
		download_required = NEW.download_required
	WHERE id = OLD.token_id
		AND deleted IS NULL;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	UPDATE core."Card" SET 
		card_number = NEW.card_number,
		site_code = NEW.site_code,
		card_format = NEW.card_format,
		card_type = NEW.card_type,
		pin_number = NEW.pin_number,
		card_valid = NEW.card_valid,
		activate_date = NEW.activate_date,
		deactivate_date = NEW.deactivate_date,
		secondary_expiration_date = NEW.secondary_expiration_date,
		expire_days = NEW.expire_days,
		action_point_id = NEW.action_point_id,
		threat_level = NEW.threat_level,
		auto_disable = NEW.auto_disable,
		grant_long_access_time = NEW.grant_long_access_time,
		escort_visitor_capable = NEW.escort_visitor_capable,
		access_cost_override_capable = NEW.access_cost_override_capable,
		event_lock_override_capable = NEW.event_lock_override_capable,
		building_passback_exemption = NEW.building_passback_exemption,
		parking_passback_exemption = NEW.parking_passback_exemption,
		card_holder_groups = NEW.card_holder_groups,
		activation_group = NEW.activation_group,
		on_access_output = NEW.on_access_output,
		compass_command_group = NEW.compass_command_group,
		low_battery = NEW.low_battery
	WHERE token_id = OLD.token_id;

	RETURN NEW;
END;
$$;


ALTER FUNCTION core."CardToken_DoUpdate"() OWNER TO core;

--
-- Name: Personnel_Delete(uuid, character varying); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "Personnel_Delete"(personnel_id uuid, username character varying) RETURNS boolean
    LANGUAGE plpgsql
    AS $_$
DECLARE
	delete_personnel_id ALIAS FOR $1;
	result boolean := false;
	deleted_ts timestamp with time zone;
	deleted_token_id uuid := NULL;
	rec RECORD;
BEGIN
	IF username IS NULL THEN
		username := CURRENT_USER;
	END IF;

	deleted_ts := CURRENT_TIMESTAMP;

	FOR rec in select name_first, name_last, name_middle, assigned_to, card_number, site_code, card_format, room 
	FROM extra."MultiCard" where extra."MultiCard".personnel_id = delete_personnel_id
	LOOP
	IF rec.card_number <= 256 and rec.site_code = 0 and rec.card_format = 26 THEN
	Insert into history."AccutechTagChange" (
				change_time, 
				event, 
				card_number,
				name_first,
				name_last,
				name_middle,
				assigned_to, 
				updated_by,
				room) 
				VALUES (
				NOW(),
				5037,
				rec.card_number,
				rec.name_first,
				rec.name_last,
				rec.name_middle,
				rec.assigned_to,
				username,
				rec.room);
	END IF;
	END LOOP;
	
	WITH deletedTokens AS (
		UPDATE core."Token" AS token SET
			deleted = deleted_ts,
			deleted_by = username
		WHERE token.personnel_id = delete_personnel_id AND token.deleted IS NULL
		RETURNING token.id
	)
	UPDATE core."Card" AS card SET
		deleted = deleted_ts
	WHERE card.token_id IN (SELECT id FROM deletedTokens);

	UPDATE core."Personnel" AS personnel SET
		deleted = deleted_ts,
		deleted_by = username
	WHERE personnel.id = delete_personnel_id AND personnel.deleted IS NULL;

	IF FOUND THEN
		result := true;
	END IF;
	
	RETURN result;
END;
$_$;


ALTER FUNCTION core."Personnel_Delete"(personnel_id uuid, username character varying) OWNER TO core;

--
-- Name: Token_Delete(uuid, character varying); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "Token_Delete"(token_id uuid, username character varying) RETURNS boolean
    LANGUAGE plpgsql
    AS $_$
DECLARE
	result boolean := false;
	deleted_ts timestamp with time zone;
	deleted_token_id uuid := NULL;
BEGIN
	IF username IS NULL THEN
		username := CURRENT_USER;
	END IF;

	deleted_ts := CURRENT_TIMESTAMP;

	UPDATE core."Token" AS token SET
		deleted = deleted_ts,
		deleted_by = username
	WHERE token.id = $1 AND token.deleted IS NULL
	RETURNING token.id INTO deleted_token_id;

	IF deleted_token_id IS NOT NULL THEN
		result := true;
		UPDATE core."Card" AS card SET
			deleted = deleted_ts
		WHERE card.token_id = deleted_token_id;
	END IF;

	RETURN result;
END;
$_$;


ALTER FUNCTION core."Token_Delete"(token_id uuid, username character varying) OWNER TO core;

--
-- Name: datediff(character varying, timestamp without time zone, timestamp without time zone); Type: FUNCTION; Schema: core; Owner: postgres
--

CREATE FUNCTION datediff(units character varying, start_t timestamp without time zone, end_t timestamp without time zone) RETURNS integer
    LANGUAGE plpgsql
    AS $$
   DECLARE
     diff_interval INTERVAL; 
     diff INT = 0;
     years_diff INT = 0;
   BEGIN
     IF units IN ('yy', 'yyyy', 'year', 'mm', 'm', 'month') THEN
       years_diff = DATE_PART('year', end_t) - DATE_PART('year', start_t);
 
       IF units IN ('yy', 'yyyy', 'year') THEN
         -- SQL Server does not count full years passed (only difference between year parts)
         RETURN years_diff;
       ELSE
         -- If end month is less than start month it will subtracted
         RETURN years_diff * 12 + (DATE_PART('month', end_t) - DATE_PART('month', start_t)); 
       END IF;
     END IF;
 
     -- Minus operator returns interval 'DDD days HH:MI:SS'  
     diff_interval = end_t - start_t;
 
     diff = diff + DATE_PART('day', diff_interval);
 
     IF units IN ('wk', 'ww', 'week') THEN
       diff = diff/7;
       RETURN diff;
     END IF;
 
     IF units IN ('dd', 'd', 'day') THEN
       RETURN diff;
     END IF;
 
     diff = diff * 24 + DATE_PART('hour', diff_interval); 
 
     IF units IN ('hh', 'hour') THEN
        RETURN diff;
     END IF;
 
     diff = diff * 60 + DATE_PART('minute', diff_interval);
 
     IF units IN ('mi', 'n', 'minute') THEN
        RETURN diff;
     END IF;
 
     diff = diff * 60 + DATE_PART('second', diff_interval);
 
     RETURN diff;
   END;
   $$;


ALTER FUNCTION core.datediff(units character varying, start_t timestamp without time zone, end_t timestamp without time zone) OWNER TO postgres;

SET search_path = extra, pg_catalog;

--
-- Name: AllAccessSet_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllAccessSet_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."AccessSet"
	WHERE id = OLD.id;

	IF FOUND THEN
		extra_found := true;
	END IF;

	IF OLD.notes_id IS NOT NULL THEN
		DELETE FROM extra."Notes" WHERE id = OLD.notes_id;
	END IF;
	
	DELETE FROM core."AccessSet"
	WHERE id = OLD.id;

	IF NOT FOUND AND NOT extra_found THEN
		RETURN NULL;
	END IF;
	
	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."AllAccessSet_DoDelete"() OWNER TO extra;

--
-- Name: AllAccessSet_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllAccessSet_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF NEW.id IS NULL THEN
		NEW.id := uuid_generate_v4();
	END IF;

	INSERT INTO core."AccessSet" (
		id,
		name,
		user_level,
		download_required)
	VALUES (
		NEW.id,
		NEW.name,
		NEW.user_level,
		NEW.download_required);

	NEW.notes_id := extra."Notes_InsertOrUpdate"(NEW.notes_id, NEW.notes);

	INSERT INTO extra."AccessSet" (
		id,
		notes_id)
	VALUES (
		NEW.id,
		NEW.notes_id);

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllAccessSet_DoInsert"() OWNER TO extra;

--
-- Name: AllAccessSet_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllAccessSet_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.id := OLD.id;

	UPDATE core."AccessSet" SET
		name = NEW.name,
		user_level = NEW.user_level,
		download_required = NEW.download_required
	WHERE id = OLD.id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	NEW.notes_id := extra."Notes_Update"(OLD.notes_id, NEW.notes_id, NEW.notes);

	UPDATE extra."AccessSet" SET
		notes_id = NEW.notes_id
	WHERE id = OLD.id;

	IF NOT FOUND THEN
		INSERT INTO extra."AccessSet" (
			id,
			notes_id)
		VALUES (
			NEW.id,
			NEW.notes_id);
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllAccessSet_DoUpdate"() OWNER TO extra;

--
-- Name: AllPersonnel_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllPersonnel_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."Personnel"
	WHERE id = OLD.id;

	IF FOUND THEN
		extra_found := true;
	END IF;

	IF OLD.notes_id IS NOT NULL THEN
		DELETE FROM extra."Notes" WHERE id = OLD.notes_id;
	END IF;

	IF OLD.photo_id IS NOT NULL THEN
		DELETE FROM extra."Blob" WHERE id = OLD.photo_id;
	END IF;

	IF OLD.signature_id IS NOT NULL THEN
		DELETE FROM extra."Blob" WHERE id = OLD.signature_id;
	END IF;

	IF OLD.fingerprint_id IS NOT NULL THEN
		DELETE FROM extra."Blob" WHERE id = OLD.fingerprint_id;
	END IF;

	DELETE FROM core."AllPersonnel"
	WHERE id = OLD.id;

	IF NOT FOUND AND NOT extra_found THEN
		RETURN NULL;
	END IF;

	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."AllPersonnel_DoDelete"() OWNER TO extra;

--
-- Name: AllPersonnel_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllPersonnel_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF NEW.id IS NULL THEN
		NEW.id := uuid_generate_v4();
	END IF;

	INSERT INTO core."AllPersonnel" (
		id,
		name_last,
		name_first,
		user_level,
		days_to_log,
		apb_type_id,
		apb_zone_id,
		apb_violations,
		created,
		created_by,
		updated,
		updated_by)
	VALUES (
		NEW.id,
		NEW.name_last,
		NEW.name_first,
		NEW.user_level,
		NEW.days_to_log,
		NEW.apb_type_id,
		NEW.apb_zone_id,
		NEW.apb_violations,
		NEW.created,
		NEW.created_by,
		NEW.updated,
		NEW.updated_by);

	NEW.notes_id := extra."Notes_InsertOrUpdate"(NEW.notes_id, NEW.notes);
	NEW.photo_id := extra."Blob_InsertOrUpdate"(NEW.photo_id, NEW.photo_type, NEW.photo);
	NEW.signature_id := extra."Blob_InsertOrUpdate"(NEW.signature_id, NEW.signature_type, NEW.signature);
	NEW.fingerprint_id := extra."Blob_InsertOrUpdate"(NEW.fingerprint_id, NEW.fingerprint_type, NEW.fingerprint);

	INSERT INTO extra."Personnel" (
		id,
		name_middle,
		name_prefix,
		name_suffix,
		company,
		department,
		job_title,
		email,
		phone_work,
		phone_work_ext,
		phone_mobile,
		phone_home,
		address,
		city,
		state_or_prov,
		postal_code,
		country,
		notes_id,
		photo_id,
		signature_id,
		fingerprint_id,
		room,
		assigned_to,
		admission_date)
	VALUES (
		NEW.id,
		NEW.name_middle,
		NEW.name_prefix,
		NEW.name_suffix,
		NEW.company,
		NEW.department,
		NEW.job_title,
		NEW.email,
		NEW.phone_work,
		NEW.phone_work_ext,
		NEW.phone_mobile,
		NEW.phone_home,
		NEW.address,
		NEW.city,
		NEW.state_or_prov,
		NEW.postal_code,
		NEW.country,
		NEW.notes_id,
		NEW.photo_id,
		NEW.signature_id,
		NEW.fingerprint_id,
		NEW.room,
		NEW.assigned_to,
		NEW.admission_date);

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllPersonnel_DoInsert"() OWNER TO extra;

--
-- Name: AllPersonnel_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllPersonnel_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.id := OLD.id;

	UPDATE core."AllPersonnel" SET
		name_last = NEW.name_last,
		name_first = NEW.name_first,
		user_level = NEW.user_level,
		days_to_log = NEW.days_to_log,
		apb_type_id = NEW.apb_type_id,
		apb_zone_id = NEW.apb_zone_id,
		apb_violations = NEW.apb_violations,
		updated = NEW.updated,
		updated_by = NEW.updated_by
	WHERE id = OLD.id;
	
	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	NEW.notes_id := extra."Notes_Update"(OLD.notes_id, NEW.notes_id, NEW.notes);
	NEW.photo_id := extra."Blob_Update"(OLD.photo_id, NEW.photo_id, NEW.photo_type, NEW.photo);
	NEW.signature_id := extra."Blob_Update"(OLD.signature_id, NEW.signature_id, NEW.signature_type, NEW.signature);
	NEW.fingerprint_id := extra."Blob_Update"(OLD.fingerprint_id, NEW.fingerprint_id, NEW.fingerprint_type, NEW.fingerprint);

	UPDATE extra."Personnel" SET
		name_middle = NEW.name_middle,
		name_prefix = NEW.name_prefix,
		name_suffix = NEW.name_suffix,
		company = NEW.company,
		department = NEW.department,
		job_title = NEW.job_title,
		email = NEW.email,
		phone_work = NEW.phone_work,
		phone_work_ext = NEW.phone_work_ext,
		phone_mobile = NEW.phone_mobile,
		phone_home = NEW.phone_home,
		address = NEW.address,
		city = NEW.city,
		state_or_prov = NEW.state_or_prov,
		postal_code = NEW.postal_code,
		country = NEW.country,
		notes_id = NEW.notes_id,
		photo_id = NEW.photo_id,
		signature_id = NEW.signature_id,
		fingerprint_id = NEW.fingerprint_id,
		room = NEW.room,
		assigned_to = NEW.assigned_to,
		admission_date = NEW.admission_date
	WHERE id = OLD.id;

	IF NOT FOUND THEN
		INSERT INTO extra."Personnel" (
			id,
			name_middle,
			name_prefix,
			name_suffix,
			company,
			department,
			job_title,
			email,
			phone_work,
			phone_work_ext,
			phone_mobile,
			phone_home,
			address,
			city,
			state_or_prov,
			postal_code,
			country,
			notes_id,
			photo_id,
			signature_id,
			fingerprint_id,
			room,
			assigned_to,
			admission_date)
		VALUES (
			NEW.id,
			NEW.name_middle,
			NEW.name_prefix,
			NEW.name_suffix,
			NEW.company,
			NEW.department,
			NEW.job_title,
			NEW.email,
			NEW.phone_work,
			NEW.phone_work_ext,
			NEW.phone_mobile,
			NEW.phone_home,
			NEW.address,
			NEW.city,
			NEW.state_or_prov,
			NEW.postal_code,
			NEW.country,
			NEW.notes_id,
			NEW.photo_id,
			NEW.signature_id,
			NEW.fingerprint_id,
			NEW.room,
			NEW.assigned_to,
			NEW.admission_date);
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllPersonnel_DoUpdate"() OWNER TO extra;

--
-- Name: AllVehicle_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllVehicle_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."Vehicle"
	WHERE id = OLD.id;

	IF FOUND THEN
		extra_found := true;
	END IF;

	IF OLD.notes_id IS NOT NULL THEN
		DELETE FROM extra."Notes" WHERE id = OLD.notes_id;
	END IF;
	
	DELETE FROM core."Vehicle"
	WHERE id = OLD.id;

	IF NOT FOUND AND NOT extra_found THEN
		RETURN NULL;
	END IF;
	
	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."AllVehicle_DoDelete"() OWNER TO extra;

--
-- Name: AllVehicle_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllVehicle_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF NEW.id IS NULL THEN
		NEW.id := uuid_generate_v4();
	END IF;

	INSERT INTO core."Vehicle" (
		id,
		personnel_id,
		make,
		model,
		color,
		accent_color,
		state_or_prov,
		tag,
		sticker,
		year)
	VALUES (
		NEW.id,
		NEW.personnel_id,
		NEW.make,
		NEW.model,
		NEW.color,
		NEW.accent_color,
		NEW.state_or_prov,
		NEW.tag,
		NEW.sticker,
		NEW.year);

	NEW.notes_id := extra."Notes_InsertOrUpdate"(NEW.notes_id, NEW.notes);

	INSERT INTO extra."Vehicle" (
		id,
		notes_id)
	VALUES (
		NEW.id,
		NEW.notes_id);

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllVehicle_DoInsert"() OWNER TO extra;

--
-- Name: AllVehicle_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllVehicle_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.id := OLD.id;

	UPDATE core."Vehicle" SET
		personnel_id = NEW.personnel_id,
		make = NEW.make,
		model = NEW.model,
		color = NEW.color,
		accent_color = NEW.accent_color,
		state_or_prov = NEW.state_or_prov,
		tag = NEW.tag,
		sticker = NEW.sticker,
		year = NEW.year
	WHERE id = OLD.id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	NEW.notes_id := extra."Notes_Update"(OLD.notes_id, NEW.notes_id, NEW.notes);

	UPDATE extra."Vehicle" SET
		notes_id = NEW.notes_id
	WHERE id = OLD.id;

	IF NOT FOUND THEN
		INSERT INTO extra."Vehicle" (
			id,
			notes_id)
		VALUES (
			NEW.id,
			NEW.notes_id);
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllVehicle_DoUpdate"() OWNER TO extra;

--
-- Name: Blob_InsertOrUpdate(uuid, character varying, bytea); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "Blob_InsertOrUpdate"(id uuid, mime_type character varying, bytes bytea) RETURNS uuid
    LANGUAGE plpgsql
    AS $$
DECLARE
	new_id ALIAS FOR id;
	new_mime_type ALIAS FOR mime_type;
	new_bytes ALIAS FOR bytes;
	new_blob RECORD;
	new_blob_type RECORD;
	new_type_id smallint;
BEGIN
	IF bytes IS NULL THEN
		RETURN NULL;
	END IF;
	
	IF new_mime_type IS NULL THEN
		new_type_id := NULL;
	ELSE
		SELECT btype.id INTO new_blob_type
		FROM core."BlobType" btype
		WHERE btype.mime_type = new_mime_type;

		new_type_id := new_blob_type.id;

		IF new_type_id IS NULL THEN
			INSERT INTO core."BlobType" (mime_type)
			VALUES (new_mime_type)
			RETURNING core."BlobType".id INTO new_blob_type;

			new_type_id := new_blob_type.id;
		END IF;
	END IF;
	
	IF id IS NULL THEN
		id := uuid_generate_v4();

		INSERT INTO extra."Blob" (id, type_id, bytes)
		VALUES (new_id, new_type_id, new_bytes)
		RETURNING extra."Blob".id INTO new_blob;
	ELSE
		UPDATE extra."Blob" blob
		SET
			type_id = new_type_id,
			bytes = new_bytes
		WHERE blob.id = new_id
		RETURNING blob.id INTO new_blob;

		IF NOT FOUND THEN
			INSERT INTO extra."Blob" (id, type_id, bytes)
			VALUES (id, new_type_id, bytes)
			RETURNING extra."Blob".id INTO new_blob;
		END IF;
	END IF;
	
	RETURN new_blob.id;
END;
$$;


ALTER FUNCTION extra."Blob_InsertOrUpdate"(id uuid, mime_type character varying, bytes bytea) OWNER TO extra;

--
-- Name: Blob_Update(uuid, uuid, character varying, bytea); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "Blob_Update"(old_id uuid, new_id uuid, mime_type character varying, bytes bytea) RETURNS uuid
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF bytes IS NULL THEN
		IF old_id IS NOT NULL THEN
			DELETE FROM extra."Blob" WHERE id = old_id;
		END IF;
		new_id := NULL;
	ELSE
		IF old_id IS NOT NULL THEN
			IF new_id IS NULL THEN
				new_id := old_id;
			ELSIF new_id <> old_id THEN
				DELETE FROM extra."Blob" WHERE id = old_id;
			END IF;
		END IF;
		new_id := extra."Blob_InsertOrUpdate"(new_id, mime_type, bytes);
	END IF;
	
	RETURN new_id;
END;
$$;


ALTER FUNCTION extra."Blob_Update"(old_id uuid, new_id uuid, mime_type character varying, bytes bytea) OWNER TO extra;

--
-- Name: CardToken_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "CardToken_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."Card"
	WHERE token_id = OLD.token_id;

	IF FOUND THEN
		extra_found := true;
	END IF;
	
	DELETE FROM core."CardToken"
	WHERE token_id = OLD.token_id;

	IF NOT FOUND AND NOT extra_found THEN
		RETURN NULL;
	END IF;
	
	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."CardToken_DoDelete"() OWNER TO extra;

--
-- Name: CardToken_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "CardToken_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	core_inserted RECORD;
BEGIN
	INSERT INTO core."CardToken" (
		token_id,
		card_number,
		site_code,
		card_format,
		card_type,
		pin_number,
		card_valid,
		activate_date,
		deactivate_date,
		secondary_expiration_date,
		expire_days,
		action_point_id,
		threat_level,
		auto_disable,
		grant_long_access_time,
		escort_visitor_capable,
		access_cost_override_capable,
		event_lock_override_capable,
		building_passback_exemption,
		parking_passback_exemption,
		card_holder_groups,
		activation_group,
		on_access_output,
		compass_command_group,
		user_level,
		personnel_id,
		badge_id,
		lost,
		last_read,
		last_reader,
		last_read_status,
		created,
		created_by,
		updated,
		updated_by,
		downloaded,
		downloaded_by,
		download_required,
		low_battery)
	VALUES (
		NEW.token_id,
		NEW.card_number,
		NEW.site_code,
		NEW.card_format,
		NEW.card_type,
		NEW.pin_number,
		NEW.card_valid,
		NEW.activate_date,
		NEW.deactivate_date,
		NEW.secondary_expiration_date,
		NEW.expire_days,
		NEW.action_point_id,
		NEW.threat_level,
		NEW.auto_disable,
		NEW.grant_long_access_time,
		NEW.escort_visitor_capable,
		NEW.access_cost_override_capable,
		NEW.event_lock_override_capable,
		NEW.building_passback_exemption,
		NEW.parking_passback_exemption,
		NEW.card_holder_groups,
		NEW.activation_group,
		NEW.on_access_output,
		NEW.compass_command_group,
		NEW.user_level,
		NEW.personnel_id,
		NEW.badge_id,
		NEW.lost,
		NEW.last_read,
		NEW.last_reader,
		NEW.last_read_status,
		NEW.created,
		NEW.created_by,
		NEW.updated,
		NEW.updated_by,
		NEW.downloaded,
		NEW.downloaded_by,
		NEW.download_required,
		NEW.low_battery)
	RETURNING token_id INTO STRICT core_inserted;
	
	IF NOT FOUND OR core_inserted.token_id IS NULL THEN
		RETURN NULL;
	END IF;

	NEW.token_id := core_inserted.token_id;

	INSERT INTO extra."Card" (
		token_id,
		card_emboss_num,
		card_label)
	VALUES (
		core_inserted.token_id,
		NEW.card_emboss_num,
		NEW.card_label);

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."CardToken_DoInsert"() OWNER TO extra;

--
-- Name: CardToken_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "CardToken_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.token_id := OLD.token_id;

	UPDATE core."CardToken" SET
		card_number = NEW.card_number,
		site_code = NEW.site_code,
		card_format = NEW.card_format,
		card_type = NEW.card_type,
		pin_number = NEW.pin_number,
		card_valid = NEW.card_valid,
		activate_date = NEW.activate_date,
		deactivate_date = NEW.deactivate_date,
		secondary_expiration_date = NEW.secondary_expiration_date,
		expire_days = NEW.expire_days,
		action_point_id = NEW.action_point_id,
		threat_level = NEW.threat_level,
		auto_disable = NEW.auto_disable,
		grant_long_access_time = NEW.grant_long_access_time,
		escort_visitor_capable = NEW.escort_visitor_capable,
		access_cost_override_capable = NEW.access_cost_override_capable,
		event_lock_override_capable = NEW.event_lock_override_capable,
		building_passback_exemption = NEW.building_passback_exemption,
		parking_passback_exemption = NEW.parking_passback_exemption,
		card_holder_groups = NEW.card_holder_groups,
		activation_group = NEW.activation_group,
		on_access_output = NEW.on_access_output,
		compass_command_group = NEW.compass_command_group,
		user_level = NEW.user_level,
		personnel_id = NEW.personnel_id,
		badge_id = NEW.badge_id,
		lost = NEW.lost,
		last_read = NEW.last_read,
		last_reader = NEW.last_reader,
		last_read_status = NEW.last_read_status,
		created = NEW.created,
		created_by = NEW.created_by,
		updated = NEW.updated,
		updated_by = NEW.updated_by,
		downloaded = NEW.downloaded,
		downloaded_by = NEW.downloaded_by,
		download_required = NEW.download_required,
		low_battery = NEW.low_battery
	WHERE token_id = OLD.token_id;
	
	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	UPDATE extra."Card" SET
		card_emboss_num = NEW.card_emboss_num,
		card_label = NEW.card_label
	WHERE token_id = OLD.token_id;

	IF NOT FOUND THEN
		INSERT INTO extra."Card" (
			token_id,
			card_emboss_num,
			card_label)
		VALUES (
			NEW.token_id,
			NEW.card_emboss_num,
			NEW.card_label);
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."CardToken_DoUpdate"() OWNER TO extra;

--
-- Name: MultiCard_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "MultiCard_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."CardToken"
	WHERE token_id = OLD.token_id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."MultiCard_DoDelete"() OWNER TO extra;

--
-- Name: MultiCard_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "MultiCard_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	new_card RECORD;
	new_personnel RECORD;
	old_personnel RECORD;
	is_new_personnel BOOLEAN;
BEGIN
	is_new_personnel := true;

	IF NEW.personnel_id IS NOT NULL THEN
		SELECT personnel.id INTO old_personnel
		FROM core."Personnel" personnel
		WHERE personnel.id = NEW.personnel_id;

		IF FOUND THEN
			is_new_personnel := false;
		END IF;
	END IF;

	IF is_new_personnel THEN
		INSERT INTO extra."AllPersonnel" (
			id,
			name_last,
			name_first,
			name_middle,
			name_prefix,
			name_suffix,
			company,
			department,
			job_title,
			email,
			phone_work,
			phone_work_ext,
			phone_mobile,
			phone_home,
			address,
			city,
			state_or_prov,
			postal_code,
			country,
			notes_id,
			notes,
			photo_id,
			photo,
			photo_type,
			signature_id,
			signature,
			signature_type,
			fingerprint_id,
			fingerprint,
			fingerprint_type,
			user_level,
			days_to_log,
			apb_type_id,
			apb_zone_id,
			apb_violations,
			created,
			created_by,
			updated,
			updated_by,
			room,
			assigned_to,
			admission_date)
		VALUES (
			NEW.personnel_id,
			NEW.name_last,
			NEW.name_first,
			NEW.name_middle,
			NEW.name_prefix,
			NEW.name_suffix,
			NEW.company,
			NEW.department,
			NEW.job_title,
			NEW.email,
			NEW.phone_work,
			NEW.phone_work_ext,
			NEW.phone_mobile,
			NEW.phone_home,
			NEW.address,
			NEW.city,
			NEW.state_or_prov,
			NEW.postal_code,
			NEW.country,
			NEW.notes_id,
			NEW.notes,
			NEW.photo_id,
			NEW.photo,
			NEW.photo_type,
			NEW.signature_id,
			NEW.signature,
			NEW.signature_type,
			NEW.fingerprint_id,
			NEW.fingerprint,
			NEW.fingerprint_type,
			NEW.personnel_user_level,
			NEW.days_to_log,
			NEW.apb_type_id,
			NEW.apb_zone_id,
			NEW.apb_violations,
			NEW.personnel_created,
			NEW.personnel_created_by,
			NEW.personnel_updated,
			NEW.personnel_updated_by,
			NEW.room,
			NEW.assigned_to,
			NEW.admission_date)
			RETURNING id INTO STRICT new_personnel;

		IF NOT FOUND OR new_personnel.id IS NULL THEN
			RETURN NULL;
		END IF;

		NEW.personnel_id := new_personnel.id;
	ELSE
		NEW.personnel_id := OLD.personnel_id;

		UPDATE extra."AllPersonnel" personnel SET
			name_last = NEW.name_last,
			name_first = NEW.name_first,
			name_middle = NEW.name_middle,
			name_prefix = NEW.name_prefix,
			name_suffix = NEW.name_suffix,
			company = NEW.company,
			department = NEW.department,
			job_title = NEW.job_title,
			email = NEW.email,
			phone_work = NEW.phone_work,
			phone_work_ext = NEW.phone_work_ext,
			phone_mobile = NEW.phone_mobile,
			phone_home = NEW.phone_home,
			address = NEW.address,
			city = NEW.city,
			state_or_prov = NEW.state_or_prov,
			postal_code = NEW.postal_code,
			country = NEW.country,
			notes_id = NEW.notes_id,
			notes = NEW.notes,
			photo_id = NEW.photo_id,
			photo = NEW.photo,
			photo_type = NEW.photo_type,
			signature_id = NEW.signature_id,
			signature = NEW.signature,
			signature_type = NEW.signature_type,
			fingerprint_id = NEW.fingerprint_id,
			fingerprint = NEW.fingerprint,
			fingerprint_type = NEW.fingerprint_type,
			user_level = NEW.personnel_user_level,
			days_to_log = NEW.days_to_log,
			apb_type_id = NEW.apb_type_id,
			apb_zone_id = NEW.apb_zone_id,
			apb_violations = NEW.apb_violations,
			created = NEW.personnel_created,
			created_by = NEW.personnel_created_by,
			updated = NEW.personnel_updated,
			updated_by = NEW.personnel_updated_by,
			room = NEW.room,
			assigned_to = NEW.assigned_to,
			admission_date = NEW.admission_date
		WHERE id = OLD.personnel_id;

		IF NOT FOUND THEN
			RETURN NULL;
		END IF;
	END IF;

	INSERT INTO extra."CardToken" (
		token_id,
		personnel_id,
		card_number,
		site_code,
		card_format,
		card_type,
		card_emboss_num,
		card_label,
		pin_number,
		card_valid,
		activate_date,
		deactivate_date,
		secondary_expiration_date,
		expire_days,
		action_point_id,
		threat_level,
		auto_disable,
		grant_long_access_time,
		escort_visitor_capable,
		access_cost_override_capable,
		event_lock_override_capable,
		building_passback_exemption,
		parking_passback_exemption,
		card_holder_groups,
		activation_group,
		on_access_output,
		compass_command_group,
		user_level,
		badge_id,
		lost,
		last_read,
		last_reader,
		last_read_status,
		created,
		created_by,
		updated,
		updated_by,
		downloaded,
		downloaded_by,
		download_required,
		low_battery)
	VALUES (
		NEW.token_id,
		NEW.personnel_id,
		NEW.card_number,
		NEW.site_code,
		NEW.card_format,
		NEW.card_type,
		NEW.card_emboss_num,
		NEW.card_label,
		NEW.pin_number,
		NEW.card_valid,
		NEW.activate_date,
		NEW.deactivate_date,
		NEW.secondary_expiration_date,
		NEW.expire_days,
		NEW.action_point_id,
		NEW.threat_level,
		NEW.auto_disable,
		NEW.grant_long_access_time,
		NEW.escort_visitor_capable,
		NEW.access_cost_override_capable,
		NEW.event_lock_override_capable,
		NEW.building_passback_exemption,
		NEW.parking_passback_exemption,
		NEW.card_holder_groups,
		NEW.activation_group,
		NEW.on_access_output,
		NEW.compass_command_group,
		NEW.card_user_level,
		NEW.badge_id,
		NEW.lost,
		NEW.last_read,
		NEW.last_reader,
		NEW.last_read_status,
		NEW.card_created,
		NEW.card_created_by,
		NEW.card_updated,
		NEW.card_updated_by,
		NEW.downloaded,
		NEW.downloaded_by,
		NEW.download_required,
		NEW.low_battery)
	RETURNING token_id INTO STRICT new_card;

	IF NOT FOUND OR new_card.token_id IS NULL THEN
		RETURN NULL;
	END IF;

	NEW.token_id := new_card.token_id;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."MultiCard_DoInsert"() OWNER TO extra;

--
-- Name: MultiCard_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "MultiCard_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.token_id := OLD.token_id;
	NEW.personnel_id := OLD.personnel_id;

	UPDATE extra."AllPersonnel" personnel SET
		name_last = NEW.name_last,
		name_first = NEW.name_first,
		name_middle = NEW.name_middle,
		name_prefix = NEW.name_prefix,
		name_suffix = NEW.name_suffix,
		company = NEW.company,
		department = NEW.department,
		job_title = NEW.job_title,
		email = NEW.email,
		phone_work = NEW.phone_work,
		phone_work_ext = NEW.phone_work_ext,
		phone_mobile = NEW.phone_mobile,
		phone_home = NEW.phone_home,
		address = NEW.address,
		city = NEW.city,
		state_or_prov = NEW.state_or_prov,
		postal_code = NEW.postal_code,
		country = NEW.country,
		notes_id = NEW.notes_id,
		notes = NEW.notes,
		photo_id = NEW.photo_id,
		photo = NEW.photo,
		photo_type = NEW.photo_type,
		signature_id = NEW.signature_id,
		signature = NEW.signature,
		signature_type = NEW.signature_type,
		fingerprint_id = NEW.fingerprint_id,
		fingerprint = NEW.fingerprint,
		fingerprint_type = NEW.fingerprint_type,
		user_level = NEW.personnel_user_level,
		days_to_log = NEW.days_to_log,
		apb_type_id = NEW.apb_type_id,
		apb_zone_id = NEW.apb_zone_id,
		apb_violations = NEW.apb_violations,
		created = NEW.personnel_created,
		created_by = NEW.personnel_created_by,
		updated = NEW.personnel_updated,
		updated_by = NEW.personnel_updated_by,
		room = NEW.room,
		assigned_to = NEW.assigned_to,
		admission_date = NEW.admission_date
	WHERE id = OLD.personnel_id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	UPDATE extra."CardToken" card SET
		card_number = NEW.card_number,
		site_code = NEW.site_code,
		card_format = NEW.card_format,
		card_type = NEW.card_type,
		card_emboss_num = NEW.card_emboss_num,
		card_label = NEW.card_label,
		pin_number = NEW.pin_number,
		card_valid = NEW.card_valid,
		activate_date = NEW.activate_date,
		deactivate_date = NEW.deactivate_date,
		secondary_expiration_date = NEW.secondary_expiration_date,
		expire_days = NEW.expire_days,
		action_point_id = NEW.action_point_id,
		threat_level = NEW.threat_level,
		auto_disable = NEW.auto_disable,
		grant_long_access_time = NEW.grant_long_access_time,
		escort_visitor_capable = NEW.escort_visitor_capable,
		access_cost_override_capable = NEW.access_cost_override_capable,
		event_lock_override_capable = NEW.event_lock_override_capable,
		building_passback_exemption = NEW.building_passback_exemption,
		parking_passback_exemption = NEW.parking_passback_exemption,
		card_holder_groups = NEW.card_holder_groups,
		activation_group = NEW.activation_group,
		on_access_output = NEW.on_access_output,
		compass_command_group = NEW.compass_command_group,
		user_level = NEW.card_user_level,
		badge_id = NEW.badge_id,
		lost = NEW.lost,
		last_read = NEW.last_read,
		last_reader = NEW.last_reader,
		last_read_status = NEW.last_read_status,
		created = NEW.card_created,
		created_by = NEW.card_created_by,
		updated = NEW.card_updated,
		updated_by = NEW.card_updated_by,
		downloaded = NEW.downloaded,
		downloaded_by = NEW.downloaded_by,
		download_required = NEW.download_required,
		low_battery = NEW.low_battery
	WHERE token_id = OLD.token_id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."MultiCard_DoUpdate"() OWNER TO extra;

--
-- Name: Notes_InsertOrUpdate(uuid, text); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "Notes_InsertOrUpdate"(id uuid, text text) RETURNS uuid
    LANGUAGE plpgsql
    AS $$
DECLARE
	new_note RECORD;
	new_id ALIAS FOR id;
	new_text ALIAS FOR text;
BEGIN
	IF text IS NULL THEN
		RETURN NULL;
	END IF;
	
	IF new_id IS NULL THEN
		new_id := uuid_generate_v4();

		INSERT INTO extra."Notes" (id, text)
		VALUES (new_id, new_text)
		RETURNING extra."Notes".id INTO new_note;
	ELSE
		UPDATE extra."Notes" notes
		SET text = new_text
		WHERE notes.id = new_id
		RETURNING notes.id INTO new_note;

		IF NOT FOUND THEN
			INSERT INTO extra."Notes" (id, text)
			VALUES (new_id, new_text)
			RETURNING extra."Notes".id INTO new_note;
		END IF;
	END IF;
	
	RETURN new_note.id;
END;
$$;


ALTER FUNCTION extra."Notes_InsertOrUpdate"(id uuid, text text) OWNER TO extra;

--
-- Name: Notes_Update(uuid, uuid, text); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "Notes_Update"(old_id uuid, new_id uuid, text text) RETURNS uuid
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF text IS NULL THEN
		IF old_id IS NOT NULL THEN
			DELETE FROM extra."Notes" WHERE id = old_id;
		END IF;
		new_id := NULL;
	ELSE
		IF old_id IS NOT NULL THEN
			IF new_id IS NULL THEN
				new_id := old_id;
			ELSIF new_id <> old_id THEN
				DELETE FROM extra."Notes" WHERE id = old_id;
			END IF;
		END IF;
		new_id := extra."Notes_InsertOrUpdate"(new_id, text);
	END IF;
	
	RETURN new_id;
END;
$$;


ALTER FUNCTION extra."Notes_Update"(old_id uuid, new_id uuid, text text) OWNER TO extra;

--
-- Name: SingleCard_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "SingleCard_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."CardToken"
	WHERE token_id = OLD.token_id;

	IF FOUND THEN
		extra_found := true;
	END IF;
	
	DELETE FROM extra."AllPersonnel"
	WHERE id = OLD.personnel_id;

	IF NOT FOUND AND NOT extra_found THEN
		RETURN NULL;
	END IF;
	
	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."SingleCard_DoDelete"() OWNER TO extra;

--
-- Name: SingleCard_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "SingleCard_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	new_card RECORD;
	new_personnel RECORD;
	old_personnel RECORD;
BEGIN
	IF NEW.personnel_id IS NOT NULL THEN
		SELECT personnel.id INTO old_personnel
		FROM core."Personnel" personnel
		WHERE personnel.id = NEW.personnel_id;
		
		IF FOUND THEN
			RAISE EXCEPTION 'An existing record exists with personnel ID: %', NEW.personnel_id
				USING ERRCODE = 'integrity_constraint_violation';
		END IF;
	END IF;

	INSERT INTO extra."AllPersonnel" (
		id,
		name_last,
		name_first,
		name_middle,
		name_prefix,
		name_suffix,
		company,
		department,
		job_title,
		email,
		phone_work,
		phone_work_ext,
		phone_mobile,
		phone_home,
		address,
		city,
		state_or_prov,
		postal_code,
		country,
		notes_id,
		notes,
		photo_id,
		photo,
		photo_type,
		signature_id,
		signature,
		signature_type,
		fingerprint_id,
		fingerprint,
		fingerprint_type,
		user_level,
		days_to_log,
		apb_type_id,
		apb_zone_id,
		apb_violations,
		created,
		created_by,
		updated,
		updated_by,
		room,
		assigned_to,
		admission_date)
	VALUES (
		NEW.personnel_id,
		NEW.name_last,
		NEW.name_first,
		NEW.name_middle,
		NEW.name_prefix,
		NEW.name_suffix,
		NEW.company,
		NEW.department,
		NEW.job_title,
		NEW.email,
		NEW.phone_work,
		NEW.phone_work_ext,
		NEW.phone_mobile,
		NEW.phone_home,
		NEW.address,
		NEW.city,
		NEW.state_or_prov,
		NEW.postal_code,
		NEW.country,
		NEW.notes_id,
		NEW.notes,
		NEW.photo_id,
		NEW.photo,
		NEW.photo_type,
		NEW.signature_id,
		NEW.signature,
		NEW.signature_type,
		NEW.fingerprint_id,
		NEW.fingerprint,
		NEW.fingerprint_type,
		NEW.personnel_user_level,
		NEW.days_to_log,
		NEW.apb_type_id,
		NEW.apb_zone_id,
		NEW.apb_violations,
		NEW.personnel_created,
		NEW.personnel_created_by,
		NEW.personnel_updated,
		NEW.personnel_updated_by,
		NEW.room,
		NEW.assigned_to,
		NEW.admission_date)
	RETURNING id INTO STRICT new_personnel;

	IF NOT FOUND OR new_personnel.id IS NULL THEN
		RETURN NULL;
	END IF;
	
	NEW.personnel_id := new_personnel.id;

	INSERT INTO extra."CardToken" (
		token_id,
		personnel_id,
		card_number,
		site_code,
		card_format,
		card_type,
		card_emboss_num,
		card_label,
		pin_number,
		card_valid,
		activate_date,
		deactivate_date,
		secondary_expiration_date,
		expire_days,
		action_point_id,
		threat_level,
		auto_disable,
		grant_long_access_time,
		escort_visitor_capable,
		access_cost_override_capable,
		event_lock_override_capable,
		building_passback_exemption,
		parking_passback_exemption,
		card_holder_groups,
		activation_group,
		on_access_output,
		compass_command_group,
		user_level,
		badge_id,
		lost,
		last_read,
		last_reader,
		last_read_status,
		created,
		created_by,
		updated,
		updated_by,
		downloaded,
		downloaded_by,
		download_required,
		low_battery)
	VALUES (
		NEW.token_id,
		NEW.personnel_id,
		NEW.card_number,
		NEW.site_code,
		NEW.card_format,
		NEW.card_type,
		NEW.card_emboss_num,
		NEW.card_label,
		NEW.pin_number,
		NEW.card_valid,
		NEW.activate_date,
		NEW.deactivate_date,
		NEW.secondary_expiration_date,
		NEW.expire_days,
		NEW.action_point_id,
		NEW.threat_level,
		NEW.auto_disable,
		NEW.grant_long_access_time,
		NEW.escort_visitor_capable,
		NEW.access_cost_override_capable,
		NEW.event_lock_override_capable,
		NEW.building_passback_exemption,
		NEW.parking_passback_exemption,
		NEW.card_holder_groups,
		NEW.activation_group,
		NEW.on_access_output,
		NEW.compass_command_group,
		NEW.card_user_level,
		NEW.badge_id,
		NEW.lost,
		NEW.last_read,
		NEW.last_reader,
		NEW.last_read_status,
		NEW.card_created,
		NEW.card_created_by,
		NEW.card_updated,
		NEW.card_updated_by,
		NEW.downloaded,
		NEW.downloaded_by,
		NEW.download_required,
		NEW.low_battery)
	RETURNING token_id INTO STRICT new_card;
	
	IF NOT FOUND OR new_card.token_id IS NULL THEN
		RETURN NULL;
	END IF;
	IF NEW.card_number <= 256 and NEW.site_code = 0 and NEW.card_format = 26 THEN
				
				Insert into history."AccutechTagChange" (
				change_time, 
				event, 
				card_number, 
				name_first, 
				name_last, 
				name_middle, 
				assigned_to, 
				updated_by,
				room) 
				VALUES (
				NOW(),
				5036,
				NEW.card_number,
				NEW.name_first,
				NEW.name_last,
				NEW.name_middle,
				NEW.assigned_to,
				NEW.personnel_created_by,
				NEW.room);
	END IF;	
	NEW.token_id := new_card.token_id;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."SingleCard_DoInsert"() OWNER TO extra;

--
-- Name: SingleCard_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "SingleCard_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	d_change_type smallint;
BEGIN
	NEW.token_id := OLD.token_id;
	NEW.personnel_id := OLD.personnel_id;

	UPDATE extra."AllPersonnel" personnel SET
		name_last = NEW.name_last,
		name_first = NEW.name_first,
		name_middle = NEW.name_middle,
		name_prefix = NEW.name_prefix,
		name_suffix = NEW.name_suffix,
		company = NEW.company,
		department = NEW.department,
		job_title = NEW.job_title,
		email = NEW.email,
		phone_work = NEW.phone_work,
		phone_work_ext = NEW.phone_work_ext,
		phone_mobile = NEW.phone_mobile,
		phone_home = NEW.phone_home,
		address = NEW.address,
		city = NEW.city,
		state_or_prov = NEW.state_or_prov,
		postal_code = NEW.postal_code,
		country = NEW.country,
		notes_id = NEW.notes_id,
		notes = NEW.notes,
		photo_id = NEW.photo_id,
		photo = NEW.photo,
		photo_type = NEW.photo_type,
		signature_id = NEW.signature_id,
		signature = NEW.signature,
		signature_type = NEW.signature_type,
		fingerprint_id = NEW.fingerprint_id,
		fingerprint = NEW.fingerprint,
		fingerprint_type = NEW.fingerprint_type,
		user_level = NEW.personnel_user_level,
		days_to_log = NEW.days_to_log,
		apb_type_id = NEW.apb_type_id,
		apb_zone_id = NEW.apb_zone_id,
		apb_violations = NEW.apb_violations,
		created = NEW.personnel_created,
		created_by = NEW.personnel_created_by,
		updated = NEW.personnel_updated,
		updated_by = NEW.personnel_updated_by,
		room = NEW.room,
		assigned_to = NEW.assigned_to,
		admission_date = NEW.admission_date
	WHERE id = OLD.personnel_id;
	
	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	UPDATE extra."CardToken" card SET
		card_number = NEW.card_number,
		site_code = NEW.site_code,
		card_format = NEW.card_format,
		card_type = NEW.card_type,
		card_emboss_num = NEW.card_emboss_num,
		card_label = NEW.card_label,
		pin_number = NEW.pin_number,
		card_valid = NEW.card_valid,
		activate_date = NEW.activate_date,
		deactivate_date = NEW.deactivate_date,
		secondary_expiration_date = NEW.secondary_expiration_date,
		expire_days = NEW.expire_days,
		action_point_id = NEW.action_point_id,
		threat_level = NEW.threat_level,
		auto_disable = NEW.auto_disable,
		grant_long_access_time = NEW.grant_long_access_time,
		escort_visitor_capable = NEW.escort_visitor_capable,
		access_cost_override_capable = NEW.access_cost_override_capable,
		event_lock_override_capable = NEW.event_lock_override_capable,
		building_passback_exemption = NEW.building_passback_exemption,
		parking_passback_exemption = NEW.parking_passback_exemption,
		card_holder_groups = NEW.card_holder_groups,
		activation_group = NEW.activation_group,
		on_access_output = NEW.on_access_output,
		compass_command_group = NEW.compass_command_group,
		user_level = NEW.card_user_level,
		badge_id = NEW.badge_id,
		lost = NEW.lost,
		last_read = NEW.last_read,
		last_reader = NEW.last_reader,
		last_read_status = NEW.last_read_status,
		created = NEW.card_created,
		created_by = NEW.card_created_by,
		updated = NEW.card_updated,
		updated_by = NEW.card_updated_by,
		downloaded = NEW.downloaded,
		downloaded_by = NEW.downloaded_by,
		download_required = NEW.download_required,
		low_battery = NEW.low_battery
	WHERE token_id = OLD.token_id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;
		d_change_type := 5039; --Owner Edited
		IF OLD.name_last = 'Unassigned' THEN
		d_change_type := 5038; --Admitted
		END IF;
		IF NEW.name_last = 'Unassigned' THEN
		d_change_type := 5041; --Discharged
		END IF;
		IF NEW.assigned_to >= 100 THEN--Tag is being re-assigned
			IF d_change_type = 5038 THEN --The tag is being admitted after being discharged, Discharge with assigned_to >=100 are ignored
				d_change_type := 5040; --Reassigned
				Insert into history."AccutechTagChange" (
				change_time, 
				event, 
				card_number, 
				name_first, 
				name_last, 
				name_middle, 
				assigned_to, 
				updated_by,
				room) 
				VALUES (
				NOW(),
				d_change_type,
				NEW.card_number,
				NEW.name_first,
				NEW.name_last,
				NEW.name_middle,
				NEW.assigned_to - 100,
				NEW.personnel_updated_by,
				NEW.room);
			END IF;
		ELSE
			Insert into history."AccutechTagChange" (
			change_time, 
			event, 
			card_number, 
			name_first, 
			name_last, 
			name_middle, 
			assigned_to, 
			updated_by,
			room) 
			VALUES (
			NOW(),
			d_change_type,
			NEW.card_number,
			NEW.name_first,
			NEW.name_last,
			NEW.name_middle,
			NEW.assigned_to,
			NEW.personnel_updated_by,
			NEW.room);		
		END IF;
	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."SingleCard_DoUpdate"() OWNER TO extra;

SET search_path = history, pg_catalog;

--
-- Name: Activity_Insert_Statistics(); Type: FUNCTION; Schema: history; Owner: core
--

CREATE FUNCTION "Activity_Insert_Statistics"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	t_activity RECORD;
	new_stats RECORD;
	l_active timestamp with time zone;
BEGIN
		IF NEW.event_type_id = 2 THEN
		SELECT id INTO t_activity
		FROM history."Activity_Statistics" stats
		WHERE stats.point_id = NEW.point_id and stats.cleared_time IS NULL and stats.acked_time IS NULL;
		END IF;		
		IF NEW.event_type_id = 1 THEN
		SELECT id INTO t_activity
		FROM history."Activity_Statistics" stats
		WHERE stats.point_id = NEW.point_id and stats.card_number = NEW.card_number and stats.cleared_time IS NULL and stats.acked_time IS NULL;
		END IF;
		IF NEW.event_type_id = 6 THEN
		SELECT id INTO t_activity 
		FROM history."Activity_Statistics" stats
		WHERE stats.point_id = NEW.point_id and stats.cleared_time IS NULL and stats.acked_time IS NULL;
		END IF;
		
	IF t_activity.id IS NULL THEN
		IF NEW.event_type_id = 2 and NEW.state = 1 THEN
		NEW.id := uuid_generate_v4();
		INSERT INTO history."Activity_Statistics" (
			id,event_type_id, rtu_id, rtu_name, point_id, point_name, state, status, card_number, site_code, card_format, 
					card_holder_name, computer, "user", user_comments, token_id, active_time, inactive_time, acked_time, cleared_time, last_active, total_active, active_count)
		VALUES (
			NEW.id,NEW.event_type_id, NEW.rtu_id, NEW.rtu_Name, NEW.point_id, NEW.point_name,null, null, NEW.card_number, NEW.site_code,	NEW.card_format,
					 NEW.card_Holder_name, NEW.computer, NEW.user, NEW.user_comments, NEW.token_id, NEW."time", NULL, NULL, NULL, NEW."time", 0,1);
		SELECT id INTO t_activity
		FROM history."Activity_Statistics" stats
		WHERE stats.point_id = NEW.point_id and stats.cleared_time IS NULL and stats.acked_time IS NULL;
		END IF;
		
		IF NEW.event_type_id = 1 THEN
		NEW.id := uuid_generate_v4();
		INSERT INTO history."Activity_Statistics" (
			id,event_type_id, rtu_id, rtu_name, point_id, point_name, state, status, card_number, site_code, card_format, 
					card_holder_name, computer, "user", user_comments, token_id, active_time, inactive_time, acked_time, cleared_time, last_active, total_active, active_count)
		VALUES (
			NEW.id,NEW.event_type_id, NEW.rtu_id, NEW.rtu_Name, NEW.point_id, NEW.point_name,null, null, NEW.card_number, NEW.site_code,	NEW.card_format,
					 NEW.card_Holder_name, NEW.computer, NEW.user, NEW.user_comments, NEW.token_id, NEW."time", NEW."time", NULL, NULL, NEW."time", 0,1);
		SELECT id INTO t_activity
		FROM history."Activity_Statistics" stats
		WHERE stats.point_id = NEW.point_id and stats.cleared_time IS NULL and stats.acked_time IS NULL;
		END IF;
		
	END IF;
	IF NOT FOUND OR t_activity.id IS NULL THEN
		RETURN NULL;
	END IF;
	IF NEW.state = 0 and NEW.event_type_id = 2 THEN
		IF NEW.user_comments IS NULL THEN
		select last_active INTO l_active from history."Activity_Statistics" where id = t_activity.id;
		Update history."Activity_Statistics" set inactive_time = NEW."time", total_active = total_active + datediff('second', l_active::timestamp(0), NEW."time"::timestamp(0)) where id = t_activity.id;
		END IF;
		IF NEW.user_comments IS NOT NULL THEN
		select last_active INTO l_active from history."Activity_Statistics" where id = t_activity.id;
		Update history."Activity_Statistics" set inactive_time = NEW."time", total_active = total_active + datediff('second', l_active::timestamp(0), NEW."time"::timestamp(0)), user_comments = 'Auto Cleared', "user" = 'System' where id = t_activity.id;
		END IF;
	END IF;
	
	IF NEW.state = 1 and NEW.event_type_id = 2 THEN
		Update history."Activity_Statistics" set last_active = NEW."time", active_count = active_count + 1 where id = t_activity.id;
	END IF;
	
	IF NEW.event_type_id = 6 and NEW.status ilike 'Acked' THEN
		Update history."Activity_Statistics" set acked_time = NEW."time", "user" = NEW."user" where id = t_activity.id;
		Update history."Activity_Statistics" set inactive_time = NEW."time" where inactive_time IS NULL;
	END IF;
	
	IF NEW.event_type_id = 6 and NEW.status ilike 'Cleared' THEN
		Update history."Activity_Statistics" set cleared_time = NEW."time", "user" = NEW."user" where id = t_activity.id;
		Update history."Activity_Statistics" set inactive_time = NEW."time" where inactive_time IS NULL;
	END IF;


	

	RETURN NEW;
END;
$$;


ALTER FUNCTION history."Activity_Insert_Statistics"() OWNER TO core;

SET search_path = core, pg_catalog;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: AccessEntry; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "AccessEntry" (
    id integer NOT NULL,
    name character varying(255)
);


ALTER TABLE "AccessEntry" OWNER TO core;

--
-- Name: AccessSet; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "AccessSet" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    name character varying(50),
    user_level integer,
    download_required boolean
);


ALTER TABLE "AccessSet" OWNER TO core;

--
-- Name: AccessSetsToAccessEntries; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "AccessSetsToAccessEntries" (
    access_set_id uuid NOT NULL,
    access_entry_id integer NOT NULL
);


ALTER TABLE "AccessSetsToAccessEntries" OWNER TO core;

--
-- Name: AccessSetsToTokens; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "AccessSetsToTokens" (
    access_set_id uuid NOT NULL,
    token_id uuid NOT NULL
);


ALTER TABLE "AccessSetsToTokens" OWNER TO core;

--
-- Name: Personnel; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Personnel" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    name_last character varying(50),
    name_first character varying(50),
    user_level integer,
    days_to_log smallint,
    apb_type_id smallint,
    apb_zone_id integer,
    apb_violations smallint,
    created timestamp with time zone DEFAULT now(),
    created_by character varying(255) DEFAULT "current_user"(),
    updated timestamp with time zone,
    updated_by character varying(255),
    deleted timestamp with time zone,
    deleted_by character varying(255)
);


ALTER TABLE "Personnel" OWNER TO core;

--
-- Name: COLUMN "Personnel".apb_type_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Personnel".apb_type_id IS 'Anti-passback type id';


--
-- Name: COLUMN "Personnel".apb_zone_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Personnel".apb_zone_id IS 'Anti-passback zone id';


--
-- Name: COLUMN "Personnel".apb_violations; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Personnel".apb_violations IS 'Anti-passback zone violation count';


--
-- Name: AllPersonnel; Type: VIEW; Schema: core; Owner: core
--

CREATE VIEW "AllPersonnel" AS
 SELECT personnel.id,
    personnel.name_last,
    personnel.name_first,
    personnel.user_level,
    personnel.days_to_log,
    personnel.apb_type_id,
    personnel.apb_zone_id,
    personnel.apb_violations,
    personnel.created,
    personnel.created_by,
    personnel.updated,
    personnel.updated_by
   FROM "Personnel" personnel
  WHERE (personnel.deleted IS NULL);


ALTER TABLE "AllPersonnel" OWNER TO core;

--
-- Name: COLUMN "AllPersonnel".apb_type_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "AllPersonnel".apb_type_id IS 'Anti-passback type id';


--
-- Name: COLUMN "AllPersonnel".apb_zone_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "AllPersonnel".apb_zone_id IS 'Anti-passback zone id';


--
-- Name: COLUMN "AllPersonnel".apb_violations; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "AllPersonnel".apb_violations IS 'Anti-passback zone violation count';


--
-- Name: AlterTableInformation; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "AlterTableInformation" (
    id integer NOT NULL,
    tabletobealtered character varying(50) NOT NULL,
    ordertoalter integer NOT NULL,
    qryschema character varying(50) NOT NULL,
    qrytable character varying(50) NOT NULL,
    viewname character varying(50),
    functionname character varying(50),
    viewaliasname character varying(50),
    returnfield1 character varying(50) NOT NULL,
    returnfield2 character varying(50),
    returnfield3 character varying(50),
    wherefield character varying(50),
    internalfunctiontableorviewname character varying(50)
);


ALTER TABLE "AlterTableInformation" OWNER TO core;

--
-- Name: AlterTableInformation_id_seq; Type: SEQUENCE; Schema: core; Owner: core
--

CREATE SEQUENCE "AlterTableInformation_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "AlterTableInformation_id_seq" OWNER TO core;

--
-- Name: AlterTableInformation_id_seq; Type: SEQUENCE OWNED BY; Schema: core; Owner: core
--

ALTER SEQUENCE "AlterTableInformation_id_seq" OWNED BY "AlterTableInformation".id;


--
-- Name: BlobType; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "BlobType" (
    id smallint NOT NULL,
    name character varying(50),
    abbrev character varying(10),
    mime_type character varying(50)
);


ALTER TABLE "BlobType" OWNER TO core;

--
-- Name: BlobType_id_seq; Type: SEQUENCE; Schema: core; Owner: core
--

CREATE SEQUENCE "BlobType_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "BlobType_id_seq" OWNER TO core;

--
-- Name: BlobType_id_seq; Type: SEQUENCE OWNED BY; Schema: core; Owner: core
--

ALTER SEQUENCE "BlobType_id_seq" OWNED BY "BlobType".id;


--
-- Name: Card; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Card" (
    token_id uuid NOT NULL,
    card_number bigint NOT NULL,
    site_code bigint DEFAULT 0 NOT NULL,
    card_format smallint DEFAULT 26 NOT NULL,
    card_type smallint DEFAULT 1,
    pin_number character varying(50),
    card_valid boolean,
    activate_date date DEFAULT (now())::date,
    deactivate_date date DEFAULT ((now() + '1 year'::interval))::date,
    secondary_expiration_date date,
    expire_days smallint,
    action_point_id integer,
    threat_level smallint,
    auto_disable boolean,
    grant_long_access_time boolean,
    escort_visitor_capable boolean,
    access_cost_override_capable boolean,
    event_lock_override_capable boolean,
    building_passback_exemption boolean,
    parking_passback_exemption boolean,
    card_holder_groups smallint,
    activation_group smallint,
    on_access_output smallint,
    compass_command_group smallint,
    deleted timestamp with time zone,
    low_battery boolean DEFAULT false
);


ALTER TABLE "Card" OWNER TO core;

--
-- Name: COLUMN "Card".activate_date; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Card".activate_date IS 'Activate card on date';


--
-- Name: COLUMN "Card".deactivate_date; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Card".deactivate_date IS 'Deactivate card on date';


--
-- Name: COLUMN "Card".expire_days; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Card".expire_days IS 'Card expires after days unused';


--
-- Name: COLUMN "Card".action_point_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Card".action_point_id IS 'Action point to trigger in project';


--
-- Name: Token; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Token" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    type_id smallint,
    user_level integer,
    personnel_id uuid,
    badge_id integer,
    lost boolean DEFAULT false NOT NULL,
    last_read timestamp with time zone,
    last_reader character varying(255),
    last_read_status character varying(255),
    created timestamp with time zone DEFAULT now(),
    created_by character varying(255) DEFAULT "current_user"(),
    updated timestamp with time zone,
    updated_by character varying(255),
    deleted timestamp with time zone,
    deleted_by character varying(255),
    downloaded timestamp with time zone,
    downloaded_by character varying(255),
    download_required boolean
);


ALTER TABLE "Token" OWNER TO core;

--
-- Name: COLUMN "Token".badge_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Token".badge_id IS 'Tree node id for badge template';


--
-- Name: CardDownload; Type: VIEW; Schema: core; Owner: core
--

CREATE VIEW "CardDownload" AS
 SELECT card.token_id,
    token.personnel_id,
    personnel.name_last,
    personnel.name_first,
    card.card_number,
    card.site_code,
    card.card_format,
    card.card_type,
    card.pin_number,
    card.card_valid,
    card.activate_date,
    card.deactivate_date,
    card.expire_days,
    card.secondary_expiration_date,
    card.action_point_id,
    card.threat_level,
    card.auto_disable,
    card.grant_long_access_time,
    card.escort_visitor_capable,
    card.access_cost_override_capable,
    card.event_lock_override_capable,
    card.building_passback_exemption,
    card.parking_passback_exemption,
    card.card_holder_groups,
    card.activation_group,
    card.on_access_output,
    card.compass_command_group,
    personnel.apb_type_id,
    personnel.apb_zone_id,
    personnel.apb_violations,
    token.lost,
    token.downloaded,
    token.downloaded_by,
    token.download_required,
    card.low_battery
   FROM (("Card" card
     JOIN "Token" token ON ((card.token_id = token.id)))
     JOIN "Personnel" personnel ON ((token.personnel_id = personnel.id)))
  WHERE (token.deleted IS NULL);


ALTER TABLE "CardDownload" OWNER TO core;

--
-- Name: CardToken; Type: VIEW; Schema: core; Owner: core
--

CREATE VIEW "CardToken" AS
 SELECT card.token_id,
    card.card_number,
    card.site_code,
    card.card_format,
    card.card_type,
    card.pin_number,
    card.card_valid,
    card.activate_date,
    card.deactivate_date,
    card.secondary_expiration_date,
    card.expire_days,
    card.action_point_id,
    card.threat_level,
    card.auto_disable,
    card.grant_long_access_time,
    card.escort_visitor_capable,
    card.access_cost_override_capable,
    card.event_lock_override_capable,
    card.building_passback_exemption,
    card.parking_passback_exemption,
    card.card_holder_groups,
    card.activation_group,
    card.on_access_output,
    card.compass_command_group,
    token.user_level,
    token.personnel_id,
    token.badge_id,
    token.lost,
    token.last_read,
    token.last_reader,
    token.last_read_status,
    token.created,
    token.created_by,
    token.updated,
    token.updated_by,
    token.downloaded,
    token.downloaded_by,
    token.download_required,
    card.low_battery
   FROM ("Card" card
     JOIN "Token" token ON ((card.token_id = token.id)))
  WHERE (token.deleted IS NULL);


ALTER TABLE "CardToken" OWNER TO core;

--
-- Name: Parameter; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Parameter" (
    id bigint NOT NULL,
    name character varying(255) NOT NULL,
    value text
);


ALTER TABLE "Parameter" OWNER TO core;

--
-- Name: Parameter_id_seq; Type: SEQUENCE; Schema: core; Owner: core
--

CREATE SEQUENCE "Parameter_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "Parameter_id_seq" OWNER TO core;

--
-- Name: Parameter_id_seq; Type: SEQUENCE OWNED BY; Schema: core; Owner: core
--

ALTER SEQUENCE "Parameter_id_seq" OWNED BY "Parameter".id;


--
-- Name: PersonnelTokenCounts; Type: VIEW; Schema: core; Owner: core
--

CREATE VIEW "PersonnelTokenCounts" AS
 SELECT personnel.id AS personnel_id,
    token.type_id,
    count(token.id) AS count
   FROM ("Personnel" personnel
     LEFT JOIN "Token" token ON (((personnel.id = token.personnel_id) AND (token.deleted IS NULL))))
  WHERE (personnel.deleted IS NULL)
  GROUP BY personnel.id, token.type_id;


ALTER TABLE "PersonnelTokenCounts" OWNER TO core;

--
-- Name: PersonnelWithSingleCard; Type: VIEW; Schema: core; Owner: core
--

CREATE VIEW "PersonnelWithSingleCard" AS
 SELECT personnel.id AS personnel_id
   FROM ("Personnel" personnel
     LEFT JOIN "Token" token ON ((((personnel.id = token.personnel_id) AND (token.type_id = 1)) AND (token.deleted IS NULL))))
  WHERE (personnel.deleted IS NULL)
  GROUP BY personnel.id
 HAVING (count(token.id) = 1);


ALTER TABLE "PersonnelWithSingleCard" OWNER TO core;

--
-- Name: Reader; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Reader" (
    id integer NOT NULL,
    name character varying(255),
    is_zone boolean DEFAULT false NOT NULL,
    is_muster_zone boolean DEFAULT false NOT NULL
);


ALTER TABLE "Reader" OWNER TO core;

--
-- Name: ReadersToAccessEntries; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "ReadersToAccessEntries" (
    reader_id integer NOT NULL,
    access_entry_id integer NOT NULL
);


ALTER TABLE "ReadersToAccessEntries" OWNER TO core;

--
-- Name: RfidTag; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "RfidTag" (
    token_id uuid NOT NULL,
    tag_number numeric(39,0) NOT NULL
);


ALTER TABLE "RfidTag" OWNER TO core;

--
-- Name: ScheduledEvent; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "ScheduledEvent" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    start timestamp with time zone,
    stop timestamp with time zone,
    event_id integer,
    active boolean DEFAULT false NOT NULL
);


ALTER TABLE "ScheduledEvent" OWNER TO core;

--
-- Name: SystemInformation; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "SystemInformation" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    created timestamp with time zone DEFAULT now(),
    computer_id integer,
    computer_name character varying(50)
);


ALTER TABLE "SystemInformation" OWNER TO core;

--
-- Name: SystemInformationItem; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "SystemInformationItem" (
    sysinfo_id uuid NOT NULL,
    item_id integer NOT NULL,
    "group" character varying(255),
    name character varying(255),
    value text,
    kind character varying(255),
    key text,
    description text
);


ALTER TABLE "SystemInformationItem" OWNER TO core;

--
-- Name: TokenType; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "TokenType" (
    id smallint NOT NULL,
    name character varying(50) NOT NULL,
    table_name character varying(63)
);


ALTER TABLE "TokenType" OWNER TO core;

--
-- Name: TokenType_id_seq; Type: SEQUENCE; Schema: core; Owner: core
--

CREATE SEQUENCE "TokenType_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "TokenType_id_seq" OWNER TO core;

--
-- Name: TokenType_id_seq; Type: SEQUENCE OWNED BY; Schema: core; Owner: core
--

ALTER SEQUENCE "TokenType_id_seq" OWNED BY "TokenType".id;


--
-- Name: Vehicle; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Vehicle" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    personnel_id uuid,
    make character varying(50),
    model character varying(50),
    color character varying(50),
    accent_color character varying(50),
    state_or_prov character varying(50),
    tag character varying(50),
    sticker character varying(50),
    year smallint
);


ALTER TABLE "Vehicle" OWNER TO core;

SET search_path = extra, pg_catalog;

--
-- Name: AccessSet; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "AccessSet" (
    id uuid NOT NULL,
    notes_id uuid
);


ALTER TABLE "AccessSet" OWNER TO extra;

--
-- Name: Notes; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "Notes" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    text text
);


ALTER TABLE "Notes" OWNER TO extra;

--
-- Name: AllAccessSet; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "AllAccessSet" AS
 SELECT core.id,
    core.name,
    core.user_level,
    core.download_required,
    extra.notes_id,
    notes.text AS notes
   FROM ((core."AccessSet" core
     LEFT JOIN "AccessSet" extra ON ((core.id = extra.id)))
     LEFT JOIN "Notes" notes ON ((extra.notes_id = notes.id)));


ALTER TABLE "AllAccessSet" OWNER TO extra;

--
-- Name: Blob; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "Blob" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    type_id smallint,
    bytes bytea
);


ALTER TABLE "Blob" OWNER TO extra;

--
-- Name: Personnel; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "Personnel" (
    id uuid NOT NULL,
    name_middle character varying(50),
    name_prefix character varying(30),
    name_suffix character varying(30),
    company character varying(50),
    department character varying(50),
    job_title character varying(50),
    email character varying(255),
    phone_work character varying(30),
    phone_work_ext character varying(20),
    phone_mobile character varying(30),
    phone_home character varying(30),
    address character varying(150),
    city character varying(50),
    state_or_prov character varying(50),
    postal_code character varying(20),
    country character varying(50),
    notes_id uuid,
    photo_id uuid,
    signature_id uuid,
    fingerprint_id uuid,
    room character varying(50),
    assigned_to smallint,
    admission_date timestamp without time zone
);


ALTER TABLE "Personnel" OWNER TO extra;

--
-- Name: AllPersonnel; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "AllPersonnel" AS
 SELECT core.id,
    core.name_last,
    core.name_first,
    extra.name_middle,
    extra.name_prefix,
    extra.name_suffix,
    extra.company,
    extra.department,
    extra.job_title,
    extra.email,
    extra.phone_work,
    extra.phone_work_ext,
    extra.phone_mobile,
    extra.phone_home,
    extra.address,
    extra.city,
    extra.state_or_prov,
    extra.postal_code,
    extra.country,
    extra.notes_id,
    notes.text AS notes,
    extra.photo_id,
    photo.bytes AS photo,
    photo_type.mime_type AS photo_type,
    extra.signature_id,
    signature.bytes AS signature,
    signature_type.mime_type AS signature_type,
    extra.fingerprint_id,
    fingerprint.bytes AS fingerprint,
    fingerprint_type.mime_type AS fingerprint_type,
    core.user_level,
    core.days_to_log,
    core.apb_type_id,
    core.apb_zone_id,
    core.apb_violations,
    core.created,
    core.created_by,
    core.updated,
    core.updated_by,
    extra.room,
    extra.assigned_to,
    extra.admission_date
   FROM ((((((((core."AllPersonnel" core
     LEFT JOIN "Personnel" extra ON ((core.id = extra.id)))
     LEFT JOIN "Notes" notes ON ((extra.notes_id = notes.id)))
     LEFT JOIN "Blob" photo ON ((extra.photo_id = photo.id)))
     LEFT JOIN core."BlobType" photo_type ON ((photo.type_id = photo_type.id)))
     LEFT JOIN "Blob" signature ON ((extra.signature_id = signature.id)))
     LEFT JOIN core."BlobType" signature_type ON ((signature.type_id = signature_type.id)))
     LEFT JOIN "Blob" fingerprint ON ((extra.fingerprint_id = fingerprint.id)))
     LEFT JOIN core."BlobType" fingerprint_type ON ((fingerprint.type_id = fingerprint_type.id)));


ALTER TABLE "AllPersonnel" OWNER TO extra;

--
-- Name: Vehicle; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "Vehicle" (
    id uuid NOT NULL,
    notes_id uuid
);


ALTER TABLE "Vehicle" OWNER TO extra;

--
-- Name: AllVehicle; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "AllVehicle" AS
 SELECT core.id,
    core.personnel_id,
    core.make,
    core.model,
    core.color,
    core.accent_color,
    core.state_or_prov,
    core.tag,
    core.sticker,
    core.year,
    extra.notes_id,
    notes.text AS notes
   FROM ((core."Vehicle" core
     LEFT JOIN "Vehicle" extra ON ((core.id = extra.id)))
     LEFT JOIN "Notes" notes ON ((extra.notes_id = notes.id)));


ALTER TABLE "AllVehicle" OWNER TO extra;

--
-- Name: Card; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "Card" (
    token_id uuid NOT NULL,
    card_emboss_num character varying(50),
    card_label character varying(50)
);


ALTER TABLE "Card" OWNER TO extra;

--
-- Name: CardToken; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "CardToken" AS
 SELECT core.token_id,
    core.card_number,
    core.site_code,
    core.card_format,
    core.card_type,
    extra.card_emboss_num,
    extra.card_label,
    core.pin_number,
    core.card_valid,
    core.activate_date,
    core.deactivate_date,
    core.secondary_expiration_date,
    core.expire_days,
    core.action_point_id,
    core.threat_level,
    core.auto_disable,
    core.grant_long_access_time,
    core.escort_visitor_capable,
    core.access_cost_override_capable,
    core.event_lock_override_capable,
    core.building_passback_exemption,
    core.parking_passback_exemption,
    core.card_holder_groups,
    core.activation_group,
    core.on_access_output,
    core.compass_command_group,
    core.user_level,
    core.personnel_id,
    core.badge_id,
    core.lost,
    core.last_read,
    core.last_reader,
    core.last_read_status,
    core.created,
    core.created_by,
    core.updated,
    core.updated_by,
    core.downloaded,
    core.downloaded_by,
    core.download_required,
    core.low_battery
   FROM (core."CardToken" core
     LEFT JOIN "Card" extra ON ((core.token_id = extra.token_id)));


ALTER TABLE "CardToken" OWNER TO extra;

--
-- Name: MultiCard; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "MultiCard" AS
 SELECT card.token_id,
    card.personnel_id,
    card.card_number,
    card.site_code,
    card.card_format,
    card.card_type,
    card.card_emboss_num,
    card.card_label,
    card.pin_number,
    card.card_valid,
    card.activate_date,
    card.deactivate_date,
    card.secondary_expiration_date,
    card.expire_days,
    card.action_point_id,
    card.threat_level,
    card.auto_disable,
    card.grant_long_access_time,
    card.escort_visitor_capable,
    card.access_cost_override_capable,
    card.event_lock_override_capable,
    card.building_passback_exemption,
    card.parking_passback_exemption,
    card.card_holder_groups,
    card.activation_group,
    card.on_access_output,
    card.compass_command_group,
    card.user_level AS card_user_level,
    card.badge_id,
    card.lost,
    card.last_read,
    card.last_reader,
    card.last_read_status,
    card.created AS card_created,
    card.created_by AS card_created_by,
    card.updated AS card_updated,
    card.updated_by AS card_updated_by,
    card.downloaded,
    card.downloaded_by,
    card.download_required,
    personnel.name_last,
    personnel.name_first,
    personnel.name_middle,
    personnel.name_prefix,
    personnel.name_suffix,
    personnel.company,
    personnel.department,
    personnel.job_title,
    personnel.email,
    personnel.phone_work,
    personnel.phone_work_ext,
    personnel.phone_mobile,
    personnel.phone_home,
    personnel.address,
    personnel.city,
    personnel.state_or_prov,
    personnel.postal_code,
    personnel.country,
    personnel.notes_id,
    personnel.notes,
    personnel.photo_id,
    personnel.photo,
    personnel.photo_type,
    personnel.signature_id,
    personnel.signature,
    personnel.signature_type,
    personnel.fingerprint_id,
    personnel.fingerprint,
    personnel.fingerprint_type,
    personnel.user_level AS personnel_user_level,
    personnel.days_to_log,
    personnel.apb_type_id,
    personnel.apb_zone_id,
    personnel.apb_violations,
    personnel.created AS personnel_created,
    personnel.created_by AS personnel_created_by,
    personnel.updated AS personnel_updated,
    personnel.updated_by AS personnel_updated_by,
    personnel.room,
    personnel.assigned_to,
    personnel.admission_date,
    card.low_battery
   FROM ("CardToken" card
     LEFT JOIN "AllPersonnel" personnel ON ((personnel.id = card.personnel_id)));


ALTER TABLE "MultiCard" OWNER TO extra;

--
-- Name: SingleCard; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "SingleCard" AS
 SELECT card.token_id,
    card.personnel_id,
    card.card_number,
    card.site_code,
    card.card_format,
    card.card_type,
    card.card_emboss_num,
    card.card_label,
    card.pin_number,
    card.card_valid,
    card.activate_date,
    card.deactivate_date,
    card.secondary_expiration_date,
    card.expire_days,
    card.action_point_id,
    card.threat_level,
    card.auto_disable,
    card.grant_long_access_time,
    card.escort_visitor_capable,
    card.access_cost_override_capable,
    card.event_lock_override_capable,
    card.building_passback_exemption,
    card.parking_passback_exemption,
    card.card_holder_groups,
    card.activation_group,
    card.on_access_output,
    card.compass_command_group,
    card.user_level AS card_user_level,
    card.badge_id,
    card.lost,
    card.last_read,
    card.last_reader,
    card.last_read_status,
    card.created AS card_created,
    card.created_by AS card_created_by,
    card.updated AS card_updated,
    card.updated_by AS card_updated_by,
    card.downloaded,
    card.downloaded_by,
    card.download_required,
    personnel.name_last,
    personnel.name_first,
    personnel.name_middle,
    personnel.name_prefix,
    personnel.name_suffix,
    personnel.company,
    personnel.department,
    personnel.job_title,
    personnel.email,
    personnel.phone_work,
    personnel.phone_work_ext,
    personnel.phone_mobile,
    personnel.phone_home,
    personnel.address,
    personnel.city,
    personnel.state_or_prov,
    personnel.postal_code,
    personnel.country,
    personnel.notes_id,
    personnel.notes,
    personnel.photo_id,
    personnel.photo,
    personnel.photo_type,
    personnel.signature_id,
    personnel.signature,
    personnel.signature_type,
    personnel.fingerprint_id,
    personnel.fingerprint,
    personnel.fingerprint_type,
    personnel.user_level AS personnel_user_level,
    personnel.days_to_log,
    personnel.apb_type_id,
    personnel.apb_zone_id,
    personnel.apb_violations,
    personnel.created AS personnel_created,
    personnel.created_by AS personnel_created_by,
    personnel.updated AS personnel_updated,
    personnel.updated_by AS personnel_updated_by,
    personnel.room,
    personnel.assigned_to,
    personnel.admission_date,
    card.low_battery
   FROM ((core."PersonnelWithSingleCard" singles
     LEFT JOIN "CardToken" card ON ((card.personnel_id = singles.personnel_id)))
     LEFT JOIN "AllPersonnel" personnel ON ((personnel.id = singles.personnel_id)));


ALTER TABLE "SingleCard" OWNER TO extra;

SET search_path = history, pg_catalog;

--
-- Name: AccutechTagChange; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "AccutechTagChange" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    change_time timestamp with time zone DEFAULT now() NOT NULL,
    event smallint NOT NULL,
    card_number bigint NOT NULL,
    name_first character varying(50),
    name_last character varying(50),
    name_middle character varying(50),
    assigned_to smallint,
    updated_by character varying(255),
    room character varying(50)
);


ALTER TABLE "AccutechTagChange" OWNER TO core;

--
-- Name: Activity; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "Activity" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    "time" timestamp with time zone DEFAULT now() NOT NULL,
    event_type_id smallint,
    rtu_id integer,
    rtu_name character varying(100),
    point_id integer,
    point_name character varying(100),
    state smallint,
    status character varying(255),
    card_number bigint,
    site_code bigint,
    card_format smallint,
    card_holder_name character varying(100),
    computer character varying(100),
    "user" character varying(100),
    user_comments text,
    token_id uuid
);


ALTER TABLE "Activity" OWNER TO core;

--
-- Name: Activity_Statistics; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "Activity_Statistics" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    event_type_id smallint,
    rtu_id integer,
    rtu_name character varying(100),
    point_id integer,
    point_name character varying(100),
    state smallint,
    status character varying(255),
    card_number bigint,
    site_code bigint,
    card_format smallint,
    card_holder_name character varying(100),
    computer character varying(100),
    "user" character varying(100),
    user_comments text,
    token_id uuid,
    active_time timestamp with time zone,
    inactive_time timestamp with time zone,
    acked_time timestamp with time zone,
    cleared_time timestamp with time zone,
    last_active timestamp with time zone,
    total_active bigint,
    active_count bigint
);


ALTER TABLE "Activity_Statistics" OWNER TO core;

--
-- Name: ChangeType; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "ChangeType" (
    id smallint NOT NULL,
    name character varying(50) NOT NULL
);


ALTER TABLE "ChangeType" OWNER TO core;

--
-- Name: ChangeType_id_seq; Type: SEQUENCE; Schema: history; Owner: core
--

CREATE SEQUENCE "ChangeType_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "ChangeType_id_seq" OWNER TO core;

--
-- Name: ChangeType_id_seq; Type: SEQUENCE OWNED BY; Schema: history; Owner: core
--

ALTER SEQUENCE "ChangeType_id_seq" OWNED BY "ChangeType".id;


--
-- Name: EventType; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "EventType" (
    id smallint NOT NULL,
    name character varying(50) NOT NULL
);


ALTER TABLE "EventType" OWNER TO core;

--
-- Name: EventType_id_seq; Type: SEQUENCE; Schema: history; Owner: core
--

CREATE SEQUENCE "EventType_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "EventType_id_seq" OWNER TO core;

--
-- Name: EventType_id_seq; Type: SEQUENCE OWNED BY; Schema: history; Owner: core
--

ALTER SEQUENCE "EventType_id_seq" OWNED BY "EventType".id;


--
-- Name: ProjectChange; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "ProjectChange" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    "time" timestamp with time zone DEFAULT now() NOT NULL,
    change_type_id smallint,
    name character varying(100),
    computer character varying(100),
    "user" character varying(100),
    old_data bytea,
    new_data bytea
);


ALTER TABLE "ProjectChange" OWNER TO core;

SET search_path = core, pg_catalog;

--
-- Name: created; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AllPersonnel" ALTER COLUMN created SET DEFAULT now();


--
-- Name: id; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AlterTableInformation" ALTER COLUMN id SET DEFAULT nextval('"AlterTableInformation_id_seq"'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "BlobType" ALTER COLUMN id SET DEFAULT nextval('"BlobType_id_seq"'::regclass);


--
-- Name: low_battery; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "CardDownload" ALTER COLUMN low_battery SET DEFAULT false;


--
-- Name: low_battery; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "CardToken" ALTER COLUMN low_battery SET DEFAULT false;


--
-- Name: id; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "Parameter" ALTER COLUMN id SET DEFAULT nextval('"Parameter_id_seq"'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "TokenType" ALTER COLUMN id SET DEFAULT nextval('"TokenType_id_seq"'::regclass);


SET search_path = extra, pg_catalog;

--
-- Name: card_type; Type: DEFAULT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "CardToken" ALTER COLUMN card_type SET DEFAULT 1;


--
-- Name: low_battery; Type: DEFAULT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "CardToken" ALTER COLUMN low_battery SET DEFAULT false;


--
-- Name: card_type; Type: DEFAULT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "MultiCard" ALTER COLUMN card_type SET DEFAULT 1;


--
-- Name: low_battery; Type: DEFAULT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "MultiCard" ALTER COLUMN low_battery SET DEFAULT false;


--
-- Name: card_type; Type: DEFAULT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "SingleCard" ALTER COLUMN card_type SET DEFAULT 1;


--
-- Name: low_battery; Type: DEFAULT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "SingleCard" ALTER COLUMN low_battery SET DEFAULT false;


SET search_path = history, pg_catalog;

--
-- Name: id; Type: DEFAULT; Schema: history; Owner: core
--

ALTER TABLE ONLY "ChangeType" ALTER COLUMN id SET DEFAULT nextval('"ChangeType_id_seq"'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: history; Owner: core
--

ALTER TABLE ONLY "EventType" ALTER COLUMN id SET DEFAULT nextval('"EventType_id_seq"'::regclass);


SET search_path = core, pg_catalog;

--
-- Data for Name: AccessEntry; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "AccessEntry" (id, name) FROM stdin;
\.


--
-- Data for Name: AccessSet; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "AccessSet" (id, name, user_level, download_required) FROM stdin;
\.


--
-- Data for Name: AccessSetsToAccessEntries; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "AccessSetsToAccessEntries" (access_set_id, access_entry_id) FROM stdin;
\.


--
-- Data for Name: AccessSetsToTokens; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "AccessSetsToTokens" (access_set_id, token_id) FROM stdin;
\.


--
-- Data for Name: AlterTableInformation; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "AlterTableInformation" (id, tabletobealtered, ordertoalter, qryschema, qrytable, viewname, functionname, viewaliasname, returnfield1, returnfield2, returnfield3, wherefield, internalfunctiontableorviewname) FROM stdin;
1	Card	1	information_schema	views	CardToken	\N	extra	table_schema	table_name	view_definition	table_name	\N
2	Card	3	information_schema	views	MultiCard	\N	card	table_schema	table_name	view_definition	table_name	\N
3	Card	2	information_schema	views	SingleCard	\N	card	table_schema	table_name	view_definition	table_name	\N
4	Card	4	pg_catalog	pg_proc	\N	CardToken_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
5	Card	5	pg_catalog	pg_proc	\N	CardToken_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
6	Card	6	pg_catalog	pg_proc	\N	MultiCard_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
7	Card	7	pg_catalog	pg_proc	\N	MultiCard_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
8	Card	8	pg_catalog	pg_proc	\N	SingleCard_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
9	Card	9	pg_catalog	pg_proc	\N	SingleCard_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
10	Personnel	1	information_schema	views	AllPersonnel	\N	extra	table_schema	table_name	view_definition	table_name	\N
11	Personnel	2	information_schema	views	MultiCard	\N	personnel	table_schema	table_name	view_definition	table_name	\N
12	Personnel	3	information_schema	views	SingleCard	\N	personnel	table_schema	table_name	view_definition	table_name	\N
13	Personnel	4	pg_catalog	pg_proc	\N	AllPersonnel_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	Personnel
14	Personnel	5	pg_catalog	pg_proc	\N	AllPersonnel_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	Personnel
15	Personnel	6	pg_catalog	pg_proc	\N	MultiCard_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	AllPersonnel
16	Personnel	7	pg_catalog	pg_proc	\N	MultiCard_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	AllPersonnel
17	Personnel	8	pg_catalog	pg_proc	\N	SingleCard_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	AllPersonnel
18	Personnel	9	pg_catalog	pg_proc	\N	SingleCard_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	AllPersonnel
19	Vehicle	1	information_schema	views	AllVehicle	\N	extra	table_schema	table_name	view_definition	table_name	\N
20	Vehicle	2	pg_catalog	pg_proc	\N	AllVehicle_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	Vehicle
21	Vehicle	3	pg_catalog	pg_proc	\N	AllVehicle_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	Vehicle
\.


--
-- Name: AlterTableInformation_id_seq; Type: SEQUENCE SET; Schema: core; Owner: core
--

SELECT pg_catalog.setval('"AlterTableInformation_id_seq"', 21, true);


--
-- Data for Name: BlobType; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "BlobType" (id, name, abbrev, mime_type) FROM stdin;
0	Binary Data	BIN	application/octet-stream
1	Plain Text	TXT	text/plain
2	Comma-separated Values	CSV	text/csv
3	Rich Text Format	RTF	text/rtf
4	HyperText Markup Language	HTML	text/html
5	Cascading Style Sheets	CSS	text/css
6	JavaScript	JS	application/javascript
7	Portable Document Format	PDF	application/pdf
8	PostScript	PS	application/postscript
9	Extensible Markup Language	XML	application/xml
10	Bitmap Image	BMP	image/bmp
11	GIF Image	GIF	image/gif
12	JPEG Image	JPEG	image/jpeg
13	PNG Image	PNG	image/png
14	SVG Image	SVG	image/svg+xml
15	µ-Law (G.711) Audio	ULAW	audio/basic
16	AIFF Audio	AIFF	audio/aiff
17	MP3/MP2/MPEG Audio	MP3	audio/mpeg
18	MP4 Audio	MP4	audio/mp4
19	Ogg Vorbis Audio	OGG	audio/ogg
20	WAV/WAVE Audio	WAV	audio/vnd.wave
\.


--
-- Name: BlobType_id_seq; Type: SEQUENCE SET; Schema: core; Owner: core
--

SELECT pg_catalog.setval('"BlobType_id_seq"', 21, true);


--
-- Data for Name: Card; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Card" (token_id, card_number, site_code, card_format, card_type, pin_number, card_valid, activate_date, deactivate_date, secondary_expiration_date, expire_days, action_point_id, threat_level, auto_disable, grant_long_access_time, escort_visitor_capable, access_cost_override_capable, event_lock_override_capable, building_passback_exemption, parking_passback_exemption, card_holder_groups, activation_group, on_access_output, compass_command_group, deleted, low_battery) FROM stdin;
\.


--
-- Data for Name: Parameter; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Parameter" (id, name, value) FROM stdin;
2	product_version	4.0.29.22
1	db_version	4.0.17.14
\.


--
-- Name: Parameter_id_seq; Type: SEQUENCE SET; Schema: core; Owner: core
--

SELECT pg_catalog.setval('"Parameter_id_seq"', 2, true);


--
-- Data for Name: Personnel; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Personnel" (id, name_last, name_first, user_level, days_to_log, apb_type_id, apb_zone_id, apb_violations, created, created_by, updated, updated_by, deleted, deleted_by) FROM stdin;
\.


--
-- Data for Name: Reader; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Reader" (id, name, is_zone, is_muster_zone) FROM stdin;
\.


--
-- Data for Name: ReadersToAccessEntries; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "ReadersToAccessEntries" (reader_id, access_entry_id) FROM stdin;
\.


--
-- Data for Name: RfidTag; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "RfidTag" (token_id, tag_number) FROM stdin;
\.


--
-- Data for Name: ScheduledEvent; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "ScheduledEvent" (id, start, stop, event_id, active) FROM stdin;
\.


--
-- Data for Name: SystemInformation; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "SystemInformation" (id, created, computer_id, computer_name) FROM stdin;
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	2018-02-28 09:13:02.592717-06	21041	OSSI-DNOVAK
7f888049-412c-4314-9660-555cd1e12068	2018-02-28 09:39:40.986154-06	4	DLarrabee
\.


--
-- Data for Name: SystemInformationItem; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "SystemInformationItem" (sysinfo_id, item_id, "group", name, value, kind, key, description) FROM stdin;
7f888049-412c-4314-9660-555cd1e12068	0	Computer System	Name	DLARRABEE	CIM:String	WMI:CIM_ManagedSystemElement.Name	\N
7f888049-412c-4314-9660-555cd1e12068	1	Computer System	DNSHostName	DLarrabee	CIM:String	WMI:Win32_ComputerSystem.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	2	Computer System	Domain	intelli-site.com	CIM:String	WMI:Win32_ComputerSystem.Domain	\N
7f888049-412c-4314-9660-555cd1e12068	3	Computer System	DomainRole	Member Workstation	string(CIM:UInt16)	WMI:Win32_ComputerSystem.DomainRole	\N
7f888049-412c-4314-9660-555cd1e12068	4	Computer System	PartOfDomain	True	CIM:Boolean	WMI:Win32_ComputerSystem.PartOfDomain	\N
7f888049-412c-4314-9660-555cd1e12068	5	Computer System	Workgroup	\N	CIM:String	WMI:Win32_ComputerSystem.Workgroup	\N
7f888049-412c-4314-9660-555cd1e12068	6	Computer System	PCSystemType	Mobile	string(CIM:UInt16)	WMI:Win32_ComputerSystem.PCSystemType	\N
7f888049-412c-4314-9660-555cd1e12068	7	Computer System	SystemType	x64-based PC	CIM:String	WMI:Win32_ComputerSystem.SystemType	\N
7f888049-412c-4314-9660-555cd1e12068	8	Computer System	Manufacturer	Hewlett-Packard	CIM:String	WMI:Win32_ComputerSystem.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	9	Computer System	Model	HP ProBook 4530s	CIM:String	WMI:Win32_ComputerSystem.Model	\N
7f888049-412c-4314-9660-555cd1e12068	10	Computer System	NumberOfProcessors	1	CIM:UInt32	WMI:Win32_ComputerSystem.NumberOfProcessors	\N
7f888049-412c-4314-9660-555cd1e12068	11	Computer System	NumberOfLogicalProcessors	4	CIM:UInt32	WMI:Win32_ComputerSystem.NumberOfLogicalProcessors	\N
7f888049-412c-4314-9660-555cd1e12068	12	Computer System	TotalPhysicalMemory	8126 MB	toMegaBytes(CIM:UInt64)	WMI:Win32_ComputerSystem.TotalPhysicalMemory	\N
7f888049-412c-4314-9660-555cd1e12068	13	Operating System	Computer System Name	DLARRABEE	CIM:String	WMI:CIM_OperatingSystem.CSName	\N
7f888049-412c-4314-9660-555cd1e12068	14	Operating System	Description	\N	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	15	Operating System	Caption	Microsoft Windows 7 Professional 	CIM:String	WMI:CIM_ManagedSystemElement.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	16	Operating System	OtherTypeDescription	\N	CIM:String	WMI:CIM_OperatingSystem.OtherTypeDescription	\N
7f888049-412c-4314-9660-555cd1e12068	17	Operating System	OperatingSystemSKU	Unknown (48)	string(CIM:UInt32)	WMI:Win32_OperatingSystem.OperatingSystemSKU	\N
7f888049-412c-4314-9660-555cd1e12068	18	Operating System	ProductType	Workstation	string(CIM:UInt32)	WMI:Win32_OperatingSystem.ProductType	\N
7f888049-412c-4314-9660-555cd1e12068	19	Operating System	OSArchitecture	64-bit	CIM:String	WMI:Win32_OperatingSystem.OSArchitecture	\N
7f888049-412c-4314-9660-555cd1e12068	20	Operating System	OSLanguage	English – United States	string(CIM:UInt32)	WMI:Win32_OperatingSystem.OSLanguage	\N
7f888049-412c-4314-9660-555cd1e12068	21	Operating System	CurrentTimeZone	-360	CIM:SInt16	WMI:CIM_OperatingSystem.CurrentTimeZone	\N
7f888049-412c-4314-9660-555cd1e12068	22	Operating System	Version	6.1.7601	CIM:String	WMI:CIM_OperatingSystem.Version	\N
7f888049-412c-4314-9660-555cd1e12068	23	Operating System	BuildNumber	7601	CIM:String	WMI:Win32_OperatingSystem.BuildNumber	\N
7f888049-412c-4314-9660-555cd1e12068	24	Operating System	BuildType	Multiprocessor Free	CIM:String	WMI:Win32_OperatingSystem.BuildType	\N
7f888049-412c-4314-9660-555cd1e12068	25	Operating System	ServicePackMajorVersion	1	CIM:UInt16	WMI:Win32_OperatingSystem.ServicePackMajorVersion	\N
7f888049-412c-4314-9660-555cd1e12068	26	Operating System	ServicePackMinorVersion	0	CIM:UInt16	WMI:Win32_OperatingSystem.ServicePackMinorVersion	\N
7f888049-412c-4314-9660-555cd1e12068	27	Motherboard	Manufacturer	Hewlett-Packard	CIM:String	WMI:CIM_PhysicalElement.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	28	Motherboard	Model	\N	CIM:String	WMI:CIM_PhysicalElement.Model	\N
7f888049-412c-4314-9660-555cd1e12068	29	Motherboard	Product	167C	CIM:String	WMI:Win32_BaseBoard.Product	\N
7f888049-412c-4314-9660-555cd1e12068	30	Motherboard	Name	Base Board	CIM:String	WMI:CIM_ManagedSystemElement.Name	\N
7f888049-412c-4314-9660-555cd1e12068	31	Motherboard	Description	Base Board	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	32	Motherboard	Version	KBC Version 22.1F	CIM:String	WMI:CIM_PhysicalElement.Version	\N
7f888049-412c-4314-9660-555cd1e12068	33	System Firmware	Manufacturer	Hewlett-Packard	CIM:String	WMI:CIM_SoftwareElement.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	34	System Firmware	Description	Default System BIOS	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	35	System Firmware	ReleaseDate	20110718000000.000000+000	CIM:DateTime	WMI:Win32_BIOS.ReleaseDate	\N
7f888049-412c-4314-9660-555cd1e12068	36	System Firmware	FirmwareType	BIOS	Enum:FirmwareType	Custom:GetFirmwareType	\N
7f888049-412c-4314-9660-555cd1e12068	37	System Firmware	BIOSVersion	HPQOEM - f	CIM:String	WMI:Win32_BIOS.BIOSVersion[0]	\N
7f888049-412c-4314-9660-555cd1e12068	38	System Firmware	SMBIOSBIOSVersion	68SRR Ver. F.0A	CIM:String	WMI:Win32_BIOS.SMBIOSBIOSVersion	\N
7f888049-412c-4314-9660-555cd1e12068	39	System Firmware	SMBIOSMajorVersion	2	CIM:UInt16	WMI:Win32_BIOS.SMBIOSMajorVersion	\N
7f888049-412c-4314-9660-555cd1e12068	40	System Firmware	SMBIOSMinorVersion	6	CIM:UInt16	WMI:Win32_BIOS.SMBIOSMinorVersion	\N
7f888049-412c-4314-9660-555cd1e12068	41	System Firmware	BiosCharacteristics	[7] PCI is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[0]	\N
7f888049-412c-4314-9660-555cd1e12068	42	System Firmware	BiosCharacteristics	[8] PC Card (PCMCIA) is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[1]	\N
7f888049-412c-4314-9660-555cd1e12068	43	System Firmware	BiosCharacteristics	[11] BIOS is Upgradable (Flash)	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[2]	\N
7f888049-412c-4314-9660-555cd1e12068	44	System Firmware	BiosCharacteristics	[12] BIOS shadowing is allowed	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[3]	\N
7f888049-412c-4314-9660-555cd1e12068	45	System Firmware	BiosCharacteristics	[15] Boot from CD is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[4]	\N
7f888049-412c-4314-9660-555cd1e12068	46	System Firmware	BiosCharacteristics	[16] Selectable Boot is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[5]	\N
7f888049-412c-4314-9660-555cd1e12068	47	System Firmware	BiosCharacteristics	[19] EDD (Enhanced Disk Drive) Specification is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[6]	\N
7f888049-412c-4314-9660-555cd1e12068	48	System Firmware	BiosCharacteristics	[26] Int 5h, Print Screen Service is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[7]	\N
7f888049-412c-4314-9660-555cd1e12068	49	System Firmware	BiosCharacteristics	[27] Int 9h, 8042 Keyboard services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[8]	\N
7f888049-412c-4314-9660-555cd1e12068	50	System Firmware	BiosCharacteristics	[28] Int 14h, Serial Services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[9]	\N
7f888049-412c-4314-9660-555cd1e12068	51	System Firmware	BiosCharacteristics	[29] Int 17h, printer services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[10]	\N
7f888049-412c-4314-9660-555cd1e12068	52	System Firmware	BiosCharacteristics	[32] ACPI is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[11]	\N
7f888049-412c-4314-9660-555cd1e12068	53	System Firmware	BiosCharacteristics	[33] USB Legacy is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[12]	\N
7f888049-412c-4314-9660-555cd1e12068	54	System Firmware	BiosCharacteristics	[39] Smart Battery is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[13]	\N
7f888049-412c-4314-9660-555cd1e12068	55	System Firmware	BiosCharacteristics	[40] BIOS Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[14]	\N
7f888049-412c-4314-9660-555cd1e12068	56	System Firmware	BiosCharacteristics	[41] BIOS Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[15]	\N
7f888049-412c-4314-9660-555cd1e12068	57	System Firmware	BiosCharacteristics	[42] BIOS Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[16]	\N
7f888049-412c-4314-9660-555cd1e12068	58	System Firmware	BiosCharacteristics	[48] System Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[17]	\N
7f888049-412c-4314-9660-555cd1e12068	59	System Firmware	BiosCharacteristics	[49] System Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[18]	\N
7f888049-412c-4314-9660-555cd1e12068	60	System Firmware	BiosCharacteristics	[50] System Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[19]	\N
7f888049-412c-4314-9660-555cd1e12068	61	System Firmware	BiosCharacteristics	[51] System Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[20]	\N
7f888049-412c-4314-9660-555cd1e12068	62	System Firmware	BiosCharacteristics	[57] System Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[21]	\N
7f888049-412c-4314-9660-555cd1e12068	63	System Firmware	BiosCharacteristics	[59] System Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[22]	\N
7f888049-412c-4314-9660-555cd1e12068	64	System Firmware	BiosCharacteristics	[65] Unknown	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[23]	\N
7f888049-412c-4314-9660-555cd1e12068	65	System Firmware	BiosCharacteristics	[69] Unknown	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[24]	\N
7f888049-412c-4314-9660-555cd1e12068	66	System Firmware	BiosCharacteristics	[72] Unknown	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[25]	\N
7f888049-412c-4314-9660-555cd1e12068	67	System Firmware	BiosCharacteristics	[73] Unknown	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[26]	\N
7f888049-412c-4314-9660-555cd1e12068	68	System Firmware	BiosCharacteristics	[74] Unknown	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[27]	\N
7f888049-412c-4314-9660-555cd1e12068	69	System Firmware	BiosCharacteristics	[75] Unknown	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[28]	\N
7f888049-412c-4314-9660-555cd1e12068	70	System Firmware	BiosCharacteristics	[76] Unknown	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[29]	\N
7f888049-412c-4314-9660-555cd1e12068	71	Processor	Manufacturer	GenuineIntel	CIM:String	WMI:Win32_Processor.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	72	Processor	Name	Intel(R) Core(TM) i5-2410M CPU @ 2.30GHz	CIM:String	WMI:CIM_ManagedSystemElement.Name	\N
7f888049-412c-4314-9660-555cd1e12068	73	Processor	Description	Intel64 Family 6 Model 42 Stepping 7	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	74	Processor	DeviceID	CPU0	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	75	Processor	Architecture	x64	string(CIM:UInt16)	WMI:Win32_Processor.Architecture	\N
7f888049-412c-4314-9660-555cd1e12068	76	Processor	Family	Unknown (205)	string(CIM:UInt16)	WMI:CIM_Processor.Family	\N
7f888049-412c-4314-9660-555cd1e12068	77	Processor	OtherFamilyDescription	\N	CIM:String	WMI:CIM_Processor.OtherFamilyDescription	\N
7f888049-412c-4314-9660-555cd1e12068	78	Processor	Version	\N	CIM:String	WMI:Win32_Processor.Version	\N
7f888049-412c-4314-9660-555cd1e12068	79	Processor	ProcessorId	BFEBFBFF000206A7	CIM:String	WMI:Win32_Processor.ProcessorId	\N
7f888049-412c-4314-9660-555cd1e12068	80	Processor	NumberOfCores	2	CIM:UInt32	WMI:Win32_Processor.NumberOfCores	\N
7f888049-412c-4314-9660-555cd1e12068	81	Processor	NumberOfLogicalProcessors	4	CIM:UInt32	WMI:Win32_Processor.NumberOfLogicalProcessors	\N
7f888049-412c-4314-9660-555cd1e12068	82	Processor	AddressWidth	64	CIM:UInt16	WMI:CIM_Processor.AddressWidth	\N
7f888049-412c-4314-9660-555cd1e12068	83	Processor	CurrentClockSpeed	2301	CIM:UInt32	WMI:CIM_Processor.CurrentClockSpeed	\N
7f888049-412c-4314-9660-555cd1e12068	84	Processor	MaxClockSpeed	2301	CIM:UInt32	WMI:CIM_Processor.MaxClockSpeed	\N
7f888049-412c-4314-9660-555cd1e12068	85	Memory [1/2]	Tag	Physical Memory 0	CIM:String	WMI:CIM_PhysicalElement.Tag	\N
7f888049-412c-4314-9660-555cd1e12068	86	Memory [1/2]	Manufacturer	01BA	CIM:String	WMI:CIM_PhysicalElement.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	87	Memory [1/2]	Model	\N	CIM:String	WMI:CIM_PhysicalElement.Model	\N
7f888049-412c-4314-9660-555cd1e12068	88	Memory [1/2]	PartNumber	64C0JKHNJ	CIM:String	WMI:CIM_PhysicalElement.PartNumber	\N
7f888049-412c-4314-9660-555cd1e12068	89	Memory [1/2]	Description	Physical Memory	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	90	Memory [1/2]	Capacity	4096 MB	toMegaBytes(CIM:UInt64)	WMI:CIM_PhysicalMemory.Capacity	\N
7f888049-412c-4314-9660-555cd1e12068	91	Memory [1/2]	Speed	1600	CIM:UInt32	WMI:CIM_PhysicalMemory.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	92	Memory [1/2]	DataWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.DataWidth	\N
7f888049-412c-4314-9660-555cd1e12068	93	Memory [1/2]	TotalWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.TotalWidth	\N
7f888049-412c-4314-9660-555cd1e12068	94	Memory [1/2]	BankLabel	BANK 0	CIM:String	WMI:CIM_PhysicalMemory.BankLabel	\N
7f888049-412c-4314-9660-555cd1e12068	95	Memory [1/2]	TypeDetail	Synchronous	string(CIM:UInt16)	WMI:Win32_PhysicalMemory.TypeDetail	\N
7f888049-412c-4314-9660-555cd1e12068	96	Memory [1/2]	MemoryType	Unknown	string(CIM:UInt16)	WMI:CIM_PhysicalMemory.MemoryType	\N
7f888049-412c-4314-9660-555cd1e12068	97	Memory [1/2]	FormFactor	SODIMM	string(CIM:UInt16)	WMI:CIM_Chip.FormFactor	\N
7f888049-412c-4314-9660-555cd1e12068	98	Memory [1/2]	Status	\N	CIM:String	WMI:CIM_ManagedSystemElement.Status	\N
7f888049-412c-4314-9660-555cd1e12068	99	Memory [1/2]	Version	\N	CIM:String	WMI:CIM_PhysicalElement.Version	\N
7f888049-412c-4314-9660-555cd1e12068	100	Memory [2/2]	Tag	Physical Memory 1	CIM:String	WMI:CIM_PhysicalElement.Tag	\N
7f888049-412c-4314-9660-555cd1e12068	101	Memory [2/2]	Manufacturer	01BA	CIM:String	WMI:CIM_PhysicalElement.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	102	Memory [2/2]	Model	\N	CIM:String	WMI:CIM_PhysicalElement.Model	\N
7f888049-412c-4314-9660-555cd1e12068	103	Memory [2/2]	PartNumber	64C0JKHNJ	CIM:String	WMI:CIM_PhysicalElement.PartNumber	\N
7f888049-412c-4314-9660-555cd1e12068	104	Memory [2/2]	Description	Physical Memory	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	105	Memory [2/2]	Capacity	4096 MB	toMegaBytes(CIM:UInt64)	WMI:CIM_PhysicalMemory.Capacity	\N
7f888049-412c-4314-9660-555cd1e12068	106	Memory [2/2]	Speed	1600	CIM:UInt32	WMI:CIM_PhysicalMemory.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	107	Memory [2/2]	DataWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.DataWidth	\N
7f888049-412c-4314-9660-555cd1e12068	108	Memory [2/2]	TotalWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.TotalWidth	\N
7f888049-412c-4314-9660-555cd1e12068	109	Memory [2/2]	BankLabel	BANK 2	CIM:String	WMI:CIM_PhysicalMemory.BankLabel	\N
7f888049-412c-4314-9660-555cd1e12068	110	Memory [2/2]	TypeDetail	Synchronous	string(CIM:UInt16)	WMI:Win32_PhysicalMemory.TypeDetail	\N
7f888049-412c-4314-9660-555cd1e12068	111	Memory [2/2]	MemoryType	Unknown	string(CIM:UInt16)	WMI:CIM_PhysicalMemory.MemoryType	\N
7f888049-412c-4314-9660-555cd1e12068	112	Memory [2/2]	FormFactor	SODIMM	string(CIM:UInt16)	WMI:CIM_Chip.FormFactor	\N
7f888049-412c-4314-9660-555cd1e12068	113	Memory [2/2]	Status	\N	CIM:String	WMI:CIM_ManagedSystemElement.Status	\N
7f888049-412c-4314-9660-555cd1e12068	114	Memory [2/2]	Version	\N	CIM:String	WMI:CIM_PhysicalElement.Version	\N
7f888049-412c-4314-9660-555cd1e12068	115	Network Adapter [1/18]	Description	WAN Miniport (SSTP)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	116	Network Adapter [1/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	117	Network Adapter [1/18]	ProductName	WAN Miniport (SSTP)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	118	Network Adapter [1/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	119	Network Adapter [1/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	120	Network Adapter [1/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	121	Network Adapter [1/18]	InterfaceIndex	2	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	122	Network Adapter [1/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	123	Network Adapter [1/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	124	Network Adapter [1/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	125	Network Adapter [1/18]	PNPDeviceID	ROOT\\MS_SSTPMINIPORT\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	126	Network Adapter [1/18]	DeviceID	0	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	127	Network Adapter [1/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	128	Network Adapter [2/18]	Description	WAN Miniport (IKEv2)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	129	Network Adapter [2/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	130	Network Adapter [2/18]	ProductName	WAN Miniport (IKEv2)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	131	Network Adapter [2/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	132	Network Adapter [2/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	133	Network Adapter [2/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	134	Network Adapter [2/18]	InterfaceIndex	16	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	135	Network Adapter [2/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	136	Network Adapter [2/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	137	Network Adapter [2/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	138	Network Adapter [2/18]	PNPDeviceID	ROOT\\MS_AGILEVPNMINIPORT\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	139	Network Adapter [2/18]	DeviceID	1	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	140	Network Adapter [2/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	141	Network Adapter [3/18]	Description	WAN Miniport (L2TP)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	142	Network Adapter [3/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	143	Network Adapter [3/18]	ProductName	WAN Miniport (L2TP)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	144	Network Adapter [3/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	145	Network Adapter [3/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	146	Network Adapter [3/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	147	Network Adapter [3/18]	InterfaceIndex	3	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	148	Network Adapter [3/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	149	Network Adapter [3/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	150	Network Adapter [3/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	151	Network Adapter [3/18]	PNPDeviceID	ROOT\\MS_L2TPMINIPORT\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	152	Network Adapter [3/18]	DeviceID	2	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	153	Network Adapter [3/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	154	Network Adapter [4/18]	Description	WAN Miniport (PPTP)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	155	Network Adapter [4/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	156	Network Adapter [4/18]	ProductName	WAN Miniport (PPTP)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	157	Network Adapter [4/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	158	Network Adapter [4/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	159	Network Adapter [4/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	160	Network Adapter [4/18]	InterfaceIndex	4	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	161	Network Adapter [4/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	162	Network Adapter [4/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	163	Network Adapter [4/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	164	Network Adapter [4/18]	PNPDeviceID	ROOT\\MS_PPTPMINIPORT\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	165	Network Adapter [4/18]	DeviceID	3	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	166	Network Adapter [4/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	167	Network Adapter [5/18]	Description	WAN Miniport (PPPOE)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	168	Network Adapter [5/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	0	Computer System	Name	OSSI-DNOVAK	CIM:String	WMI:CIM_ManagedSystemElement.Name	\N
7f888049-412c-4314-9660-555cd1e12068	169	Network Adapter [5/18]	ProductName	WAN Miniport (PPPOE)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	170	Network Adapter [5/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	171	Network Adapter [5/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	172	Network Adapter [5/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	173	Network Adapter [5/18]	InterfaceIndex	5	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	174	Network Adapter [5/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	175	Network Adapter [5/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	176	Network Adapter [5/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	177	Network Adapter [5/18]	PNPDeviceID	ROOT\\MS_PPPOEMINIPORT\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	178	Network Adapter [5/18]	DeviceID	4	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	179	Network Adapter [5/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	180	Network Adapter [6/18]	Description	WAN Miniport (IPv6)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	181	Network Adapter [6/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	182	Network Adapter [6/18]	ProductName	WAN Miniport (IPv6)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	183	Network Adapter [6/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	184	Network Adapter [6/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	185	Network Adapter [6/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	186	Network Adapter [6/18]	InterfaceIndex	6	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	187	Network Adapter [6/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	188	Network Adapter [6/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	189	Network Adapter [6/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	190	Network Adapter [6/18]	PNPDeviceID	ROOT\\MS_NDISWANIPV6\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	191	Network Adapter [6/18]	DeviceID	5	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	192	Network Adapter [6/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	193	Network Adapter [7/18]	Description	WAN Miniport (Network Monitor)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	194	Network Adapter [7/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	195	Network Adapter [7/18]	ProductName	WAN Miniport (Network Monitor)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	196	Network Adapter [7/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	197	Network Adapter [7/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	198	Network Adapter [7/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	199	Network Adapter [7/18]	InterfaceIndex	7	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	200	Network Adapter [7/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	201	Network Adapter [7/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	202	Network Adapter [7/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	203	Network Adapter [7/18]	PNPDeviceID	ROOT\\MS_NDISWANBH\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	204	Network Adapter [7/18]	DeviceID	6	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	205	Network Adapter [7/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	206	Network Adapter [8/18]	Description	Realtek PCIe GBE Family Controller	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	207	Network Adapter [8/18]	Manufacturer	Realtek	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	208	Network Adapter [8/18]	ProductName	Realtek PCIe GBE Family Controller	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	209	Network Adapter [8/18]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	210	Network Adapter [8/18]	MACAddress	10:1F:74:FC:FC:C0	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	211	Network Adapter [8/18]	GUID	{AE39AC40-EA12-4AA3-B826-96CB0088AC41}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	212	Network Adapter [8/18]	InterfaceIndex	10	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	213	Network Adapter [8/18]	NetConnectionStatus	2	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	214	Network Adapter [8/18]	Speed	100.00 Mbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	215	Network Adapter [8/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	216	Network Adapter [8/18]	PNPDeviceID	PCI\\VEN_10EC&DEV_8168&SUBSYS_167C103C&REV_06\\01000000684CE00000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	217	Network Adapter [8/18]	DeviceID	7	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	218	Network Adapter [8/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	219	Network Adapter [9/18]	Description	WAN Miniport (IP)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	220	Network Adapter [9/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	221	Network Adapter [9/18]	ProductName	WAN Miniport (IP)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	222	Network Adapter [9/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	223	Network Adapter [9/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	224	Network Adapter [9/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	225	Network Adapter [9/18]	InterfaceIndex	8	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	226	Network Adapter [9/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	227	Network Adapter [9/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	228	Network Adapter [9/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	229	Network Adapter [9/18]	PNPDeviceID	ROOT\\MS_NDISWANIP\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	230	Network Adapter [9/18]	DeviceID	8	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	231	Network Adapter [9/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	232	Network Adapter [10/18]	Description	Microsoft ISATAP Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	233	Network Adapter [10/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	234	Network Adapter [10/18]	ProductName	Microsoft ISATAP Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	235	Network Adapter [10/18]	AdapterType	Tunnel	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	236	Network Adapter [10/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	237	Network Adapter [10/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	238	Network Adapter [10/18]	InterfaceIndex	19	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	239	Network Adapter [10/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	240	Network Adapter [10/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	241	Network Adapter [10/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	242	Network Adapter [10/18]	PNPDeviceID	ROOT\\*ISATAP\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	243	Network Adapter [10/18]	DeviceID	9	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	244	Network Adapter [10/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	245	Network Adapter [11/18]	Description	RAS Async Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	246	Network Adapter [11/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	247	Network Adapter [11/18]	ProductName	RAS Async Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	248	Network Adapter [11/18]	AdapterType	Wide Area Network (WAN)	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	249	Network Adapter [11/18]	MACAddress	20:41:53:59:4E:FF	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	250	Network Adapter [11/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	251	Network Adapter [11/18]	InterfaceIndex	9	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	252	Network Adapter [11/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	253	Network Adapter [11/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	254	Network Adapter [11/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	255	Network Adapter [11/18]	PNPDeviceID	SW\\{EEAB7790-C514-11D1-B42B-00805FC1270E}\\ASYNCMAC	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	256	Network Adapter [11/18]	DeviceID	10	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	257	Network Adapter [11/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	258	Network Adapter [12/18]	Description	Bluetooth Device (Personal Area Network)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	259	Network Adapter [12/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	260	Network Adapter [12/18]	ProductName	Bluetooth Device (Personal Area Network)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	261	Network Adapter [12/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	262	Network Adapter [12/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	263	Network Adapter [12/18]	GUID	{852551B7-5097-4EE8-918A-BFAFD20B8BCD}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	264	Network Adapter [12/18]	InterfaceIndex	11	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	265	Network Adapter [12/18]	NetConnectionStatus	0	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	266	Network Adapter [12/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	267	Network Adapter [12/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	268	Network Adapter [12/18]	PNPDeviceID	BTH\\MS_BTHPAN\\7&5DBC8DB&0&2	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	269	Network Adapter [12/18]	DeviceID	11	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	270	Network Adapter [12/18]	ConfigManagerErrorCode	22	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	271	Network Adapter [13/18]	Description	Qualcomm Atheros AR9285 802.11b/g/n WiFi Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	272	Network Adapter [13/18]	Manufacturer	Qualcomm Atheros Communications Inc.	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	273	Network Adapter [13/18]	ProductName	Qualcomm Atheros AR9285 802.11b/g/n WiFi Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	274	Network Adapter [13/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	275	Network Adapter [13/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	276	Network Adapter [13/18]	GUID	{EF14CEA5-E1C2-40BB-A2D9-A65FF6B8142E}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	277	Network Adapter [13/18]	InterfaceIndex	13	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	278	Network Adapter [13/18]	NetConnectionStatus	0	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	279	Network Adapter [13/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	280	Network Adapter [13/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	281	Network Adapter [13/18]	PNPDeviceID	PCI\\VEN_168C&DEV_002B&SUBSYS_1461103C&REV_01\\001517FFFF24141200	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	282	Network Adapter [13/18]	DeviceID	13	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	283	Network Adapter [13/18]	ConfigManagerErrorCode	22	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	284	Network Adapter [14/18]	Description	Microsoft ISATAP Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	285	Network Adapter [14/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	286	Network Adapter [14/18]	ProductName	Microsoft ISATAP Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	287	Network Adapter [14/18]	AdapterType	Tunnel	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	288	Network Adapter [14/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	289	Network Adapter [14/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	290	Network Adapter [14/18]	InterfaceIndex	20	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	291	Network Adapter [14/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	292	Network Adapter [14/18]	Speed	100.00 Kbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	293	Network Adapter [14/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	294	Network Adapter [14/18]	PNPDeviceID	ROOT\\*ISATAP\\0001	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	295	Network Adapter [14/18]	DeviceID	14	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	296	Network Adapter [14/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	297	Network Adapter [15/18]	Description	Microsoft Teredo Tunneling Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	298	Network Adapter [15/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	299	Network Adapter [15/18]	ProductName	Microsoft Teredo Tunneling Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	300	Network Adapter [15/18]	AdapterType	Tunnel	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	301	Network Adapter [15/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	302	Network Adapter [15/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	303	Network Adapter [15/18]	InterfaceIndex	14	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	304	Network Adapter [15/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	305	Network Adapter [15/18]	Speed	100.00 Kbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	306	Network Adapter [15/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	307	Network Adapter [15/18]	PNPDeviceID	ROOT\\*TEREDO\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	308	Network Adapter [15/18]	DeviceID	16	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	309	Network Adapter [15/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	310	Network Adapter [16/18]	Description	Microsoft Virtual WiFi Miniport Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	311	Network Adapter [16/18]	Manufacturer	\N	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	312	Network Adapter [16/18]	ProductName	Microsoft Virtual WiFi Miniport Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	313	Network Adapter [16/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	314	Network Adapter [16/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	315	Network Adapter [16/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	316	Network Adapter [16/18]	InterfaceIndex	15	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	317	Network Adapter [16/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	318	Network Adapter [16/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	319	Network Adapter [16/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	320	Network Adapter [16/18]	PNPDeviceID	\N	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	321	Network Adapter [16/18]	DeviceID	17	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	322	Network Adapter [16/18]	ConfigManagerErrorCode	\N	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	323	Network Adapter [17/18]	Description	Cisco AnyConnect Secure Mobility Client Virtual Miniport Adapter for Windows x64	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	324	Network Adapter [17/18]	Manufacturer	Cisco Systems	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	325	Network Adapter [17/18]	ProductName	Cisco AnyConnect Secure Mobility Client Virtual Miniport Adapter for Windows x64	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	326	Network Adapter [17/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	327	Network Adapter [17/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	328	Network Adapter [17/18]	GUID	{FF0F4A5C-5AB8-4A90-B3CE-12F0BF30AA03}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	329	Network Adapter [17/18]	InterfaceIndex	18	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	330	Network Adapter [17/18]	NetConnectionStatus	0	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	331	Network Adapter [17/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	332	Network Adapter [17/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	333	Network Adapter [17/18]	PNPDeviceID	ROOT\\NET\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	334	Network Adapter [17/18]	DeviceID	18	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	335	Network Adapter [17/18]	ConfigManagerErrorCode	22	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	336	Network Adapter [18/18]	Description	BlackBerry Device	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	337	Network Adapter [18/18]	Manufacturer	\N	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	338	Network Adapter [18/18]	ProductName	BlackBerry Device	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	339	Network Adapter [18/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
7f888049-412c-4314-9660-555cd1e12068	340	Network Adapter [18/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	341	Network Adapter [18/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
7f888049-412c-4314-9660-555cd1e12068	342	Network Adapter [18/18]	InterfaceIndex	17	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	343	Network Adapter [18/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
7f888049-412c-4314-9660-555cd1e12068	344	Network Adapter [18/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
7f888049-412c-4314-9660-555cd1e12068	345	Network Adapter [18/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	346	Network Adapter [18/18]	PNPDeviceID	\N	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	347	Network Adapter [18/18]	DeviceID	22	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	348	Network Adapter [18/18]	ConfigManagerErrorCode	\N	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	349	Network Adapter Configuration [1/18]	Caption	[00000000] WAN Miniport (SSTP)	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	350	Network Adapter Configuration [1/18]	InterfaceIndex	2	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	351	Network Adapter Configuration [1/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	352	Network Adapter Configuration [1/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	353	Network Adapter Configuration [1/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	354	Network Adapter Configuration [1/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	355	Network Adapter Configuration [1/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	356	Network Adapter Configuration [1/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	357	Network Adapter Configuration [1/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	358	Network Adapter Configuration [1/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	359	Network Adapter Configuration [1/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	360	Network Adapter Configuration [1/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	361	Network Adapter Configuration [1/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	362	Network Adapter Configuration [2/18]	Caption	[00000001] WAN Miniport (IKEv2)	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	363	Network Adapter Configuration [2/18]	InterfaceIndex	16	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	364	Network Adapter Configuration [2/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	365	Network Adapter Configuration [2/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	366	Network Adapter Configuration [2/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	367	Network Adapter Configuration [2/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	368	Network Adapter Configuration [2/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	369	Network Adapter Configuration [2/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	370	Network Adapter Configuration [2/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	371	Network Adapter Configuration [2/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	372	Network Adapter Configuration [2/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	373	Network Adapter Configuration [2/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	374	Network Adapter Configuration [2/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	375	Network Adapter Configuration [3/18]	Caption	[00000002] WAN Miniport (L2TP)	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	376	Network Adapter Configuration [3/18]	InterfaceIndex	3	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	377	Network Adapter Configuration [3/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	378	Network Adapter Configuration [3/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	379	Network Adapter Configuration [3/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	380	Network Adapter Configuration [3/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	381	Network Adapter Configuration [3/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	382	Network Adapter Configuration [3/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	383	Network Adapter Configuration [3/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	384	Network Adapter Configuration [3/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	385	Network Adapter Configuration [3/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	386	Network Adapter Configuration [3/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	387	Network Adapter Configuration [3/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	388	Network Adapter Configuration [4/18]	Caption	[00000003] WAN Miniport (PPTP)	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	389	Network Adapter Configuration [4/18]	InterfaceIndex	4	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	390	Network Adapter Configuration [4/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	391	Network Adapter Configuration [4/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	392	Network Adapter Configuration [4/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	393	Network Adapter Configuration [4/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	394	Network Adapter Configuration [4/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	395	Network Adapter Configuration [4/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	396	Network Adapter Configuration [4/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	397	Network Adapter Configuration [4/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	398	Network Adapter Configuration [4/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	399	Network Adapter Configuration [4/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	400	Network Adapter Configuration [4/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	401	Network Adapter Configuration [5/18]	Caption	[00000004] WAN Miniport (PPPOE)	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	402	Network Adapter Configuration [5/18]	InterfaceIndex	5	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	403	Network Adapter Configuration [5/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	404	Network Adapter Configuration [5/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	405	Network Adapter Configuration [5/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	406	Network Adapter Configuration [5/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	407	Network Adapter Configuration [5/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	408	Network Adapter Configuration [5/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	409	Network Adapter Configuration [5/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	410	Network Adapter Configuration [5/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	411	Network Adapter Configuration [5/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	412	Network Adapter Configuration [5/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	413	Network Adapter Configuration [5/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	414	Network Adapter Configuration [6/18]	Caption	[00000005] WAN Miniport (IPv6)	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	415	Network Adapter Configuration [6/18]	InterfaceIndex	6	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	416	Network Adapter Configuration [6/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	417	Network Adapter Configuration [6/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	418	Network Adapter Configuration [6/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	419	Network Adapter Configuration [6/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	420	Network Adapter Configuration [6/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	421	Network Adapter Configuration [6/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	422	Network Adapter Configuration [6/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	423	Network Adapter Configuration [6/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	424	Network Adapter Configuration [6/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	425	Network Adapter Configuration [6/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	426	Network Adapter Configuration [6/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	427	Network Adapter Configuration [7/18]	Caption	[00000006] WAN Miniport (Network Monitor)	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	428	Network Adapter Configuration [7/18]	InterfaceIndex	7	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	429	Network Adapter Configuration [7/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	430	Network Adapter Configuration [7/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	431	Network Adapter Configuration [7/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	432	Network Adapter Configuration [7/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	433	Network Adapter Configuration [7/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	434	Network Adapter Configuration [7/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	435	Network Adapter Configuration [7/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	436	Network Adapter Configuration [7/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	437	Network Adapter Configuration [7/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	438	Network Adapter Configuration [7/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	439	Network Adapter Configuration [7/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	440	Network Adapter Configuration [8/18]	Caption	[00000007] Realtek PCIe GBE Family Controller	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	441	Network Adapter Configuration [8/18]	InterfaceIndex	10	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	442	Network Adapter Configuration [8/18]	MACAddress	10:1F:74:FC:FC:C0	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	443	Network Adapter Configuration [8/18]	IPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	444	Network Adapter Configuration [8/18]	IPAddress	192.168.20.135	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[0]	\N
7f888049-412c-4314-9660-555cd1e12068	445	Network Adapter Configuration [8/18]	IPSubnet	255.255.255.0	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[0]	\N
7f888049-412c-4314-9660-555cd1e12068	446	Network Adapter Configuration [8/18]	DefaultIPGateway	192.168.20.254	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway[0]	\N
7f888049-412c-4314-9660-555cd1e12068	447	Network Adapter Configuration [8/18]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	448	Network Adapter Configuration [8/18]	DHCPServer	192.168.20.5	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	449	Network Adapter Configuration [8/18]	DNSHostName	DLarrabee	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	450	Network Adapter Configuration [8/18]	DNSDomain	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	451	Network Adapter Configuration [8/18]	DNSDomainSuffixSearchOrder	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder[0]	\N
7f888049-412c-4314-9660-555cd1e12068	452	Network Adapter Configuration [8/18]	DNSServerSearchOrder	192.168.20.5	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder[0]	\N
7f888049-412c-4314-9660-555cd1e12068	453	Network Adapter Configuration [8/18]	DNSServerSearchOrder	192.168.12.4	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder[1]	\N
7f888049-412c-4314-9660-555cd1e12068	454	Network Adapter Configuration [9/18]	Caption	[00000008] WAN Miniport (IP)	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	455	Network Adapter Configuration [9/18]	InterfaceIndex	8	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	456	Network Adapter Configuration [9/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	457	Network Adapter Configuration [9/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	458	Network Adapter Configuration [9/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	459	Network Adapter Configuration [9/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	460	Network Adapter Configuration [9/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	461	Network Adapter Configuration [9/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	462	Network Adapter Configuration [9/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	463	Network Adapter Configuration [9/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	464	Network Adapter Configuration [9/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	465	Network Adapter Configuration [9/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	466	Network Adapter Configuration [9/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	467	Network Adapter Configuration [10/18]	Caption	[00000009] Microsoft ISATAP Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	468	Network Adapter Configuration [10/18]	InterfaceIndex	19	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	469	Network Adapter Configuration [10/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	470	Network Adapter Configuration [10/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	471	Network Adapter Configuration [10/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	472	Network Adapter Configuration [10/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	473	Network Adapter Configuration [10/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	474	Network Adapter Configuration [10/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	475	Network Adapter Configuration [10/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	476	Network Adapter Configuration [10/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	477	Network Adapter Configuration [10/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	478	Network Adapter Configuration [10/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	479	Network Adapter Configuration [10/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	480	Network Adapter Configuration [11/18]	Caption	[00000010] RAS Async Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	481	Network Adapter Configuration [11/18]	InterfaceIndex	9	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	482	Network Adapter Configuration [11/18]	MACAddress	20:41:53:59:4E:FF	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	483	Network Adapter Configuration [11/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	484	Network Adapter Configuration [11/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	485	Network Adapter Configuration [11/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	486	Network Adapter Configuration [11/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	487	Network Adapter Configuration [11/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	488	Network Adapter Configuration [11/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	489	Network Adapter Configuration [11/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	490	Network Adapter Configuration [11/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	491	Network Adapter Configuration [11/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	492	Network Adapter Configuration [11/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	493	Network Adapter Configuration [12/18]	Caption	[00000011] Bluetooth Device (Personal Area Network)	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	494	Network Adapter Configuration [12/18]	InterfaceIndex	11	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	495	Network Adapter Configuration [12/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	496	Network Adapter Configuration [12/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	497	Network Adapter Configuration [12/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	498	Network Adapter Configuration [12/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	499	Network Adapter Configuration [12/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	500	Network Adapter Configuration [12/18]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	501	Network Adapter Configuration [12/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	502	Network Adapter Configuration [12/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	503	Network Adapter Configuration [12/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	504	Network Adapter Configuration [12/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	505	Network Adapter Configuration [12/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	506	Network Adapter Configuration [13/18]	Caption	[00000013] Qualcomm Atheros AR9285 802.11b/g/n WiFi Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	507	Network Adapter Configuration [13/18]	InterfaceIndex	13	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	508	Network Adapter Configuration [13/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	509	Network Adapter Configuration [13/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	510	Network Adapter Configuration [13/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	511	Network Adapter Configuration [13/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	512	Network Adapter Configuration [13/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	513	Network Adapter Configuration [13/18]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	514	Network Adapter Configuration [13/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	515	Network Adapter Configuration [13/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	516	Network Adapter Configuration [13/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	517	Network Adapter Configuration [13/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	518	Network Adapter Configuration [13/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	519	Network Adapter Configuration [14/18]	Caption	[00000014] Microsoft ISATAP Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	520	Network Adapter Configuration [14/18]	InterfaceIndex	20	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	521	Network Adapter Configuration [14/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	522	Network Adapter Configuration [14/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	523	Network Adapter Configuration [14/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	524	Network Adapter Configuration [14/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	525	Network Adapter Configuration [14/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	526	Network Adapter Configuration [14/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	527	Network Adapter Configuration [14/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	528	Network Adapter Configuration [14/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	529	Network Adapter Configuration [14/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	530	Network Adapter Configuration [14/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	531	Network Adapter Configuration [14/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	532	Network Adapter Configuration [15/18]	Caption	[00000016] Microsoft Teredo Tunneling Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	533	Network Adapter Configuration [15/18]	InterfaceIndex	14	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	534	Network Adapter Configuration [15/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	535	Network Adapter Configuration [15/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	536	Network Adapter Configuration [15/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	537	Network Adapter Configuration [15/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	538	Network Adapter Configuration [15/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	539	Network Adapter Configuration [15/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	540	Network Adapter Configuration [15/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	541	Network Adapter Configuration [15/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	542	Network Adapter Configuration [15/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	543	Network Adapter Configuration [15/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	544	Network Adapter Configuration [15/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	545	Network Adapter Configuration [16/18]	Caption	[00000017] Microsoft Virtual WiFi Miniport Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	546	Network Adapter Configuration [16/18]	InterfaceIndex	15	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	547	Network Adapter Configuration [16/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	548	Network Adapter Configuration [16/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	549	Network Adapter Configuration [16/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	550	Network Adapter Configuration [16/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	551	Network Adapter Configuration [16/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	552	Network Adapter Configuration [16/18]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	553	Network Adapter Configuration [16/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	554	Network Adapter Configuration [16/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	555	Network Adapter Configuration [16/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	556	Network Adapter Configuration [16/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	557	Network Adapter Configuration [16/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	558	Network Adapter Configuration [17/18]	Caption	[00000018] Cisco AnyConnect Secure Mobility Client Virtual Miniport Adapter for Windows x64	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	559	Network Adapter Configuration [17/18]	InterfaceIndex	18	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	560	Network Adapter Configuration [17/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	561	Network Adapter Configuration [17/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	562	Network Adapter Configuration [17/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	563	Network Adapter Configuration [17/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	564	Network Adapter Configuration [17/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	565	Network Adapter Configuration [17/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	566	Network Adapter Configuration [17/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	567	Network Adapter Configuration [17/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	568	Network Adapter Configuration [17/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	569	Network Adapter Configuration [17/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	570	Network Adapter Configuration [17/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	571	Network Adapter Configuration [18/18]	Caption	[00000022] BlackBerry Device	CIM:String	WMI:CIM_Setting.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	572	Network Adapter Configuration [18/18]	InterfaceIndex	17	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
7f888049-412c-4314-9660-555cd1e12068	573	Network Adapter Configuration [18/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
7f888049-412c-4314-9660-555cd1e12068	574	Network Adapter Configuration [18/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	575	Network Adapter Configuration [18/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
7f888049-412c-4314-9660-555cd1e12068	576	Network Adapter Configuration [18/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
7f888049-412c-4314-9660-555cd1e12068	577	Network Adapter Configuration [18/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
7f888049-412c-4314-9660-555cd1e12068	578	Network Adapter Configuration [18/18]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
7f888049-412c-4314-9660-555cd1e12068	579	Network Adapter Configuration [18/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
7f888049-412c-4314-9660-555cd1e12068	580	Network Adapter Configuration [18/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
7f888049-412c-4314-9660-555cd1e12068	581	Network Adapter Configuration [18/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
7f888049-412c-4314-9660-555cd1e12068	582	Network Adapter Configuration [18/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	583	Network Adapter Configuration [18/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
7f888049-412c-4314-9660-555cd1e12068	584	Video Adapter [1/2]	Description	AMD Radeon HD 7470M	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	585	Video Adapter [1/2]	AdapterRAM	1024 MB	toMegaBytes(CIM:UInt32)	WMI:Win32_VideoController.AdapterRAM	\N
7f888049-412c-4314-9660-555cd1e12068	586	Video Adapter [1/2]	VideoMemoryType	2	CIM:UInt16	WMI:CIM_VideoController.VideoMemoryType	\N
7f888049-412c-4314-9660-555cd1e12068	587	Video Adapter [1/2]	VideoModeDescription	1920 x 1080 x 4294967296 colors	CIM:String	WMI:Win32_VideoController.VideoModeDescription	\N
7f888049-412c-4314-9660-555cd1e12068	588	Video Adapter [1/2]	VideoProcessor	ATI display adapter (0x6760)	CIM:String	WMI:CIM_VideoController.VideoProcessor	\N
7f888049-412c-4314-9660-555cd1e12068	589	Video Adapter [1/2]	CurrentBitsPerPixel	32	CIM:UInt32	WMI:CIM_VideoController.CurrentBitsPerPixel	\N
7f888049-412c-4314-9660-555cd1e12068	590	Video Adapter [1/2]	CurrentHorizontalResolution	1920	CIM:UInt32	WMI:CIM_VideoController.CurrentHorizontalResolution	\N
7f888049-412c-4314-9660-555cd1e12068	591	Video Adapter [1/2]	CurrentVerticalResolution	1080	CIM:UInt32	WMI:CIM_VideoController.CurrentVerticalResolution	\N
7f888049-412c-4314-9660-555cd1e12068	592	Video Adapter [1/2]	CurrentRefreshRate	59	CIM:UInt32	WMI:CIM_VideoController.CurrentRefreshRate	\N
7f888049-412c-4314-9660-555cd1e12068	593	Video Adapter [1/2]	InstalledDisplayDrivers	aticfx64.dll,aticfx64.dll,aticfx64.dll,aticfx32,aticfx32,aticfx32,atiumd64.dll,atidxx64.dll,atidxx64.dll,atiumdag,atidxx32,atidxx32,atiumdva,atiumd6a.cap,atitmm64.dll	CIM:String	WMI:Win32_VideoController.InstalledDisplayDrivers	\N
7f888049-412c-4314-9660-555cd1e12068	594	Video Adapter [1/2]	DriverVersion	8.910.0.0	CIM:String	WMI:Win32_VideoController.DriverVersion	\N
7f888049-412c-4314-9660-555cd1e12068	595	Video Adapter [1/2]	DriverDate	20111013000000.000000-000	CIM:DateTime	WMI:Win32_VideoController.DriverDate	\N
7f888049-412c-4314-9660-555cd1e12068	596	Video Adapter [1/2]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	597	Video Adapter [1/2]	PNPDeviceID	PCI\\VEN_1002&DEV_6760&SUBSYS_167D103C&REV_00\\4&2679E7DC&0&0008	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	598	Video Adapter [1/2]	DeviceID	VideoController1	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	599	Video Adapter [1/2]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	600	Video Adapter [2/2]	Description	Intel(R) HD Graphics Family	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	601	Video Adapter [2/2]	AdapterRAM	3839 MB	toMegaBytes(CIM:UInt32)	WMI:Win32_VideoController.AdapterRAM	\N
7f888049-412c-4314-9660-555cd1e12068	602	Video Adapter [2/2]	VideoMemoryType	2	CIM:UInt16	WMI:CIM_VideoController.VideoMemoryType	\N
7f888049-412c-4314-9660-555cd1e12068	603	Video Adapter [2/2]	VideoModeDescription	1920 x 1080 x 4294967296 colors	CIM:String	WMI:Win32_VideoController.VideoModeDescription	\N
7f888049-412c-4314-9660-555cd1e12068	604	Video Adapter [2/2]	VideoProcessor	Intel(R) HD Graphics Family	CIM:String	WMI:CIM_VideoController.VideoProcessor	\N
7f888049-412c-4314-9660-555cd1e12068	605	Video Adapter [2/2]	CurrentBitsPerPixel	32	CIM:UInt32	WMI:CIM_VideoController.CurrentBitsPerPixel	\N
7f888049-412c-4314-9660-555cd1e12068	606	Video Adapter [2/2]	CurrentHorizontalResolution	1920	CIM:UInt32	WMI:CIM_VideoController.CurrentHorizontalResolution	\N
7f888049-412c-4314-9660-555cd1e12068	607	Video Adapter [2/2]	CurrentVerticalResolution	1080	CIM:UInt32	WMI:CIM_VideoController.CurrentVerticalResolution	\N
7f888049-412c-4314-9660-555cd1e12068	608	Video Adapter [2/2]	CurrentRefreshRate	60	CIM:UInt32	WMI:CIM_VideoController.CurrentRefreshRate	\N
7f888049-412c-4314-9660-555cd1e12068	609	Video Adapter [2/2]	InstalledDisplayDrivers	igdumd64.dll,igd10umd64.dll,igd10umd64.dll,igdumdx32,igd10umd32,igd10umd32	CIM:String	WMI:Win32_VideoController.InstalledDisplayDrivers	\N
7f888049-412c-4314-9660-555cd1e12068	610	Video Adapter [2/2]	DriverVersion	8.910.0.0	CIM:String	WMI:Win32_VideoController.DriverVersion	\N
7f888049-412c-4314-9660-555cd1e12068	611	Video Adapter [2/2]	DriverDate	20111013000000.000000-000	CIM:DateTime	WMI:Win32_VideoController.DriverDate	\N
7f888049-412c-4314-9660-555cd1e12068	612	Video Adapter [2/2]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	613	Video Adapter [2/2]	PNPDeviceID	PCI\\VEN_8086&DEV_0116&SUBSYS_167D103C&REV_09\\3&21436425&0&10	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	614	Video Adapter [2/2]	DeviceID	VideoController2	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	615	Video Adapter [2/2]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	616	Sound Device [1/3]	Description	Bluetooth Audio Device	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	617	Sound Device [1/3]	Manufacturer	Atheros Communications	CIM:String	WMI:Win32_SoundDevice.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	618	Sound Device [1/3]	ProductName	Bluetooth Audio Device	CIM:String	WMI:Win32_SoundDevice.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	619	Sound Device [1/3]	Availability	\N	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	620	Sound Device [1/3]	PNPDeviceID	BTHENUM\\{61118058-486C-4BB0-B4B8-ACE4DCADEC44}_LOCALMFG&0000\\8&255154EC&0&000000000000_00000000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	621	Sound Device [1/3]	DeviceID	BTHENUM\\{61118058-486C-4BB0-B4B8-ACE4DCADEC44}_LOCALMFG&0000\\8&255154EC&0&000000000000_00000000	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	1	Computer System	DNSHostName	OSSI-DNovak	CIM:String	WMI:Win32_ComputerSystem.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	2	Computer System	Domain	intelli-site.com	CIM:String	WMI:Win32_ComputerSystem.Domain	\N
7f888049-412c-4314-9660-555cd1e12068	622	Sound Device [1/3]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	623	Sound Device [2/3]	Description	IDT High Definition Audio CODEC	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	624	Sound Device [2/3]	Manufacturer	IDT	CIM:String	WMI:Win32_SoundDevice.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	625	Sound Device [2/3]	ProductName	IDT High Definition Audio CODEC	CIM:String	WMI:Win32_SoundDevice.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	626	Sound Device [2/3]	Availability	\N	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	627	Sound Device [2/3]	PNPDeviceID	HDAUDIO\\FUNC_01&VEN_111D&DEV_76D1&SUBSYS_103C167D&REV_1002\\4&5DEB806&0&0001	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	628	Sound Device [2/3]	DeviceID	HDAUDIO\\FUNC_01&VEN_111D&DEV_76D1&SUBSYS_103C167D&REV_1002\\4&5DEB806&0&0001	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	629	Sound Device [2/3]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	630	Sound Device [3/3]	Description	Intel(R) Display Audio	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	631	Sound Device [3/3]	Manufacturer	Intel(R) Corporation	CIM:String	WMI:Win32_SoundDevice.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	632	Sound Device [3/3]	ProductName	Intel(R) Display Audio	CIM:String	WMI:Win32_SoundDevice.ProductName	\N
7f888049-412c-4314-9660-555cd1e12068	633	Sound Device [3/3]	Availability	\N	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
7f888049-412c-4314-9660-555cd1e12068	634	Sound Device [3/3]	PNPDeviceID	HDAUDIO\\FUNC_01&VEN_8086&DEV_2805&SUBSYS_80860101&REV_1000\\4&5DEB806&0&0301	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	635	Sound Device [3/3]	DeviceID	HDAUDIO\\FUNC_01&VEN_8086&DEV_2805&SUBSYS_80860101&REV_1000\\4&5DEB806&0&0301	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	636	Sound Device [3/3]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	637	Disk Drive [1/2]	Description	Disk drive	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	638	Disk Drive [1/2]	Manufacturer	(Standard disk drives)	CIM:String	WMI:Win32_DiskDrive.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	639	Disk Drive [1/2]	Model	SAMSUNG HM320HJ	CIM:String	WMI:Win32_DiskDrive.Model	\N
7f888049-412c-4314-9660-555cd1e12068	640	Disk Drive [1/2]	FirmwareRevision	2AK1	CIM:String	WMI:Win32_DiskDrive.FirmwareRevision	\N
7f888049-412c-4314-9660-555cd1e12068	641	Disk Drive [1/2]	InterfaceType	IDE	CIM:String	WMI:Win32_DiskDrive.InterfaceType	\N
7f888049-412c-4314-9660-555cd1e12068	642	Disk Drive [1/2]	MediaType	Fixed hard disk media	CIM:String	WMI:Win32_DiskDrive.MediaType	\N
7f888049-412c-4314-9660-555cd1e12068	643	Disk Drive [1/2]	Size	0.32 TB (0.29 TiB)	toStorageBytes(CIM:UInt64)	WMI:Win32_DiskDrive.Size	\N
7f888049-412c-4314-9660-555cd1e12068	644	Disk Drive [1/2]	Partitions	4	CIM:UInt32	WMI:Win32_DiskDrive.Partitions	\N
7f888049-412c-4314-9660-555cd1e12068	645	Disk Drive [1/2]	PNPDeviceID	IDE\\DISKSAMSUNG_HM320HJ_________________________2AK10002\\4&3A93AF2C&0&0.0.0	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	646	Disk Drive [1/2]	DeviceID	\\\\.\\PHYSICALDRIVE0	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	647	Disk Drive [1/2]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	648	Disk Drive [2/2]	Description	Disk drive	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	649	Disk Drive [2/2]	Manufacturer	(Standard disk drives)	CIM:String	WMI:Win32_DiskDrive.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	650	Disk Drive [2/2]	Model	Apple iPod USB Device	CIM:String	WMI:Win32_DiskDrive.Model	\N
7f888049-412c-4314-9660-555cd1e12068	651	Disk Drive [2/2]	FirmwareRevision	1.62	CIM:String	WMI:Win32_DiskDrive.FirmwareRevision	\N
7f888049-412c-4314-9660-555cd1e12068	652	Disk Drive [2/2]	InterfaceType	USB	CIM:String	WMI:Win32_DiskDrive.InterfaceType	\N
7f888049-412c-4314-9660-555cd1e12068	653	Disk Drive [2/2]	MediaType	Removable Media	CIM:String	WMI:Win32_DiskDrive.MediaType	\N
7f888049-412c-4314-9660-555cd1e12068	654	Disk Drive [2/2]	Size	0.08 TB (0.07 TiB)	toStorageBytes(CIM:UInt64)	WMI:Win32_DiskDrive.Size	\N
7f888049-412c-4314-9660-555cd1e12068	655	Disk Drive [2/2]	Partitions	1	CIM:UInt32	WMI:Win32_DiskDrive.Partitions	\N
7f888049-412c-4314-9660-555cd1e12068	656	Disk Drive [2/2]	PNPDeviceID	USBSTOR\\DISK&VEN_APPLE&PROD_IPOD&REV_1.62\\000A270015158519&0	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	657	Disk Drive [2/2]	DeviceID	\\\\.\\PHYSICALDRIVE1	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	658	Disk Drive [2/2]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
7f888049-412c-4314-9660-555cd1e12068	659	CD-ROM Drive	Description	CD-ROM Drive	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
7f888049-412c-4314-9660-555cd1e12068	660	CD-ROM Drive	Manufacturer	(Standard CD-ROM drives)	CIM:String	WMI:Win32_CDROMDrive.Manufacturer	\N
7f888049-412c-4314-9660-555cd1e12068	661	CD-ROM Drive	Caption	hp DVD A  DS8A5LH	CIM:String	WMI:CIM_ManagedSystemElement.Caption	\N
7f888049-412c-4314-9660-555cd1e12068	662	CD-ROM Drive	Drive	F:	CIM:String	WMI:Win32_CDROMDrive.Drive	\N
7f888049-412c-4314-9660-555cd1e12068	663	CD-ROM Drive	MediaType	DVD Writer	CIM:String	WMI:Win32_CDROMDrive.MediaType	\N
7f888049-412c-4314-9660-555cd1e12068	664	CD-ROM Drive	PNPDeviceID	IDE\\CDROMHP_DVD_A__DS8A5LH_______________________1H68____\\4&3A93AF2C&0&0.1.0	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	665	CD-ROM Drive	DeviceID	IDE\\CDROMHP_DVD_A__DS8A5LH_______________________1H68____\\4&3A93AF2C&0&0.1.0	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
7f888049-412c-4314-9660-555cd1e12068	666	CD-ROM Drive	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	3	Computer System	DomainRole	Member Workstation	string(CIM:UInt16)	WMI:Win32_ComputerSystem.DomainRole	\N
7f888049-412c-4314-9660-555cd1e12068	667	Installed Programs	A360 Desktop	6.0.3.1100	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B209E611-5511-4AD6-B4B3-9D36F93DBCD4}	\N
7f888049-412c-4314-9660-555cd1e12068	668	Installed Programs	Access Control	5.21.73	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1F9F247F-CC99-4EBB-943A-974E662B8528}	\N
7f888049-412c-4314-9660-555cd1e12068	669	Installed Programs	ActiveCheck component for HP Active Support Library	3.0.0.3	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{254C37AA-6B72-4300-84F6-98A82419187E}	\N
7f888049-412c-4314-9660-555cd1e12068	670	Installed Programs	Adobe Acrobat Reader DC	18.011.20038	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{AC76BA86-7AD7-1033-7B44-AC0F074E4100}	\N
7f888049-412c-4314-9660-555cd1e12068	671	Installed Programs	Adobe Bridge 1.0	001.000.000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B74D4E10-1033-0000-0000-000000000001}	\N
7f888049-412c-4314-9660-555cd1e12068	672	Installed Programs	Adobe Common File Installer	1.00.0000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{8EDBA74D-0686-4C99-BFDD-F894678E5B39}	\N
7f888049-412c-4314-9660-555cd1e12068	673	Installed Programs	Adobe Creative Suite 2	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{0134A1A1-C283-4A47-91A1-92F19F960372}	\N
7f888049-412c-4314-9660-555cd1e12068	674	Installed Programs	Adobe Flash Player 24 NPAPI	24.0.0.186	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Adobe Flash Player NPAPI	\N
7f888049-412c-4314-9660-555cd1e12068	675	Installed Programs	Adobe Flash Player 26 ActiveX	26.0.0.131	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Adobe Flash Player ActiveX	\N
7f888049-412c-4314-9660-555cd1e12068	676	Installed Programs	Adobe Help Center 1.0	001.000.000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E9787678-1033-0000-8E67-000000000001}	\N
7f888049-412c-4314-9660-555cd1e12068	677	Installed Programs	Adobe Photoshop CS2	9.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{236BB7C4-4419-42FD-0409-1E257A25E34D}	\N
7f888049-412c-4314-9660-555cd1e12068	678	Installed Programs	Adobe Refresh Manager	1.8.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{AC76BA86-0804-1033-1959-001824265200}	\N
7f888049-412c-4314-9660-555cd1e12068	679	Installed Programs	Adobe Stock Photos 1.0	001.000.000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{786C5747-1033-0000-B58E-000000000001}	\N
7f888049-412c-4314-9660-555cd1e12068	680	Installed Programs	Agatha Christie - Peril at End House	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT089362	\N
7f888049-412c-4314-9660-555cd1e12068	681	Installed Programs	AMD APP SDK Runtime	2.5.793.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{503F672D-6C84-448A-8F8F-4BC35AC83441}	\N
7f888049-412c-4314-9660-555cd1e12068	682	Installed Programs	AMD Media Foundation Decoders	1.0.61013.1636	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3D2D0DB9-5199-4A77-B6D3-646693FAE63C}	\N
7f888049-412c-4314-9660-555cd1e12068	683	Installed Programs	Apple Application Support (32-bit)	6.3	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D4C80B0C-CF67-43A7-90C3-466853543B54}	\N
7f888049-412c-4314-9660-555cd1e12068	684	Installed Programs	Apple Application Support (64-bit)	6.3	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B2A2E8AF-BC48-4191-B2C4-3846A19835CA}	\N
7f888049-412c-4314-9660-555cd1e12068	685	Installed Programs	Apple Mobile Device Support	11.0.5.14	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{AA7D90D2-2387-4FA5-A3AF-96811BE49BFD}	\N
7f888049-412c-4314-9660-555cd1e12068	686	Installed Programs	Apple Software Update	2.5.0.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{19589375-5C58-4AFA-842F-8B34744CCEAD}	\N
7f888049-412c-4314-9660-555cd1e12068	687	Installed Programs	ArcSoft TotalMedia	1.0.48.25	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4114A073-7385-4742-8A5E-A5788FAC838F}	\N
7f888049-412c-4314-9660-555cd1e12068	688	Installed Programs	ArcSoft TotalMedia	2.0.39.12	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\ArcSoft TotalMedia	\N
7f888049-412c-4314-9660-555cd1e12068	689	Installed Programs	ArcSoft Webcam Sharing Manager	2.0.0.30	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{190A7D93-3823-439C-91B9-ADCE3EC2A6A2}	\N
7f888049-412c-4314-9660-555cd1e12068	690	Installed Programs	Atheros Driver Installation Program	9.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C3A32068-8AB1-4327-BB16-BED9C6219DC7}	\N
7f888049-412c-4314-9660-555cd1e12068	691	Installed Programs	AutoCAD LT 2016 - English	20.1.49.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5783F2D7-F009-0000-0102-0060B0CE6BBA}	\N
7f888049-412c-4314-9660-555cd1e12068	692	Installed Programs	AutoCAD LT 2016 - English	20.1.49.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5783F2D7-F009-0409-2102-0060B0CE6BBA}	\N
7f888049-412c-4314-9660-555cd1e12068	693	Installed Programs	AutoCAD LT 2016 Language Pack - English	20.1.49.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5783F2D7-F009-0409-1102-0060B0CE6BBA}	\N
7f888049-412c-4314-9660-555cd1e12068	694	Installed Programs	Autodesk Advanced Material Library Image Library 2016	6.3.0.15	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{94AD53E7-493B-4291-8714-7A3B761D2783}	\N
7f888049-412c-4314-9660-555cd1e12068	695	Installed Programs	Autodesk AutoCAD LT 2016 - English	20.1.49.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\AutoCAD LT 2016 - English	\N
7f888049-412c-4314-9660-555cd1e12068	696	Installed Programs	Autodesk Content Service	3.2.0.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A37CDB58-AAE8-0000-8C13-E0F7BACB0D5F}	\N
7f888049-412c-4314-9660-555cd1e12068	697	Installed Programs	Autodesk Content Service	3.2.0.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Autodesk Content Service	\N
7f888049-412c-4314-9660-555cd1e12068	698	Installed Programs	Autodesk Content Service Language Pack	3.2.0.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A37CDB58-AAE8-0001-8C13-E0F7BACB0D5F}	\N
7f888049-412c-4314-9660-555cd1e12068	699	Installed Programs	Autodesk Desktop App	6.0.108.150	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Autodesk Desktop App	\N
7f888049-412c-4314-9660-555cd1e12068	700	Installed Programs	Autodesk Download Manager	4.0.14.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{EC92633C-8F08-470A-BCDF-3FE5FD778C8D}	\N
7f888049-412c-4314-9660-555cd1e12068	701	Installed Programs	Autodesk DWG TrueView 2016 - English	20.1.107.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\DWG TrueView 2016 - English	\N
7f888049-412c-4314-9660-555cd1e12068	702	Installed Programs	Autodesk Material Library 2016	6.3.0.15	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{29A7D6EC-63C2-42FD-8143-5812ABD2923F}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	4	Computer System	PartOfDomain	True	CIM:Boolean	WMI:Win32_ComputerSystem.PartOfDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	5	Computer System	Workgroup	\N	CIM:String	WMI:Win32_ComputerSystem.Workgroup	\N
7f888049-412c-4314-9660-555cd1e12068	703	Installed Programs	Autodesk Material Library Base Resolution Image Library 2016	6.3.0.15	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6B4CFC6E-ECB0-47FE-95D3-65C680ED0687}	\N
7f888049-412c-4314-9660-555cd1e12068	704	Installed Programs	Avery Design & Print	3.0.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Avery Design & Print 3.0.2	\N
7f888049-412c-4314-9660-555cd1e12068	705	Installed Programs	AXIS Media Control 6.00 Redist	6.00	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\AXIS Media Control SDK_is1	\N
7f888049-412c-4314-9660-555cd1e12068	706	Installed Programs	Bejeweled 2 Deluxe	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087428	\N
7f888049-412c-4314-9660-555cd1e12068	707	Installed Programs	Blasterball 3	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT089308	\N
7f888049-412c-4314-9660-555cd1e12068	708	Installed Programs	Bluetooth Win7 Suite (64)	7.02.000.55	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{230D1595-57DA-4933-8C4E-375797EBB7E1}	\N
7f888049-412c-4314-9660-555cd1e12068	709	Installed Programs	Bonjour	3.1.0.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{56DDDFB8-7F79-4480-89D5-25E1F52AB28F}	\N
7f888049-412c-4314-9660-555cd1e12068	710	Installed Programs	Bounce Symphony	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087330	\N
7f888049-412c-4314-9660-555cd1e12068	711	Installed Programs	Brother HL-5250DN	1.00	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{894F571B-3B34-4659-8E57-0B1B2F2F44BB}	\N
7f888049-412c-4314-9660-555cd1e12068	712	Installed Programs	Brother MFL-Pro Suite MFC-7860DW	1.1.3.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3ACCCFB3-7B17-4E9F-ACB0-46868FCD4487}	\N
7f888049-412c-4314-9660-555cd1e12068	713	Installed Programs	Build-a-Lot - The Elizabethan Era	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT089303	\N
7f888049-412c-4314-9660-555cd1e12068	714	Installed Programs	Cake Mania	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT089359	\N
7f888049-412c-4314-9660-555cd1e12068	715	Installed Programs	Catalyst Control Center	2011.1013.1702.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3A53DC94-79F4-2141-772A-569A7FCD38A9}	\N
7f888049-412c-4314-9660-555cd1e12068	716	Installed Programs	Catalyst Control Center - Branding	1.00.0000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C33240AB-1F4B-4DE2-B1C7-54E0A182BB5D}	\N
7f888049-412c-4314-9660-555cd1e12068	717	Installed Programs	Catalyst Control Center Graphics Previews Common	2011.1013.1702.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{2396EE07-88BE-67F0-229D-E46088C86AC1}	\N
7f888049-412c-4314-9660-555cd1e12068	718	Installed Programs	Catalyst Control Center InstallProxy	2011.1013.1702.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{99BBECCE-5865-B26C-912A-0B339081F799}	\N
7f888049-412c-4314-9660-555cd1e12068	719	Installed Programs	Catalyst Control Center Localization All	2011.1013.1702.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B975C052-531D-97C0-AB47-EB6BA7620887}	\N
7f888049-412c-4314-9660-555cd1e12068	720	Installed Programs	Catalyst Control Center Profiles Mobile	2011.1013.1702.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{501B8F04-368E-A540-2E46-19A44FDF7109}	\N
7f888049-412c-4314-9660-555cd1e12068	721	Installed Programs	CC Get MAC Address 2.3	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\CC Get MAC Address_is1	\N
7f888049-412c-4314-9660-555cd1e12068	722	Installed Programs	CCC Help Chinese Standard	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{692C218E-34B2-1D36-670D-9AB3A8D107BC}	\N
7f888049-412c-4314-9660-555cd1e12068	723	Installed Programs	CCC Help Chinese Traditional	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{110A6D3A-A966-992B-173F-6D4A6A93A7F3}	\N
7f888049-412c-4314-9660-555cd1e12068	724	Installed Programs	CCC Help Czech	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7C62B5F1-938A-50F9-78AF-4143E9604507}	\N
7f888049-412c-4314-9660-555cd1e12068	725	Installed Programs	CCC Help Danish	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5DF24781-FA89-2E36-3FDE-D3974BCB5675}	\N
7f888049-412c-4314-9660-555cd1e12068	726	Installed Programs	CCC Help Dutch	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{EAD66E57-B386-DB10-29F9-A5A75BC60952}	\N
7f888049-412c-4314-9660-555cd1e12068	727	Installed Programs	CCC Help English	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{670B9685-76B4-0E94-99F8-92FCBFAF3547}	\N
7f888049-412c-4314-9660-555cd1e12068	728	Installed Programs	CCC Help Finnish	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{48B40F85-4F69-456F-82EB-E3DCCA15E9F0}	\N
7f888049-412c-4314-9660-555cd1e12068	729	Installed Programs	CCC Help French	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C7DF9961-9EB4-B130-D201-BE71591673F9}	\N
7f888049-412c-4314-9660-555cd1e12068	730	Installed Programs	CCC Help German	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B78F6C6D-3EFB-B64D-FE49-C6318FDD116E}	\N
7f888049-412c-4314-9660-555cd1e12068	731	Installed Programs	CCC Help Greek	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B1525FFC-6691-BCC7-CBFF-CDCF47BC606C}	\N
7f888049-412c-4314-9660-555cd1e12068	732	Installed Programs	CCC Help Hungarian	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{96F82870-A977-2AE6-BAF0-04B143412099}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	6	Computer System	PCSystemType	Mobile	string(CIM:UInt16)	WMI:Win32_ComputerSystem.PCSystemType	\N
7f888049-412c-4314-9660-555cd1e12068	733	Installed Programs	CCC Help Italian	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{FD53BD91-BAA5-2F85-315D-CD3816A280A6}	\N
7f888049-412c-4314-9660-555cd1e12068	734	Installed Programs	CCC Help Japanese	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3327995E-0937-0BB1-F258-711F165E096F}	\N
7f888049-412c-4314-9660-555cd1e12068	735	Installed Programs	CCC Help Korean	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{638FCD4E-0EA4-4EC2-6C06-FC1A06BAB336}	\N
7f888049-412c-4314-9660-555cd1e12068	736	Installed Programs	CCC Help Norwegian	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{19D899D7-CF47-8DEC-4976-F8CB8DAD6C61}	\N
7f888049-412c-4314-9660-555cd1e12068	737	Installed Programs	CCC Help Polish	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E7EA2C61-4E65-AD62-B151-D517F37AFB80}	\N
7f888049-412c-4314-9660-555cd1e12068	738	Installed Programs	CCC Help Portuguese	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{08D02198-001C-FB17-9280-756444349E29}	\N
7f888049-412c-4314-9660-555cd1e12068	739	Installed Programs	CCC Help Russian	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B2506DF2-78E6-8C09-A40D-EA92DB0FA5F0}	\N
7f888049-412c-4314-9660-555cd1e12068	740	Installed Programs	CCC Help Spanish	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{610C146B-F818-BD30-C0F1-7D6E46EEC025}	\N
7f888049-412c-4314-9660-555cd1e12068	741	Installed Programs	CCC Help Swedish	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6A822F2F-8C69-4095-8B18-32326C49B0ED}	\N
7f888049-412c-4314-9660-555cd1e12068	742	Installed Programs	CCC Help Thai	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E328DF8F-CD40-DE5A-E9D0-4367EBA5BD25}	\N
7f888049-412c-4314-9660-555cd1e12068	743	Installed Programs	CCC Help Turkish	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B6B16F49-0533-8772-7C20-09C241847185}	\N
7f888049-412c-4314-9660-555cd1e12068	744	Installed Programs	ccc-utility64	2011.1013.1702.28713	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{2C233758-BD55-8F3F-4BBE-0A11B833CB96}	\N
7f888049-412c-4314-9660-555cd1e12068	745	Installed Programs	Chuzzle Deluxe	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087453	\N
7f888049-412c-4314-9660-555cd1e12068	746	Installed Programs	Cisco AnyConnect Secure Mobility Client	4.2.03013	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{69ABC61D-AE14-4833-A598-E2852A1AAA8A}	\N
7f888049-412c-4314-9660-555cd1e12068	747	Installed Programs	Cisco AnyConnect Secure Mobility Client	4.2.03013	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Cisco AnyConnect Secure Mobility Client	\N
7f888049-412c-4314-9660-555cd1e12068	748	Installed Programs	Cisco Connect	1.4.11299.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Cisco Connect	\N
7f888049-412c-4314-9660-555cd1e12068	749	Installed Programs	Cisco EAP-FAST Module	2.2.14	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{64BF0187-F3D2-498B-99EA-163AF9AE6EC9}	\N
7f888049-412c-4314-9660-555cd1e12068	750	Installed Programs	Cisco LEAP Module	1.0.19	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{51C7AD07-C3F6-4635-8E8A-231306D810FE}	\N
7f888049-412c-4314-9660-555cd1e12068	751	Installed Programs	Cisco PEAP Module	1.1.6	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{ED5776D5-59B4-46B7-AF81-5F2D94D7C640}	\N
7f888049-412c-4314-9660-555cd1e12068	752	Installed Programs	Cisco WebEx Meetings	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\ActiveTouchMeetingClient	\N
7f888049-412c-4314-9660-555cd1e12068	753	Installed Programs	Citrix Online Launcher	1.0.335	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{DB014C85-A264-4BCA-A66F-6DD1FCF8EC36}	\N
7f888049-412c-4314-9660-555cd1e12068	754	Installed Programs	CodeMeter Runtime Kit v6.40	6.40.2396.500	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F6DA1584-1044-466A-BB16-828F30CA8C85}	\N
7f888049-412c-4314-9660-555cd1e12068	755	Installed Programs	ComponentSoftware Revision Control System (CS-RCS)	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\CS-RCS	\N
7f888049-412c-4314-9660-555cd1e12068	756	Installed Programs	Cross Match Technologies L SCAN Essentials (x64) Runtime 6.6.5.0	6.6.5.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{EDE7514E-C390-4CCC-83C0-61EACE19A136}	\N
7f888049-412c-4314-9660-555cd1e12068	757	Installed Programs	Crystal Reports Viewer 2011 SP2	14.0.2.364	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D1ED9B6B-2804-4708-9F8E-D494A3D54288}	\N
7f888049-412c-4314-9660-555cd1e12068	758	Installed Programs	crystalreports.designers.java.documentation.viewer-4.0-en-32	14.0.2.364	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{822F8085-B67C-4C80-B8B4-E024B177516B}	\N
7f888049-412c-4314-9660-555cd1e12068	759	Installed Programs	crystalreports.designers.java.javaviewer-4.0-core-32	14.0.2.364	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{61220D25-5D7E-4C95-935D-249501E71B19}	\N
7f888049-412c-4314-9660-555cd1e12068	760	Installed Programs	crystalreports.designers.java.javaviewer-4.0-en-32	14.0.1.287	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7E9A9833-DD3E-4AED-B49E-26CBDDF58864}	\N
7f888049-412c-4314-9660-555cd1e12068	761	Installed Programs	crystalreports.designers.java.launcher-4.0-core-32	14.0.0.760	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E620C02B-9597-4391-9493-6316F8FD68A2}	\N
7f888049-412c-4314-9660-555cd1e12068	762	Installed Programs	CutePDF Writer 2.7	\N	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\CutePDF Writer Installation	\N
7f888049-412c-4314-9660-555cd1e12068	763	Installed Programs	D3DX10	15.4.2368.0902	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E09C4DB7-630C-4F06-A631-8EA7239923AF}	\N
7f888049-412c-4314-9660-555cd1e12068	764	Installed Programs	Definition Update for Microsoft Office 2010 (KB3115321) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{0ED568CA-DDB4-4F60-81A8-FA0595BC6B97}	\N
7f888049-412c-4314-9660-555cd1e12068	765	Installed Programs	Diner Dash 2 Restaurant Rescue	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087536	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	7	Computer System	SystemType	x64-based PC	CIM:String	WMI:Win32_ComputerSystem.SystemType	\N
7f888049-412c-4314-9660-555cd1e12068	766	Installed Programs	Dropbox	43.4.50	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Dropbox	\N
7f888049-412c-4314-9660-555cd1e12068	767	Installed Programs	Dropbox Update Helper	1.3.65.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{099218A5-A723-43DC-8DB5-6173656A1E94}	\N
7f888049-412c-4314-9660-555cd1e12068	768	Installed Programs	DW Spectrum Bundle	3.1.0.16975	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7e4985c5-ff3c-4315-8b58-737f0311c603}	\N
7f888049-412c-4314-9660-555cd1e12068	769	Installed Programs	DW Spectrum Client	3.1.0.16975	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{47D0F46F-EDC9-4009-8B4B-3313F68D219B}	\N
7f888049-412c-4314-9660-555cd1e12068	770	Installed Programs	DW Spectrum Server	3.1.0.16975	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{EDD7BA73-74FD-403E-A98E-679E9660433B}	\N
7f888049-412c-4314-9660-555cd1e12068	771	Installed Programs	DWG TrueView 2016 - English	20.1.107.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5783F2D7-F028-0409-0100-0060B0CE6BBA}	\N
7f888049-412c-4314-9660-555cd1e12068	772	Installed Programs	Echelon iLON 10	2.00.28	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1D11C43D-4A24-49E2-8584-BE035A008024}	\N
7f888049-412c-4314-9660-555cd1e12068	773	Installed Programs	Echelon OpenLDV 4.0	4.00.102	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{266C3F8F-F098-4731-B82F-E2D60868ADE0}	\N
7f888049-412c-4314-9660-555cd1e12068	774	Installed Programs	Energy Star Digital Logo	1.0.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{BD1A34C9-4764-4F79-AE1F-112F8C89D3D4}	\N
7f888049-412c-4314-9660-555cd1e12068	775	Installed Programs	Farm Frenzy	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT089328	\N
7f888049-412c-4314-9660-555cd1e12068	776	Installed Programs	FATE	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087361	\N
7f888049-412c-4314-9660-555cd1e12068	777	Installed Programs	Galería fotográfica de Windows Live	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E85A4EFC-82F2-4CEE-8A8E-62FDAD353A66}	\N
7f888049-412c-4314-9660-555cd1e12068	778	Installed Programs	Galeria fotogràfica del Windows Live	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4736B0ED-F6A1-48EC-A1B7-C053027648F1}	\N
7f888049-412c-4314-9660-555cd1e12068	779	Installed Programs	Galerie de photos Windows Live	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{488F0347-C4A7-4374-91A7-30818BEDA710}	\N
7f888049-412c-4314-9660-555cd1e12068	780	Installed Programs	Google Update Helper	1.3.25.11	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A92DAB39-4E2C-4304-9AB6-BC44E68B55E2}	\N
7f888049-412c-4314-9660-555cd1e12068	781	Installed Programs	Google Update Helper	1.3.33.5	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{60EC980A-BDA2-4CB6-A427-B07A5498B4CA}	\N
7f888049-412c-4314-9660-555cd1e12068	782	Installed Programs	GoTo Opener	1.0.459	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C0A5FA19-686C-490A-91CF-513FE6832187}	\N
7f888049-412c-4314-9660-555cd1e12068	783	Installed Programs	GoToAssist Customer 4.3.0.1575	4.3.0.1575	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\GoToAssist Express Customer	\N
7f888049-412c-4314-9660-555cd1e12068	784	Installed Programs	Heatsoft ADCS	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Heatsoft ADCS	\N
7f888049-412c-4314-9660-555cd1e12068	785	Installed Programs	Hotfix for Microsoft Visual Studio 2007 Tools for Applications - ENU (KB946040)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4ECF4BDC-8387-329A-ABE9-CF5798F84BB2}.KB946040	\N
7f888049-412c-4314-9660-555cd1e12068	786	Installed Programs	Hotfix for Microsoft Visual Studio 2007 Tools for Applications - ENU (KB946308)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4ECF4BDC-8387-329A-ABE9-CF5798F84BB2}.KB946308	\N
7f888049-412c-4314-9660-555cd1e12068	787	Installed Programs	Hotfix for Microsoft Visual Studio 2007 Tools for Applications - ENU (KB946344)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4ECF4BDC-8387-329A-ABE9-CF5798F84BB2}.KB946344	\N
7f888049-412c-4314-9660-555cd1e12068	788	Installed Programs	Hotfix for Microsoft Visual Studio 2007 Tools for Applications - ENU (KB947540)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4ECF4BDC-8387-329A-ABE9-CF5798F84BB2}.KB947540	\N
7f888049-412c-4314-9660-555cd1e12068	789	Installed Programs	Hotfix for Microsoft Visual Studio 2007 Tools for Applications - ENU (KB947789)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4ECF4BDC-8387-329A-ABE9-CF5798F84BB2}.KB947789	\N
7f888049-412c-4314-9660-555cd1e12068	790	Installed Programs	HP 3D DriveGuard	4.1.4.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{83DA38AB-1014-41C2-A3CD-E2B93832A71A}	\N
7f888049-412c-4314-9660-555cd1e12068	791	Installed Programs	HP Auto	1.0.12494.3472	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CC4D56B7-6F18-470B-8734-ABCD75BCF4F1}	\N
7f888049-412c-4314-9660-555cd1e12068	792	Installed Programs	HP Customer Experience Enhancements	6.0.1.7	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{07FA4960-B038-49EB-891B-9F95930AA544}	\N
7f888049-412c-4314-9660-555cd1e12068	793	Installed Programs	HP DayStarter	2.0.0.12	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{483D5A49-A26B-4CB8-AA2D-0D1811322061}	\N
7f888049-412c-4314-9660-555cd1e12068	794	Installed Programs	HP Documentation	1.2.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6A9C9BE1-14A3-42ED-A388-42E30A1412E9}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	8	Computer System	Manufacturer	Dell Inc.	CIM:String	WMI:Win32_ComputerSystem.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	9	Computer System	Model	Precision 7510	CIM:String	WMI:Win32_ComputerSystem.Model	\N
7f888049-412c-4314-9660-555cd1e12068	795	Installed Programs	HP ESU for Microsoft Windows 7	1.1.11.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CFC1988A-F492-4BC5-B6F7-683A95718AE9}	\N
7f888049-412c-4314-9660-555cd1e12068	796	Installed Programs	HP Game Console	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\My HP Game Console	\N
7f888049-412c-4314-9660-555cd1e12068	797	Installed Programs	HP Games	1.0.1.5	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WildTangent hp Master Uninstall	\N
7f888049-412c-4314-9660-555cd1e12068	798	Installed Programs	HP HD Webcam [Fixed]	3.3.4.07	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Sunplus SPUVCb	\N
7f888049-412c-4314-9660-555cd1e12068	799	Installed Programs	HP HotKey Support	4.0.10.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7D1C63D1-6520-49DA-B738-958133526E80}	\N
7f888049-412c-4314-9660-555cd1e12068	800	Installed Programs	HP Power Assistant	2.0.2.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3D8EDF72-13CC-4E51-AAB6-32A20524D2E0}	\N
7f888049-412c-4314-9660-555cd1e12068	801	Installed Programs	HP QuickWeb	3.0.0.9057	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{20976B1F-E910-404D-9261-C16EE7E12DC8}	\N
7f888049-412c-4314-9660-555cd1e12068	802	Installed Programs	HP Setup	8.5.4526.3645	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{03046EBB-CB7C-4B98-BEFB-690EB955DA22}	\N
7f888049-412c-4314-9660-555cd1e12068	803	Installed Programs	HP SoftPaq Download Manager	3.2.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{344A1AA2-AC8E-4741-BDB0-65B68FDA883C}	\N
7f888049-412c-4314-9660-555cd1e12068	804	Installed Programs	HP Software Framework	4.0.112.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B7F60A16-7A7B-41FB-9AE3-DE9E324FBA06}	\N
7f888049-412c-4314-9660-555cd1e12068	805	Installed Programs	HP Software Setup	8.2.1.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{531000B3-DBEE-4115-BBF3-DA48B67C053F}	\N
7f888049-412c-4314-9660-555cd1e12068	806	Installed Programs	HP Support Assistant	5.2.3.4	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E02FBF01-0DE3-4BCB-89E8-D300FEFC3289}	\N
7f888049-412c-4314-9660-555cd1e12068	807	Installed Programs	HP System Default Settings	2.1.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{54C65FE7-83BD-4A5B-A9B4-41F793C5F241}	\N
7f888049-412c-4314-9660-555cd1e12068	808	Installed Programs	HP Wallpaper	2.00	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{11C9A461-DD9D-4C71-85A4-6DCE7F99CC44}	\N
7f888049-412c-4314-9660-555cd1e12068	809	Installed Programs	HPAsset component for HP Active Support Library	3.0.0.3	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{669D4A35-146B-4314-89F1-1AC3D7B88367}	\N
7f888049-412c-4314-9660-555cd1e12068	810	Installed Programs	IDT Audio	1.0.6325.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E3A5A8AB-58F6-45FF-AFCB-C9AE18C05001}	\N
7f888049-412c-4314-9660-555cd1e12068	811	Installed Programs	Insaniquarium Deluxe	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087480	\N
7f888049-412c-4314-9660-555cd1e12068	812	Installed Programs	Intel(R) Display Audio Driver	6.14.00.3074	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F0E3AD40-2BBD-4360-9C76-B9AC9A5886EA}	\N
7f888049-412c-4314-9660-555cd1e12068	813	Installed Programs	Intel(R) Identity Protection Technology 1.0.71.0	1.0.71.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{2C43790E-8470-1027-82D3-DF319F3C410F}	\N
7f888049-412c-4314-9660-555cd1e12068	814	Installed Programs	Intel(R) Management Engine Components	7.0.0.1144	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{65153EA5-8B6E-43B6-857B-C6E4FC25798A}	\N
7f888049-412c-4314-9660-555cd1e12068	815	Installed Programs	Intel(R) Rapid Storage Technology	10.1.2.1004	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3E29EE6C-963A-4aae-86C1-DC237C4A49FC}	\N
7f888049-412c-4314-9660-555cd1e12068	816	Installed Programs	Intelli-Site	4.0.29.22	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A7FAAD35-A654-41A2-B2A8-14A8AF86FFF0}	\N
7f888049-412c-4314-9660-555cd1e12068	817	Installed Programs	Intelli-Site	4.0.29.22	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\InstallShield_{A7FAAD35-A654-41A2-B2A8-14A8AF86FFF0}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	10	Computer System	NumberOfProcessors	1	CIM:UInt32	WMI:Win32_ComputerSystem.NumberOfProcessors	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	11	Computer System	NumberOfLogicalProcessors	8	CIM:UInt32	WMI:Win32_ComputerSystem.NumberOfLogicalProcessors	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	12	Computer System	TotalPhysicalMemory	32659 MB	toMegaBytes(CIM:UInt64)	WMI:Win32_ComputerSystem.TotalPhysicalMemory	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	13	Operating System	Computer System Name	OSSI-DNOVAK	CIM:String	WMI:CIM_OperatingSystem.CSName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	14	Operating System	Description	OSSI-DNovak	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	15	Operating System	Caption	Microsoft Windows 10 Pro	CIM:String	WMI:CIM_ManagedSystemElement.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	16	Operating System	OtherTypeDescription	\N	CIM:String	WMI:CIM_OperatingSystem.OtherTypeDescription	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	17	Operating System	OperatingSystemSKU	Unknown (48)	string(CIM:UInt32)	WMI:Win32_OperatingSystem.OperatingSystemSKU	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	18	Operating System	ProductType	Workstation	string(CIM:UInt32)	WMI:Win32_OperatingSystem.ProductType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	19	Operating System	OSArchitecture	64-bit	CIM:String	WMI:Win32_OperatingSystem.OSArchitecture	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	20	Operating System	OSLanguage	English – United States	string(CIM:UInt32)	WMI:Win32_OperatingSystem.OSLanguage	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	21	Operating System	CurrentTimeZone	-360	CIM:SInt16	WMI:CIM_OperatingSystem.CurrentTimeZone	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	22	Operating System	Version	10.0.16299	CIM:String	WMI:CIM_OperatingSystem.Version	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	23	Operating System	BuildNumber	16299	CIM:String	WMI:Win32_OperatingSystem.BuildNumber	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	24	Operating System	BuildType	Multiprocessor Free	CIM:String	WMI:Win32_OperatingSystem.BuildType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	25	Operating System	ServicePackMajorVersion	0	CIM:UInt16	WMI:Win32_OperatingSystem.ServicePackMajorVersion	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	26	Operating System	ServicePackMinorVersion	0	CIM:UInt16	WMI:Win32_OperatingSystem.ServicePackMinorVersion	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	27	Motherboard	Manufacturer	Dell Inc.	CIM:String	WMI:CIM_PhysicalElement.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	28	Motherboard	Model	\N	CIM:String	WMI:CIM_PhysicalElement.Model	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	29	Motherboard	Product	0M1YNP	CIM:String	WMI:Win32_BaseBoard.Product	\N
7f888049-412c-4314-9660-555cd1e12068	818	Installed Programs	Intelli-Site	3.9.71	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{0DB69541-0103-11D5-9396-00E0B8161E5B}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	30	Motherboard	Name	Base Board	CIM:String	WMI:CIM_ManagedSystemElement.Name	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	31	Motherboard	Description	Base Board	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	32	Motherboard	Version	A00	CIM:String	WMI:CIM_PhysicalElement.Version	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	33	System Firmware	Manufacturer	Dell Inc.	CIM:String	WMI:CIM_SoftwareElement.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	34	System Firmware	Description	1.13.6	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	35	System Firmware	ReleaseDate	20170621000000.000000+000	CIM:DateTime	WMI:Win32_BIOS.ReleaseDate	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	36	System Firmware	FirmwareType	Unknown	Enum:FirmwareType	Custom:GetFirmwareType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	37	System Firmware	BIOSVersion	DELL   - 1072009	CIM:String	WMI:Win32_BIOS.BIOSVersion[0]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	38	System Firmware	BIOSVersion	1.13.6	CIM:String	WMI:Win32_BIOS.BIOSVersion[1]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	39	System Firmware	BIOSVersion	American Megatrends - 5000B	CIM:String	WMI:Win32_BIOS.BIOSVersion[2]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	40	System Firmware	SMBIOSBIOSVersion	1.13.6	CIM:String	WMI:Win32_BIOS.SMBIOSBIOSVersion	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	41	System Firmware	SMBIOSMajorVersion	3	CIM:UInt16	WMI:Win32_BIOS.SMBIOSMajorVersion	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	42	System Firmware	SMBIOSMinorVersion	0	CIM:UInt16	WMI:Win32_BIOS.SMBIOSMinorVersion	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	43	System Firmware	BiosCharacteristics	[7] PCI is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[0]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	44	System Firmware	BiosCharacteristics	[9] Plug and Play is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[1]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	45	System Firmware	BiosCharacteristics	[11] BIOS is Upgradable (Flash)	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[2]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	46	System Firmware	BiosCharacteristics	[12] BIOS shadowing is allowed	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[3]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	47	System Firmware	BiosCharacteristics	[15] Boot from CD is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[4]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	48	System Firmware	BiosCharacteristics	[16] Selectable Boot is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[5]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	49	System Firmware	BiosCharacteristics	[19] EDD (Enhanced Disk Drive) Specification is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[6]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	50	System Firmware	BiosCharacteristics	[23] Int 13h - 5.25 /1.2MB Floppy Services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[7]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	51	System Firmware	BiosCharacteristics	[24] Int 13h - 3.5 / 720 KB Floppy Services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[8]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	52	System Firmware	BiosCharacteristics	[25] Int 13h - 3.5 / 2.88 MB Floppy Services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[9]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	53	System Firmware	BiosCharacteristics	[26] Int 5h, Print Screen Service is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[10]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	54	System Firmware	BiosCharacteristics	[27] Int 9h, 8042 Keyboard services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[11]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	55	System Firmware	BiosCharacteristics	[28] Int 14h, Serial Services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[12]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	56	System Firmware	BiosCharacteristics	[29] Int 17h, printer services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[13]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	57	System Firmware	BiosCharacteristics	[32] ACPI is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[14]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	58	System Firmware	BiosCharacteristics	[33] USB Legacy is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[15]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	59	System Firmware	BiosCharacteristics	[39] Smart Battery is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[16]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	60	System Firmware	BiosCharacteristics	[40] BIOS Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[17]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	61	System Firmware	BiosCharacteristics	[41] BIOS Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[18]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	62	System Firmware	BiosCharacteristics	[42] BIOS Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[19]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	63	System Firmware	BiosCharacteristics	[43] BIOS Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[20]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	64	Processor	Manufacturer	GenuineIntel	CIM:String	WMI:Win32_Processor.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	65	Processor	Name	Intel(R) Core(TM) i7-6920HQ CPU @ 2.90GHz	CIM:String	WMI:CIM_ManagedSystemElement.Name	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	66	Processor	Description	Intel64 Family 6 Model 94 Stepping 3	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	67	Processor	DeviceID	CPU0	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	68	Processor	Architecture	x64	string(CIM:UInt16)	WMI:Win32_Processor.Architecture	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	69	Processor	Family	Intel Core™ i7-2760QM	string(CIM:UInt16)	WMI:CIM_Processor.Family	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	70	Processor	OtherFamilyDescription	\N	CIM:String	WMI:CIM_Processor.OtherFamilyDescription	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	71	Processor	Version	\N	CIM:String	WMI:Win32_Processor.Version	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	72	Processor	ProcessorId	BFEBFBFF000506E3	CIM:String	WMI:Win32_Processor.ProcessorId	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	73	Processor	NumberOfCores	4	CIM:UInt32	WMI:Win32_Processor.NumberOfCores	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	74	Processor	NumberOfLogicalProcessors	8	CIM:UInt32	WMI:Win32_Processor.NumberOfLogicalProcessors	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	75	Processor	AddressWidth	64	CIM:UInt16	WMI:CIM_Processor.AddressWidth	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	76	Processor	CurrentClockSpeed	2901	CIM:UInt32	WMI:CIM_Processor.CurrentClockSpeed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	77	Processor	MaxClockSpeed	2901	CIM:UInt32	WMI:CIM_Processor.MaxClockSpeed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	78	Memory [1/4]	Tag	Physical Memory 0	CIM:String	WMI:CIM_PhysicalElement.Tag	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	79	Memory [1/4]	Manufacturer	SK Hynix	CIM:String	WMI:CIM_PhysicalElement.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	80	Memory [1/4]	Model	\N	CIM:String	WMI:CIM_PhysicalElement.Model	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	81	Memory [1/4]	PartNumber	HMA41GS6AFR8N-TF    	CIM:String	WMI:CIM_PhysicalElement.PartNumber	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	82	Memory [1/4]	Description	Physical Memory	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	83	Memory [1/4]	Capacity	8192 MB	toMegaBytes(CIM:UInt64)	WMI:CIM_PhysicalMemory.Capacity	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	84	Memory [1/4]	Speed	2133	CIM:UInt32	WMI:CIM_PhysicalMemory.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	85	Memory [1/4]	DataWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.DataWidth	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	86	Memory [1/4]	TotalWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.TotalWidth	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	87	Memory [1/4]	BankLabel	BANK 0	CIM:String	WMI:CIM_PhysicalMemory.BankLabel	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	88	Memory [1/4]	TypeDetail	Synchronous	string(CIM:UInt16)	WMI:Win32_PhysicalMemory.TypeDetail	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	89	Memory [1/4]	MemoryType	Unknown	string(CIM:UInt16)	WMI:CIM_PhysicalMemory.MemoryType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	90	Memory [1/4]	FormFactor	SODIMM	string(CIM:UInt16)	WMI:CIM_Chip.FormFactor	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	91	Memory [1/4]	Status	\N	CIM:String	WMI:CIM_ManagedSystemElement.Status	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	92	Memory [1/4]	Version	\N	CIM:String	WMI:CIM_PhysicalElement.Version	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	93	Memory [2/4]	Tag	Physical Memory 1	CIM:String	WMI:CIM_PhysicalElement.Tag	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	94	Memory [2/4]	Manufacturer	SK Hynix	CIM:String	WMI:CIM_PhysicalElement.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	95	Memory [2/4]	Model	\N	CIM:String	WMI:CIM_PhysicalElement.Model	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	96	Memory [2/4]	PartNumber	HMA41GS6AFR8N-TF    	CIM:String	WMI:CIM_PhysicalElement.PartNumber	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	97	Memory [2/4]	Description	Physical Memory	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	98	Memory [2/4]	Capacity	8192 MB	toMegaBytes(CIM:UInt64)	WMI:CIM_PhysicalMemory.Capacity	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	99	Memory [2/4]	Speed	2133	CIM:UInt32	WMI:CIM_PhysicalMemory.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	100	Memory [2/4]	DataWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.DataWidth	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	101	Memory [2/4]	TotalWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.TotalWidth	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	102	Memory [2/4]	BankLabel	BANK 1	CIM:String	WMI:CIM_PhysicalMemory.BankLabel	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	103	Memory [2/4]	TypeDetail	Synchronous	string(CIM:UInt16)	WMI:Win32_PhysicalMemory.TypeDetail	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	104	Memory [2/4]	MemoryType	Unknown	string(CIM:UInt16)	WMI:CIM_PhysicalMemory.MemoryType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	105	Memory [2/4]	FormFactor	SODIMM	string(CIM:UInt16)	WMI:CIM_Chip.FormFactor	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	106	Memory [2/4]	Status	\N	CIM:String	WMI:CIM_ManagedSystemElement.Status	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	107	Memory [2/4]	Version	\N	CIM:String	WMI:CIM_PhysicalElement.Version	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	108	Memory [3/4]	Tag	Physical Memory 2	CIM:String	WMI:CIM_PhysicalElement.Tag	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	109	Memory [3/4]	Manufacturer	SK Hynix	CIM:String	WMI:CIM_PhysicalElement.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	110	Memory [3/4]	Model	\N	CIM:String	WMI:CIM_PhysicalElement.Model	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	111	Memory [3/4]	PartNumber	HMA41GS6AFR8N-TF    	CIM:String	WMI:CIM_PhysicalElement.PartNumber	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	112	Memory [3/4]	Description	Physical Memory	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	113	Memory [3/4]	Capacity	8192 MB	toMegaBytes(CIM:UInt64)	WMI:CIM_PhysicalMemory.Capacity	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	114	Memory [3/4]	Speed	2133	CIM:UInt32	WMI:CIM_PhysicalMemory.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	115	Memory [3/4]	DataWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.DataWidth	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	116	Memory [3/4]	TotalWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.TotalWidth	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	117	Memory [3/4]	BankLabel	BANK 2	CIM:String	WMI:CIM_PhysicalMemory.BankLabel	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	118	Memory [3/4]	TypeDetail	Synchronous	string(CIM:UInt16)	WMI:Win32_PhysicalMemory.TypeDetail	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	119	Memory [3/4]	MemoryType	Unknown	string(CIM:UInt16)	WMI:CIM_PhysicalMemory.MemoryType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	120	Memory [3/4]	FormFactor	SODIMM	string(CIM:UInt16)	WMI:CIM_Chip.FormFactor	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	121	Memory [3/4]	Status	\N	CIM:String	WMI:CIM_ManagedSystemElement.Status	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	122	Memory [3/4]	Version	\N	CIM:String	WMI:CIM_PhysicalElement.Version	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	123	Memory [4/4]	Tag	Physical Memory 3	CIM:String	WMI:CIM_PhysicalElement.Tag	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	124	Memory [4/4]	Manufacturer	SK Hynix	CIM:String	WMI:CIM_PhysicalElement.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	125	Memory [4/4]	Model	\N	CIM:String	WMI:CIM_PhysicalElement.Model	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	126	Memory [4/4]	PartNumber	HMA41GS6AFR8N-TF    	CIM:String	WMI:CIM_PhysicalElement.PartNumber	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	127	Memory [4/4]	Description	Physical Memory	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	128	Memory [4/4]	Capacity	8192 MB	toMegaBytes(CIM:UInt64)	WMI:CIM_PhysicalMemory.Capacity	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	129	Memory [4/4]	Speed	2133	CIM:UInt32	WMI:CIM_PhysicalMemory.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	130	Memory [4/4]	DataWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.DataWidth	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	131	Memory [4/4]	TotalWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.TotalWidth	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	132	Memory [4/4]	BankLabel	BANK 3	CIM:String	WMI:CIM_PhysicalMemory.BankLabel	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	133	Memory [4/4]	TypeDetail	Synchronous	string(CIM:UInt16)	WMI:Win32_PhysicalMemory.TypeDetail	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	134	Memory [4/4]	MemoryType	Unknown	string(CIM:UInt16)	WMI:CIM_PhysicalMemory.MemoryType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	135	Memory [4/4]	FormFactor	SODIMM	string(CIM:UInt16)	WMI:CIM_Chip.FormFactor	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	136	Memory [4/4]	Status	\N	CIM:String	WMI:CIM_ManagedSystemElement.Status	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	137	Memory [4/4]	Version	\N	CIM:String	WMI:CIM_PhysicalElement.Version	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	138	Network Adapter [1/19]	Description	Microsoft Kernel Debug Network Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	139	Network Adapter [1/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	140	Network Adapter [1/19]	ProductName	Microsoft Kernel Debug Network Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	141	Network Adapter [1/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	142	Network Adapter [1/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	143	Network Adapter [1/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	144	Network Adapter [1/19]	InterfaceIndex	20	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	145	Network Adapter [1/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	146	Network Adapter [1/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	147	Network Adapter [1/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	148	Network Adapter [1/19]	PNPDeviceID	ROOT\\KDNIC\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	149	Network Adapter [1/19]	DeviceID	0	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	150	Network Adapter [1/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	151	Network Adapter [2/19]	Description	Intel(R) Ethernet Connection (2) I219-LM	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	152	Network Adapter [2/19]	Manufacturer	Intel	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	153	Network Adapter [2/19]	ProductName	Intel(R) Ethernet Connection (2) I219-LM	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	154	Network Adapter [2/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	155	Network Adapter [2/19]	MACAddress	A4:4C:C8:57:01:94	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	156	Network Adapter [2/19]	GUID	{5776BA17-4C6A-4FF4-A1DF-B5EBEBDE19A5}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	157	Network Adapter [2/19]	InterfaceIndex	10	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	158	Network Adapter [2/19]	NetConnectionStatus	2	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	159	Network Adapter [2/19]	Speed	1,000.00 Mbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	160	Network Adapter [2/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	161	Network Adapter [2/19]	PNPDeviceID	PCI\\VEN_8086&DEV_15B7&SUBSYS_06D91028&REV_31\\3&11583659&0&FE	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	162	Network Adapter [2/19]	DeviceID	1	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	163	Network Adapter [2/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	164	Network Adapter [3/19]	Description	Qualcomm QCA61x4A 802.11ac Wireless Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	165	Network Adapter [3/19]	Manufacturer	Qualcomm Communications Inc.	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	166	Network Adapter [3/19]	ProductName	Qualcomm QCA61x4A 802.11ac Wireless Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	167	Network Adapter [3/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	168	Network Adapter [3/19]	MACAddress	9C:30:5B:0C:7D:3F	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	169	Network Adapter [3/19]	GUID	{437F570F-077F-4210-98F4-83687A25B49E}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	170	Network Adapter [3/19]	InterfaceIndex	8	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	171	Network Adapter [3/19]	NetConnectionStatus	7	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	172	Network Adapter [3/19]	Speed	144.40 Mbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	173	Network Adapter [3/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	174	Network Adapter [3/19]	PNPDeviceID	PCI\\VEN_168C&DEV_003E&SUBSYS_03101028&REV_32\\4&213D636C&0&00E0	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	175	Network Adapter [3/19]	DeviceID	2	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	176	Network Adapter [3/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	177	Network Adapter [4/19]	Description	Microsoft Wi-Fi Direct Virtual Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	178	Network Adapter [4/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	179	Network Adapter [4/19]	ProductName	Microsoft Wi-Fi Direct Virtual Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	180	Network Adapter [4/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	181	Network Adapter [4/19]	MACAddress	9E:30:5B:0C:7D:3F	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	182	Network Adapter [4/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	183	Network Adapter [4/19]	InterfaceIndex	15	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	184	Network Adapter [4/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	185	Network Adapter [4/19]	Speed	9,223,372.04 Tbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	186	Network Adapter [4/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	187	Network Adapter [4/19]	PNPDeviceID	{5D624F94-8850-40C3-A3FA-A4FD2080BAF3}\\VWIFIMP_WFD\\5&25B05188&1&12	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	188	Network Adapter [4/19]	DeviceID	3	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	189	Network Adapter [4/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	190	Network Adapter [5/19]	Description	Bluetooth Device (RFCOMM Protocol TDI)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	191	Network Adapter [5/19]	Manufacturer	\N	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	192	Network Adapter [5/19]	ProductName	Bluetooth Device (RFCOMM Protocol TDI)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	193	Network Adapter [5/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	194	Network Adapter [5/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	195	Network Adapter [5/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	196	Network Adapter [5/19]	InterfaceIndex	19	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	197	Network Adapter [5/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	198	Network Adapter [5/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	199	Network Adapter [5/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	200	Network Adapter [5/19]	PNPDeviceID	\N	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	201	Network Adapter [5/19]	DeviceID	4	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	202	Network Adapter [5/19]	ConfigManagerErrorCode	\N	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	203	Network Adapter [6/19]	Description	Bluetooth Device (Personal Area Network)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	204	Network Adapter [6/19]	Manufacturer	\N	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	205	Network Adapter [6/19]	ProductName	Bluetooth Device (Personal Area Network)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	206	Network Adapter [6/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	207	Network Adapter [6/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	208	Network Adapter [6/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	209	Network Adapter [6/19]	InterfaceIndex	2	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	210	Network Adapter [6/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	211	Network Adapter [6/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	212	Network Adapter [6/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	213	Network Adapter [6/19]	PNPDeviceID	\N	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	214	Network Adapter [6/19]	DeviceID	5	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	215	Network Adapter [6/19]	ConfigManagerErrorCode	\N	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	216	Network Adapter [7/19]	Description	WAN Miniport (SSTP)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	217	Network Adapter [7/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	218	Network Adapter [7/19]	ProductName	WAN Miniport (SSTP)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	219	Network Adapter [7/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	220	Network Adapter [7/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	221	Network Adapter [7/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	222	Network Adapter [7/19]	InterfaceIndex	3	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	223	Network Adapter [7/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	224	Network Adapter [7/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	225	Network Adapter [7/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	226	Network Adapter [7/19]	PNPDeviceID	SWD\\MSRRAS\\MS_SSTPMINIPORT	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	227	Network Adapter [7/19]	DeviceID	6	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	228	Network Adapter [7/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	229	Network Adapter [8/19]	Description	WAN Miniport (IKEv2)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	230	Network Adapter [8/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	231	Network Adapter [8/19]	ProductName	WAN Miniport (IKEv2)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	232	Network Adapter [8/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	233	Network Adapter [8/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	234	Network Adapter [8/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	235	Network Adapter [8/19]	InterfaceIndex	13	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	236	Network Adapter [8/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	237	Network Adapter [8/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	238	Network Adapter [8/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	239	Network Adapter [8/19]	PNPDeviceID	SWD\\MSRRAS\\MS_AGILEVPNMINIPORT	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	240	Network Adapter [8/19]	DeviceID	7	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	241	Network Adapter [8/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	242	Network Adapter [9/19]	Description	WAN Miniport (L2TP)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	243	Network Adapter [9/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	244	Network Adapter [9/19]	ProductName	WAN Miniport (L2TP)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	245	Network Adapter [9/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	246	Network Adapter [9/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	247	Network Adapter [9/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	248	Network Adapter [9/19]	InterfaceIndex	18	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	249	Network Adapter [9/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	250	Network Adapter [9/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	251	Network Adapter [9/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	252	Network Adapter [9/19]	PNPDeviceID	SWD\\MSRRAS\\MS_L2TPMINIPORT	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	253	Network Adapter [9/19]	DeviceID	8	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	254	Network Adapter [9/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	255	Network Adapter [10/19]	Description	WAN Miniport (PPTP)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	256	Network Adapter [10/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	257	Network Adapter [10/19]	ProductName	WAN Miniport (PPTP)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	258	Network Adapter [10/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	259	Network Adapter [10/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	260	Network Adapter [10/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	261	Network Adapter [10/19]	InterfaceIndex	7	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	262	Network Adapter [10/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	263	Network Adapter [10/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	264	Network Adapter [10/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	265	Network Adapter [10/19]	PNPDeviceID	SWD\\MSRRAS\\MS_PPTPMINIPORT	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	266	Network Adapter [10/19]	DeviceID	9	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	267	Network Adapter [10/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	268	Network Adapter [11/19]	Description	WAN Miniport (PPPOE)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	269	Network Adapter [11/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	270	Network Adapter [11/19]	ProductName	WAN Miniport (PPPOE)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	271	Network Adapter [11/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	272	Network Adapter [11/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	273	Network Adapter [11/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	274	Network Adapter [11/19]	InterfaceIndex	17	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	275	Network Adapter [11/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	276	Network Adapter [11/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	277	Network Adapter [11/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	278	Network Adapter [11/19]	PNPDeviceID	SWD\\MSRRAS\\MS_PPPOEMINIPORT	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	279	Network Adapter [11/19]	DeviceID	10	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	280	Network Adapter [11/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	281	Network Adapter [12/19]	Description	WAN Miniport (IP)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	282	Network Adapter [12/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	283	Network Adapter [12/19]	ProductName	WAN Miniport (IP)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	284	Network Adapter [12/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	285	Network Adapter [12/19]	MACAddress	94:0C:20:52:41:53	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	286	Network Adapter [12/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	287	Network Adapter [12/19]	InterfaceIndex	12	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	288	Network Adapter [12/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	289	Network Adapter [12/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	290	Network Adapter [12/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	291	Network Adapter [12/19]	PNPDeviceID	SWD\\MSRRAS\\MS_NDISWANIP	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	292	Network Adapter [12/19]	DeviceID	11	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	293	Network Adapter [12/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	294	Network Adapter [13/19]	Description	WAN Miniport (IPv6)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	295	Network Adapter [13/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	296	Network Adapter [13/19]	ProductName	WAN Miniport (IPv6)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	297	Network Adapter [13/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	298	Network Adapter [13/19]	MACAddress	98:DE:20:52:41:53	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	299	Network Adapter [13/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	300	Network Adapter [13/19]	InterfaceIndex	4	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	301	Network Adapter [13/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	302	Network Adapter [13/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	303	Network Adapter [13/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	304	Network Adapter [13/19]	PNPDeviceID	SWD\\MSRRAS\\MS_NDISWANIPV6	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	305	Network Adapter [13/19]	DeviceID	12	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	306	Network Adapter [13/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	307	Network Adapter [14/19]	Description	WAN Miniport (Network Monitor)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	308	Network Adapter [14/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	309	Network Adapter [14/19]	ProductName	WAN Miniport (Network Monitor)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	310	Network Adapter [14/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	311	Network Adapter [14/19]	MACAddress	9E:4E:20:52:41:53	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	312	Network Adapter [14/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	313	Network Adapter [14/19]	InterfaceIndex	5	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	314	Network Adapter [14/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	315	Network Adapter [14/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	316	Network Adapter [14/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	317	Network Adapter [14/19]	PNPDeviceID	SWD\\MSRRAS\\MS_NDISWANBH	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	318	Network Adapter [14/19]	DeviceID	13	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	319	Network Adapter [14/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	320	Network Adapter [15/19]	Description	Microsoft Teredo Tunneling Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	321	Network Adapter [15/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	322	Network Adapter [15/19]	ProductName	Microsoft Teredo Tunneling Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	323	Network Adapter [15/19]	AdapterType	Tunnel	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	324	Network Adapter [15/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	325	Network Adapter [15/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	326	Network Adapter [15/19]	InterfaceIndex	6	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	327	Network Adapter [15/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	328	Network Adapter [15/19]	Speed	100.00 Kbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	329	Network Adapter [15/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	330	Network Adapter [15/19]	PNPDeviceID	SWD\\IP_TUNNEL_VBUS\\TEREDO_TUNNEL_DEVICE	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	331	Network Adapter [15/19]	DeviceID	14	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	332	Network Adapter [15/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	333	Network Adapter [16/19]	Description	Microsoft Wi-Fi Direct Virtual Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	334	Network Adapter [16/19]	Manufacturer	\N	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	335	Network Adapter [16/19]	ProductName	Microsoft Wi-Fi Direct Virtual Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	336	Network Adapter [16/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	337	Network Adapter [16/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	338	Network Adapter [16/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	339	Network Adapter [16/19]	InterfaceIndex	11	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	340	Network Adapter [16/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	341	Network Adapter [16/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	342	Network Adapter [16/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	343	Network Adapter [16/19]	PNPDeviceID	\N	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	344	Network Adapter [16/19]	DeviceID	15	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	345	Network Adapter [16/19]	ConfigManagerErrorCode	\N	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	346	Network Adapter [17/19]	Description	Cisco AnyConnect Secure Mobility Client Virtual Miniport Adapter for Windows x64	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	347	Network Adapter [17/19]	Manufacturer	Cisco Systems	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	348	Network Adapter [17/19]	ProductName	Cisco AnyConnect Secure Mobility Client Virtual Miniport Adapter for Windows x64	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	349	Network Adapter [17/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	350	Network Adapter [17/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	351	Network Adapter [17/19]	GUID	{D82D7D9C-2D02-4C25-9ED8-DFB5F5E7DD24}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	352	Network Adapter [17/19]	InterfaceIndex	16	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	353	Network Adapter [17/19]	NetConnectionStatus	0	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	354	Network Adapter [17/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	355	Network Adapter [17/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	356	Network Adapter [17/19]	PNPDeviceID	ROOT\\NET\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	357	Network Adapter [17/19]	DeviceID	16	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	358	Network Adapter [17/19]	ConfigManagerErrorCode	22	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	359	Network Adapter [18/19]	Description	VMware Virtual Ethernet Adapter for VMnet1	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	360	Network Adapter [18/19]	Manufacturer	VMware, Inc.	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	361	Network Adapter [18/19]	ProductName	VMware Virtual Ethernet Adapter for VMnet1	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	362	Network Adapter [18/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	363	Network Adapter [18/19]	MACAddress	00:50:56:C0:00:01	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	364	Network Adapter [18/19]	GUID	{575BA24A-1B69-4F70-8F0E-8C780CC13056}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	365	Network Adapter [18/19]	InterfaceIndex	9	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	366	Network Adapter [18/19]	NetConnectionStatus	2	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	367	Network Adapter [18/19]	Speed	100.00 Mbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	368	Network Adapter [18/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	369	Network Adapter [18/19]	PNPDeviceID	ROOT\\VMWARE\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	370	Network Adapter [18/19]	DeviceID	17	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	371	Network Adapter [18/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	372	Network Adapter [19/19]	Description	VMware Virtual Ethernet Adapter for VMnet8	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	373	Network Adapter [19/19]	Manufacturer	VMware, Inc.	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	374	Network Adapter [19/19]	ProductName	VMware Virtual Ethernet Adapter for VMnet8	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	375	Network Adapter [19/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	376	Network Adapter [19/19]	MACAddress	00:50:56:C0:00:08	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	377	Network Adapter [19/19]	GUID	{BA7F8F6A-D5CC-4DE4-A999-52907CE27923}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	378	Network Adapter [19/19]	InterfaceIndex	14	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	379	Network Adapter [19/19]	NetConnectionStatus	2	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	380	Network Adapter [19/19]	Speed	100.00 Mbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	381	Network Adapter [19/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	382	Network Adapter [19/19]	PNPDeviceID	ROOT\\VMWARE\\0001	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	383	Network Adapter [19/19]	DeviceID	18	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	384	Network Adapter [19/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	385	Network Adapter Configuration [1/19]	Caption	[00000000] Microsoft Kernel Debug Network Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	386	Network Adapter Configuration [1/19]	InterfaceIndex	20	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	387	Network Adapter Configuration [1/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	388	Network Adapter Configuration [1/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	389	Network Adapter Configuration [1/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	390	Network Adapter Configuration [1/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	391	Network Adapter Configuration [1/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	392	Network Adapter Configuration [1/19]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	393	Network Adapter Configuration [1/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	394	Network Adapter Configuration [1/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	395	Network Adapter Configuration [1/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	396	Network Adapter Configuration [1/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	397	Network Adapter Configuration [1/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	398	Network Adapter Configuration [2/19]	Caption	[00000001] Intel(R) Ethernet Connection (2) I219-LM	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	399	Network Adapter Configuration [2/19]	InterfaceIndex	10	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	400	Network Adapter Configuration [2/19]	MACAddress	A4:4C:C8:57:01:94	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	401	Network Adapter Configuration [2/19]	IPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	402	Network Adapter Configuration [2/19]	IPAddress	192.168.20.143	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[0]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	403	Network Adapter Configuration [2/19]	IPAddress	fe80::90a2:ee8b:5350:d960	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[1]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	404	Network Adapter Configuration [2/19]	IPSubnet	255.255.255.0	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[0]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	405	Network Adapter Configuration [2/19]	IPSubnet	64	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[1]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	406	Network Adapter Configuration [2/19]	DefaultIPGateway	192.168.20.254	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway[0]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	407	Network Adapter Configuration [2/19]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	408	Network Adapter Configuration [2/19]	DHCPServer	192.168.20.5	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	409	Network Adapter Configuration [2/19]	DNSHostName	OSSI-DNovak	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	410	Network Adapter Configuration [2/19]	DNSDomain	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	411	Network Adapter Configuration [2/19]	DNSDomainSuffixSearchOrder	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder[0]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	412	Network Adapter Configuration [2/19]	DNSDomainSuffixSearchOrder	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder[1]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	413	Network Adapter Configuration [2/19]	DNSServerSearchOrder	192.168.20.5	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder[0]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	414	Network Adapter Configuration [2/19]	DNSServerSearchOrder	192.168.12.4	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder[1]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	415	Network Adapter Configuration [3/19]	Caption	[00000002] Qualcomm QCA61x4A 802.11ac Wireless Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	416	Network Adapter Configuration [3/19]	InterfaceIndex	8	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	417	Network Adapter Configuration [3/19]	MACAddress	9C:30:5B:0C:7D:3F	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	418	Network Adapter Configuration [3/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	419	Network Adapter Configuration [3/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	420	Network Adapter Configuration [3/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	421	Network Adapter Configuration [3/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	422	Network Adapter Configuration [3/19]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	423	Network Adapter Configuration [3/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	424	Network Adapter Configuration [3/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	425	Network Adapter Configuration [3/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	426	Network Adapter Configuration [3/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	427	Network Adapter Configuration [3/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	428	Network Adapter Configuration [4/19]	Caption	[00000003] Microsoft Wi-Fi Direct Virtual Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	429	Network Adapter Configuration [4/19]	InterfaceIndex	15	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	430	Network Adapter Configuration [4/19]	MACAddress	9E:30:5B:0C:7D:3F	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	431	Network Adapter Configuration [4/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	432	Network Adapter Configuration [4/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	433	Network Adapter Configuration [4/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	434	Network Adapter Configuration [4/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	435	Network Adapter Configuration [4/19]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	436	Network Adapter Configuration [4/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	437	Network Adapter Configuration [4/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	438	Network Adapter Configuration [4/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	439	Network Adapter Configuration [4/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	440	Network Adapter Configuration [4/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	441	Network Adapter Configuration [5/19]	Caption	[00000004] Bluetooth Device (RFCOMM Protocol TDI)	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	442	Network Adapter Configuration [5/19]	InterfaceIndex	19	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	443	Network Adapter Configuration [5/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	444	Network Adapter Configuration [5/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	445	Network Adapter Configuration [5/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	446	Network Adapter Configuration [5/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	447	Network Adapter Configuration [5/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	448	Network Adapter Configuration [5/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	449	Network Adapter Configuration [5/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	450	Network Adapter Configuration [5/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	451	Network Adapter Configuration [5/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	452	Network Adapter Configuration [5/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	453	Network Adapter Configuration [5/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	454	Network Adapter Configuration [6/19]	Caption	[00000005] Bluetooth Device (Personal Area Network)	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	455	Network Adapter Configuration [6/19]	InterfaceIndex	2	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	456	Network Adapter Configuration [6/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	457	Network Adapter Configuration [6/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	458	Network Adapter Configuration [6/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	459	Network Adapter Configuration [6/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	460	Network Adapter Configuration [6/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	461	Network Adapter Configuration [6/19]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	462	Network Adapter Configuration [6/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	463	Network Adapter Configuration [6/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	464	Network Adapter Configuration [6/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	465	Network Adapter Configuration [6/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	466	Network Adapter Configuration [6/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	467	Network Adapter Configuration [7/19]	Caption	[00000006] WAN Miniport (SSTP)	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	468	Network Adapter Configuration [7/19]	InterfaceIndex	3	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	469	Network Adapter Configuration [7/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	470	Network Adapter Configuration [7/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	471	Network Adapter Configuration [7/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	472	Network Adapter Configuration [7/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	473	Network Adapter Configuration [7/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	474	Network Adapter Configuration [7/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	475	Network Adapter Configuration [7/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	476	Network Adapter Configuration [7/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	477	Network Adapter Configuration [7/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	478	Network Adapter Configuration [7/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	479	Network Adapter Configuration [7/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	480	Network Adapter Configuration [8/19]	Caption	[00000007] WAN Miniport (IKEv2)	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	481	Network Adapter Configuration [8/19]	InterfaceIndex	13	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	482	Network Adapter Configuration [8/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	483	Network Adapter Configuration [8/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	484	Network Adapter Configuration [8/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	485	Network Adapter Configuration [8/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	486	Network Adapter Configuration [8/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	487	Network Adapter Configuration [8/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	488	Network Adapter Configuration [8/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	489	Network Adapter Configuration [8/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	490	Network Adapter Configuration [8/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	491	Network Adapter Configuration [8/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	492	Network Adapter Configuration [8/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	493	Network Adapter Configuration [9/19]	Caption	[00000008] WAN Miniport (L2TP)	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	494	Network Adapter Configuration [9/19]	InterfaceIndex	18	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	495	Network Adapter Configuration [9/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	496	Network Adapter Configuration [9/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	497	Network Adapter Configuration [9/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	498	Network Adapter Configuration [9/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	499	Network Adapter Configuration [9/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	500	Network Adapter Configuration [9/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	501	Network Adapter Configuration [9/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	502	Network Adapter Configuration [9/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	503	Network Adapter Configuration [9/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	504	Network Adapter Configuration [9/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	505	Network Adapter Configuration [9/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	506	Network Adapter Configuration [10/19]	Caption	[00000009] WAN Miniport (PPTP)	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	507	Network Adapter Configuration [10/19]	InterfaceIndex	7	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	508	Network Adapter Configuration [10/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	509	Network Adapter Configuration [10/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	510	Network Adapter Configuration [10/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	511	Network Adapter Configuration [10/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	512	Network Adapter Configuration [10/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	513	Network Adapter Configuration [10/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	514	Network Adapter Configuration [10/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	515	Network Adapter Configuration [10/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	516	Network Adapter Configuration [10/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	517	Network Adapter Configuration [10/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	518	Network Adapter Configuration [10/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	519	Network Adapter Configuration [11/19]	Caption	[00000010] WAN Miniport (PPPOE)	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	520	Network Adapter Configuration [11/19]	InterfaceIndex	17	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	521	Network Adapter Configuration [11/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	522	Network Adapter Configuration [11/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	523	Network Adapter Configuration [11/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	524	Network Adapter Configuration [11/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	525	Network Adapter Configuration [11/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	526	Network Adapter Configuration [11/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	527	Network Adapter Configuration [11/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	528	Network Adapter Configuration [11/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	529	Network Adapter Configuration [11/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	530	Network Adapter Configuration [11/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	531	Network Adapter Configuration [11/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	532	Network Adapter Configuration [12/19]	Caption	[00000011] WAN Miniport (IP)	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	533	Network Adapter Configuration [12/19]	InterfaceIndex	12	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	534	Network Adapter Configuration [12/19]	MACAddress	94:0C:20:52:41:53	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	535	Network Adapter Configuration [12/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	536	Network Adapter Configuration [12/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	537	Network Adapter Configuration [12/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	538	Network Adapter Configuration [12/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	539	Network Adapter Configuration [12/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	540	Network Adapter Configuration [12/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	541	Network Adapter Configuration [12/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	542	Network Adapter Configuration [12/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	543	Network Adapter Configuration [12/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	544	Network Adapter Configuration [12/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	545	Network Adapter Configuration [13/19]	Caption	[00000012] WAN Miniport (IPv6)	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	546	Network Adapter Configuration [13/19]	InterfaceIndex	4	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	547	Network Adapter Configuration [13/19]	MACAddress	98:DE:20:52:41:53	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	548	Network Adapter Configuration [13/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	549	Network Adapter Configuration [13/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	550	Network Adapter Configuration [13/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	551	Network Adapter Configuration [13/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	552	Network Adapter Configuration [13/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	553	Network Adapter Configuration [13/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	554	Network Adapter Configuration [13/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	555	Network Adapter Configuration [13/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	556	Network Adapter Configuration [13/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	557	Network Adapter Configuration [13/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	558	Network Adapter Configuration [14/19]	Caption	[00000013] WAN Miniport (Network Monitor)	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	559	Network Adapter Configuration [14/19]	InterfaceIndex	5	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	560	Network Adapter Configuration [14/19]	MACAddress	9E:4E:20:52:41:53	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	561	Network Adapter Configuration [14/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	562	Network Adapter Configuration [14/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	563	Network Adapter Configuration [14/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	564	Network Adapter Configuration [14/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	565	Network Adapter Configuration [14/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	566	Network Adapter Configuration [14/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	567	Network Adapter Configuration [14/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	568	Network Adapter Configuration [14/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	569	Network Adapter Configuration [14/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	570	Network Adapter Configuration [14/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	571	Network Adapter Configuration [15/19]	Caption	[00000014] Microsoft Teredo Tunneling Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	572	Network Adapter Configuration [15/19]	InterfaceIndex	6	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	573	Network Adapter Configuration [15/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	574	Network Adapter Configuration [15/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	575	Network Adapter Configuration [15/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	576	Network Adapter Configuration [15/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	577	Network Adapter Configuration [15/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	578	Network Adapter Configuration [15/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	579	Network Adapter Configuration [15/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	580	Network Adapter Configuration [15/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	581	Network Adapter Configuration [15/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	582	Network Adapter Configuration [15/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	583	Network Adapter Configuration [15/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	584	Network Adapter Configuration [16/19]	Caption	[00000015] Microsoft Wi-Fi Direct Virtual Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	585	Network Adapter Configuration [16/19]	InterfaceIndex	11	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	586	Network Adapter Configuration [16/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	587	Network Adapter Configuration [16/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	588	Network Adapter Configuration [16/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	589	Network Adapter Configuration [16/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	590	Network Adapter Configuration [16/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	591	Network Adapter Configuration [16/19]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	592	Network Adapter Configuration [16/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	593	Network Adapter Configuration [16/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	594	Network Adapter Configuration [16/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	595	Network Adapter Configuration [16/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	596	Network Adapter Configuration [16/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	597	Network Adapter Configuration [17/19]	Caption	[00000016] Cisco AnyConnect Secure Mobility Client Virtual Miniport Adapter for Windows x64	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	598	Network Adapter Configuration [17/19]	InterfaceIndex	16	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	599	Network Adapter Configuration [17/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	600	Network Adapter Configuration [17/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	601	Network Adapter Configuration [17/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	602	Network Adapter Configuration [17/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	603	Network Adapter Configuration [17/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	604	Network Adapter Configuration [17/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	605	Network Adapter Configuration [17/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	606	Network Adapter Configuration [17/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	607	Network Adapter Configuration [17/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	608	Network Adapter Configuration [17/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	609	Network Adapter Configuration [17/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	610	Network Adapter Configuration [18/19]	Caption	[00000017] VMware Virtual Ethernet Adapter for VMnet1	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	611	Network Adapter Configuration [18/19]	InterfaceIndex	9	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	612	Network Adapter Configuration [18/19]	MACAddress	00:50:56:C0:00:01	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	613	Network Adapter Configuration [18/19]	IPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	614	Network Adapter Configuration [18/19]	IPAddress	192.168.80.1	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[0]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	615	Network Adapter Configuration [18/19]	IPAddress	fe80::9480:d7fb:babf:e00a	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[1]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	616	Network Adapter Configuration [18/19]	IPSubnet	255.255.255.0	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[0]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	617	Network Adapter Configuration [18/19]	IPSubnet	64	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[1]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	618	Network Adapter Configuration [18/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	619	Network Adapter Configuration [18/19]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	620	Network Adapter Configuration [18/19]	DHCPServer	192.168.80.254	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	621	Network Adapter Configuration [18/19]	DNSHostName	OSSI-DNovak	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	622	Network Adapter Configuration [18/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	623	Network Adapter Configuration [18/19]	DNSDomainSuffixSearchOrder	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder[0]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	624	Network Adapter Configuration [18/19]	DNSDomainSuffixSearchOrder	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder[1]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	625	Network Adapter Configuration [18/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	626	Network Adapter Configuration [19/19]	Caption	[00000018] VMware Virtual Ethernet Adapter for VMnet8	CIM:String	WMI:CIM_Setting.Caption	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	627	Network Adapter Configuration [19/19]	InterfaceIndex	14	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	628	Network Adapter Configuration [19/19]	MACAddress	00:50:56:C0:00:08	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	629	Network Adapter Configuration [19/19]	IPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	630	Network Adapter Configuration [19/19]	IPAddress	192.168.169.1	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[0]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	631	Network Adapter Configuration [19/19]	IPAddress	fe80::7491:e9ca:9a19:ba8	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[1]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	632	Network Adapter Configuration [19/19]	IPSubnet	255.255.255.0	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[0]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	633	Network Adapter Configuration [19/19]	IPSubnet	64	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[1]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	634	Network Adapter Configuration [19/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	635	Network Adapter Configuration [19/19]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	636	Network Adapter Configuration [19/19]	DHCPServer	192.168.169.254	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	637	Network Adapter Configuration [19/19]	DNSHostName	OSSI-DNovak	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	638	Network Adapter Configuration [19/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	639	Network Adapter Configuration [19/19]	DNSDomainSuffixSearchOrder	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder[0]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	640	Network Adapter Configuration [19/19]	DNSDomainSuffixSearchOrder	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder[1]	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	641	Network Adapter Configuration [19/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	642	Video Adapter [1/2]	Description	Intel(R) HD Graphics 530	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	643	Video Adapter [1/2]	AdapterRAM	1024 MB	toMegaBytes(CIM:UInt32)	WMI:Win32_VideoController.AdapterRAM	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	644	Video Adapter [1/2]	VideoMemoryType	2	CIM:UInt16	WMI:CIM_VideoController.VideoMemoryType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	645	Video Adapter [1/2]	VideoModeDescription	1920 x 1080 x 4294967296 colors	CIM:String	WMI:Win32_VideoController.VideoModeDescription	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	646	Video Adapter [1/2]	VideoProcessor	Intel(R) HD Graphics Family	CIM:String	WMI:CIM_VideoController.VideoProcessor	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	647	Video Adapter [1/2]	CurrentBitsPerPixel	32	CIM:UInt32	WMI:CIM_VideoController.CurrentBitsPerPixel	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	648	Video Adapter [1/2]	CurrentHorizontalResolution	1920	CIM:UInt32	WMI:CIM_VideoController.CurrentHorizontalResolution	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	649	Video Adapter [1/2]	CurrentVerticalResolution	1080	CIM:UInt32	WMI:CIM_VideoController.CurrentVerticalResolution	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	650	Video Adapter [1/2]	CurrentRefreshRate	60	CIM:UInt32	WMI:CIM_VideoController.CurrentRefreshRate	\N
7f888049-412c-4314-9660-555cd1e12068	819	Installed Programs	iTunes	12.7.3.46	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1D7D1271-5258-4F5A-B8C1-7176BF398782}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	651	Video Adapter [1/2]	InstalledDisplayDrivers	C:\\Windows\\System32\\DriverStore\\FileRepository\\ki125175.inf_amd64_4d74412f913cd0aa\\igdumdim64.dll,C:\\Windows\\System32\\DriverStore\\FileRepository\\ki125175.inf_amd64_4d74412f913cd0aa\\igd10iumd64.dll,C:\\Windows\\System32\\DriverStore\\FileRepository\\ki125175.inf_amd64_4d74412f913cd0aa\\igd10iumd64.dll,C:\\Windows\\System32\\DriverStore\\FileRepository\\ki125175.inf_amd64_4d74412f913cd0aa\\igd12umd64.dll	CIM:String	WMI:Win32_VideoController.InstalledDisplayDrivers	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	652	Video Adapter [1/2]	DriverVersion	22.20.16.4836	CIM:String	WMI:Win32_VideoController.DriverVersion	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	653	Video Adapter [1/2]	DriverDate	20171017000000.000000-000	CIM:DateTime	WMI:Win32_VideoController.DriverDate	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	654	Video Adapter [1/2]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	655	Video Adapter [1/2]	PNPDeviceID	PCI\\VEN_8086&DEV_191B&SUBSYS_06D91028&REV_06\\3&11583659&0&10	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	656	Video Adapter [1/2]	DeviceID	VideoController1	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	657	Video Adapter [1/2]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	658	Video Adapter [2/2]	Description	AMD FirePro W5170M	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	659	Video Adapter [2/2]	AdapterRAM	2048 MB	toMegaBytes(CIM:UInt32)	WMI:Win32_VideoController.AdapterRAM	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	660	Video Adapter [2/2]	VideoMemoryType	2	CIM:UInt16	WMI:CIM_VideoController.VideoMemoryType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	661	Video Adapter [2/2]	VideoModeDescription	1920 x 1080 x 4294967296 colors	CIM:String	WMI:Win32_VideoController.VideoModeDescription	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	662	Video Adapter [2/2]	VideoProcessor	AMD FirePro SDI (0x6820)	CIM:String	WMI:CIM_VideoController.VideoProcessor	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	663	Video Adapter [2/2]	CurrentBitsPerPixel	32	CIM:UInt32	WMI:CIM_VideoController.CurrentBitsPerPixel	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	664	Video Adapter [2/2]	CurrentHorizontalResolution	1920	CIM:UInt32	WMI:CIM_VideoController.CurrentHorizontalResolution	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	665	Video Adapter [2/2]	CurrentVerticalResolution	1080	CIM:UInt32	WMI:CIM_VideoController.CurrentVerticalResolution	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	666	Video Adapter [2/2]	CurrentRefreshRate	60	CIM:UInt32	WMI:CIM_VideoController.CurrentRefreshRate	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	667	Video Adapter [2/2]	InstalledDisplayDrivers	C:\\Windows\\System32\\DriverStore\\FileRepository\\c0308392.inf_amd64_bcaeacb8aa4bb9e8\\aticfx64.dll,C:\\Windows\\System32\\DriverStore\\FileRepository\\c0308392.inf_amd64_bcaeacb8aa4bb9e8\\aticfx64.dll,C:\\Windows\\System32\\DriverStore\\FileRepository\\c0308392.inf_amd64_bcaeacb8aa4bb9e8\\aticfx64.dll,C:\\Windows\\System32\\DriverStore\\FileRepository\\c0308392.inf_amd64_bcaeacb8aa4bb9e8\\amdxc64.dll	CIM:String	WMI:Win32_VideoController.InstalledDisplayDrivers	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	668	Video Adapter [2/2]	DriverVersion	21.19.154.768	CIM:String	WMI:Win32_VideoController.DriverVersion	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	669	Video Adapter [2/2]	DriverDate	20161026000000.000000-000	CIM:DateTime	WMI:Win32_VideoController.DriverDate	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	670	Video Adapter [2/2]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	671	Video Adapter [2/2]	PNPDeviceID	PCI\\VEN_1002&DEV_6820&SUBSYS_06D91028&REV_83\\4&3062E079&0&0008	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	672	Video Adapter [2/2]	DeviceID	VideoController2	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	673	Video Adapter [2/2]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	674	Sound Device [1/3]	Description	Realtek Audio	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	675	Sound Device [1/3]	Manufacturer	Realtek	CIM:String	WMI:Win32_SoundDevice.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	676	Sound Device [1/3]	ProductName	Realtek Audio	CIM:String	WMI:Win32_SoundDevice.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	677	Sound Device [1/3]	Availability	\N	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	678	Sound Device [1/3]	PNPDeviceID	HDAUDIO\\FUNC_01&VEN_10EC&DEV_0293&SUBSYS_102806D9&REV_1000\\4&39F3B2C8&0&0001	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	679	Sound Device [1/3]	DeviceID	HDAUDIO\\FUNC_01&VEN_10EC&DEV_0293&SUBSYS_102806D9&REV_1000\\4&39F3B2C8&0&0001	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	680	Sound Device [1/3]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	681	Sound Device [2/3]	Description	Intel(R) Display Audio	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	682	Sound Device [2/3]	Manufacturer	Intel(R) Corporation	CIM:String	WMI:Win32_SoundDevice.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	683	Sound Device [2/3]	ProductName	Intel(R) Display Audio	CIM:String	WMI:Win32_SoundDevice.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	684	Sound Device [2/3]	Availability	\N	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	685	Sound Device [2/3]	PNPDeviceID	HDAUDIO\\FUNC_01&VEN_8086&DEV_2809&SUBSYS_80860101&REV_1000\\4&39F3B2C8&0&0201	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	686	Sound Device [2/3]	DeviceID	HDAUDIO\\FUNC_01&VEN_8086&DEV_2809&SUBSYS_80860101&REV_1000\\4&39F3B2C8&0&0201	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	687	Sound Device [2/3]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	688	Sound Device [3/3]	Description	AMD High Definition Audio Device	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	689	Sound Device [3/3]	Manufacturer	Advanced Micro Devices	CIM:String	WMI:Win32_SoundDevice.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	690	Sound Device [3/3]	ProductName	AMD High Definition Audio Device	CIM:String	WMI:Win32_SoundDevice.ProductName	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	691	Sound Device [3/3]	Availability	\N	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	692	Sound Device [3/3]	PNPDeviceID	HDAUDIO\\FUNC_01&VEN_1002&DEV_AA01&SUBSYS_00AA0100&REV_1003\\5&2704266C&0&0001	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	693	Sound Device [3/3]	DeviceID	HDAUDIO\\FUNC_01&VEN_1002&DEV_AA01&SUBSYS_00AA0100&REV_1003\\5&2704266C&0&0001	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	694	Sound Device [3/3]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	695	Disk Drive	Description	Disk drive	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	696	Disk Drive	Manufacturer	(Standard disk drives)	CIM:String	WMI:Win32_DiskDrive.Manufacturer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	697	Disk Drive	Model	THNSN5512GPU7 NVMe TOSHIBA 512GB	CIM:String	WMI:Win32_DiskDrive.Model	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	698	Disk Drive	FirmwareRevision	57DC4102	CIM:String	WMI:Win32_DiskDrive.FirmwareRevision	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	699	Disk Drive	InterfaceType	SCSI	CIM:String	WMI:Win32_DiskDrive.InterfaceType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	700	Disk Drive	MediaType	Fixed hard disk media	CIM:String	WMI:Win32_DiskDrive.MediaType	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	701	Disk Drive	Size	0.51 TB (0.47 TiB)	toStorageBytes(CIM:UInt64)	WMI:Win32_DiskDrive.Size	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	702	Disk Drive	Partitions	3	CIM:UInt32	WMI:Win32_DiskDrive.Partitions	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	703	Disk Drive	PNPDeviceID	SCSI\\DISK&VEN_NVME&PROD_THNSN5512GPU7_NV\\4&38D6DE9&0&010000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	704	Disk Drive	DeviceID	\\\\.\\PHYSICALDRIVE0	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	705	Disk Drive	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	706	Installed Programs	7-Zip 16.04 (x64)	16.04	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\7-Zip	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	707	Installed Programs	A360 Desktop	8.2.3.1800	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B65CD59E-A771-4354-AA4B-C3E01B496BCD}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	708	Installed Programs	Adobe Acrobat Reader DC	18.011.20038	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{AC76BA86-7AD7-1033-7B44-AC0F074E4100}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	709	Installed Programs	Adobe Bridge CC 2018	8.0.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\KBRG_8_0_1	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	710	Installed Programs	Adobe Creative Cloud	4.4.0.294	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Adobe Creative Cloud	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	711	Installed Programs	Adobe Illustrator CC 2018	22.0.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\ILST_22_0_1	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	712	Installed Programs	Adobe InDesign CC 2018	13.0.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\IDSN_13_0_1	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	713	Installed Programs	Adobe Photoshop CC 2018	19.0.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\PHSP_19_0_1	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	714	Installed Programs	Adobe Refresh Manager	1.8.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{AC76BA86-0804-1033-1959-001824265200}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	715	Installed Programs	AMD Install Manager	9.0.000.4	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\AMD Catalyst Install Manager	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	716	Installed Programs	AMD Install Manager	9.0.000.4	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{DF7CFEF3-5F05-AB56-E931-0FFACFC3DF35}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	717	Installed Programs	AMD Radeon Pro and AMD FirePro Settings	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6A2F70B5-9EA9-70EF-3BD6-4E53E7C87F68}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	718	Installed Programs	AMD Settings	2016.1026.404.5510	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{BA99E23E-C8CB-3391-98EA-677FF43162C3}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	719	Installed Programs	AMD Settings - Branding	1.00.0000	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{78ACE60E-0CB7-4935-BCD4-F33422105607}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	720	Installed Programs	Asmedia USB Host Controller Driver	1.16.49.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E4FB0B39-C991-4EE7-95DD-1A1A7857D33D}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	721	Installed Programs	AutoCAD LT 2018 - English	22.0.49.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{28B89EEF-1009-0000-0102-CF3F3A09B77D}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	722	Installed Programs	AutoCAD LT 2018 - English	22.0.49.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{28B89EEF-1009-0409-2102-CF3F3A09B77D}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	723	Installed Programs	AutoCAD LT 2018 Language Pack - English	22.0.49.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{28B89EEF-1009-0409-1102-CF3F3A09B77D}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	724	Installed Programs	Autodesk Advanced Material Library Image Library 2018	16.11.1.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{177AD7F6-9C77-4E50-BA53-B7259C5F282D}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	725	Installed Programs	Autodesk AutoCAD LT 2018 - English	22.0.49.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\AutoCAD LT 2018 - English	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	726	Installed Programs	Autodesk Desktop App	7.0.7.232	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Autodesk Desktop App	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	727	Installed Programs	Autodesk License Service (x64) - 5.1.4	5.1.4.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3609A8D9-FC0C-4C9B-9F58-0B1D1A4FE556}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	728	Installed Programs	Autodesk Material Library 2018	16.11.1.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7847611E-92E9-4917-B395-71C91D523104}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	729	Installed Programs	Autodesk Material Library Base Resolution Image Library 2018	16.11.1.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{FCDED119-A969-4E48-8A32-D21AD6B03253}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	730	Installed Programs	Catalyst Control Center Next Localization BR	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{8198911E-61B6-5269-900A-8835A1DB745C}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	731	Installed Programs	Catalyst Control Center Next Localization CHS	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3228102A-A1BC-B292-813A-3D8525C0EBBE}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	732	Installed Programs	Catalyst Control Center Next Localization CHT	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{FD9717CA-77A2-3C16-2799-2E821A90CF85}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	733	Installed Programs	Catalyst Control Center Next Localization CS	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A19DDC9C-DCC8-56E2-A118-E9B1BE3697A0}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	734	Installed Programs	Catalyst Control Center Next Localization DA	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{40C9B535-4197-FB0D-B167-3294734C9B39}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	735	Installed Programs	Catalyst Control Center Next Localization DE	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C840CAF7-42F8-C474-3354-804013E79D69}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	736	Installed Programs	Catalyst Control Center Next Localization EL	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C806EF06-DA5D-7E3E-1469-64D44A04A434}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	737	Installed Programs	Catalyst Control Center Next Localization ES	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D7A53E33-3755-D0BB-80A3-FB4E3169B489}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	738	Installed Programs	Catalyst Control Center Next Localization FI	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F40C52DB-FEA5-503F-DA04-58F784BC2837}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	739	Installed Programs	Catalyst Control Center Next Localization FR	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3E8846D9-CB92-6BC7-D010-64EBAB024121}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	740	Installed Programs	Catalyst Control Center Next Localization HU	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{679C5976-0CFD-EC79-E2D7-63DFCF7A4E42}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	741	Installed Programs	Catalyst Control Center Next Localization IT	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{91B18C11-8470-81DF-07B1-919DB4D0D27E}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	742	Installed Programs	Catalyst Control Center Next Localization JA	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E7AE8A79-2357-0198-00DC-81B4A7466E4B}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	743	Installed Programs	Catalyst Control Center Next Localization KO	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CEEA750F-C747-1B3F-93E5-DD248E6E4AC0}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	744	Installed Programs	Catalyst Control Center Next Localization NL	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E8F66119-B17F-C43D-4908-AFCA24B66F08}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	745	Installed Programs	Catalyst Control Center Next Localization NO	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{70653054-8D22-1D7F-A059-15A549E320BD}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	746	Installed Programs	Catalyst Control Center Next Localization PL	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{FDE07145-B01B-4C13-12DF-EAFE5F1E7AA8}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	747	Installed Programs	Catalyst Control Center Next Localization RU	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{94B5DC1E-DCD0-A1CD-7F6D-4147F10EC337}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	748	Installed Programs	Catalyst Control Center Next Localization SV	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{711F94EC-F1A4-AE21-D715-F700C2203F0F}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	749	Installed Programs	Catalyst Control Center Next Localization TH	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{8FA6BE00-0F49-86E0-EF4E-0C8DC0D702E3}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	750	Installed Programs	Catalyst Control Center Next Localization TR	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{0E137770-540F-B927-7DA7-D50A3027D497}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	751	Installed Programs	Cisco AnyConnect Secure Mobility Client	4.2.03013	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Cisco AnyConnect Secure Mobility Client	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	752	Installed Programs	Cisco AnyConnect Secure Mobility Client	4.2.03013	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{69ABC61D-AE14-4833-A598-E2852A1AAA8A}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	753	Installed Programs	Dell ControlVault Host Components Installer 64 bit	4.7.26.65	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{54874EC0-CEC5-4BD0-A442-9332BBA7AF89}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	754	Installed Programs	Dell Touchpad	10.2207.101.108	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{9F72EF8B-AEC9-4CA5-B483-143980AFD6FD}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	755	Installed Programs	Dell WLAN Radio Switch Driver	1.0.0.9	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A084898A-E69D-453F-ABE9-A7A075A4B261}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	756	Installed Programs	ESET Security	11.0.159.5	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3EB22EED-2263-4174-9F36-09BD15A7AEF8}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	757	Installed Programs	Google Chrome	64.0.3282.186	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Google Chrome	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	758	Installed Programs	Google Update Helper	1.3.33.7	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{60EC980A-BDA2-4CB6-A427-B07A5498B4CA}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	759	Installed Programs	GoTo Opener	1.0.473	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1F803452-798F-49FB-A5DD-9F527F7017E4}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	760	Installed Programs	GoToAssist Customer 4.3.0.1575	4.3.0.1575	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\GoToAssist Express Customer	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	761	Installed Programs	Intel(R) Chipset Device Software	10.1.1.9	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{c7f54569-0018-439c-809a-48046a4d4ebc}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	762	Installed Programs	Intel(R) Chipset Device Software	10.1.1.9	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{55398EAC-F58E-4F19-B553-BDF8B9EFD839}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	763	Installed Programs	Intel(R) Dynamic Platform and Thermal Framework	8.2.10900.330	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{654EE65D-FAA4-4EA6-8C07-DC94E6A304D4}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	764	Installed Programs	Intel(R) Management Engine Components	11.0.0.1167	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1CEAC85D-2590-4760-800F-8DE5E91F3700}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	765	Installed Programs	Intel(R) Management Engine Components	11.0.0.1167	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{24962326-A318-4620-85A7-F91DD6DBF5C4}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	766	Installed Programs	Intel(R) Management Engine Components	1.0.0.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92979371-FDF4-45F8-8245-28560F71EC17}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	767	Installed Programs	Intel(R) Management Engine Components	1.0.0.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1F26F2D5-8DD0-4C68-A1E8-D7B423EC8B7C}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	768	Installed Programs	Intel(R) ME UninstallLegacy	1.0.1.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{DC051DD8-4EFB-4414-8721-4D45B448D1BE}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	769	Installed Programs	Intel(R) Network Connections 22.3.108.0	22.3.108.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1BF1F291-FDA4-404E-994E-AD711C689CFC}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	770	Installed Programs	Intel(R) Network Connections 22.3.108.0	22.3.108.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\PROSetDX	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	771	Installed Programs	Intel(R) Processor Graphics	22.20.16.4836	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F0E3AD40-2BBD-4360-9C76-B9AC9A5886EA}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	772	Installed Programs	Intel(R) Rapid Storage Technology	15.7.5.1025	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{409CB30E-E457-4008-9B1A-ED1B9EA21140}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	773	Installed Programs	Intel(R) Rapid Storage Technology	15.7.5.1025	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{69A3A70F-818A-47ED-8226-583A839DF7F9}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	774	Installed Programs	Intel® Security Assist	1.0.0.532	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4B230374-6475-4A73-BA6E-41015E9C5013}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	775	Installed Programs	Intel® Trusted Connect Service Client	1.42.17.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7D84E343-A23D-451C-B123-0195B2D903A6}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	776	Installed Programs	Intelli-Site	4.0.29.22	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\InstallShield_{A7FAAD35-A654-41A2-B2A8-14A8AF86FFF0}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	777	Installed Programs	Intelli-Site	4.0.29.22	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A7FAAD35-A654-41A2-B2A8-14A8AF86FFF0}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	778	Installed Programs	LinkPoint for Salesforce	5.00.0000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{DECDCD14-DEF6-49ED-9440-CC5E562FDC41}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	779	Installed Programs	Maxx Audio Installer (x64)	2.6.8627.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{307032B2-6AF2-46D7-B933-62438DEB2B9A}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	780	Installed Programs	Microsoft Office Home and Business 2016 - en-us	16.0.9001.2171	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\HomeBusinessRetail - en-us	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	781	Installed Programs	Microsoft Visual C++ 2005 Redistributable	8.0.56336	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7299052b-02a4-4627-81f2-1818da5d550d}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	782	Installed Programs	Microsoft Visual C++ 2005 Redistributable (x64)	8.0.56336	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{071c9b48-7c32-4621-a0ac-3f809523288f}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	783	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x64 9.0.30729.17	9.0.30729	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{8220EEFE-38CD-377E-8595-13398D740ACE}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	784	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x64 9.0.30729.4148	9.0.30729.4148	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4B6C7001-C7D6-3710-913E-5BC23FCE91E6}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	785	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x86 9.0.30729.17	9.0.30729	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{9A25302D-30C0-39D9-BD6F-21E6EC160475}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	786	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x86 9.0.30729.4148	9.0.30729.4148	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1F1C2DFC-2D24-3E06-BCB8-725134ADF989}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	787	Installed Programs	Microsoft Visual C++ 2010  x64 Redistributable - 10.0.40219	10.0.40219	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1D8E6291-B0D5-35EC-8441-6616F567A0F7}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	788	Installed Programs	Microsoft Visual C++ 2010  x86 Redistributable - 10.0.40219	10.0.40219	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F0C3E5D1-1ADE-321E-8167-68EF0DE699A5}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	789	Installed Programs	Microsoft Visual C++ 2012 Redistributable (x64) - 11.0.61030	11.0.61030.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{ca67548a-5ebe-413a-b50c-4b9ceb6d66c6}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	790	Installed Programs	Microsoft Visual C++ 2012 Redistributable (x86) - 11.0.60610	11.0.60610.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{95716cce-fc71-413f-8ad5-56c2892d4b3a}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	791	Installed Programs	Microsoft Visual C++ 2012 Redistributable (x86) - 11.0.61030	11.0.61030.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{33d1fd90-4274-48a1-9bc1-97e33d9c2d6f}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	792	Installed Programs	Microsoft Visual C++ 2012 x64 Additional Runtime - 11.0.61030	11.0.61030	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{37B8F9C7-03FB-3253-8781-2517C99D7C00}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	793	Installed Programs	Microsoft Visual C++ 2012 x64 Minimum Runtime - 11.0.61030	11.0.61030	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CF2BEA3C-26EA-32F8-AA9B-331F7E34BA97}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	794	Installed Programs	Microsoft Visual C++ 2012 x86 Additional Runtime - 11.0.61030	11.0.61030	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B175520C-86A2-35A7-8619-86DC379688B9}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	795	Installed Programs	Microsoft Visual C++ 2012 x86 Minimum Runtime - 11.0.61030	11.0.61030	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{BD95A8CD-1D9F-35AD-981A-3E7925026EBB}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	796	Installed Programs	Microsoft Visual C++ 2013 Redistributable (x64) - 12.0.30501	12.0.30501.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{050d4fc8-5d48-4b8f-8972-47c82c46020f}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	797	Installed Programs	Microsoft Visual C++ 2013 Redistributable (x86) - 12.0.30501	12.0.30501.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{f65db027-aff3-4070-886a-0d87064aabb1}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	798	Installed Programs	Microsoft Visual C++ 2013 x64 Additional Runtime - 12.0.21005	12.0.21005	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{929FBD26-9020-399B-9A7A-751D61F0B942}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	799	Installed Programs	Microsoft Visual C++ 2013 x64 Minimum Runtime - 12.0.21005	12.0.21005	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A749D8E6-B613-3BE3-8F5F-045C84EBA29B}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	800	Installed Programs	Microsoft Visual C++ 2013 x86 Additional Runtime - 12.0.21005	12.0.21005	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F8CFEB22-A2E7-3971-9EDA-4B11EDEFC185}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	801	Installed Programs	Microsoft Visual C++ 2013 x86 Minimum Runtime - 12.0.21005	12.0.21005	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{13A4EE12-23EA-3371-91EE-EFB36DDFFF3E}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	802	Installed Programs	Microsoft Visual C++ 2017 Redistributable (x64) - 14.12.25810	14.12.25810.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{e2ee15e2-a480-4bc5-bfb7-e9803d1d9823}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	803	Installed Programs	Microsoft Visual C++ 2017 Redistributable (x86) - 14.12.25810	14.12.25810.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{56e11d69-7cc9-40a5-a4f9-8f6190c4d84d}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	804	Installed Programs	Microsoft Visual C++ 2017 x64 Additional Runtime - 14.12.25810	14.12.25810	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{2CD849A7-86A1-34A6-B8F9-D72F5B21A9AE}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	805	Installed Programs	Microsoft Visual C++ 2017 x64 Minimum Runtime - 14.12.25810	14.12.25810	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C99E2ADC-0347-336E-A603-F1992B09D582}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	806	Installed Programs	Microsoft Visual C++ 2017 x86 Additional Runtime - 14.12.25810	14.12.25810	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7FED75A1-600C-394B-8376-712E2A8861F2}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	807	Installed Programs	Microsoft Visual C++ 2017 x86 Minimum Runtime - 14.12.25810	14.12.25810	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{828952EB-5572-3666-8CA9-000B6CE79350}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	808	Installed Programs	Mozilla Firefox 57.0.4 (x64 en-US)	57.0.4	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Mozilla Firefox 57.0.4 (x64 en-US)	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	809	Installed Programs	Mozilla Maintenance Service	57.0.4	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\MozillaMaintenanceService	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	810	Installed Programs	Office 16 Click-to-Run Extensibility Component	16.0.9001.2171	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90160000-008C-0000-0000-0000000FF1CE}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	811	Installed Programs	Office 16 Click-to-Run Extensibility Component 64-bit Registration	16.0.9001.2171	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90160000-00DD-0000-1000-0000000FF1CE}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	812	Installed Programs	Office 16 Click-to-Run Licensing Component	16.0.9001.2171	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90160000-008F-0000-1000-0000000FF1CE}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	813	Installed Programs	Office 16 Click-to-Run Localization Component	16.0.9001.2171	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90160000-008C-0409-0000-0000000FF1CE}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	814	Installed Programs	PX Profile Update	1.00.1.	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E4D56AEC-96DF-C9BA-62AC-691A9AF21AE1}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	815	Installed Programs	Qualcomm Atheros Bluetooth Installer (64)	10.0.0.303	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{628988B4-3FA5-4EA6-BAA3-DA640F6718BD}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	816	Installed Programs	Qualcomm Unified Wireless Suite	11.0.0.10426	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6CFE6F33-3D69-4B9C-AA20-FF1F8CB064D5}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	817	Installed Programs	Realtek Audio COM Components	1.0.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{2355B503-9B11-4449-861D-1C1748B26320}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	818	Installed Programs	Realtek Card Reader	10.0.10586.21289	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5BC2B5AB-80DE-4E83-B8CF-426902051D0A}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	819	Installed Programs	Realtek High Definition Audio Driver	6.0.1.6111	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F132AF7F-7BCA-4EDE-8A7C-958108FE7DBC}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	820	Installed Programs	ST Microelectronics 3 Axis Digital Accelerometer Solution	4.10.0071	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{9C24F411-9CA7-4A8A-91F3-F08A4A38EB31}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	821	Installed Programs	Thunderbolt™ Software	16.3.61.275	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{87A31923-8F18-4943-8093-17DBEE0101B7}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	822	Installed Programs	VMware Workstation	12.1.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F4C0A853-FA3B-4404-954B-799299EB5A98}	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	823	Installed Programs	Vulkan Run Time Libraries 1.0.26.0	1.0.26.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\VulkanRT1.0.26.0	\N
bf0c79a3-d58b-4fab-af72-98c69dcc3d34	824	Installed Programs	Vulkan Run Time Libraries 1.0.54.1	1.0.54.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\VulkanRT1.0.54.1	\N
7f888049-412c-4314-9660-555cd1e12068	820	Installed Programs	Java 8 Update 131	8.0.1310.11	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{26A24AE4-039D-4CA4-87B4-2F32180131F0}	\N
7f888049-412c-4314-9660-555cd1e12068	821	Installed Programs	Java Auto Updater	2.8.131.11	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4A03706F-666A-4037-7777-5F2748764D10}	\N
7f888049-412c-4314-9660-555cd1e12068	822	Installed Programs	JavaFX 2.1.1	2.1.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1111706F-666A-4037-7777-211328764D10}	\N
7f888049-412c-4314-9660-555cd1e12068	823	Installed Programs	Jewel Quest II	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087485	\N
7f888049-412c-4314-9660-555cd1e12068	824	Installed Programs	Jewel Quest Solitaire	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087490	\N
7f888049-412c-4314-9660-555cd1e12068	825	Installed Programs	JMicron Flash Media Controller Driver	1.0.57.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{26604C7E-A313-4D12-867F-7C6E7820BE4C}	\N
7f888049-412c-4314-9660-555cd1e12068	826	Installed Programs	John Deere Drive Green	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087380	\N
7f888049-412c-4314-9660-555cd1e12068	827	Installed Programs	Malwarebytes version 3.2.2.2029	3.2.2.2029	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{35065F43-4BB2-439A-BFF7-0F1014F2E0CD}_is1	\N
7f888049-412c-4314-9660-555cd1e12068	828	Installed Programs	Microsoft .NET Framework 1.1	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Microsoft .NET Framework 1.1  (1033)	\N
7f888049-412c-4314-9660-555cd1e12068	829	Installed Programs	Microsoft .NET Framework 1.1	1.1.4322	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CB2F7EDD-9D1F-43C1-90FC-4F52EAE172A1}	\N
7f888049-412c-4314-9660-555cd1e12068	830	Installed Programs	Microsoft .NET Framework 4.5.2	4.5.51209	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{26784146-6E05-3FF9-9335-786C7C0FB5BE}	\N
7f888049-412c-4314-9660-555cd1e12068	831	Installed Programs	Microsoft .NET Framework 4.5.2	4.5.51209	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132} - 1033	\N
7f888049-412c-4314-9660-555cd1e12068	832	Installed Programs	Microsoft Application Error Reporting	12.0.6015.5000	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{95120000-00B9-0409-1000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	833	Installed Programs	Microsoft Application Error Reporting	12.0.6012.5000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{95120000-00B9-0409-0000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	834	Installed Programs	Microsoft Office Access MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0015-0409-0000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	835	Installed Programs	Microsoft Office Access Setup Metadata MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0117-0409-0000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	836	Installed Programs	Microsoft Office Excel MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0016-0409-0000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	837	Installed Programs	Microsoft Office Home and Business 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Office14.SingleImage	\N
7f888049-412c-4314-9660-555cd1e12068	838	Installed Programs	Microsoft Office Office 64-bit Components 2010	14.0.7015.1000	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	839	Installed Programs	Microsoft Office OneNote MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-00A1-0409-0000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	840	Installed Programs	Microsoft Office Outlook MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001A-0409-0000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	841	Installed Programs	Microsoft Office PowerPoint MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0018-0409-0000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	842	Installed Programs	Microsoft Office Proof (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-0409-0000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	843	Installed Programs	Microsoft Office Proof (French) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-040C-0000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	844	Installed Programs	Microsoft Office Proof (Spanish) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-0C0A-0000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	845	Installed Programs	Microsoft Office Proofing (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002C-0409-0000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	846	Installed Programs	Microsoft Office Publisher MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0019-0409-0000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	847	Installed Programs	Microsoft Office Shared 64-bit MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0409-1000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	848	Installed Programs	Microsoft Office Shared 64-bit Setup Metadata MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0116-0409-1000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	849	Installed Programs	Microsoft Office Shared MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-006E-0409-0000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	850	Installed Programs	Microsoft Office Shared Setup Metadata MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0115-0409-0000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	851	Installed Programs	Microsoft Office Single Image 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	852	Installed Programs	Microsoft Office Word MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001B-0409-0000-0000000FF1CE}	\N
7f888049-412c-4314-9660-555cd1e12068	853	Installed Programs	Microsoft Report Viewer Redistributable 2008 (KB971119)	9.0.30731	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CED243AB-C7BA-3D42-9609-14EF5A6FC601}	\N
7f888049-412c-4314-9660-555cd1e12068	854	Installed Programs	Microsoft Report Viewer Redistributable 2008 SP1	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Microsoft Report Viewer Redistributable 2008 (KB971119)	\N
7f888049-412c-4314-9660-555cd1e12068	855	Installed Programs	Microsoft Security Client	4.7.0205.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{996D32B6-F629-4764-894B-CB24D9C19051}	\N
7f888049-412c-4314-9660-555cd1e12068	856	Installed Programs	Microsoft Security Essentials	4.7.205.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Microsoft Security Client	\N
7f888049-412c-4314-9660-555cd1e12068	857	Installed Programs	Microsoft Silverlight	5.1.50907.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{89F4137D-6C26-4A84-BDB8-2E5A4BB71E00}	\N
7f888049-412c-4314-9660-555cd1e12068	858	Installed Programs	Microsoft SQL Server 2005 Backward compatibility	8.05.2309	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{8909B8A7-CEAB-4772-BF29-1892C4E6603B}	\N
7f888049-412c-4314-9660-555cd1e12068	859	Installed Programs	Microsoft SQL Server 2008 R2	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Microsoft SQL Server 10	\N
7f888049-412c-4314-9660-555cd1e12068	860	Installed Programs	Microsoft SQL Server 2008 R2	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Microsoft SQL Server 2008 R2	\N
7f888049-412c-4314-9660-555cd1e12068	861	Installed Programs	Microsoft SQL Server 2008 R2 Native Client	10.51.2500.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{471AAD2C-9078-4DAC-BD43-FA10FB7C3FCE}	\N
7f888049-412c-4314-9660-555cd1e12068	862	Installed Programs	Microsoft SQL Server 2008 R2 Policies	10.50.1600.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D21BC5B2-CBAC-48FA-A701-B5A63C1CA7B8}	\N
7f888049-412c-4314-9660-555cd1e12068	863	Installed Programs	Microsoft SQL Server 2008 R2 RsFx Driver	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{93968FB2-C67A-4A9B-80C2-5D4D9393058E}	\N
7f888049-412c-4314-9660-555cd1e12068	864	Installed Programs	Microsoft SQL Server 2008 R2 Setup (English)	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{48B08845-0CB0-45EC-893C-15319ADDA312}	\N
7f888049-412c-4314-9660-555cd1e12068	865	Installed Programs	Microsoft SQL Server 2008 Setup Support Files	10.1.2731.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D441BD04-E548-4F8E-97A4-1B66135BAAA8}	\N
7f888049-412c-4314-9660-555cd1e12068	866	Installed Programs	Microsoft SQL Server Browser	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{BF9BF038-FE03-429D-9B26-2FA0FD756052}	\N
7f888049-412c-4314-9660-555cd1e12068	867	Installed Programs	Microsoft SQL Server Compact 3.5 SP2 ENU	3.5.8080.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3A9FC03D-C685-4831-94CF-4EDFD3749497}	\N
7f888049-412c-4314-9660-555cd1e12068	868	Installed Programs	Microsoft SQL Server Compact 3.5 SP2 Query Tools ENU	3.5.8080.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{DDFD8348-058C-4F4B-85E5-6D740D4AB3FE}	\N
7f888049-412c-4314-9660-555cd1e12068	869	Installed Programs	Microsoft SQL Server VSS Writer	10.51.2500.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{288D79EE-A2D1-42AF-9597-B0ADCC23A8ED}	\N
7f888049-412c-4314-9660-555cd1e12068	870	Installed Programs	Microsoft Text-to-Speech Engine 4.0 (English)	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\MSTTS	\N
7f888049-412c-4314-9660-555cd1e12068	871	Installed Programs	Microsoft VC9 runtime libraries	2.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{553C904F-57A2-4113-888E-BA0C3D1C69C0}	\N
7f888049-412c-4314-9660-555cd1e12068	872	Installed Programs	Microsoft Visual C++ 2005 Redistributable	8.0.61001	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{710f4c1c-cc18-4c49-8cbf-51240c89a1a2}	\N
7f888049-412c-4314-9660-555cd1e12068	873	Installed Programs	Microsoft Visual C++ 2005 Redistributable (x64)	8.0.59192	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6ce5bae9-d3ca-4b99-891a-1dc6c118a5fc}	\N
7f888049-412c-4314-9660-555cd1e12068	874	Installed Programs	Microsoft Visual C++ 2005 Redistributable (x64)	8.0.61000	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{ad8a2fa1-06e7-4b0d-927d-6e54b3d31028}	\N
7f888049-412c-4314-9660-555cd1e12068	875	Installed Programs	Microsoft Visual C++ 2005 Redistributable (x64)	8.0.56336	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{071c9b48-7c32-4621-a0ac-3f809523288f}	\N
7f888049-412c-4314-9660-555cd1e12068	876	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x64 9.0.30729.17	9.0.30729	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{8220EEFE-38CD-377E-8595-13398D740ACE}	\N
7f888049-412c-4314-9660-555cd1e12068	877	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x64 9.0.30729.4148	9.0.30729.4148	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4B6C7001-C7D6-3710-913E-5BC23FCE91E6}	\N
7f888049-412c-4314-9660-555cd1e12068	878	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x64 9.0.30729.6161	9.0.30729.6161	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5FCE6D76-F5DC-37AB-B2B8-22AB8CEDB1D4}	\N
7f888049-412c-4314-9660-555cd1e12068	879	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x86 9.0.30729.17	9.0.30729	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{9A25302D-30C0-39D9-BD6F-21E6EC160475}	\N
7f888049-412c-4314-9660-555cd1e12068	880	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x86 9.0.30729.4148	9.0.30729.4148	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1F1C2DFC-2D24-3E06-BCB8-725134ADF989}	\N
7f888049-412c-4314-9660-555cd1e12068	881	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x86 9.0.30729.6161	9.0.30729.6161	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{9BE518E6-ECC6-35A9-88E4-87755C07200F}	\N
7f888049-412c-4314-9660-555cd1e12068	882	Installed Programs	Microsoft Visual C++ 2010  x64 Redistributable - 10.0.40219	10.0.40219	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1D8E6291-B0D5-35EC-8441-6616F567A0F7}	\N
7f888049-412c-4314-9660-555cd1e12068	883	Installed Programs	Microsoft Visual C++ 2010  x86 Redistributable - 10.0.40219	10.0.40219	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F0C3E5D1-1ADE-321E-8167-68EF0DE699A5}	\N
7f888049-412c-4314-9660-555cd1e12068	884	Installed Programs	Microsoft Visual C++ 2012 Redistributable (x64) - 11.0.61030	11.0.61030.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{ca67548a-5ebe-413a-b50c-4b9ceb6d66c6}	\N
7f888049-412c-4314-9660-555cd1e12068	885	Installed Programs	Microsoft Visual C++ 2012 Redistributable (x86) - 11.0.60610	11.0.60610.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{95716cce-fc71-413f-8ad5-56c2892d4b3a}	\N
7f888049-412c-4314-9660-555cd1e12068	886	Installed Programs	Microsoft Visual C++ 2012 Redistributable (x86) - 11.0.61030	11.0.61030.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{33d1fd90-4274-48a1-9bc1-97e33d9c2d6f}	\N
7f888049-412c-4314-9660-555cd1e12068	887	Installed Programs	Microsoft Visual C++ 2012 x64 Additional Runtime - 11.0.61030	11.0.61030	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{37B8F9C7-03FB-3253-8781-2517C99D7C00}	\N
7f888049-412c-4314-9660-555cd1e12068	888	Installed Programs	Microsoft Visual C++ 2012 x64 Minimum Runtime - 11.0.61030	11.0.61030	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CF2BEA3C-26EA-32F8-AA9B-331F7E34BA97}	\N
7f888049-412c-4314-9660-555cd1e12068	889	Installed Programs	Microsoft Visual C++ 2012 x86 Additional Runtime - 11.0.61030	11.0.61030	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B175520C-86A2-35A7-8619-86DC379688B9}	\N
7f888049-412c-4314-9660-555cd1e12068	890	Installed Programs	Microsoft Visual C++ 2012 x86 Minimum Runtime - 11.0.61030	11.0.61030	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{BD95A8CD-1D9F-35AD-981A-3E7925026EBB}	\N
7f888049-412c-4314-9660-555cd1e12068	891	Installed Programs	Microsoft Visual C++ 2013 Redistributable (x64) - 12.0.21005	12.0.21005.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7f51bdb9-ee21-49ee-94d6-90afc321780e}	\N
7f888049-412c-4314-9660-555cd1e12068	892	Installed Programs	Microsoft Visual C++ 2013 Redistributable (x86) - 12.0.21005	12.0.21005.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{ce085a78-074e-4823-8dc1-8a721b94b76d}	\N
7f888049-412c-4314-9660-555cd1e12068	893	Installed Programs	Microsoft Visual C++ 2013 x64 Additional Runtime - 12.0.21005	12.0.21005	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{929FBD26-9020-399B-9A7A-751D61F0B942}	\N
7f888049-412c-4314-9660-555cd1e12068	894	Installed Programs	Microsoft Visual C++ 2013 x64 Minimum Runtime - 12.0.21005	12.0.21005	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A749D8E6-B613-3BE3-8F5F-045C84EBA29B}	\N
7f888049-412c-4314-9660-555cd1e12068	895	Installed Programs	Microsoft Visual C++ 2013 x86 Additional Runtime - 12.0.21005	12.0.21005	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F8CFEB22-A2E7-3971-9EDA-4B11EDEFC185}	\N
7f888049-412c-4314-9660-555cd1e12068	896	Installed Programs	Microsoft Visual C++ 2013 x86 Minimum Runtime - 12.0.21005	12.0.21005	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{13A4EE12-23EA-3371-91EE-EFB36DDFFF3E}	\N
7f888049-412c-4314-9660-555cd1e12068	897	Installed Programs	Microsoft Visual Studio 2010 Tools for Office Runtime (x64)	10.0.50903	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Microsoft Visual Studio 2010 Tools for Office Runtime (x64)	\N
7f888049-412c-4314-9660-555cd1e12068	898	Installed Programs	Microsoft Visual Studio 2010 Tools for Office Runtime (x64)	10.0.50908	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{9495AEB4-AB97-39DE-8C42-806EEF75ECA7}	\N
7f888049-412c-4314-9660-555cd1e12068	899	Installed Programs	Microsoft Visual Studio Tools for Applications 2.0 - ENU	9.0.35191	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4ECF4BDC-8387-329A-ABE9-CF5798F84BB2}	\N
7f888049-412c-4314-9660-555cd1e12068	900	Installed Programs	Microsoft_VC90_CRT_x86	1.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{DF2035BE-5820-4965-BD97-7FAF8D4A7879}	\N
7f888049-412c-4314-9660-555cd1e12068	901	Installed Programs	Mozilla Firefox 57.0 (x64 en-US)	57.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Mozilla Firefox 57.0 (x64 en-US)	\N
7f888049-412c-4314-9660-555cd1e12068	902	Installed Programs	Mozilla Firefox 57.0.2 (x64 en-US)	57.0.2	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Mozilla Firefox 57.0.2 (x64 en-US)	\N
7f888049-412c-4314-9660-555cd1e12068	903	Installed Programs	Mozilla Maintenance Service	57.0.2	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\MozillaMaintenanceService	\N
7f888049-412c-4314-9660-555cd1e12068	904	Installed Programs	MPLAB X IDE v3.26	v3.26	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\MPLAB X IDE v3.26 v3.26	\N
7f888049-412c-4314-9660-555cd1e12068	905	Installed Programs	MSVCRT	15.4.2862.0708	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{8DD46C6A-0056-4FEC-B70A-28BB16A1F11F}	\N
7f888049-412c-4314-9660-555cd1e12068	906	Installed Programs	MSXML 4.0 SP2 (KB954430)	4.20.9870.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{86493ADD-824D-4B8E-BD72-8C5DCDC52A71}	\N
7f888049-412c-4314-9660-555cd1e12068	907	Installed Programs	MSXML 4.0 SP2 (KB973688)	4.20.9876.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F662A8E6-F4DC-41A2-901E-8C11F044BDEC}	\N
7f888049-412c-4314-9660-555cd1e12068	908	Installed Programs	Notepad++ (32-bit x86)	7.2.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Notepad++	\N
7f888049-412c-4314-9660-555cd1e12068	909	Installed Programs	OSSI	1.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{45024190-9404-44EA-BD4A-A06AA29D52E8}	\N
7f888049-412c-4314-9660-555cd1e12068	910	Installed Programs	Pelco SDK (ver 2.0.0)	2.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5E09A0E6-63F0-46F9-B995-0FA3B98595A4}	\N
7f888049-412c-4314-9660-555cd1e12068	911	Installed Programs	PelcoEnduraRedist	1.00.0000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4144D69C-E9EF-46B2-A9AC-72CBBAFCCA54}	\N
7f888049-412c-4314-9660-555cd1e12068	912	Installed Programs	Penguins!	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087394	\N
7f888049-412c-4314-9660-555cd1e12068	913	Installed Programs	Plants vs. Zombies	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087501	\N
7f888049-412c-4314-9660-555cd1e12068	914	Installed Programs	Polar Bowler	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087396	\N
7f888049-412c-4314-9660-555cd1e12068	915	Installed Programs	PostgreSQL 9.4	9.4	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\PostgreSQL 9.4	\N
7f888049-412c-4314-9660-555cd1e12068	916	Installed Programs	Print Artist Platinum 25	25.0.0.6	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{54E76A97-D5FB-4EF4-857B-838E47705B98}	\N
7f888049-412c-4314-9660-555cd1e12068	917	Installed Programs	product.crystalreportsviewer.arp-4.0-core-32	14.0.2.364	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{337AF528-96DA-4946-94BD-92F40A712484}	\N
7f888049-412c-4314-9660-555cd1e12068	918	Installed Programs	product.crystalreportsviewer.installiverse.reg-4.0-core-nu	14.0.0.760	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5176A2AA-DEA7-435F-94AA-AC80C3E0ADFB}	\N
7f888049-412c-4314-9660-555cd1e12068	919	Installed Programs	product.crystalreportsviewer.langpackproperty-4.0-en-nu	14.0.1.287	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7CF3BDB0-E3EB-48B2-AA59-B48CEAC696D7}	\N
7f888049-412c-4314-9660-555cd1e12068	920	Installed Programs	PuTTY version 0.66 x64	0.66 x64	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6B04E35A-94EB-4F24-8A55-4276390C0EE3}_is1	\N
7f888049-412c-4314-9660-555cd1e12068	921	Installed Programs	PX Profile Update	1.00.1.	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{80C45B94-2BA0-8E23-95A7-8A9FCD836EFD}	\N
7f888049-412c-4314-9660-555cd1e12068	922	Installed Programs	PX Profile Update	1.00.1.	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{DB94388C-62E9-570D-2BD6-90864F7E1282}	\N
7f888049-412c-4314-9660-555cd1e12068	923	Installed Programs	R3.9.58 Workstation Hikvision IP Camera Patch	3.9.58.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\R3.9.58 Workstation Hikvision IP Camera Patch	\N
7f888049-412c-4314-9660-555cd1e12068	924	Installed Programs	Realtek Ethernet Controller All-In-One Windows Driver	1.12.0016	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F7E7F0CB-AA41-4D5A-B6F2-8E6738EB063F}	\N
7f888049-412c-4314-9660-555cd1e12068	925	Installed Programs	Revo Uninstaller 2.0.4	2.0.4	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A28DBDA2-3CC7-4ADC-8BFE-66D7743C6C97}_is1	\N
7f888049-412c-4314-9660-555cd1e12068	926	Installed Programs	SADPTool	3.0.0.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7D9B79C2-B1B2-433B-844F-F4299B86F26E}	\N
7f888049-412c-4314-9660-555cd1e12068	927	Installed Programs	Samsung USB Driver for Mobile Phones	1.5.63.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D0795B21-0CDA-4a92-AB9E-6E92D8111E44}	\N
7f888049-412c-4314-9660-555cd1e12068	928	Installed Programs	SDK	2.24.025	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{0DEA342C-15CB-4F52-97B6-06A9C4B9C06F}	\N
7f888049-412c-4314-9660-555cd1e12068	929	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB2972107)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB2972107	\N
7f888049-412c-4314-9660-555cd1e12068	930	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB2972216)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB2972216	\N
7f888049-412c-4314-9660-555cd1e12068	931	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB2978128)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB2978128	\N
7f888049-412c-4314-9660-555cd1e12068	932	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB2979578v2)	2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB2979578v2	\N
7f888049-412c-4314-9660-555cd1e12068	933	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3023224)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3023224	\N
7f888049-412c-4314-9660-555cd1e12068	934	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3035490)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3035490	\N
7f888049-412c-4314-9660-555cd1e12068	935	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3037581)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3037581	\N
7f888049-412c-4314-9660-555cd1e12068	936	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3074230)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3074230	\N
7f888049-412c-4314-9660-555cd1e12068	937	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3074550)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3074550	\N
7f888049-412c-4314-9660-555cd1e12068	938	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3097996)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3097996	\N
7f888049-412c-4314-9660-555cd1e12068	939	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3098781)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3098781	\N
7f888049-412c-4314-9660-555cd1e12068	940	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3122656)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3122656	\N
7f888049-412c-4314-9660-555cd1e12068	941	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3127229)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3127229	\N
7f888049-412c-4314-9660-555cd1e12068	942	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3135996)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3135996	\N
7f888049-412c-4314-9660-555cd1e12068	943	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3142033)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3142033	\N
7f888049-412c-4314-9660-555cd1e12068	944	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3163251)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3163251	\N
7f888049-412c-4314-9660-555cd1e12068	945	Installed Programs	Security Update for Microsoft Access 2010 (KB3101544) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{DAE3147C-5212-428A-982D-4D8B298548C4}	\N
7f888049-412c-4314-9660-555cd1e12068	946	Installed Programs	Security Update for Microsoft Excel 2010 (KB3115322) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{14949093-4B12-40A0-A45F-8F7A3B78E62F}	\N
7f888049-412c-4314-9660-555cd1e12068	947	Installed Programs	Security Update for Microsoft InfoPath 2010 (KB3114414) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{B3F75577-16EF-48AA-9259-2AF290C973FD}	\N
7f888049-412c-4314-9660-555cd1e12068	948	Installed Programs	Security Update for Microsoft Office 2010 (KB2553313) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{473DA037-A808-4DF4-9F37-548928C3CDA1}	\N
7f888049-412c-4314-9660-555cd1e12068	949	Installed Programs	Security Update for Microsoft Office 2010 (KB2553313) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{473DA037-A808-4DF4-9F37-548928C3CDA1}	\N
7f888049-412c-4314-9660-555cd1e12068	950	Installed Programs	Security Update for Microsoft Office 2010 (KB2850016) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{7AC3F78E-ECA0-45F4-A9CC-3E885DA23662}	\N
7f888049-412c-4314-9660-555cd1e12068	951	Installed Programs	Security Update for Microsoft Office 2010 (KB2880971) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{5EE42B42-1159-435C-898A-2A3298453B20}	\N
7f888049-412c-4314-9660-555cd1e12068	952	Installed Programs	Security Update for Microsoft Office 2010 (KB2881029) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{433890E5-7858-4D14-8FD3-CCD28015472F}	\N
7f888049-412c-4314-9660-555cd1e12068	953	Installed Programs	Security Update for Microsoft Office 2010 (KB2881071) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{0BC570F0-7352-4A3A-B2A2-CA56ADA7375F}	\N
7f888049-412c-4314-9660-555cd1e12068	954	Installed Programs	Security Update for Microsoft Office 2010 (KB2956063) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{0567725C-77BA-47C1-BE23-FFC218C8F953}	\N
7f888049-412c-4314-9660-555cd1e12068	955	Installed Programs	Security Update for Microsoft Office 2010 (KB2956076) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-006E-0409-0000-0000000FF1CE}_Office14.SingleImage_{A12F43A5-CF0B-44E3-942F-2441CD442F0D}	\N
7f888049-412c-4314-9660-555cd1e12068	956	Installed Programs	Security Update for Microsoft Office 2010 (KB3054984) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{7D8AB432-0662-4DC9-8C37-5BA7541153C9}	\N
7f888049-412c-4314-9660-555cd1e12068	957	Installed Programs	Security Update for Microsoft Office 2010 (KB3085528) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{9429D223-4B64-4038-B63D-3F239216F6E5}	\N
7f888049-412c-4314-9660-555cd1e12068	958	Installed Programs	Security Update for Microsoft Office 2010 (KB3085560) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-006E-0409-0000-0000000FF1CE}_Office14.SingleImage_{DA24C5B4-EB67-4143-8CBE-18C3B4F13694}	\N
7f888049-412c-4314-9660-555cd1e12068	959	Installed Programs	Security Update for Microsoft Office 2010 (KB3101520) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{B6BB5C05-372B-48FE-8348-D3ED54EF172B}	\N
7f888049-412c-4314-9660-555cd1e12068	960	Installed Programs	Security Update for Microsoft OneNote 2010 (KB3054978) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-00A1-0409-0000-0000000FF1CE}_Office14.SingleImage_{82148027-13B5-4920-97F3-6A44A29B83D0}	\N
7f888049-412c-4314-9660-555cd1e12068	961	Installed Programs	Security Update for Microsoft Outlook 2010 (KB3115246) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{CD2932ED-8DA5-4B7F-B220-7CEE3549D12A}	\N
7f888049-412c-4314-9660-555cd1e12068	962	Installed Programs	Security Update for Microsoft PowerPoint 2010 (KB2920812) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0018-0409-0000-0000000FF1CE}_Office14.SingleImage_{DF548669-AAED-467B-A074-AE2B72A4A871}	\N
7f888049-412c-4314-9660-555cd1e12068	963	Installed Programs	Security Update for Microsoft PowerPoint 2010 (KB3115118) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{715F30CA-6F8C-4115-8928-CD24DA9025BF}	\N
7f888049-412c-4314-9660-555cd1e12068	964	Installed Programs	Security Update for Microsoft Publisher 2010 (KB2817478) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{7DD2401D-E882-499C-9009-5F2A6B610C7A}	\N
7f888049-412c-4314-9660-555cd1e12068	965	Installed Programs	Security Update for Microsoft Visio 2010 (KB3114872) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{14044761-B4DB-4690-BA5C-E79CC538C58E}	\N
7f888049-412c-4314-9660-555cd1e12068	966	Installed Programs	Security Update for Microsoft Visio Viewer 2010 (KB2999465) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{D54D39CD-37D6-42EF-AD2E-2222515782F1}	\N
7f888049-412c-4314-9660-555cd1e12068	967	Installed Programs	Security Update for Microsoft Word 2010 (KB2965313) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001B-0409-0000-0000000FF1CE}_Office14.SingleImage_{102FADF9-3B36-4EAB-A272-BF6E539223F8}	\N
7f888049-412c-4314-9660-555cd1e12068	968	Installed Programs	Security Update for Microsoft Word 2010 (KB2965313) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001A-0409-0000-0000000FF1CE}_Office14.SingleImage_{102FADF9-3B36-4EAB-A272-BF6E539223F8}	\N
7f888049-412c-4314-9660-555cd1e12068	969	Installed Programs	Security Update for Microsoft Word 2010 (KB3115317) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{0AAE878F-DA45-4DD8-A32D-E85AB53889CB}	\N
7f888049-412c-4314-9660-555cd1e12068	970	Installed Programs	Sentinel HASP Run-time	5.0.1.14210	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{2A414CBE-CDF3-48C6-A91B-D3D4522F8EB5}	\N
7f888049-412c-4314-9660-555cd1e12068	971	Installed Programs	Sentinel System Driver Installer 7.5.2	7.5.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{504B7439-03BB-4C23-B17E-A1EC2D1D47B1}	\N
7f888049-412c-4314-9660-555cd1e12068	972	Installed Programs	Service Pack 1 for SQL Server 2008 R2 (KB2528583)	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\KB2528583	\N
7f888049-412c-4314-9660-555cd1e12068	973	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0018-0409-0000-0000000FF1CE}_Office14.SingleImage_{D6A2CD7F-C90C-4B90-BBA7-2BADE2E08610}	\N
7f888049-412c-4314-9660-555cd1e12068	974	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0117-0409-0000-0000000FF1CE}_Office14.SingleImage_{D6A2CD7F-C90C-4B90-BBA7-2BADE2E08610}	\N
7f888049-412c-4314-9660-555cd1e12068	975	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-00A1-0409-0000-0000000FF1CE}_Office14.SingleImage_{D6A2CD7F-C90C-4B90-BBA7-2BADE2E08610}	\N
7f888049-412c-4314-9660-555cd1e12068	976	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0016-0409-0000-0000000FF1CE}_Office14.SingleImage_{D6A2CD7F-C90C-4B90-BBA7-2BADE2E08610}	\N
7f888049-412c-4314-9660-555cd1e12068	977	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0015-0409-0000-0000000FF1CE}_Office14.SingleImage_{D6A2CD7F-C90C-4B90-BBA7-2BADE2E08610}	\N
7f888049-412c-4314-9660-555cd1e12068	978	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0115-0409-0000-0000000FF1CE}_Office14.SingleImage_{8DD50F3B-E0BD-4E39-AF1F-2F316B4FC528}	\N
7f888049-412c-4314-9660-555cd1e12068	979	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-006E-0409-0000-0000000FF1CE}_Office14.SingleImage_{8DD50F3B-E0BD-4E39-AF1F-2F316B4FC528}	\N
7f888049-412c-4314-9660-555cd1e12068	980	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001B-0409-0000-0000000FF1CE}_Office14.SingleImage_{D6A2CD7F-C90C-4B90-BBA7-2BADE2E08610}	\N
7f888049-412c-4314-9660-555cd1e12068	981	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{DE28B448-32E8-4E8F-84F0-A52B21A49B5B}	\N
7f888049-412c-4314-9660-555cd1e12068	982	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0019-0409-0000-0000000FF1CE}_Office14.SingleImage_{D6A2CD7F-C90C-4B90-BBA7-2BADE2E08610}	\N
7f888049-412c-4314-9660-555cd1e12068	983	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0116-0409-1000-0000000FF1CE}_Office14.SingleImage_{03AE1408-7BF1-4AC6-A327-E32E7799BCE4}	\N
7f888049-412c-4314-9660-555cd1e12068	984	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002C-0409-0000-0000000FF1CE}_Office14.SingleImage_{945F1D43-451D-4383-9BBE-241F37950B15}	\N
7f888049-412c-4314-9660-555cd1e12068	985	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-0409-0000-0000000FF1CE}_Office14.SingleImage_{09A9DF49-DA06-4093-A2FD-F339211E39EA}	\N
7f888049-412c-4314-9660-555cd1e12068	986	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-0C0A-0000-0000000FF1CE}_Office14.SingleImage_{8C5A05B6-FF56-480F-A0E6-9F4BCA4B4CAC}	\N
7f888049-412c-4314-9660-555cd1e12068	987	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001A-0409-0000-0000000FF1CE}_Office14.SingleImage_{D6A2CD7F-C90C-4B90-BBA7-2BADE2E08610}	\N
7f888049-412c-4314-9660-555cd1e12068	988	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0409-1000-0000000FF1CE}_Office14.SingleImage_{03AE1408-7BF1-4AC6-A327-E32E7799BCE4}	\N
7f888049-412c-4314-9660-555cd1e12068	989	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-040C-0000-0000000FF1CE}_Office14.SingleImage_{ECC1D579-DC17-4B90-929C-B4A0BB35F7B3}	\N
7f888049-412c-4314-9660-555cd1e12068	990	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{E4D76E88-C65F-4003-9C71-EC4306679D17}	\N
7f888049-412c-4314-9660-555cd1e12068	991	Installed Programs	SimonsVoss Locking System Management Basic 3.1 (English UK)	3.1.20412	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7D2ABFC5-8710-42C0-9288-1C43BAE22D79}	\N
7f888049-412c-4314-9660-555cd1e12068	992	Installed Programs	SimonsVoss LSM Mobile (English UK)	3.1.20412	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6DD70464-1843-4F24-BD7E-E4F412F7C57E}	\N
7f888049-412c-4314-9660-555cd1e12068	993	Installed Programs	Slingo Deluxe	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087510	\N
7f888049-412c-4314-9660-555cd1e12068	994	Installed Programs	Spybot - Search & Destroy	1.6.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B4092C6D-E886-4CB2-BA68-FE5A88D31DE6}_is1	\N
7f888049-412c-4314-9660-555cd1e12068	995	Installed Programs	SQL Server 2008 R2 SP1 Common Files	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CACEA8C8-3D38-4F51-953D-1E6FC3346FEF}	\N
7f888049-412c-4314-9660-555cd1e12068	996	Installed Programs	SQL Server 2008 R2 SP1 Common Files	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{FC835376-FF3B-4CAA-83E0-2148B3FB7C98}	\N
7f888049-412c-4314-9660-555cd1e12068	997	Installed Programs	SQL Server 2008 R2 SP1 Database Engine Services	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{58721EC3-8D4E-4B79-BC51-1054E2DDCD10}	\N
7f888049-412c-4314-9660-555cd1e12068	998	Installed Programs	SQL Server 2008 R2 SP1 Database Engine Services	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B5153233-9AEE-4CD4-9D2C-4FAAC870DBE2}	\N
7f888049-412c-4314-9660-555cd1e12068	999	Installed Programs	SQL Server 2008 R2 SP1 Database Engine Shared	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F021CC0C-21C3-4038-AA4A-6E3CBC669CE8}	\N
7f888049-412c-4314-9660-555cd1e12068	1000	Installed Programs	SQL Server 2008 R2 SP1 Database Engine Shared	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4C9D82EB-9001-4E59-8F64-0BEEE5F4A30A}	\N
7f888049-412c-4314-9660-555cd1e12068	1001	Installed Programs	SQL Server 2008 R2 SP1 Management Studio	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{020617D7-2F72-4D02-BF59-A5CBC1761177}	\N
7f888049-412c-4314-9660-555cd1e12068	1002	Installed Programs	SQL Server 2008 R2 SP1 Management Studio	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{121475F5-2598-4574-8801-8F6B3D6A99BB}	\N
7f888049-412c-4314-9660-555cd1e12068	1003	Installed Programs	Sql Server Customer Experience Improvement Program	10.50.1600.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{93998800-1608-403F-9A51-420A77D23C25}	\N
7f888049-412c-4314-9660-555cd1e12068	1004	Installed Programs	Suite Specific	2.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C49DAA9C-5BA8-459A-8244-E57B69DF0F04}	\N
7f888049-412c-4314-9660-555cd1e12068	1005	Installed Programs	Synaptics Pointing Device Driver	15.2.11.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\SynTPDeinstKey	\N
7f888049-412c-4314-9660-555cd1e12068	1006	Installed Programs	tp.azalea.fonts-5.5-core-nu	14.0.0.760	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{EC895F19-3571-4429-83F0-441674E04989}	\N
7f888049-412c-4314-9660-555cd1e12068	1007	Installed Programs	U3Launcher	1.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D8E363A7-88B7-446D-B2C0-E26CE4DC8E54}	\N
7f888049-412c-4314-9660-555cd1e12068	1008	Installed Programs	ULinx USB Driver	1.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{01F41214-12C3-4118-AF55-5A4605CAEB6A}	\N
7f888049-412c-4314-9660-555cd1e12068	1009	Installed Programs	Update for Microsoft Excel 2010 (KB2956084) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0016-0409-0000-0000000FF1CE}_Office14.SingleImage_{A7C2902F-C60B-428F-BDD7-ECE4DC0A2CA1}	\N
7f888049-412c-4314-9660-555cd1e12068	1010	Installed Programs	Update for Microsoft Excel 2010 (KB2956084) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0018-0409-0000-0000000FF1CE}_Office14.SingleImage_{A7C2902F-C60B-428F-BDD7-ECE4DC0A2CA1}	\N
7f888049-412c-4314-9660-555cd1e12068	1011	Installed Programs	Update for Microsoft Excel 2010 (KB2956084) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001B-0409-0000-0000000FF1CE}_Office14.SingleImage_{A7C2902F-C60B-428F-BDD7-ECE4DC0A2CA1}	\N
7f888049-412c-4314-9660-555cd1e12068	1012	Installed Programs	Update for Microsoft Filter Pack 2.0 (KB2999508) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{9DCB10B2-8E20-4678-B85B-DDB48895B885}	\N
7f888049-412c-4314-9660-555cd1e12068	1013	Installed Programs	Update for Microsoft Filter Pack 2.0 (KB2999508) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{9DCB10B2-8E20-4678-B85B-DDB48895B885}	\N
7f888049-412c-4314-9660-555cd1e12068	1014	Installed Programs	Update for Microsoft InfoPath 2010 (KB2817369) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{4EEA3D3E-989C-4DF4-AB0A-3042C0C12AA3}	\N
7f888049-412c-4314-9660-555cd1e12068	1015	Installed Programs	Update for Microsoft Office 2010 (KB2553140) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-006E-0409-0000-0000000FF1CE}_Office14.SingleImage_{8BEEA2FC-D416-428A-B52A-A3ED45921151}	\N
7f888049-412c-4314-9660-555cd1e12068	1016	Installed Programs	Update for Microsoft Office 2010 (KB2553140) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{8BEEA2FC-D416-428A-B52A-A3ED45921151}	\N
7f888049-412c-4314-9660-555cd1e12068	1017	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1018	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001B-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1019	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0018-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1020	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1021	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-040C-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1022	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-006E-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1023	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0016-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1024	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0116-0409-1000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1025	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0409-1000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1026	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002C-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1027	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1028	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001A-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1029	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0015-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1030	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-00A1-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1031	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0117-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1032	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0019-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1033	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-0C0A-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1034	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0115-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
7f888049-412c-4314-9660-555cd1e12068	1035	Installed Programs	Update for Microsoft Office 2010 (KB2553388) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{AEB4E79E-26B6-42F3-9980-096443C534BE}	\N
7f888049-412c-4314-9660-555cd1e12068	1036	Installed Programs	Update for Microsoft Office 2010 (KB2589298) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{DADF7E25-FFA4-4D02-BE84-1DAE62C18516}	\N
7f888049-412c-4314-9660-555cd1e12068	1037	Installed Programs	Update for Microsoft Office 2010 (KB2589318) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{091CB6F9-4347-4084-A572-7C320DA7D686}	\N
7f888049-412c-4314-9660-555cd1e12068	1038	Installed Programs	Update for Microsoft Office 2010 (KB2589352) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{F4284D93-7AE8-4309-8CF3-9AD394F35F3A}	\N
7f888049-412c-4314-9660-555cd1e12068	1039	Installed Programs	Update for Microsoft Office 2010 (KB2589352) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{F4284D93-7AE8-4309-8CF3-9AD394F35F3A}	\N
7f888049-412c-4314-9660-555cd1e12068	1040	Installed Programs	Update for Microsoft Office 2010 (KB2589375) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{287A1E92-9E41-4BC1-8920-B3D0E9220800}	\N
7f888049-412c-4314-9660-555cd1e12068	1041	Installed Programs	Update for Microsoft Office 2010 (KB2589386) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{A4F91D60-654C-4892-BFD3-0D41ADA649B6}	\N
7f888049-412c-4314-9660-555cd1e12068	1042	Installed Programs	Update for Microsoft Office 2010 (KB2597087) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{9D69691D-823D-4C3E-9B12-563A3F520366}	\N
7f888049-412c-4314-9660-555cd1e12068	1043	Installed Programs	Update for Microsoft Office 2010 (KB2687275) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{0B7744D2-1FDD-4843-9987-7CE11B79F370}	\N
7f888049-412c-4314-9660-555cd1e12068	1044	Installed Programs	Update for Microsoft Office 2010 (KB2791057) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{43EBBFDD-8FB7-4FCC-9780-EB40277987A2}	\N
7f888049-412c-4314-9660-555cd1e12068	1045	Installed Programs	Update for Microsoft Office 2010 (KB2794737) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{5AA578BB-759C-40FD-9661-A737C0884541}	\N
7f888049-412c-4314-9660-555cd1e12068	1046	Installed Programs	Update for Microsoft Office 2010 (KB2881030) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{D6C976E4-E88C-4048-9A6B-39400D2933C7}	\N
7f888049-412c-4314-9660-555cd1e12068	1047	Installed Programs	Update for Microsoft Office 2010 (KB2883019) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{D1C4AD0B-CC79-41D2-8D6A-571E7B30658C}	\N
7f888049-412c-4314-9660-555cd1e12068	1048	Installed Programs	Update for Microsoft Office 2010 (KB3054873) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{9C9636BD-37A7-43F7-BB00-5C7606B42D27}	\N
7f888049-412c-4314-9660-555cd1e12068	1049	Installed Programs	Update for Microsoft Office 2010 (KB3054886) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{A786FC51-D7D5-4499-A230-D1EBEA64932C}	\N
7f888049-412c-4314-9660-555cd1e12068	1050	Installed Programs	Update for Microsoft Office 2010 (KB3054886) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{A786FC51-D7D5-4499-A230-D1EBEA64932C}	\N
7f888049-412c-4314-9660-555cd1e12068	1051	Installed Programs	Update for Microsoft Office 2010 (KB3055047) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{B29C45D3-4B2D-4FC2-B072-81E3528E4EE1}	\N
7f888049-412c-4314-9660-555cd1e12068	1052	Installed Programs	Update for Microsoft Office 2010 (KB3085605) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-040C-0000-0000000FF1CE}_Office14.SingleImage_{C1954E2B-1672-4E5C-B564-F8CB2D08345B}	\N
7f888049-412c-4314-9660-555cd1e12068	1053	Installed Programs	Update for Microsoft Office 2010 (KB3085605) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-0C0A-0000-0000000FF1CE}_Office14.SingleImage_{A7AA9E77-A9F4-4596-8AFD-4910FF258C3D}	\N
7f888049-412c-4314-9660-555cd1e12068	1054	Installed Programs	Update for Microsoft Office 2010 (KB3085605) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-0409-0000-0000000FF1CE}_Office14.SingleImage_{548F42CA-61CC-4A49-9963-50124AC7B81D}	\N
7f888049-412c-4314-9660-555cd1e12068	1055	Installed Programs	Update for Microsoft Office 2010 (KB3114555) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{F2644070-2DCF-4ABF-812B-DDCFD4652E3A}	\N
7f888049-412c-4314-9660-555cd1e12068	1056	Installed Programs	Update for Microsoft Office 2010 (KB3114750) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{F4F9D4DD-8D81-4424-BCCD-333DE4305105}	\N
7f888049-412c-4314-9660-555cd1e12068	1057	Installed Programs	Update for Microsoft Office 2010 (KB3114989) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{37377C07-9556-4A60-B42D-85EC9B955C71}	\N
7f888049-412c-4314-9660-555cd1e12068	1058	Installed Programs	Update for Microsoft OneNote 2010 (KB3114410) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{007AAA88-1D1E-400B-B8FE-2C8DF2ABC700}	\N
7f888049-412c-4314-9660-555cd1e12068	1059	Installed Programs	Update for Microsoft OneNote 2010 (KB3114410) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{007AAA88-1D1E-400B-B8FE-2C8DF2ABC700}	\N
7f888049-412c-4314-9660-555cd1e12068	1060	Installed Programs	Update for Microsoft Outlook 2010 (KB2760779) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{B8BF0BCB-30FA-4BCA-BB01-2243B6295CC8}	\N
7f888049-412c-4314-9660-555cd1e12068	1061	Installed Programs	Update for Microsoft Outlook 2010 (KB3114756) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001A-0409-0000-0000000FF1CE}_Office14.SingleImage_{F81ABFD2-D304-4C54-A52B-A9640C4885CE}	\N
7f888049-412c-4314-9660-555cd1e12068	1062	Installed Programs	Update for Microsoft Outlook Social Connector 2010 (KB2553308) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{E7C8C158-9575-4120-AF5E-5CCEF2DD6761}	\N
7f888049-412c-4314-9660-555cd1e12068	1063	Installed Programs	Update for Microsoft SharePoint Workspace 2010 (KB2760601) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{F9F5A080-AF38-4966-9A6B-C43DCA465035}	\N
7f888049-412c-4314-9660-555cd1e12068	1064	Installed Programs	USSC Web Components	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4AD000A7-A6AD-46B1-95DC-11912B026D37}_is1	\N
7f888049-412c-4314-9660-555cd1e12068	1065	Installed Programs	VIP Access SDK x64(1.0.0.50)	1.0.0.50	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\VIP Access SDK	\N
7f888049-412c-4314-9660-555cd1e12068	1066	Installed Programs	Virtual Villagers - The Secret City	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087513	\N
7f888049-412c-4314-9660-555cd1e12068	1067	Installed Programs	Web Components	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{03B13AF8-9625-478A-AF0E-205337B9415A}_is1	\N
7f888049-412c-4314-9660-555cd1e12068	1068	Installed Programs	WebM Media Foundation Components	1.0.1.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\webmmf	\N
7f888049-412c-4314-9660-555cd1e12068	1069	Installed Programs	Wedding Dash	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087519	\N
7f888049-412c-4314-9660-555cd1e12068	1070	Installed Programs	Windows Driver Package - Segger (jlink) USB  (07/28/2014 2.6.8.1)	07/28/2014 2.6.8.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\468237BA12C6D9DD0125166A16609C632EE9CF1C	\N
7f888049-412c-4314-9660-555cd1e12068	1071	Installed Programs	Windows Driver Package - SEGGER (JLinkCDC_x64) Ports  (08/28/2014 6.0.2601.5)	08/28/2014 6.0.2601.5	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\ED80E3D3A350D18BFD3D3D8DAED8E2B19105763A	\N
7f888049-412c-4314-9660-555cd1e12068	1072	Installed Programs	Windows Live	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{34319F1F-7CF2-4CC9-B357-1AE7D2FF3AC5}	\N
7f888049-412c-4314-9660-555cd1e12068	1073	Installed Programs	Windows Live Argazki Galeria	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{86F444A5-C9B9-41DC-AF28-B5E46F5497C7}	\N
7f888049-412c-4314-9660-555cd1e12068	1074	Installed Programs	Windows Live Communications Platform	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D45240D3-B6B3-4FF9-B243-54ECE3E10066}	\N
7f888049-412c-4314-9660-555cd1e12068	1075	Installed Programs	Windows Live Essentials	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{43B43577-2514-4CE0-B14A-7E85C17C0453}	\N
7f888049-412c-4314-9660-555cd1e12068	1076	Installed Programs	Windows Live Essentials	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WinLiveSuite	\N
7f888049-412c-4314-9660-555cd1e12068	1077	Installed Programs	Windows Live Essentials	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{06B05153-97E4-427E-B1A8-E098F6C5E52F}	\N
7f888049-412c-4314-9660-555cd1e12068	1078	Installed Programs	Windows Live Essentials	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7D1C7B9F-2744-4388-B128-5C75B8BCCC84}	\N
7f888049-412c-4314-9660-555cd1e12068	1079	Installed Programs	Windows Live Essentials	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7D99B933-E29C-4599-92F0-DAED2AF041E3}	\N
7f888049-412c-4314-9660-555cd1e12068	1080	Installed Programs	Windows Live Essentials	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{FE044230-9CA5-43F7-9B58-5AC5A28A1F33}	\N
7f888049-412c-4314-9660-555cd1e12068	1081	Installed Programs	Windows Live Galeria de Fotos	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F7A46527-DF1F-4B0F-9637-98547E189442}	\N
7f888049-412c-4314-9660-555cd1e12068	1082	Installed Programs	Windows Live ID Sign-in Assistant	7.250.4225.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1B8ABA62-74F0-47ED-B18C-A43128E591B8}	\N
7f888049-412c-4314-9660-555cd1e12068	1083	Installed Programs	Windows Live Installer	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{0B0F231F-CE6A-483D-AA23-77B364F75917}	\N
7f888049-412c-4314-9660-555cd1e12068	1084	Installed Programs	Windows Live Language Selector	15.4.3502.0922	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5EB6F3CB-46F4-451F-A028-7F6D8D35D7D0}	\N
7f888049-412c-4314-9660-555cd1e12068	1085	Installed Programs	Windows Live Movie Maker	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A199DB88-E22D-4CE7-90AC-B8BE396D7BF4}	\N
7f888049-412c-4314-9660-555cd1e12068	1086	Installed Programs	Windows Live Movie Maker	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92EA4134-10D1-418A-91E1-5A0453131A38}	\N
7f888049-412c-4314-9660-555cd1e12068	1087	Installed Programs	Windows Live Movie Maker	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{71527C7C-5289-4CB2-88C9-23344C0FF6C1}	\N
7f888049-412c-4314-9660-555cd1e12068	1088	Installed Programs	Windows Live Movie Maker	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6DEC8BD5-7574-47FA-B080-492BBBE2FEA3}	\N
7f888049-412c-4314-9660-555cd1e12068	1089	Installed Programs	Windows Live Movie Maker	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5D273F60-0525-48BA-A5FB-D0CAA4A952AE}	\N
7f888049-412c-4314-9660-555cd1e12068	1090	Installed Programs	Windows Live Movie Maker	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{19BA08F7-C728-469C-8A35-BFBD3633BE08}	\N
7f888049-412c-4314-9660-555cd1e12068	1091	Installed Programs	Windows Live Movie Maker	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{226F0D93-76DE-4F1C-B14D-DE10443ADB60}	\N
7f888049-412c-4314-9660-555cd1e12068	1092	Installed Programs	Windows Live Photo Common	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{120C160F-F53D-4A15-A873-E79BF5B98B48}	\N
7f888049-412c-4314-9660-555cd1e12068	1093	Installed Programs	Windows Live Photo Common	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D436F577-1695-4D2F-8B44-AC76C99E0002}	\N
7f888049-412c-4314-9660-555cd1e12068	1094	Installed Programs	Windows Live Photo Common	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B33B61FE-701F-425F-98AB-2B85725CBF68}	\N
7f888049-412c-4314-9660-555cd1e12068	1095	Installed Programs	Windows Live Photo Common	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C893D8C0-1BA0-4517-B11C-E89B65E72F70}	\N
7f888049-412c-4314-9660-555cd1e12068	1096	Installed Programs	Windows Live Photo Common	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A41A708E-3BE6-4561-855D-44027C1CF0F8}	\N
7f888049-412c-4314-9660-555cd1e12068	1097	Installed Programs	Windows Live Photo Common	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A9BDCA6B-3653-467B-AC83-94367DA3BFE3}	\N
7f888049-412c-4314-9660-555cd1e12068	1098	Installed Programs	Windows Live Photo Common	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F0F5D89A-197C-495B-827E-3E98B811CD2E}	\N
7f888049-412c-4314-9660-555cd1e12068	1099	Installed Programs	Windows Live Photo Gallery	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3336F667-9049-4D46-98B6-4C743EEBC5B1}	\N
7f888049-412c-4314-9660-555cd1e12068	1100	Installed Programs	Windows Live Photo Gallery	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{34F4D9A4-42C2-4348-BEF4-E553C84549E7}	\N
7f888049-412c-4314-9660-555cd1e12068	1101	Installed Programs	Windows Live PIMT Platform	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4CBABDFD-49F8-47FD-BE7D-ECDE7270525A}	\N
7f888049-412c-4314-9660-555cd1e12068	1102	Installed Programs	Windows Live SOXE	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{682B3E4F-696A-42DE-A41C-4C07EA1678B4}	\N
7f888049-412c-4314-9660-555cd1e12068	1103	Installed Programs	Windows Live SOXE Definitions	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{200FEC62-3C34-4D60-9CE8-EC372E01C08F}	\N
7f888049-412c-4314-9660-555cd1e12068	1104	Installed Programs	Windows Live UX Platform	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CE95A79E-E4FC-4FFF-8A75-29F04B942FF2}	\N
7f888049-412c-4314-9660-555cd1e12068	1105	Installed Programs	Windows Live UX Platform Language Pack	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{ED86C4AB-D1E5-42CF-BFA3-56BAAE617D4E}	\N
7f888049-412c-4314-9660-555cd1e12068	1106	Installed Programs	Windows Live UX Platform Language Pack	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5CADEAC5-0A9C-4680-B850-6A9085ADD23B}	\N
7f888049-412c-4314-9660-555cd1e12068	1107	Installed Programs	Windows Live UX Platform Language Pack	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6A05FEDF-662E-46BF-8A25-010E3F1C9C69}	\N
7f888049-412c-4314-9660-555cd1e12068	1108	Installed Programs	Windows Live UX Platform Language Pack	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{9A66D83C-269C-4812-932A-7CF41F0B1ABF}	\N
7f888049-412c-4314-9660-555cd1e12068	1109	Installed Programs	Windows Live UX Platform Language Pack	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{96303101-1FF8-4887-9E89-993024271145}	\N
7f888049-412c-4314-9660-555cd1e12068	1110	Installed Programs	Windows Live UX Platform Language Pack	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{09F56A49-A7B1-4AAB-95B9-D13094254AD1}	\N
7f888049-412c-4314-9660-555cd1e12068	1111	Installed Programs	Windows Mobile Device Center Driver Update	6.1.6965.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92DBCA36-9B41-4DD1-941A-AED149DD37F0}	\N
7f888049-412c-4314-9660-555cd1e12068	1112	Installed Programs	Xobni Core	1.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{8DC069E7-893C-41E1-9442-DE89FEC33371}	\N
7f888049-412c-4314-9660-555cd1e12068	1113	Installed Programs	Zuma Deluxe	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087533	\N
\.


--
-- Data for Name: Token; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Token" (id, type_id, user_level, personnel_id, badge_id, lost, last_read, last_reader, last_read_status, created, created_by, updated, updated_by, deleted, deleted_by, downloaded, downloaded_by, download_required) FROM stdin;
\.


--
-- Data for Name: TokenType; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "TokenType" (id, name, table_name) FROM stdin;
1	Access Card	Card
2	RFID Tag	RfidTag
\.


--
-- Name: TokenType_id_seq; Type: SEQUENCE SET; Schema: core; Owner: core
--

SELECT pg_catalog.setval('"TokenType_id_seq"', 3, true);


--
-- Data for Name: Vehicle; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Vehicle" (id, personnel_id, make, model, color, accent_color, state_or_prov, tag, sticker, year) FROM stdin;
\.


SET search_path = extra, pg_catalog;

--
-- Data for Name: AccessSet; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "AccessSet" (id, notes_id) FROM stdin;
\.


--
-- Data for Name: Blob; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "Blob" (id, type_id, bytes) FROM stdin;
\.


--
-- Data for Name: Card; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "Card" (token_id, card_emboss_num, card_label) FROM stdin;
\.


--
-- Data for Name: Notes; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "Notes" (id, text) FROM stdin;
\.


--
-- Data for Name: Personnel; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "Personnel" (id, name_middle, name_prefix, name_suffix, company, department, job_title, email, phone_work, phone_work_ext, phone_mobile, phone_home, address, city, state_or_prov, postal_code, country, notes_id, photo_id, signature_id, fingerprint_id, room, assigned_to, admission_date) FROM stdin;
\.


--
-- Data for Name: Vehicle; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "Vehicle" (id, notes_id) FROM stdin;
\.


SET search_path = history, pg_catalog;

--
-- Data for Name: AccutechTagChange; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "AccutechTagChange" (id, change_time, event, card_number, name_first, name_last, name_middle, assigned_to, updated_by, room) FROM stdin;
\.


--
-- Data for Name: Activity; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "Activity" (id, "time", event_type_id, rtu_id, rtu_name, point_id, point_name, state, status, card_number, site_code, card_format, card_holder_name, computer, "user", user_comments, token_id) FROM stdin;
\.


--
-- Data for Name: Activity_Statistics; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "Activity_Statistics" (id, event_type_id, rtu_id, rtu_name, point_id, point_name, state, status, card_number, site_code, card_format, card_holder_name, computer, "user", user_comments, token_id, active_time, inactive_time, acked_time, cleared_time, last_active, total_active, active_count) FROM stdin;
\.


--
-- Data for Name: ChangeType; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "ChangeType" (id, name) FROM stdin;
1	Node Add
2	Node Modify
3	Node Delete
4	Card Add
5	Card Modify
6	Card Delete
7	Personnel Add
8	Personnel Modify
9	Personnel Delete
10	Access Set Add
11	Access Set Modify
12	Access Set Delete
\.


--
-- Name: ChangeType_id_seq; Type: SEQUENCE SET; Schema: history; Owner: core
--

SELECT pg_catalog.setval('"ChangeType_id_seq"', 9, true);


--
-- Data for Name: EventType; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "EventType" (id, name) FROM stdin;
1	Card
2	I/O
3	Exception
4	Download
5	Client
6	Alarm
\.


--
-- Name: EventType_id_seq; Type: SEQUENCE SET; Schema: history; Owner: core
--

SELECT pg_catalog.setval('"EventType_id_seq"', 5, true);


--
-- Data for Name: ProjectChange; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "ProjectChange" (id, "time", change_type_id, name, computer, "user", old_data, new_data) FROM stdin;
e639e94b-2196-4d1c-becd-ac6caa0efcd7	2018-02-26 13:16:00.877431-06	2	[165] Control Room	[4] DLarrabee	[293] master	\N	\N
85d9fd36-9e00-4de2-8c35-55cd96124f3f	2018-02-26 13:16:17.308074-06	1	[1039] New Area	[4] DLarrabee	[293] master	\N	\N
d24ca674-d0a2-47fe-b12f-731a6a2d49cb	2018-02-26 13:16:30.639407-06	2	[1039] Room 304	[4] DLarrabee	[293] master	\N	\N
04d5b0d7-df68-4b1f-9934-7a811138378b	2018-02-26 13:16:43.076651-06	1	[1040] New Area	[4] DLarrabee	[293] master	\N	\N
4b0756ef-0252-495d-a5f2-80dcb6bf52e8	2018-02-26 13:17:06.010944-06	2	[1040] Room 372	[4] DLarrabee	[293] master	\N	\N
462cd569-39af-4caf-8aab-5f56cbead7b6	2018-02-26 13:17:11.808524-06	1	[1041] New Area	[4] DLarrabee	[293] master	\N	\N
6fb4a094-c6b8-49d8-afa1-70e770c320eb	2018-02-26 13:17:30.209364-06	2	[1041] Room 474	[4] DLarrabee	[293] master	\N	\N
abbf1ddb-cb4f-4c86-aaa1-14abc0cd0f94	2018-02-26 13:17:55.97894-06	1	[1042] New MAC Driver	[4] DLarrabee	[293] master	\N	\N
58733b30-4f1c-4611-a4a0-da6d8441d0b6	2018-02-26 13:18:01.947537-06	2	[1042] New MAC Driver	[4] DLarrabee	[293] master	\N	\N
8539ccd8-1b72-48ed-bbf9-0ab4ccad8186	2018-02-26 13:18:32.97764-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
47a977e6-ae02-463b-92ce-5d713b305e2c	2018-02-26 13:19:23.167658-06	1	[1043] MAC	[4] DLarrabee	[293] master	\N	\N
864f6220-3138-4d92-8795-b8b0e04db1bf	2018-02-26 13:19:23.194661-06	1	[1044] *Always*	[4] DLarrabee	[293] master	\N	\N
840fd75f-2f11-4a9c-b407-30985e57f861	2018-02-26 13:19:23.369679-06	1	[1045] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
ad35f2f4-a72b-4ec7-a2a5-c64e6880a920	2018-02-26 13:19:23.38668-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
c84f8e7b-92f7-46b2-b696-130768e03bf4	2018-02-26 13:19:23.390681-06	1	[1187] Control Room Popup Screens	[4] DLarrabee	[293] master	\N	\N
3e0c67a7-93e1-42c7-b401-51a6f5c7febe	2018-02-26 13:19:24.768818-06	1	[1188] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
938ab5e4-616a-4458-9064-5bab1eb7c8e6	2018-02-26 13:19:24.922834-06	1	[1513] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
684eefc4-9eaf-401e-b274-17669c0adf9a	2018-02-26 13:19:24.942836-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
32731500-ae14-4216-ad66-912c3ee9f216	2018-02-26 13:19:26.302972-06	1	[1655] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
f632122c-331e-4981-b755-1297803818d4	2018-02-26 13:20:24.911832-06	1	[1980] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
4d6dd2c0-c488-4c39-a70c-640d294a6d78	2018-02-26 13:20:24.927834-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
9ce9378f-e60e-46f2-9cb7-1e24fe090a6b	2018-02-26 13:20:25.646906-06	1	[2074] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
86a53e99-c1f5-44e9-8dea-930947ee1cbd	2018-02-26 13:20:25.726914-06	1	[2300] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
680955c2-b183-4ce0-ab3d-d6c46f1224be	2018-02-26 13:20:25.746916-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
485ce311-74b3-4a1c-912a-05df295d4071	2018-02-26 13:20:26.576999-06	1	[2394] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
61b9b6e2-b829-4929-8ed1-25f7b2ce7c48	2018-02-26 13:20:26.661007-06	1	[2620] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
91c73e3d-d686-4c57-ae0e-1048178e779e	2018-02-26 13:20:26.679009-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
39b55964-6291-4dfe-942b-d6593e26eac7	2018-02-26 13:20:27.466088-06	1	[2714] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
0974aa60-2d6d-4d9c-ac4d-f20eb99e6648	2018-02-26 13:24:47.285067-06	1	[2940] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
dbc2db89-040a-4cb5-b115-587a0d677d59	2018-02-26 13:24:47.304069-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
37933016-8e28-480b-aefb-6015ca522f8e	2018-02-26 13:24:48.353174-06	1	[3042] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
46348988-191f-4c5a-884d-dc03209ffd53	2018-02-26 13:24:48.498188-06	1	[3380] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
e095f65e-e0c9-40b5-ba94-9c2a29f456aa	2018-02-26 13:24:48.51519-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
836496ee-6d61-49ef-bc33-9540f88d726b	2018-02-26 13:24:49.631301-06	1	[3482] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
244cf415-b57b-4814-ba8b-95fcec410295	2018-02-26 13:24:49.746313-06	1	[3820] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
d5be2ef1-75b0-435a-b9bf-c0dffe6f23c8	2018-02-26 13:24:49.769315-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
697098a2-23a9-4ca7-a8ea-33e645ce6334	2018-02-26 13:24:50.847423-06	1	[3922] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
aaa10a77-4301-4b63-889e-6f27fb8c31d2	2018-02-26 13:24:50.973436-06	1	[4260] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
cbc2179d-24cd-4851-9da9-8903792c62b3	2018-02-26 13:24:50.992438-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
f5152493-102d-4a43-b17a-2ef0d3e999e0	2018-02-26 13:24:52.12055-06	1	[4362] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
c79f0d03-86ab-42e3-af6c-5a8044496083	2018-02-26 13:24:52.245563-06	1	[4700] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
1648c27e-0d0c-40cf-abe1-9b7758969071	2018-02-26 13:24:52.266565-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
dc44f280-a819-466b-ae0b-f8857176a44b	2018-02-26 13:24:53.386677-06	1	[4802] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
c3ac7643-6d41-497f-a2b3-7f271c9002e2	2018-02-26 13:24:53.51669-06	1	[5140] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
50abf561-59f1-4e31-b844-156b3bf449fc	2018-02-26 13:24:53.536692-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
d8fca0c2-21d0-4b74-a859-1eca9c566d86	2018-02-26 13:24:54.690807-06	1	[5242] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
0cd6eda4-8708-4cc1-9523-5b9f5d0ee54f	2018-02-26 13:24:54.81582-06	1	[5580] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
a0202e96-4ce5-437d-a2f9-017524a50813	2018-02-26 13:24:54.836822-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
4572871a-cfe9-4fd3-91b7-b00a10949eba	2018-02-26 13:24:55.972936-06	1	[5682] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
fa59fba5-f4ea-47e3-8016-6b522046192b	2018-02-26 13:24:56.098948-06	1	[6020] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
e99e5183-c490-49fb-9c27-afba9af6cd4a	2018-02-26 13:24:56.128951-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
cfb7f867-97ca-4870-8643-75c988c9a135	2018-02-26 13:24:57.256064-06	1	[6122] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
72461e51-1b32-43d7-bd47-69682ae7d009	2018-02-26 13:24:57.371075-06	1	[6460] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
fc20793a-c8c0-426d-8082-7b2091144ede	2018-02-26 13:24:57.394078-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
8fafcdb6-0aad-4087-a874-3d2fb7c7d08b	2018-02-26 13:24:58.493188-06	1	[6562] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
a072e17b-83b3-49b3-9a9e-486e6ea1a9a2	2018-02-26 13:24:58.606199-06	1	[6900] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
caeac68f-8e8a-40a4-afb5-13c61598fc78	2018-02-26 13:24:58.631201-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
4b058603-3306-466f-adfe-344beea9a888	2018-02-26 13:24:59.725311-06	1	[7002] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
376c14be-28c2-4872-bbf2-84766d3c0d31	2018-02-26 13:24:59.842322-06	1	[7340] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
c8b9ff78-7322-41f8-bf9b-c5a10c774628	2018-02-26 13:24:59.866325-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
52f1b4a9-07fd-41cb-81ba-c0f0b6da065b	2018-02-26 13:25:00.996438-06	1	[7442] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
e59f206d-3a0a-4210-8065-61f2aebeb7ff	2018-02-26 13:25:01.11445-06	1	[7780] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
1a625668-59a0-4180-8231-0e331ce29fbc	2018-02-26 13:25:01.149453-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
f2cffb7c-1b86-4d64-ac37-0a05892be4a9	2018-02-26 13:25:02.261564-06	1	[7882] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
93ddad53-1aa7-4b50-bab0-4a5adc178b28	2018-02-26 13:30:50.036338-06	1	[8220] New MAC Driver	[4] DLarrabee	[293] master	\N	\N
a350797a-f921-4ce1-b052-f4672cf30a69	2018-02-26 13:31:07.137048-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
cf766b6c-6583-429f-a510-ffa15c19f194	2018-02-26 13:35:38.391171-06	1	[8221] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
fdbf1529-2c3d-4c98-8360-f046bc75b1bf	2018-02-26 13:35:38.438176-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
e44029e9-d5c7-49e3-9120-1e27d0b7a192	2018-02-26 13:35:38.442176-06	1	[8323] Room 304 Popup Screens	[4] DLarrabee	[293] master	\N	\N
44a9b555-fce0-4abd-a28f-4b44d8d0e9be	2018-02-26 13:35:39.451277-06	1	[8324] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
8796342e-464f-4b8c-af40-09d4cc9e0e51	2018-02-26 13:35:39.57929-06	1	[8662] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
0ed81cb5-d492-4775-8d03-c4b62b0db321	2018-02-26 13:35:39.601292-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
252f4992-ebfe-4128-9e34-82fc23625941	2018-02-26 13:35:40.700402-06	1	[8764] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
4fbbb241-d525-472a-80af-d27df6e8ae69	2018-02-26 13:35:40.822414-06	1	[9102] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
3c091e3c-530c-47cc-80e2-42e39f184843	2018-02-26 13:35:40.839416-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
622ed172-c32c-432a-aee0-088eb9f5315e	2018-02-26 13:35:41.956527-06	1	[9204] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
124a7ef2-235d-413a-b1df-bc54c15e073c	2018-02-26 13:35:42.089541-06	1	[9542] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
deb9a631-eeaf-41c3-aab4-877697b433fb	2018-02-26 13:35:42.105542-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
76d6c081-6421-4f99-9e47-3d5a4ab6d828	2018-02-26 13:35:43.209653-06	1	[9644] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
e61ae8f9-3f73-4601-a2e9-959c267a5982	2018-02-26 13:35:43.331665-06	1	[9982] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
22b52a7e-c6a8-4758-bbfb-b9c5daef1851	2018-02-26 13:35:43.349667-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
cbceb137-f432-41e9-acdc-b41ca1f8ad18	2018-02-26 13:35:44.509783-06	1	[10084] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
9a6ce809-cc91-4a30-91e3-cc4075ee4d00	2018-02-26 13:35:44.631795-06	1	[10422] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
f89519d1-b116-4043-a3ee-14544bd45bd6	2018-02-26 13:35:44.649797-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
7e6c0f60-bf34-449b-b26f-f0ee510a2479	2018-02-26 13:35:45.816913-06	1	[10524] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
0db6e579-20a3-4ac6-9f39-14f74374d973	2018-02-26 13:35:45.941926-06	1	[10862] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
b4207a33-67eb-489d-8a38-b224853014ce	2018-02-26 13:35:45.962928-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
803112c9-026c-4d6f-bbce-c4674be79f2c	2018-02-26 13:35:47.069039-06	1	[10964] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
fd51becd-9162-44f6-a19e-6c9683271444	2018-02-26 13:35:47.198052-06	1	[11302] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
0f47f43b-a3cd-433e-bf83-a72b626af712	2018-02-26 13:35:47.217053-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
8abeafdc-5bf5-46ed-ab21-a8a7df959015	2018-02-26 13:35:48.324164-06	1	[11404] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
e34e6945-c9f4-49ff-8daa-9d652a947cff	2018-02-26 13:35:48.455177-06	1	[11742] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
f569a4a8-56bf-4369-81ca-10cf66bda7c9	2018-02-26 13:35:48.48218-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
41d6cd0f-8013-4f64-91d4-289d25f94db4	2018-02-26 13:35:49.619294-06	1	[11844] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
cd26fabc-555f-43ed-b933-4f750732b47d	2018-02-26 13:35:49.744306-06	1	[12182] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
39451d8e-9f40-43f2-9167-9c3fdc1ab998	2018-02-26 13:35:49.772309-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
df1cd46c-6007-4140-b3af-f9e8f9707cba	2018-02-26 13:35:50.877419-06	1	[12284] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
6f2d3c55-2f87-42cc-94e9-a67281ce2075	2018-02-26 13:35:50.996431-06	1	[12622] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
ace6eeb0-53e6-4bc5-bdb3-dcb6dc2bfb67	2018-02-26 13:35:51.023434-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
74ddcd9f-a64f-4cf9-bb1a-a91dd3d21fbc	2018-02-26 13:35:52.094541-06	1	[12724] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
53e1c392-3ffc-4b4b-8a1a-1f954c10f98b	2018-02-26 13:35:52.241556-06	1	[13062] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
d011b0df-8ba3-4dda-b81c-98a306070308	2018-02-26 13:35:52.261558-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
cc95a0e9-86ea-45b0-9f15-226cba378873	2018-02-26 13:35:53.433675-06	1	[13164] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
277730ae-257a-43a8-b820-e29e695eeafa	2018-02-26 13:35:53.557687-06	1	[13502] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
aa7ffd8f-30b8-42be-a003-8431f67379f9	2018-02-26 13:35:53.58769-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
59b145e4-3d6e-4ede-81b4-27c06c74ae5a	2018-02-26 13:35:54.725804-06	1	[13604] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
1525e0fb-2791-4c0f-8e0d-f597b14fade0	2018-02-26 13:35:54.856817-06	1	[13942] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
b241a091-b95a-4f65-8502-2ea28ba2141c	2018-02-26 13:35:54.877819-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
a7220e2d-19fe-43b2-b53f-7c59d702bd21	2018-02-26 13:35:55.991931-06	1	[14044] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
7d0bd08f-9eff-4a8a-8555-6d7d26059fcb	2018-02-26 13:36:27.856117-06	1	[14382] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
0c994dfd-bd24-492d-9583-4a4471cab065	2018-02-26 13:36:27.877119-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
3debca5c-d0ea-4333-b6fc-bde94b552f76	2018-02-26 13:36:29.132245-06	1	[14524] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
25ff3fbd-b508-4145-bf49-f648e4012f06	2018-02-26 13:36:29.313263-06	1	[14849] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
2a62c7a5-a63e-4842-b6b9-8be91b29320e	2018-02-26 13:36:29.342266-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
eff0daad-c1c3-4b2f-9f18-443a05804fd4	2018-02-26 13:36:30.744406-06	1	[14991] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
280c3612-b4b3-4662-ac62-6647a8d1262b	2018-02-26 13:36:30.89142-06	1	[15316] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
66902123-05a2-41c6-911d-f6110dec1e64	2018-02-26 13:36:30.919423-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
f598be09-94ed-4e1f-8c33-fce876234816	2018-02-26 13:36:32.305562-06	1	[15458] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
fd6093db-be7c-49ab-8c53-324b28cc8790	2018-02-26 13:37:04.436775-06	1	[15783] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
eced6dae-7f7b-40a6-99dc-c061c3b24b96	2018-02-26 13:37:04.460777-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
4bcd00e5-97d5-421c-a871-cd3c9a70362f	2018-02-26 13:37:05.209852-06	1	[15877] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
a09133cc-c2c5-430d-b7ed-92eb0e19616b	2018-02-26 13:37:05.314862-06	1	[16103] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
cebc6588-b887-4aad-b258-620d9962f70a	2018-02-26 13:37:05.336865-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
9ec5c375-951c-477d-a1b1-c81bf687a136	2018-02-26 13:37:06.136945-06	1	[16197] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
86aa76de-c726-4fa4-9017-e5b3f6497b71	2018-02-26 13:37:06.224953-06	1	[16423] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
2a522c94-2f36-4fe8-b30e-bece3730e2ee	2018-02-26 13:37:06.247956-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
0cfd9f3d-77f9-4c30-b9bb-cc190e8021e6	2018-02-26 13:37:07.046036-06	1	[16517] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
87cfa773-6764-4229-ae08-a12770d13aaa	2018-02-26 13:37:07.151046-06	1	[16743] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
206ea769-fe05-4118-9c35-cd74891a0350	2018-02-26 13:37:07.175048-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
1bc785c0-34fa-47d0-ab41-2702a16d34c2	2018-02-26 13:37:07.970128-06	1	[16837] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
9ff5f28a-dfb7-4c61-996a-c9a6052df8f8	2018-02-26 13:37:08.072138-06	1	[17063] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
c86a111d-1e03-4c53-aa77-545156d49a1c	2018-02-26 13:37:08.103141-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
70d4e11d-f4f8-4a5a-9feb-d3f083f0333b	2018-02-26 13:37:08.951226-06	1	[17157] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
7582842c-5828-450a-95f9-8bfa53ddfcb6	2018-02-26 13:37:52.902621-06	1	[17383] New MAC Driver	[4] DLarrabee	[293] master	\N	\N
41b9a404-f5df-4f40-9563-a4f17d27a8c2	2018-02-26 13:38:04.564787-06	2	[17383] RM 372 MAC Driver	[4] DLarrabee	[293] master	\N	\N
81e921b6-009a-46a0-8786-d9d35c117b98	2018-02-26 13:38:56.671997-06	1	[17384] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
0168f936-9a3a-4a29-ad0d-53aa6b3af6c1	2018-02-26 13:38:56.688999-06	2	[17383] RM 372 MAC Driver	[4] DLarrabee	[293] master	\N	\N
76fb724f-5e89-4037-b03c-30b33c837b05	2018-02-26 13:38:56.693999-06	1	[17486] Room 372 Popup Screens	[4] DLarrabee	[293] master	\N	\N
3c38f9c3-87fd-485a-9aab-047857311a9d	2018-02-26 13:38:57.715101-06	1	[17487] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
d701c1ae-cc5f-49f7-8301-d78631192f94	2018-02-26 13:38:57.845114-06	1	[17825] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
0add2166-0080-4838-b74a-887c34fece79	2018-02-26 13:38:57.861116-06	2	[17383] RM 372 MAC Driver	[4] DLarrabee	[293] master	\N	\N
0cb48717-1d31-42fc-88d3-8afb538c75a1	2018-02-26 13:38:58.966226-06	1	[17927] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
5b0d7fa0-373e-4064-bebf-16fd9c6f286f	2018-02-26 13:38:59.093239-06	1	[18265] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
627713d8-2474-4cb9-96f9-ff28843668dc	2018-02-26 13:38:59.111241-06	2	[17383] RM 372 MAC Driver	[4] DLarrabee	[293] master	\N	\N
ac1a2ee1-7a01-409d-b9bb-c75c8524f86d	2018-02-26 13:39:00.243354-06	1	[18367] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
28da16fd-848a-49c8-8a42-4a1412973a10	2018-02-26 13:39:15.193849-06	1	[18705] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
1ff64fd3-226c-40cc-b158-4115157e6cd2	2018-02-26 13:39:15.214851-06	2	[17383] RM 372 MAC Driver	[4] DLarrabee	[293] master	\N	\N
4db89c59-45cb-4e40-99b1-b45d5d818129	2018-02-26 13:39:16.477977-06	1	[18847] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
15feaf09-9c9e-4b35-89e1-1dc27fdaf4e0	2018-02-26 13:39:51.169446-06	1	[19172] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
f58100b3-cbd6-49ca-87a3-534bb095227d	2018-02-26 13:39:51.215451-06	2	[17383] RM 372 MAC Driver	[4] DLarrabee	[293] master	\N	\N
28014582-4791-4a2f-aa13-863f934ee8ff	2018-02-26 13:39:51.941523-06	1	[19266] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
d127abcf-d2c2-4cfc-8f90-53bc4343e978	2018-02-26 13:40:06.753004-06	1	[19492] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
7314defd-2063-4a76-8ab9-7a21f37d1fc0	2018-02-26 13:40:06.772006-06	2	[17383] RM 372 MAC Driver	[4] DLarrabee	[293] master	\N	\N
058f79fb-dada-4e3c-a946-62984cfd343f	2018-02-26 13:40:07.500079-06	1	[19586] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
9ac8533a-b8af-49ac-a6ee-8146ba162fb7	2018-02-26 13:40:48.61019-06	1	[19812] New MAC Driver	[4] DLarrabee	[293] master	\N	\N
ed321bae-a9be-49fb-9995-13e2d6087207	2018-02-26 13:41:45.7189-06	2	[19812] RM 474 MAC Driver	[4] DLarrabee	[293] master	\N	\N
9c9dc007-4b35-4dd4-8975-1d07f67edd4a	2018-02-26 13:42:03.551683-06	1	[19813] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
cadcc87d-7330-4f16-85b9-363270f73391	2018-02-26 13:42:03.570685-06	2	[19812] RM 474 MAC Driver	[4] DLarrabee	[293] master	\N	\N
1db17b37-c645-4fb7-98aa-2cb4fb711e9a	2018-02-26 13:42:03.576686-06	1	[19955] Room 474 Popup Screens	[4] DLarrabee	[293] master	\N	\N
72e1d155-80e7-4894-b452-14fbcd7880dc	2018-02-26 13:42:04.860814-06	1	[19956] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
f15e19f0-08ef-43f3-9434-6b6b3e423907	2018-02-26 13:42:21.916519-06	1	[20281] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
2e7c0727-c41b-4939-9e4c-1e5ec41ff893	2018-02-26 13:42:21.934521-06	2	[19812] RM 474 MAC Driver	[4] DLarrabee	[293] master	\N	\N
c1d4d597-d6c4-4eaa-ae4c-1b3ef39b3a55	2018-02-26 13:42:22.674595-06	1	[20375] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
3ebafec1-602a-4de0-b10a-7b0a6a40a2cb	2018-02-26 13:42:50.271355-06	1	[20601] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
c217969d-5801-48e7-a15c-7ab581165f25	2018-02-26 13:42:50.289356-06	2	[19812] RM 474 MAC Driver	[4] DLarrabee	[293] master	\N	\N
a79d7503-afba-4ead-a600-1360b56892a9	2018-02-26 13:42:51.32346-06	1	[20703] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
85874ab1-d663-4ce4-9862-ed63dae9681e	2018-02-26 14:51:33.988685-06	2	[2942] IC-316-inB Call Button	[4] DLarrabee	[293] master	\N	\N
3050462a-1fa4-417e-b030-87b590d703e9	2018-02-26 14:51:34.082695-06	2	[2993] IC-316-inB Call Button Supervision	[4] DLarrabee	[293] master	\N	\N
351219a9-ed11-4d0a-bb9f-5574292a9f58	2018-02-27 15:18:07.462341-06	1	[21041] New Computer	[4] DLarrabee	[293] master	\N	\N
51efb388-6679-41ed-ad3d-05fd2bb2f325	2018-02-27 15:49:40.370613-06	2	[21041] OSSI-DNOVAK	[4] DLarrabee	[293] master	\N	\N
1cd733dc-b707-4746-a711-157aedb09740	2018-02-27 16:05:51.722738-06	3	[291] Title Pad	[21041] OSSI-DNOVAK	[293] master	\N	\N
3e810bd5-7966-4141-a3b6-791fce3e3f92	2018-02-27 16:06:03.564922-06	2	[290] LeadIn	[21041] OSSI-DNOVAK	[293] master	\N	\N
9cb1a35c-6949-4659-98fd-bc949ef6ad63	2018-02-27 16:06:29.268492-06	1	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
d0df7585-e0d9-42ca-963f-f339f5e19570	2018-02-27 16:06:54.584024-06	1	[21042] Floorplans	[21041] OSSI-DNOVAK	[293] master	\N	\N
d08a0478-99dd-4904-ba5a-9c84ffaf4dfd	2018-02-27 16:06:56.169182-06	2	[21042] Floorplans	[21041] OSSI-DNOVAK	[293] master	\N	\N
ea52f1b4-69d3-4131-b7c4-a54e891c4036	2018-02-27 16:07:06.941259-06	1	[21043] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
9daa3624-ddde-4c92-87c8-e363fff28e25	2018-02-27 16:07:08.799445-06	2	[21043] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
85826752-427c-4975-8ff9-a989cef78a77	2018-02-27 16:07:14.093974-06	1	[21044] Key-samp.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
3beb8186-1b71-4a68-90c5-57f1aa8d2cd5	2018-02-27 16:07:15.580123-06	2	[21044] Key-samp.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
95d997b7-70e3-4f6f-b9fd-af74a95f3abc	2018-02-27 16:07:31.745739-06	1	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
509d9fcd-bc44-40f9-b117-396c7bab8ddf	2018-02-27 16:09:06.297194-06	1	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
85a762b4-d530-4e6e-b971-5a5e211e498f	2018-02-27 16:09:30.26259-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
e0a8905d-583c-4daf-9b6d-492f2ed64334	2018-02-27 16:09:51.330696-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
67025d3d-f0e8-45cf-be96-4df27109e7d2	2018-02-27 16:10:49.040467-06	1	[21047] Tool 200x300.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
6498d803-81c6-415d-8bb8-8a83a95cdd8c	2018-02-27 16:11:01.800743-06	2	[21047] Tool 200x300.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
5cdddd90-78ae-4197-8199-33e6fb7fcfeb	2018-02-27 16:13:17.141275-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
72266821-f98e-4b64-8dd5-dfbee7285ffc	2018-02-27 16:16:19.833543-06	2	[291] Fill.png	[4] DLarrabee	[293] master	\N	\N
275a1d9c-8577-4567-9f86-9f70e42e1ce9	2018-02-27 16:16:39.663526-06	2	[291] Fill.png	[4] DLarrabee	[293] master	\N	\N
1f73e46c-ca4d-42f7-9508-dbf888f81352	2018-02-27 16:17:43.264885-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
361fbf99-cf76-4826-9d11-a897e323286b	2018-02-27 16:19:46.313189-06	2	[21045] PODs 3X Drop sd.png	[4] DLarrabee	[293] master	\N	\N
ba26fe3d-8997-460e-8cb1-f720cbb788c3	2018-02-27 16:20:04.619019-06	2	[291] Fill.png	[4] DLarrabee	[293] master	\N	\N
e3d83ec7-2b93-4c2e-b66b-f315ed175f8d	2018-02-27 16:20:33.975955-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
b71c41f9-1c0c-46d6-abdd-7803212e87e8	2018-02-27 16:20:39.911548-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
e94b4576-9683-41ef-b55b-4a5b2c685f61	2018-02-27 16:21:01.583715-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
770b83ed-2eda-4bc9-a004-f57d2c9757fa	2018-02-27 16:22:03.874944-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
fe01964d-5825-4b25-86b1-da266054453f	2018-02-27 16:22:54.715027-06	2	[291] Fill.png	[4] DLarrabee	[293] master	\N	\N
9c9e91f6-e0f9-47c8-be2c-14c7b80549f3	2018-02-27 16:23:53.084863-06	2	[291] Fill.png	[4] DLarrabee	[293] master	\N	\N
f8de1ca0-7fc5-4429-b37f-60d8bf382d7c	2018-02-27 16:24:20.479603-06	2	[291] Fill.png	[4] DLarrabee	[293] master	\N	\N
9fba4b2d-9c80-4fcc-ac11-393239ecfda1	2018-02-27 16:24:43.784933-06	2	[291] Fill.png	[4] DLarrabee	[293] master	\N	\N
0258d40f-2918-45b9-bafa-4764aba79ca8	2018-02-27 16:26:01.082662-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
82b19450-bf7c-4a37-8d47-9bf1e4511ec8	2018-02-27 16:26:11.569711-06	2	[293] master	[4] DLarrabee	[293] master	\N	\N
58560473-30f8-46f3-ae8e-f5f6d30ec900	2018-02-27 16:31:58.19937-06	2	[293] master	[4] DLarrabee	[293] master	\N	\N
04828cf2-5a2c-4226-a4ed-417af2f60a11	2018-02-27 16:39:58.289374-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
ccc0c42c-27bd-4e37-a2f8-725ef7fd1380	2018-02-27 16:40:19.762521-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
2766efa3-9ea1-41e7-818d-1fa9bdd93ff9	2018-02-27 16:41:24.482993-06	2	[121] Popup Queues	[21041] OSSI-DNOVAK	[293] master	\N	\N
0892663a-e094-4db0-9011-8993a2f46e3d	2018-02-27 16:41:26.750219-06	1	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
bffbc3be-5eb0-4a75-aac0-59812f8a8766	2018-02-27 16:41:31.039648-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
eddd67d4-fbbd-4de1-a1c9-8f10c08cbf24	2018-02-27 16:41:43.736918-06	1	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
b86ba9ce-3a4f-49a0-9c69-90be9d5ff117	2018-02-27 16:42:15.292073-06	2	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
479f3c93-e862-4c8d-a244-9d9e10e97ee3	2018-02-27 16:42:55.901134-06	3	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
a2d28268-301d-4979-92cf-24d8e6b2b04d	2018-02-27 16:43:24.229966-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
40c8d316-d72d-4379-8ca6-0b5763ee49a7	2018-02-27 16:43:45.355079-06	1	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
7a9b0eb1-1cdf-4713-a322-1fdf127f2db7	2018-02-27 16:44:34.915034-06	1	[21050] Virtual Points	[21041] OSSI-DNOVAK	[293] master	\N	\N
a58d231d-457d-4557-baaa-3bcb6fa00d70	2018-02-27 16:44:34.930036-06	1	[21051] New Virtual Point Group	[21041] OSSI-DNOVAK	[293] master	\N	\N
e556967f-f9ef-4082-b438-6c8c36bb28c9	2018-02-27 16:44:34.935036-06	1	[21052] New Virtual Point	[21041] OSSI-DNOVAK	[293] master	\N	\N
14dfde5d-62ac-4991-989a-6431203beb33	2018-02-27 16:44:36.951238-06	2	[21050] Virtual Points	[21041] OSSI-DNOVAK	[293] master	\N	\N
d2a2fff2-6273-40b3-833c-c786383fc1ff	2018-02-27 16:44:45.770119-06	2	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
5ba89dc5-5c42-4c73-8186-16b83f1544f1	2018-02-27 16:45:16.550197-06	2	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
71ba51db-d7ef-448d-9946-b53cd96be810	2018-02-27 16:45:48.168359-06	2	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
d8c16c7b-0ef5-4d8b-b1fb-a2a8c2590118	2018-02-27 16:46:05.337075-06	2	[21052] New Virtual Point	[21041] OSSI-DNOVAK	[293] master	\N	\N
f6471443-cd74-44d6-8cd3-a03c25d651fb	2018-02-27 16:47:38.375378-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
da72fbd1-779f-4fc0-a3d2-4797fb422586	2018-02-27 16:47:57.902331-06	2	[293] master	[21041] OSSI-DNOVAK	[293] master	\N	\N
4c94feed-8849-4b09-af2d-b1a44358fe14	2018-02-27 16:48:41.275668-06	2	[293] master	[21041] OSSI-DNOVAK	[293] master	\N	\N
b35ea7d1-0c93-4a76-8ac0-86f9ce34a993	2018-02-27 16:49:05.686108-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
b5fb6cf3-f8f9-4a7a-9fd5-7d0397a99c32	2018-02-27 16:49:57.839323-06	2	[21052] New Virtual Point	[21041] OSSI-DNOVAK	[293] master	\N	\N
183ccd89-2482-40fd-9c72-ee0bafa5d41b	2018-02-27 16:50:16.839223-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
20d338a9-7ccf-4f15-9199-45455d69c72f	2018-02-27 16:52:26.183156-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
42d651c5-199a-4ed4-9ff7-734010a92c16	2018-02-27 16:54:11.108648-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
173e406a-4426-405c-b5dd-65807d2f512e	2018-02-27 16:54:51.030639-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
c14d6cc9-984f-4867-a6b7-8378a49f84f7	2018-02-27 16:56:04.252961-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
06a155d9-ce3f-4d0e-90f8-354fcf62feea	2018-02-27 16:56:47.827318-06	2	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
08ede26f-022d-44d0-93e1-edd452929aef	2018-02-27 16:57:22.533788-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
1d4b57e8-68b7-475d-846f-0233a18589e5	2018-02-27 16:57:40.465581-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
ed3aed7d-1df7-4800-9bc1-71353c90ebf1	2018-02-27 16:58:23.838918-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
2ba84359-8dc3-4682-b477-4b3edb85a7e7	2018-02-27 17:00:00.699603-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
12ddf4e4-37c0-4436-86e8-ad035a12fedd	2018-02-27 17:01:02.344767-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
0acc4d4a-d326-4956-b77d-013e2f18e277	2018-02-27 17:01:39.922525-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
42043330-5a33-409d-a530-d371b2991064	2018-02-27 17:03:16.639195-06	3	[21047] Tool 200x300.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
2d3ddb2a-c195-441f-a325-ba779f8cc5ed	2018-02-27 17:03:37.412272-06	1	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
244b37c8-488f-45d1-ba6f-97145ddf5039	2018-02-27 17:03:56.240155-06	3	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
a52bed44-5023-4a69-9989-0406284aa575	2018-02-27 17:04:46.280158-06	1	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
0c22976f-d32c-4ac2-b80d-78a0563cfe98	2018-02-27 17:06:13.341864-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
5931b674-3bf1-41e8-a728-af2e9066003f	2018-02-27 17:06:24.857015-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
48884d6b-8ef1-48a2-8e92-a8ec7fb2bf46	2018-02-27 17:07:20.60659-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
51001c20-abfd-4957-8ef3-faead45f15aa	2018-02-27 17:07:45.986127-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
73df4133-8219-493f-9274-787178b1e176	2018-02-27 17:08:48.346363-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
3842b6b6-7c00-43f8-8f06-03200e4ad2a0	2018-02-27 17:09:10.509579-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
bb9cd11d-2ad9-477b-bc5d-bf36741e2b68	2018-02-27 17:12:38.793405-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
8fff1242-862d-48cc-ac33-a1acaf08927e	2018-02-27 17:12:49.859512-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
12d51475-1a4a-4a6f-a808-2f543b9910de	2018-02-27 17:15:11.223647-06	3	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
1ab4091f-1144-4b39-b14f-93f9f98aca95	2018-02-27 17:15:33.837908-06	1	[21047] Tool 200x300.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
1e93fdb7-0d9f-4d73-aba6-a877b7d3cf16	2018-02-27 17:15:54.882012-06	2	[21047] Tool 200x300.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
096a96b7-f71b-4f33-9f3a-09a17e7e54c8	2018-02-27 17:18:42.923814-06	2	[21047] Tool 200x300.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
d2bbf9a3-8c8e-42e0-86bc-661e2959c3a0	2018-02-27 17:21:01.89271-06	2	[21047] Tool 200x300.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
9d7195cf-12cc-4ede-94b8-8c69a04b25b3	2018-02-28 07:44:48.745999-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
9aad1b6e-1f4d-4432-bdfc-adac3bede893	2018-02-28 07:46:18.503974-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
7fbbc4ab-f625-4554-9a29-37bfe83a7589	2018-02-28 07:46:43.141438-06	3	[21047] Tool 200x300.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
717cc016-3679-458b-9227-a3eaac47e53e	2018-02-28 07:47:02.388362-06	1	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
a401c8b1-e617-4dbd-a328-a475926d9142	2018-02-28 07:47:17.292852-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
8a6062ba-8c4a-4275-80e3-2e58a779107a	2018-02-28 07:47:56.26775-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
fc252360-7a9c-46a7-8a18-861ce5ab8d52	2018-02-28 07:49:17.034825-06	3	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
af1efbf3-c79e-4fd9-aede-e483a74acab6	2018-02-28 07:49:17.222844-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
714008d5-bce7-4381-a7a9-9ba9ddba5075	2018-02-28 07:50:39.955117-06	1	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
115981e2-392a-4cb9-90b3-2ce49096c13b	2018-02-28 07:51:04.571578-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
41cdb722-87e3-4910-8ba3-8d117391dfe1	2018-02-28 07:51:15.134634-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
d799bb8c-e62b-4a13-b8e2-a8deb03c4407	2018-02-28 07:51:58.90001-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
78b57b61-28e1-48e3-8e55-0bc576a5f861	2018-02-28 07:52:18.383959-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
ecc0a61c-38be-4ca1-bccf-73f10ebff778	2018-02-28 07:53:00.10113-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
23c8f7b2-fa70-4f6f-8282-a40493d9b473	2018-02-28 07:53:39.595079-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
f36c22f6-880d-4927-a4a1-c13ce02da9ca	2018-02-28 07:53:58.153935-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
8af9be64-9c40-4100-8e99-ad9c562aa7b8	2018-02-28 07:54:05.616681-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
6cd7151c-68a2-4dbc-a169-f98ed8099a8e	2018-02-28 07:54:28.316951-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
23ad361e-f4cc-406e-bc83-c648e7f8daa2	2018-02-28 07:56:02.080326-06	1	[21053] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
c43b7bb1-379b-4984-aaaa-510172397f9b	2018-02-28 07:56:06.251743-06	3	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
9e5b887c-9fdb-499d-bdf2-9b4939a8d865	2018-02-28 07:56:06.443762-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
5ae4fffe-0a23-4726-9108-6b68ee6c882e	2018-02-28 07:58:07.547871-06	1	[21047] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
f2330b9d-4287-4ce4-95f4-64df4e992a1d	2018-02-28 07:58:20.127129-06	2	[21047] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
9889e011-91ce-47ba-adba-6aaa3571a8f7	2018-02-28 07:58:48.077924-06	2	[21047] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
20089baf-a90a-45fc-ab3d-555a9e958347	2018-02-28 07:59:00.671183-06	2	[21047] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
f998191b-8b5a-4733-a511-c1e71143b3c6	2018-02-28 07:59:42.787394-06	2	[21047] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
3cd55cae-9be8-4ce2-9386-4d9460aa431b	2018-02-28 08:00:13.193435-06	1	[21053] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
f39e1e4f-8a64-45f8-86e6-3a32abc4c4b8	2018-02-28 08:00:49.708086-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
748ea686-dc0a-4f65-8512-c24ce09a0429	2018-02-28 08:00:59.363051-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
ca202025-8f11-4ad7-a1e5-8b6a51eebf0f	2018-02-28 08:01:05.871702-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
9aea9049-5647-46f2-bd6c-4c90d0238b34	2018-02-28 08:01:19.965111-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
a0cea8f5-a760-47c6-974f-cfcdcffcb9d1	2018-02-28 08:01:52.05832-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
c5fdd379-ceee-443c-b8a5-3a6b78eda0ba	2018-02-28 08:03:05.109625-06	1	[21054] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
7a941d62-520e-4281-bfcd-281bdc2c4f8b	2018-02-28 08:03:25.000614-06	3	[21054] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
67a149f6-f77c-432d-9fa8-9e2d9bc45f10	2018-02-28 08:04:21.927306-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
29db88cd-8352-4e4b-aff1-9ab97ede446a	2018-02-28 08:06:55.959707-06	1	[21054] Buttons	[21041] OSSI-DNOVAK	[293] master	\N	\N
d85368fe-72e4-4d31-bc66-49fb322ad6bb	2018-02-28 08:06:57.505862-06	2	[21054] Buttons	[21041] OSSI-DNOVAK	[293] master	\N	\N
ed20c4a1-95c2-499f-90a9-b2e83f94d587	2018-02-28 08:07:48.524963-06	1	[21055] Rectangle 2 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
1b90b5b7-daf8-49ab-aae8-68b5f7156aee	2018-02-28 08:08:18.563967-06	3	[21055] Rectangle 2 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
5397072d-0525-4eb8-9baf-613e1b0fb5b4	2018-02-28 08:08:35.141625-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
f99b21ab-8b0e-44f5-a410-6f723cb55843	2018-02-28 08:08:42.988409-06	1	[21055] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
adfe8023-61e6-4dcd-bf97-d7870fa8b255	2018-02-28 08:09:01.449255-06	1	[21056] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
3828aa23-06fb-40e5-aaa7-6e2ac950ae65	2018-02-28 08:09:12.472357-06	1	[21057] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
657acb69-9bde-4a68-9260-a3e30bf49fa0	2018-02-28 08:09:21.257236-06	1	[21058] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
36bd67ce-5990-4880-968b-50428a01c71e	2018-02-28 08:09:27.936904-06	1	[21059] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
14ad38a4-2d27-485a-adfd-0f18ebce1984	2018-02-28 08:09:32.610371-06	1	[21060] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
04fdc01f-15fc-4f57-b681-1f81262b2018	2018-02-28 08:10:28.994009-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
a5988518-b06a-4d0f-b6d7-9b6cbadab436	2018-02-28 08:10:56.994808-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
cd812616-33e7-4398-848d-d587f473c12d	2018-02-28 08:11:53.981507-06	1	[21061] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
cf5946cd-0e02-4c21-b638-4b2eb877ba7b	2018-02-28 08:12:39.291037-06	2	[21061] Tool Bar Name	[21041] OSSI-DNOVAK	[293] master	\N	\N
5ee66c56-dac2-4d87-bb89-dc33ba20601d	2018-02-28 08:13:31.281236-06	2	[21061] Tool Bar Name	[21041] OSSI-DNOVAK	[293] master	\N	\N
288e7396-6ec3-4a32-b2dc-e4d583f7d1a8	2018-02-28 08:15:08.091916-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
b3f192ed-8903-49cb-9e9a-c1d229d15fc5	2018-02-28 08:15:30.078114-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
14ce77da-396b-4c2a-ad78-1d965c1b3e4c	2018-02-28 08:16:20.113117-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
122f03c9-2b91-4d3a-8f93-299ba4d66c69	2018-02-28 08:16:55.566662-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
754fc876-8e74-4aec-b566-7e9eb661a02f	2018-02-28 08:35:12.747369-06	1	[21062] master Copy	[4] DLarrabee	[293] master	\N	\N
8a57f15f-54b8-43b1-9288-1c5e87b4c5ba	2018-02-28 08:35:33.377432-06	2	[21062] a	[4] DLarrabee	[293] master	\N	\N
1834396f-3bdf-481b-8581-f73e9914a0ed	2018-02-28 08:37:57.003793-06	2	[1047] DPIS-316B Call Button	[4] DLarrabee	[21062] a	\N	\N
0fff1b42-0d04-44c5-b92f-f7a1fef83989	2018-02-28 08:37:57.027796-06	2	[1055] DPIS-337A Call Button	[4] DLarrabee	[21062] a	\N	\N
c1d35b79-9e2b-4f8d-a9ee-fa11a45f25fc	2018-02-28 08:37:57.043797-06	2	[1056] DPIS-338A Call Button	[4] DLarrabee	[21062] a	\N	\N
f79058e2-7093-49f9-b1fa-ec0da6372552	2018-02-28 08:37:57.056798-06	2	[1057] DPIS-343A Call Button	[4] DLarrabee	[21062] a	\N	\N
ccbc33b4-a799-432e-8a0f-fbc4a7c1cb42	2018-02-28 08:37:57.0718-06	2	[1058] DPIS-344A Call Button	[4] DLarrabee	[21062] a	\N	\N
b077029f-2c12-495a-9fbd-4ea7fe602b02	2018-02-28 08:37:57.085801-06	2	[1059] DPIS-346A Call Button	[4] DLarrabee	[21062] a	\N	\N
7162a333-a2e0-4282-aa5c-2ed0b8fc049d	2018-02-28 08:37:57.102803-06	2	[1060] DPIS-347A Call Button	[4] DLarrabee	[21062] a	\N	\N
6363f276-7e56-4de5-85a9-da2f40c5f2c0	2018-02-28 08:37:57.116804-06	2	[1061] DPIS-348A Call Button	[4] DLarrabee	[21062] a	\N	\N
f71f1ba5-32db-4909-a039-9cf2a38ace7f	2018-02-28 08:37:57.129806-06	2	[1062] DPIS-349A Call Button	[4] DLarrabee	[21062] a	\N	\N
3e2d8ffc-ffc8-4406-9aaa-b1a513ce0152	2018-02-28 08:37:57.133806-06	2	[1114] DPIS-316B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6206c0f6-6e5a-4b9f-9b15-a7a0947b72a6	2018-02-28 08:37:57.136806-06	2	[1115] DPIS-326A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
17947b76-81c9-4d2d-8991-37856d9613dc	2018-02-28 08:37:57.139807-06	2	[1116] DPIS-327A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d7b20ef8-5678-4522-83bb-dde4394190dc	2018-02-28 08:37:57.141807-06	2	[1117] DPIS-329A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fb4c56c3-7629-428a-aa4a-ba68af0499e3	2018-02-28 08:37:57.144807-06	2	[1118] DPIS-329B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
59417281-25fd-4689-b537-a2f02ab616a2	2018-02-28 08:37:57.148808-06	2	[1119] DPIS-334A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7dd910de-58de-4db3-bd66-a6328c48961a	2018-02-28 08:37:57.165809-06	2	[1120] DPIS-335A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1f923b8d-e51c-4de7-a9c9-6d6123e57433	2018-02-28 08:37:57.16981-06	2	[1121] DPIS-336A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
43828158-0098-410a-8f72-253c727fb7c2	2018-02-28 08:37:57.17381-06	2	[1122] DPIS-337A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
63c43930-6f62-4871-9bed-1d34405660f6	2018-02-28 08:37:57.177811-06	2	[1123] DPIS-338A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
62c741fb-3b18-481f-b18a-bbcc119f0c05	2018-02-28 08:37:57.181811-06	2	[1124] DPIS-343A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ab8999fd-ae12-4a27-b660-d650aaf36320	2018-02-28 08:37:57.185811-06	2	[1125] DPIS-344A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c9986704-c6e2-4a65-a7ed-c9008c36d28f	2018-02-28 08:37:57.188812-06	2	[1126] DPIS-346A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9939017b-bc94-401d-8842-936c741e3bfd	2018-02-28 08:37:57.192812-06	2	[1127] DPIS-347A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2369a06c-b888-42c3-99be-b6c78ee8125f	2018-02-28 08:37:57.196812-06	2	[1128] DPIS-348A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c1ba25d1-3a35-4f06-b62a-201b5fa3ae97	2018-02-28 08:37:57.199813-06	2	[1129] DPIS-349A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0105a944-d585-4120-bdd4-81705deb0506	2018-02-28 08:37:57.203813-06	2	[1130] DPIS-351A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4692b8e6-2f5b-4e8d-848c-55acfd39c09c	2018-02-28 08:37:57.207814-06	2	[1131] DPIS-351B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
bfda0ed2-7e7a-48e1-8137-84a475a71ec4	2018-02-28 08:37:57.210814-06	2	[1132] DPIS-352A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
5a0f721d-8c4a-4012-b766-367f496a6937	2018-02-28 08:37:57.214814-06	2	[1133] DPIS-405A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f2b001a2-585e-44b0-a608-37d824ca2121	2018-02-28 08:37:57.217815-06	2	[1134] DPIS-414A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d6b9c685-1ae4-40ba-9f32-ad87307c1d56	2018-02-28 08:37:57.221815-06	2	[1135] DPIS-414B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
da0a2e03-6109-4769-8b5d-977f242efec5	2018-02-28 08:37:57.224815-06	2	[1136] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4e82ebcb-816d-45d0-ac6c-98aa012c1df7	2018-02-28 08:37:57.227816-06	2	[1137] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
04478132-8288-4655-9114-a7bb3d7ec23b	2018-02-28 08:37:57.231816-06	2	[1138] DPIS-422A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
19b13851-03a6-4f3a-89c5-1fd4f76bb09c	2018-02-28 08:37:57.233816-06	2	[1139] DPIS-422B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
376ce571-dcec-4508-a1ae-6aa631f57208	2018-02-28 08:37:57.236816-06	2	[1140] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
981e3db6-7aef-4cd4-afa6-99c551dfdd22	2018-02-28 08:37:57.239817-06	2	[1141] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
34b7b064-796e-4acc-91e0-a126579c5ea2	2018-02-28 08:37:57.242817-06	2	[1142] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4cf467e1-b0d8-40f0-9c01-91861a77005a	2018-02-28 08:37:57.246817-06	2	[1143] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0e874896-eebb-462c-9719-5f057a1a2384	2018-02-28 08:37:57.249818-06	2	[1144] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
aeec9222-b2a4-4c97-8e8d-2fe38a5ddb6e	2018-02-28 08:37:57.252818-06	2	[1145] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ab87e33d-385b-4f03-96f0-14bb8016e12c	2018-02-28 08:37:57.309824-06	2	[1513] R1C2-32I	[4] DLarrabee	[21062] a	\N	\N
3127646e-bf89-49af-a2de-ee5b6d3cc865	2018-02-28 08:37:57.326825-06	2	[1515] DPIS-438A Call Button	[4] DLarrabee	[21062] a	\N	\N
a7493e84-facc-4e6d-a59c-386a8d46e94a	2018-02-28 08:37:57.341827-06	2	[1516] DPIS-439A Call Button	[4] DLarrabee	[21062] a	\N	\N
206db204-d470-49ba-bd41-1d698f1a0d56	2018-02-28 08:37:57.354828-06	2	[1517] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
400a2873-6ce7-4dd3-b0df-17fcc713ef9f	2018-02-28 08:37:57.37083-06	2	[1518] DPIS-443A Call Button	[4] DLarrabee	[21062] a	\N	\N
19319c0f-376f-410c-bf6d-80e79b571eb3	2018-02-28 08:37:57.388832-06	2	[1519] DPIS-443B Call Button	[4] DLarrabee	[21062] a	\N	\N
501b8ce5-84c7-49d4-aaa7-813e80ee0652	2018-02-28 08:37:57.403833-06	2	[1520] DPIS-444A Call Button	[4] DLarrabee	[21062] a	\N	\N
1528e22b-f0fd-4b20-a1ac-ec4be9aaa452	2018-02-28 08:37:57.421835-06	2	[1521] DPIS-444B Call Button	[4] DLarrabee	[21062] a	\N	\N
7e671275-f5ac-4b22-a7e0-e4bf0b21445c	2018-02-28 08:37:57.439837-06	2	[1522] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
e45cf027-b733-429c-9f50-a4363d12f560	2018-02-28 08:37:57.456838-06	2	[1523] DPIS-447A Call Button	[4] DLarrabee	[21062] a	\N	\N
cdaf86c5-6ae1-4d39-b00b-f56a0f7c9223	2018-02-28 08:37:57.47084-06	2	[1524] DPIS-447B Call Button	[4] DLarrabee	[21062] a	\N	\N
b50d1d66-ccc3-4d77-9598-b10abf35a1d2	2018-02-28 08:37:57.483841-06	2	[1525] DPIS-448A Call Button	[4] DLarrabee	[21062] a	\N	\N
ee403e38-4fc0-46da-9c05-698c5c90d6c0	2018-02-28 08:37:57.499843-06	2	[1526] DPIS-451A Call Button	[4] DLarrabee	[21062] a	\N	\N
329a06fe-70bd-44f7-827a-85e5e8d75ee7	2018-02-28 08:37:57.513844-06	2	[1527] DPIS-455A Call Button	[4] DLarrabee	[21062] a	\N	\N
61bd5da8-f508-4c9d-a521-d67461604605	2018-02-28 08:37:57.534846-06	2	[1528] DPIS-455B Call Button	[4] DLarrabee	[21062] a	\N	\N
e2ef2880-bf40-438d-9cc8-382df164c03a	2018-02-28 08:37:57.546847-06	2	[1529] DPIS-455D Call Button	[4] DLarrabee	[21062] a	\N	\N
a4c90410-1851-4381-98a5-e279d52c8523	2018-02-28 08:37:57.560849-06	2	[1530] DPIS-316B Call Button	[4] DLarrabee	[21062] a	\N	\N
87578d5f-0f50-408d-aaeb-5174a7b44898	2018-02-28 08:37:57.57385-06	2	[1531] DPIS-326A Call Button	[4] DLarrabee	[21062] a	\N	\N
5de9f3cd-1366-42c2-8b56-db7452531fed	2018-02-28 08:37:57.589852-06	2	[1532] DPIS-327A Call Button	[4] DLarrabee	[21062] a	\N	\N
f11f61c6-fdb6-4b8c-9a2b-929e46e81c94	2018-02-28 08:37:57.602853-06	2	[1533] DPIS-329A Call Button	[4] DLarrabee	[21062] a	\N	\N
d8a97d43-8000-4ec1-8da9-248905693e8a	2018-02-28 08:37:57.620855-06	2	[1534] DPIS-329B Call Button	[4] DLarrabee	[21062] a	\N	\N
4f6daf42-4096-483a-a008-f0b5e1c36d44	2018-02-28 08:37:57.633856-06	2	[1535] DPIS-334A Call Button	[4] DLarrabee	[21062] a	\N	\N
b207aacc-2b26-4750-8879-b413c16f34e3	2018-02-28 08:37:57.648858-06	2	[1536] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
21ca0e08-7095-4371-9534-f1d5080074b2	2018-02-28 08:37:57.665859-06	2	[1537] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
3f0e871c-fc77-4001-ad2c-cf3ac18c149e	2018-02-28 08:37:57.680861-06	2	[1538] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
666dbd73-9a1d-4548-890d-32da7bb09928	2018-02-28 08:37:57.697863-06	2	[1539] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
da0b196d-22d6-48b9-82a3-61303d81ea2e	2018-02-28 08:37:57.713864-06	2	[1540] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
5ee67fa3-caec-4f8f-b973-03831b59c8b4	2018-02-28 08:37:57.735866-06	2	[1541] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
377b8502-bd16-4ae2-b941-781c0e4be140	2018-02-28 08:37:57.753868-06	2	[1542] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
a127167d-b479-4740-b83c-ff1a9dcfa14e	2018-02-28 08:37:57.77087-06	2	[1543] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
dfcda9a4-5814-4a4d-86ea-0fb06d1f8f40	2018-02-28 08:37:57.784871-06	2	[1544] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
433a066a-680e-4ddb-8af1-5ee9aadc0e82	2018-02-28 08:37:57.803873-06	2	[1545] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
5c01129e-637f-4b3a-87a5-beb49ae898c7	2018-02-28 08:37:57.815874-06	2	[1546] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
5a547518-04ff-4344-9466-c50b4ce3359c	2018-02-28 08:37:57.819875-06	2	[1582] DPIS-438A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1a31bc00-507c-4229-a29d-33afac0bd5d7	2018-02-28 08:37:57.823875-06	2	[1583] DPIS-439A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6e29063b-dacc-41ee-a90e-7010aa718513	2018-02-28 08:37:57.825875-06	2	[1584] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
768b2303-7b0f-4826-87f8-fce193b1d20f	2018-02-28 08:37:57.828876-06	2	[1585] DPIS-443A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e94d45e9-cbf4-44f9-b868-dbdd3fd9f5ea	2018-02-28 08:37:57.831876-06	2	[1586] DPIS-443B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1f3c11f0-894d-4dbc-9bfb-140a058c54d8	2018-02-28 08:37:57.834876-06	2	[1587] DPIS-444A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4480ab6f-407e-4b77-9dab-13dd5799f880	2018-02-28 08:37:57.837877-06	2	[1588] DPIS-444B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f533f82c-d097-4fe5-b904-9290430af1bd	2018-02-28 08:37:57.840877-06	2	[1589] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6ebe421d-1321-4115-bf69-4ffa91ce5b1b	2018-02-28 08:37:57.843877-06	2	[1590] DPIS-447A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c96b85ef-3c3f-4bc9-8a98-7e7f26b44957	2018-02-28 08:37:57.847878-06	2	[1591] DPIS-447B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a640b901-fe89-49ea-b4c5-1bd017abc1c9	2018-02-28 08:37:57.850878-06	2	[1592] DPIS-448A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4c210021-6675-4864-8685-09a71e7743cf	2018-02-28 08:37:57.854878-06	2	[1593] DPIS-451A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2d5a02ac-7854-46ef-b3a9-5fd1d6275aa8	2018-02-28 08:37:57.858879-06	2	[1594] DPIS-455A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e49714d2-1749-467e-a86f-b26ec07d8a80	2018-02-28 08:37:57.861879-06	2	[1595] DPIS-455B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d77fb46d-513e-4065-8860-1ac613881746	2018-02-28 08:37:57.864879-06	2	[1596] DPIS-455D Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c8b6cb9e-9ade-476d-8c77-fb433307d84d	2018-02-28 08:37:57.86788-06	2	[1597] DPIS-316B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4634de8e-4a06-4d20-8cb5-b5656e13e803	2018-02-28 08:37:57.87088-06	2	[1598] DPIS-326A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f3063d95-7973-4cae-be3e-9ad6f771b510	2018-02-28 08:37:57.87488-06	2	[1599] DPIS-327A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
84686006-3aaf-40fb-8426-a7f0313c8faa	2018-02-28 08:37:57.877881-06	2	[1600] DPIS-329A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
46b583dd-a89f-40ce-86b2-09e1e69fe839	2018-02-28 08:37:57.880881-06	2	[1601] DPIS-329B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2eeac0fa-d51c-437a-af13-669b57f64542	2018-02-28 08:37:57.883881-06	2	[1602] DPIS-334A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e8e9a4fa-67dc-43cd-ad4a-61065d473f38	2018-02-28 08:37:57.887882-06	2	[1603] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0ca245e9-488a-4dc9-b332-2907f33d84d6	2018-02-28 08:37:57.891882-06	2	[1604] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9e758bec-3cf6-4960-b5bd-5256e55d6f12	2018-02-28 08:37:57.896882-06	2	[1605] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
5ff5ebca-94b9-4a42-9fd7-1eedafa51d90	2018-02-28 08:37:57.900883-06	2	[1606] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
79fabf08-3582-422a-9ec3-bd0af7c17032	2018-02-28 08:37:57.904883-06	2	[1607] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9b9bfde9-da7b-4564-a9db-b8fc7576af61	2018-02-28 08:37:57.907884-06	2	[1608] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c36bfb51-b3e9-404d-871d-b16b13b0edf1	2018-02-28 08:37:57.911884-06	2	[1609] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
50029455-34fd-401e-8e18-be16da5963c4	2018-02-28 08:37:57.914884-06	2	[1610] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c273afb2-e896-4780-9473-afcc1af80542	2018-02-28 08:37:57.918885-06	2	[1611] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
bb9e79e2-f450-460d-bd32-0a7fde4c3900	2018-02-28 08:37:57.922885-06	2	[1612] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
49d8921f-1114-4c4c-81e6-04ce915fc7c1	2018-02-28 08:37:57.925885-06	2	[1613] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6abf19cf-abcd-4cee-934f-d01f3b012038	2018-02-28 08:37:57.944887-06	2	[1980] R1C3-16R	[4] DLarrabee	[21062] a	\N	\N
57cfef88-6bbe-4e47-90f4-6d9ce7ade535	2018-02-28 08:37:57.964889-06	2	[1983] LOCK RELAY-316B Relay	[4] DLarrabee	[21062] a	\N	\N
e1ee396f-9a54-4621-b984-27fcf3dae910	2018-02-28 08:37:57.977891-06	2	[1984] LOCK RELAY-326A Relay	[4] DLarrabee	[21062] a	\N	\N
c7a4d106-c734-42c8-88bd-233c9b0ca567	2018-02-28 08:37:57.990892-06	2	[1985] LOCK RELAY-327A Relay	[4] DLarrabee	[21062] a	\N	\N
cea80bf1-01f0-4acc-80d3-688b0a25d89c	2018-02-28 08:37:58.005893-06	2	[1986] LOCK RELAY-329A Relay	[4] DLarrabee	[21062] a	\N	\N
548ee996-9a86-46bf-9d3c-c942861db3d0	2018-02-28 08:37:58.018895-06	2	[1987] LOCK RELAY-329B Relay	[4] DLarrabee	[21062] a	\N	\N
e510199e-9fb4-4c09-bbbb-ebde2b97a2b6	2018-02-28 08:37:58.032896-06	2	[1988] LOCK RELAY-334A Relay	[4] DLarrabee	[21062] a	\N	\N
ab437985-07f1-4693-b8c4-892fb781b283	2018-02-28 08:37:58.050898-06	2	[1989] LOCK RELAY-335A Relay	[4] DLarrabee	[21062] a	\N	\N
7a8fd87b-16b5-4e5a-be6e-3490f9f6dc8c	2018-02-28 08:37:58.0679-06	2	[1990] LOCK RELAY-336A Relay	[4] DLarrabee	[21062] a	\N	\N
0b4e2591-df46-49a1-9764-c859e43f1710	2018-02-28 08:37:58.086901-06	2	[1991] LOCK RELAY-337A Relay	[4] DLarrabee	[21062] a	\N	\N
1a3b4640-e06a-4e19-b499-4e3556d3544c	2018-02-28 08:37:58.103903-06	2	[1992] LOCK RELAY-338A Relay	[4] DLarrabee	[21062] a	\N	\N
26d84afc-f64f-4617-acc1-5b33514d6493	2018-02-28 08:37:58.119905-06	2	[1993] LOCK RELAY-343A Relay	[4] DLarrabee	[21062] a	\N	\N
117d3389-7e73-48fe-b9e3-a7bbe6603550	2018-02-28 08:37:58.133906-06	2	[1994] LOCK RELAY-344A Relay	[4] DLarrabee	[21062] a	\N	\N
e5ab8e8d-c674-4627-80e5-1214a49a6a44	2018-02-28 08:37:58.149908-06	2	[1995] LOCK RELAY-346A Relay	[4] DLarrabee	[21062] a	\N	\N
4f26a414-999a-4db9-9930-54f03de30ad0	2018-02-28 08:37:58.166909-06	2	[1996] LOCK RELAY-347A Relay	[4] DLarrabee	[21062] a	\N	\N
3a3828a9-adce-4a4f-ad2d-23b7ab07c50c	2018-02-28 08:37:58.181911-06	2	[1997] LOCK RELAY-348A Relay	[4] DLarrabee	[21062] a	\N	\N
49684a8e-898e-4f64-b320-e99e8f023ea2	2018-02-28 08:37:58.196912-06	2	[1998] LOCK RELAY-349A Relay	[4] DLarrabee	[21062] a	\N	\N
e11d4f71-a7f9-47b6-813c-2da73618a383	2018-02-28 08:37:58.215914-06	2	[2300] R1C4-16R	[4] DLarrabee	[21062] a	\N	\N
0ae3c3fd-31b9-4feb-a1fb-ddb531d20ca2	2018-02-28 08:37:58.233916-06	2	[2303] LOCK RELAY-351A Relay	[4] DLarrabee	[21062] a	\N	\N
780dc32e-29d8-4be4-9b0c-cc87314cfaeb	2018-02-28 08:37:58.249918-06	2	[2304] LOCK RELAY-351B Relay	[4] DLarrabee	[21062] a	\N	\N
138e37c4-c0c3-4142-836a-a43861318ed6	2018-02-28 08:37:58.264919-06	2	[2305] LOCK RELAY-352A Relay	[4] DLarrabee	[21062] a	\N	\N
ae3626f9-d611-40c8-be18-c25389f3f249	2018-02-28 08:37:58.280921-06	2	[2306] LOCK RELAY-405A Relay	[4] DLarrabee	[21062] a	\N	\N
4f957a1e-dd6e-4230-b325-eb1d6c6f2c68	2018-02-28 08:37:58.295922-06	2	[2307] LOCK RELAY-414A Relay	[4] DLarrabee	[21062] a	\N	\N
138a2e03-16f8-44a8-b438-bbc3289ddf3f	2018-02-28 08:37:58.308924-06	2	[2308] LOCK RELAY-414B Relay	[4] DLarrabee	[21062] a	\N	\N
36062271-8121-4669-a326-d039761c7598	2018-02-28 08:37:58.323925-06	2	[2309] LOCK RELAY-422A Relay	[4] DLarrabee	[21062] a	\N	\N
4a833345-f462-4943-a5ab-6eac5c7fd5be	2018-02-28 08:37:58.340927-06	2	[2310] LOCK RELAY-422B Relay	[4] DLarrabee	[21062] a	\N	\N
387228e8-33c5-474a-9ee4-cc7786dc16ed	2018-02-28 08:37:58.357929-06	2	[2311] LOCK RELAY-438A Relay	[4] DLarrabee	[21062] a	\N	\N
ccd78e2a-8440-4fc0-b4db-3618d2d23eaa	2018-02-28 08:37:58.37093-06	2	[2312] LOCK RELAY-439A Relay	[4] DLarrabee	[21062] a	\N	\N
55fcffb6-c54e-470a-b35c-3259d9f29cc2	2018-02-28 08:37:58.385931-06	2	[2313] LOCK RELAY-443A Relay	[4] DLarrabee	[21062] a	\N	\N
fe771b2f-340c-4bbd-b8a9-49c35a4c4544	2018-02-28 08:37:58.401933-06	2	[2314] LOCK RELAY-443B Relay	[4] DLarrabee	[21062] a	\N	\N
6d1b1580-d783-4581-b695-a1d2a02f5478	2018-02-28 08:37:58.415934-06	2	[2315] LOCK RELAY-444A Relay	[4] DLarrabee	[21062] a	\N	\N
41025f70-569e-4b4d-9dd3-e791ebc98c01	2018-02-28 08:37:58.432936-06	2	[2316] LOCK RELAY-444B Relay	[4] DLarrabee	[21062] a	\N	\N
807a9578-432b-49d1-8719-ec56c986b849	2018-02-28 08:37:58.447938-06	2	[2317] LOCK RELAY-447A Relay	[4] DLarrabee	[21062] a	\N	\N
11f94cfb-48bb-40c3-8317-0900687f2f06	2018-02-28 08:37:58.460939-06	2	[2318] LOCK RELAY-447B Relay	[4] DLarrabee	[21062] a	\N	\N
99be6aff-375a-4009-bab4-cdd1d68ae684	2018-02-28 08:37:58.47694-06	2	[2620] R1C5-16R	[4] DLarrabee	[21062] a	\N	\N
e0199eaf-7829-4b8c-a062-0bb4e55f3323	2018-02-28 08:37:58.510944-06	2	[2623] LOCK RELAY-448A Relay	[4] DLarrabee	[21062] a	\N	\N
7c8a715d-18d2-47b7-b97f-7576a26e6fff	2018-02-28 08:37:58.528946-06	2	[2624] LOCK RELAY-455A Relay	[4] DLarrabee	[21062] a	\N	\N
12419831-032e-4847-8ac7-33470107549d	2018-02-28 08:37:58.545947-06	2	[2625] LOCK RELAY-455B Relay	[4] DLarrabee	[21062] a	\N	\N
62e6cd10-c0d2-4c30-abdc-62c4e05a53d9	2018-02-28 08:37:58.562949-06	2	[2626] LOCK RELAY-455D Relay	[4] DLarrabee	[21062] a	\N	\N
7a0948f0-f7c4-45da-aaa8-79cfb9e9618d	2018-02-28 08:37:58.578951-06	2	[2627] LOCK RELAY-316B Relay	[4] DLarrabee	[21062] a	\N	\N
a146e79e-4949-4d9c-8b0d-116c5bf093f9	2018-02-28 08:37:58.591952-06	2	[2628] LOCK RELAY-326A Relay	[4] DLarrabee	[21062] a	\N	\N
e25e414c-3cb7-41a5-bd4d-0fab6618e26c	2018-02-28 08:37:58.607954-06	2	[2629] LOCK RELAY-327A Relay	[4] DLarrabee	[21062] a	\N	\N
f1462903-8b69-497a-b48d-6651acab8797	2018-02-28 08:37:58.621955-06	2	[2630] LOCK RELAY-329A Relay	[4] DLarrabee	[21062] a	\N	\N
8a3a3a7a-e96f-4379-9814-20a9c77869d6	2018-02-28 08:37:58.639957-06	2	[2631] LOCK RELAY-329B Relay	[4] DLarrabee	[21062] a	\N	\N
4dd0f990-c78e-4ff1-9153-688b65fff4a9	2018-02-28 08:37:58.654958-06	2	[2632] LOCK RELAY-334A Relay	[4] DLarrabee	[21062] a	\N	\N
0c7d5b61-c3c8-45b3-bd83-47f2af11ccc1	2018-02-28 08:37:58.66896-06	2	[2633] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
0bde82f6-10c7-4544-a169-30814fab7324	2018-02-28 08:37:58.687962-06	2	[2634] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
f346d9d4-5e94-400b-887c-50b9f8272c26	2018-02-28 08:37:58.706963-06	2	[2635] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
94a31da7-7038-4579-8804-39b2bcda532a	2018-02-28 08:37:58.720965-06	2	[2636] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
d8642f54-47a8-4a0b-b040-bab71db7547e	2018-02-28 08:37:58.735966-06	2	[2637] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
24fb1098-bf8f-4bc2-97a9-9810066a586d	2018-02-28 08:37:58.748968-06	2	[2638] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
54c04162-e6e6-4077-9fa3-82bd23d32886	2018-02-28 08:37:58.940987-06	2	[2940] R2C1-8IC	[4] DLarrabee	[21062] a	\N	\N
3d934094-5fdc-4f32-9d34-62f9517ea022	2018-02-28 08:37:58.953988-06	2	[2942] IC-316B-inB Call Button	[4] DLarrabee	[21062] a	\N	\N
92ab27fc-6315-4a7a-adf0-3d8c940e5713	2018-02-28 08:37:58.966989-06	2	[2943] IC-316B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
b825c521-3879-4b69-a1e7-f1eefa16f65e	2018-02-28 08:37:58.982991-06	2	[2944] IC-326A Call Button	[4] DLarrabee	[21062] a	\N	\N
7b728a6c-b180-498c-b5fc-f0ab9b535c1a	2018-02-28 08:37:58.999993-06	2	[2945] IC-326A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
86a827b1-85dd-4c34-9406-85248f15d97a	2018-02-28 08:37:59.013994-06	2	[2946] IC-327A Call Button	[4] DLarrabee	[21062] a	\N	\N
3d389f93-7ce0-41f7-a25c-d4a4e8593a23	2018-02-28 08:37:59.024995-06	2	[2947] IC-327A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
d75bfb0d-b354-4134-a0aa-d44f82b7bbd2	2018-02-28 08:37:59.038997-06	2	[2948] IC-329A Call Button	[4] DLarrabee	[21062] a	\N	\N
d56966ae-f631-424e-a867-09e69985af32	2018-02-28 08:37:59.051998-06	2	[2949] IC-329A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
a42b0a7d-c5e6-46a8-95d7-5cab9b1b23ff	2018-02-28 08:37:59.068-06	2	[2951] IC-316B-inB Relay	[4] DLarrabee	[21062] a	\N	\N
f45208c3-8482-4478-b77d-a68208f6c9b7	2018-02-28 08:37:59.083001-06	2	[2952] IC-316B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
b1432491-4fec-4008-b080-5d2327f32cc2	2018-02-28 08:37:59.100003-06	2	[2953] IC-326A Relay	[4] DLarrabee	[21062] a	\N	\N
d643bbab-2880-4af4-9040-b11e53074250	2018-02-28 08:37:59.117004-06	2	[2954] IC-326A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
1a28f384-8f67-47a7-8223-34e41b1397f4	2018-02-28 08:37:59.136006-06	2	[2955] IC-327A Relay	[4] DLarrabee	[21062] a	\N	\N
47a473e7-67ea-4232-9577-bcf203ada3cc	2018-02-28 08:37:59.149008-06	2	[2956] IC-327A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
57d85eb4-c507-4edb-b04a-696d186e0894	2018-02-28 08:37:59.163009-06	2	[2957] IC-329A Relay	[4] DLarrabee	[21062] a	\N	\N
74b9cc56-0a1d-46c5-9ba1-3109b1b36548	2018-02-28 08:37:59.178011-06	2	[2958] IC-329A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
bf89a337-876a-40e6-a8ee-23d8d93a8b1b	2018-02-28 08:37:59.181011-06	2	[2960] IC-316B-inB Connect	[4] DLarrabee	[21062] a	\N	\N
21cbbaec-3a0f-41cb-af9f-f78f4eae88b9	2018-02-28 08:37:59.184011-06	2	[2961] IC-316B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
7ea4a6d2-77da-4d28-9d92-07391ef4ca0d	2018-02-28 08:37:59.186011-06	2	[2962] IC-326A Connect	[4] DLarrabee	[21062] a	\N	\N
ac04d713-b550-4f22-b014-7724d3d29486	2018-02-28 08:37:59.190012-06	2	[2963] IC-326A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
7bc2eb32-5368-4022-b770-02c489ad8369	2018-02-28 08:37:59.193012-06	2	[2964] IC-327A Connect	[4] DLarrabee	[21062] a	\N	\N
b732a560-aba1-436c-8e78-0217f66ebefc	2018-02-28 08:37:59.197012-06	2	[2965] IC-327A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
16a70cad-4357-4387-9b79-79c79f86fcae	2018-02-28 08:37:59.199013-06	2	[2966] IC-329A Connect	[4] DLarrabee	[21062] a	\N	\N
a88621ff-7f82-4bb5-8c39-26169783486c	2018-02-28 08:37:59.203013-06	2	[2967] IC-329A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
b56a1966-4063-468d-9743-1be3fc75aa50	2018-02-28 08:37:59.206013-06	2	[2993] IC-316B-inB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d3ff1771-8e4b-4ff3-9948-edbcec2cec13	2018-02-28 08:37:59.209014-06	2	[2994] IC-316B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
38fc2f11-f30d-44f3-9d6c-87fbaa145937	2018-02-28 08:37:59.213014-06	2	[2995] IC-326A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fa1f77b8-591c-486d-84d3-7136764e8e15	2018-02-28 08:37:59.216014-06	2	[2996] IC-326A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
48095d9e-a67a-45d6-826b-56f3b15f98a0	2018-02-28 08:37:59.220015-06	2	[2997] IC-327A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
51b30c94-77bc-45ce-aa73-d9f042451802	2018-02-28 08:37:59.223015-06	2	[2998] IC-327A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
96bd573e-b879-4322-b11f-6482720c70c6	2018-02-28 08:37:59.227015-06	2	[2999] IC-329A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b02a9415-b35f-4b17-a25b-720c5b18f229	2018-02-28 08:37:59.231016-06	2	[3000] IC-329A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b9c2328e-433e-4e73-9698-17b74b4a7d6d	2018-02-28 08:37:59.234016-06	2	[3012] IC-316B-inB Call	[4] DLarrabee	[21062] a	\N	\N
cc49bdc7-19a1-448d-85a8-27d3ddfd56c3	2018-02-28 08:37:59.237016-06	2	[3013] IC-316B-outB Call	[4] DLarrabee	[21062] a	\N	\N
f774fa2b-2305-418b-b31b-c44e89f3e582	2018-02-28 08:37:59.240017-06	2	[3014] IC-326A Call	[4] DLarrabee	[21062] a	\N	\N
51fa6fa5-91df-43ef-b811-c9bb5a455883	2018-02-28 08:37:59.243017-06	2	[3015] IC-326A-outB Call	[4] DLarrabee	[21062] a	\N	\N
0af8be9d-f1b8-4712-8e26-deaf071e65f3	2018-02-28 08:37:59.246017-06	2	[3016] IC-327A Call	[4] DLarrabee	[21062] a	\N	\N
d498d452-23a5-4ad2-a0aa-0d8c619b7a91	2018-02-28 08:37:59.250018-06	2	[3017] IC-327A-outB Call	[4] DLarrabee	[21062] a	\N	\N
723cb006-4270-47cd-bdb8-df19e5fd4f66	2018-02-28 08:37:59.253018-06	2	[3018] IC-329A Call	[4] DLarrabee	[21062] a	\N	\N
ecb8ceb1-7d92-41bb-b661-037c28896488	2018-02-28 08:37:59.255018-06	2	[3019] IC-329A-outB Call	[4] DLarrabee	[21062] a	\N	\N
ac068223-4d67-4632-a6e1-eed1731e3e2d	2018-02-28 08:37:59.37603-06	2	[3380] R2C2-8IC	[4] DLarrabee	[21062] a	\N	\N
0515f318-b317-4d4d-a459-fa86a9b0c4f3	2018-02-28 08:37:59.392032-06	2	[3382] IC-329B Call Button	[4] DLarrabee	[21062] a	\N	\N
69b58ef4-6492-43a2-841d-aefd262fb28f	2018-02-28 08:37:59.407033-06	2	[3383] IC-329B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
8020b1dd-71b8-456f-9a55-6d99c6f58fb9	2018-02-28 08:37:59.425035-06	2	[3384] IC-334A Call Button	[4] DLarrabee	[21062] a	\N	\N
2aba85d2-8da7-415d-be64-5a3b7c8d9619	2018-02-28 08:37:59.442037-06	2	[3385] IC-334A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
4cf4dce8-0b8f-406b-94a3-08f11516fd5a	2018-02-28 08:37:59.455038-06	2	[3386] IC-335A Call Button	[4] DLarrabee	[21062] a	\N	\N
8c3e90ab-7c1f-4d89-83f5-199fe4d8a95a	2018-02-28 08:37:59.47004-06	2	[3387] IC-335A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
71b7aacf-6310-477f-ab99-bf12ea26fe0c	2018-02-28 08:37:59.485041-06	2	[3388] IC-336A Call Button	[4] DLarrabee	[21062] a	\N	\N
f543170d-0db1-4494-ba0a-74b5da35d171	2018-02-28 08:37:59.502043-06	2	[3389] IC-336A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
e79e89cc-a4de-4f15-97e2-438d620526f0	2018-02-28 08:37:59.515044-06	2	[3391] IC-329B Relay	[4] DLarrabee	[21062] a	\N	\N
d8e84a0b-29fc-4714-adc1-b3977b464cd0	2018-02-28 08:37:59.533046-06	2	[3392] IC-329B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
3a94ce19-0521-4966-a6ce-647f93da7944	2018-02-28 08:37:59.552048-06	2	[3393] IC-334A Relay	[4] DLarrabee	[21062] a	\N	\N
35cc504c-a3be-489c-a094-bdfc5e23edc2	2018-02-28 08:37:59.56905-06	2	[3394] IC-334A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
b7776f80-f73a-4cd4-8550-5664b472f861	2018-02-28 08:37:59.581051-06	2	[3395] IC-335A Relay	[4] DLarrabee	[21062] a	\N	\N
7b8b43e6-62fb-4bbc-b396-1cab52394627	2018-02-28 08:37:59.594052-06	2	[3396] IC-335A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
2b444853-5258-45fe-a17d-18aa69c2c6f9	2018-02-28 08:37:59.613054-06	2	[3397] IC-336A Relay	[4] DLarrabee	[21062] a	\N	\N
3fb30ce3-9eb7-4770-ad40-c15792514cad	2018-02-28 08:37:59.631056-06	2	[3398] IC-336A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
b3835a14-2a2c-4fc2-8cab-c7b12ebabad7	2018-02-28 08:37:59.635056-06	2	[3400] IC-329B Connect	[4] DLarrabee	[21062] a	\N	\N
26bf5daa-24e4-4056-bf7e-98927833fcd1	2018-02-28 08:37:59.639057-06	2	[3401] IC-329B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
3342c02f-4ae7-4232-a6ba-0025727f8884	2018-02-28 08:37:59.644057-06	2	[3402] IC-334A Connect	[4] DLarrabee	[21062] a	\N	\N
3355622b-809d-4014-b976-0c860f0faf4b	2018-02-28 08:37:59.649058-06	2	[3403] IC-334A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
24c73d84-6e5e-4f62-b27d-973b6137efae	2018-02-28 08:37:59.653058-06	2	[3404] IC-335A Connect	[4] DLarrabee	[21062] a	\N	\N
5f78d998-0954-42ad-ad3e-206f7748e36c	2018-02-28 08:37:59.655058-06	2	[3405] IC-335A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
e9e0a06e-d393-455a-8a40-672428a6620d	2018-02-28 08:37:59.659059-06	2	[3406] IC-336A Connect	[4] DLarrabee	[21062] a	\N	\N
5d2409a7-fd37-44f2-8d0c-96b986435b9f	2018-02-28 08:37:59.665059-06	2	[3407] IC-336A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
22389822-22e7-4cf2-844a-76de630dfbe2	2018-02-28 08:37:59.66906-06	2	[3433] IC-329B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
984aa9f5-a968-488b-8316-26b64aa3c985	2018-02-28 08:37:59.67306-06	2	[3434] IC-329B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8175f508-9413-4028-bd82-685d43ae3d18	2018-02-28 08:37:59.67706-06	2	[3435] IC-334A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f87f939b-d33d-4500-9cff-e9f47219ae6c	2018-02-28 08:37:59.681061-06	2	[3436] IC-334A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8fca813f-a9a9-4ef2-ad15-3b9005d1127c	2018-02-28 08:37:59.685061-06	2	[3437] IC-335A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1b8e13a2-1679-40fe-b7c5-12a9cfa1a292	2018-02-28 08:37:59.689062-06	2	[3438] IC-335A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
bb67440d-3fc3-4990-b3ef-4929a161d0cf	2018-02-28 08:37:59.692062-06	2	[3439] IC-336A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
19f10f64-6159-48b7-bf82-388b8550ea28	2018-02-28 08:37:59.696062-06	2	[3440] IC-336A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2449ded1-4878-4a76-8d1d-0558a6927074	2018-02-28 08:37:59.700063-06	2	[3452] IC-329B Call	[4] DLarrabee	[21062] a	\N	\N
827c95f6-e51d-4ea8-8e50-2a5f3c53a2cb	2018-02-28 08:37:59.703063-06	2	[3453] IC-329B-outB Call	[4] DLarrabee	[21062] a	\N	\N
4b86da82-654c-4dd4-8144-5bfb635a1fcc	2018-02-28 08:37:59.707063-06	2	[3454] IC-334A Call	[4] DLarrabee	[21062] a	\N	\N
ed5b8375-4821-44d9-8ec1-8ddda8f6feef	2018-02-28 08:37:59.711064-06	2	[3455] IC-334A-outB Call	[4] DLarrabee	[21062] a	\N	\N
80dd8a25-f902-423b-b7e0-a966509a97e4	2018-02-28 08:37:59.715064-06	2	[3456] IC-335A Call	[4] DLarrabee	[21062] a	\N	\N
255683e5-7cb2-48ae-8253-5bde87570b7b	2018-02-28 08:37:59.718065-06	2	[3457] IC-335A-outB Call	[4] DLarrabee	[21062] a	\N	\N
b4361b9b-fb77-4b39-98f1-b2d48cbdfbb7	2018-02-28 08:37:59.722065-06	2	[3458] IC-336A Call	[4] DLarrabee	[21062] a	\N	\N
39d9f501-f68c-4e06-baeb-a4b5ab893d0b	2018-02-28 08:37:59.727065-06	2	[3459] IC-336A-outB Call	[4] DLarrabee	[21062] a	\N	\N
1d73b0d6-feb0-4096-90f7-bff7caa55fd8	2018-02-28 08:37:59.854078-06	2	[3820] R2C3-8IC	[4] DLarrabee	[21062] a	\N	\N
67010d40-a402-4f72-993f-ad68efe77b5e	2018-02-28 08:37:59.86908-06	2	[3822] IC-337A Call Button	[4] DLarrabee	[21062] a	\N	\N
59d49741-dd0f-48d5-bff4-d5e8bdb6c40b	2018-02-28 08:37:59.884081-06	2	[3823] IC-337A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
eef93bcf-fa45-45a0-9218-2e77af06510e	2018-02-28 08:37:59.903083-06	2	[3824] IC-338A Call Button	[4] DLarrabee	[21062] a	\N	\N
3cf419b3-f0cc-4317-9d3b-94f762818719	2018-02-28 08:37:59.922085-06	2	[3825] IC-338A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
80576151-6826-4172-9524-e8823bca2397	2018-02-28 08:37:59.940087-06	2	[3826] IC-343A Call Button	[4] DLarrabee	[21062] a	\N	\N
e2f8912b-bdc4-4b22-985f-5a0ae6316b7d	2018-02-28 08:37:59.955088-06	2	[3827] IC-343A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
a58a8a97-1870-47b3-a069-fae3ba58b686	2018-02-28 08:37:59.96809-06	2	[3828] IC-344A Call Button	[4] DLarrabee	[21062] a	\N	\N
28e058ca-5eb4-4433-b46f-5869596463bc	2018-02-28 08:37:59.983091-06	2	[3829] IC-344A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
9c716877-f4fc-40ac-bf24-c452a51f5319	2018-02-28 08:38:00.000093-06	2	[3831] IC-337A Relay	[4] DLarrabee	[21062] a	\N	\N
7cbd7460-a71c-46b0-b295-d57236e28207	2018-02-28 08:38:00.015094-06	2	[3832] IC-337A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
9a9a7b66-7d7b-4867-bfc8-d67a04db6f79	2018-02-28 08:38:00.031096-06	2	[3833] IC-338A Relay	[4] DLarrabee	[21062] a	\N	\N
8539ee1e-beb6-4f87-9e70-177edd9b67d3	2018-02-28 08:38:00.050098-06	2	[3834] IC-338A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
9ddb70ad-001e-44e0-b1c6-43ce4c6ac39c	2018-02-28 08:38:00.0681-06	2	[3835] IC-343A Relay	[4] DLarrabee	[21062] a	\N	\N
a8606ff1-2313-47c2-83e3-d32fee47ce3b	2018-02-28 08:38:00.082101-06	2	[3836] IC-343A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
b5c308cd-065b-45ac-ab3a-275579cc1025	2018-02-28 08:38:00.101103-06	2	[3837] IC-344A Relay	[4] DLarrabee	[21062] a	\N	\N
871ad34b-96e7-4518-9ab7-0ff157623218	2018-02-28 08:38:00.115104-06	2	[3838] IC-344A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
4c741793-00f6-4d7d-ae24-6c70f2ce8bd8	2018-02-28 08:38:00.118105-06	2	[3840] IC-337A Connect	[4] DLarrabee	[21062] a	\N	\N
53c861be-8a0c-408f-9557-cd329b4d1da4	2018-02-28 08:38:00.121105-06	2	[3841] IC-337A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
d97aa646-7407-4fcc-bf7b-7679b781e7e7	2018-02-28 08:38:00.123105-06	2	[3842] IC-338A Connect	[4] DLarrabee	[21062] a	\N	\N
21e230cb-c794-42d8-b318-15b48e0a5fb2	2018-02-28 08:38:00.126105-06	2	[3843] IC-338A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
082122b0-0578-4263-9e37-0eeabc53620e	2018-02-28 08:38:00.130106-06	2	[3844] IC-343A Connect	[4] DLarrabee	[21062] a	\N	\N
b048c207-08bb-4961-ad7a-b0ef21589dcc	2018-02-28 08:38:00.134106-06	2	[3845] IC-343A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
7bc7c39e-e2d9-4746-a140-0a0e2c81139d	2018-02-28 08:38:00.137106-06	2	[3846] IC-344A Connect	[4] DLarrabee	[21062] a	\N	\N
b78eda9c-2860-4ad3-9820-b1505e9356dc	2018-02-28 08:38:00.140107-06	2	[3847] IC-344A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
65f63770-8ace-403d-93e4-76af7c04b8e2	2018-02-28 08:38:00.142107-06	2	[3873] IC-337A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
152a0d56-f482-4402-899e-486d717ca119	2018-02-28 08:38:00.147107-06	2	[3874] IC-337A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
57b4d320-6866-4a1e-a55b-04d22f914525	2018-02-28 08:38:00.150108-06	2	[3875] IC-338A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c49e1f90-d016-403f-8f3d-f885f78c6284	2018-02-28 08:38:00.154108-06	2	[3876] IC-338A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ad1ae164-5337-4672-a086-6db49de5c24e	2018-02-28 08:38:00.158109-06	2	[3877] IC-343A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e9d09d0f-8eb3-47b6-940a-4604aa64a4c8	2018-02-28 08:38:00.161109-06	2	[3878] IC-343A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f79a3c90-84f0-4ecc-8b95-51d8f91ef968	2018-02-28 08:38:00.164109-06	2	[3879] IC-344A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
da45703b-9e9d-4d27-84f6-1d73bc4e072d	2018-02-28 08:38:00.167109-06	2	[3880] IC-344A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
5db2bc95-1fe8-4fe4-824e-c255296bacde	2018-02-28 08:38:00.17011-06	2	[3892] IC-337A Call	[4] DLarrabee	[21062] a	\N	\N
d8decfdd-2d83-4538-ab7f-5c86170f2f7f	2018-02-28 08:38:00.17411-06	2	[3893] IC-337A-outB Call	[4] DLarrabee	[21062] a	\N	\N
fa5a5da2-3a11-4e6f-940a-9749c818a881	2018-02-28 08:38:00.17711-06	2	[3894] IC-338A Call	[4] DLarrabee	[21062] a	\N	\N
3b8eaf09-554e-4354-b6f3-2caf805a4ed8	2018-02-28 08:38:00.180111-06	2	[3895] IC-338A-outB Call	[4] DLarrabee	[21062] a	\N	\N
fac1260a-adb3-4d94-9db7-1068e02dbebf	2018-02-28 08:38:00.183111-06	2	[3896] IC-343A Call	[4] DLarrabee	[21062] a	\N	\N
687151af-8691-4e4f-a56d-ddb54e93bd6c	2018-02-28 08:38:00.186111-06	2	[3897] IC-343A-outB Call	[4] DLarrabee	[21062] a	\N	\N
7383f30a-4954-4a5d-ace7-9574293e9d19	2018-02-28 08:38:00.189112-06	2	[3898] IC-344A Call	[4] DLarrabee	[21062] a	\N	\N
3b7cdd17-1f75-4ed5-b4a7-1708ef96db1d	2018-02-28 08:38:00.193112-06	2	[3899] IC-344A-outB Call	[4] DLarrabee	[21062] a	\N	\N
27c77ff7-2bff-4ceb-bcb5-83fea0626865	2018-02-28 08:38:00.313124-06	2	[4260] R2C4-8IC	[4] DLarrabee	[21062] a	\N	\N
1eeb7078-f1d6-40b8-8500-bab140dccf0e	2018-02-28 08:38:00.327125-06	2	[4262] IC-346A Call Button	[4] DLarrabee	[21062] a	\N	\N
68470ad2-3a5e-47d3-a65e-9fdd2c613c1c	2018-02-28 08:38:00.343127-06	2	[4263] IC-346A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
ef84d3cd-8f1e-470e-82cd-ba59467d76bf	2018-02-28 08:38:00.362129-06	2	[4264] IC-347A Call Button	[4] DLarrabee	[21062] a	\N	\N
34b27b10-10fa-448f-9c54-daa8c0999e38	2018-02-28 08:38:00.379131-06	2	[4265] IC-347A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
a8c8841c-1e70-47d5-83e5-783772d91148	2018-02-28 08:38:00.394132-06	2	[4266] IC-348A Call Button	[4] DLarrabee	[21062] a	\N	\N
02cc1f2d-988d-44bf-9597-720cdbb20095	2018-02-28 08:38:00.406133-06	2	[4267] IC-348A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
6579179b-17df-4014-a1e3-aa5af1255dc1	2018-02-28 08:38:00.418135-06	2	[4268] IC-349A Call Button	[4] DLarrabee	[21062] a	\N	\N
565d6dd1-6197-4b05-b30f-b2709086adf7	2018-02-28 08:38:00.437136-06	2	[4269] IC-349A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
97fc7a4b-d3a2-4527-9317-bcd3cd8dd133	2018-02-28 08:38:00.452138-06	2	[4271] IC-346A Relay	[4] DLarrabee	[21062] a	\N	\N
503713cb-67e7-4158-abec-e4b568883c19	2018-02-28 08:38:00.464139-06	2	[4272] IC-346A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
7072ebf7-85f2-477d-bb85-b6b3ee701443	2018-02-28 08:38:00.478141-06	2	[4273] IC-347A Relay	[4] DLarrabee	[21062] a	\N	\N
9d5926c6-8d46-4c73-b5d3-085262e00dee	2018-02-28 08:38:00.491142-06	2	[4274] IC-347A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
73e51bdf-53fd-4014-8cb8-756a5437bc69	2018-02-28 08:38:00.503143-06	2	[4275] IC-348A Relay	[4] DLarrabee	[21062] a	\N	\N
f8c1363f-4430-4be9-9aa9-17afa7779209	2018-02-28 08:38:00.522145-06	2	[4276] IC-348A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
a678fdf8-489c-4c23-b0c8-ee31ca99fabc	2018-02-28 08:38:00.540147-06	2	[4277] IC-349A Relay	[4] DLarrabee	[21062] a	\N	\N
14235b59-e234-41b9-8cf3-3a9e5885f073	2018-02-28 08:38:00.556148-06	2	[4278] IC-349A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
5c7bb9ca-29e1-43f7-a211-bd1a1071af98	2018-02-28 08:38:00.559149-06	2	[4280] IC-346A Connect	[4] DLarrabee	[21062] a	\N	\N
c761c6a6-f791-4516-b8fb-66d177e03975	2018-02-28 08:38:00.563149-06	2	[4281] IC-346A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
7eee7655-e9c7-43d4-a38f-ea84a9dcfade	2018-02-28 08:38:00.566149-06	2	[4282] IC-347A Connect	[4] DLarrabee	[21062] a	\N	\N
8e9dc0eb-c52d-4f28-a695-7615a52a5822	2018-02-28 08:38:00.56915-06	2	[4283] IC-347A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
28558a54-7051-4262-97c1-a7cb299dd79e	2018-02-28 08:38:00.57215-06	2	[4284] IC-348A Connect	[4] DLarrabee	[21062] a	\N	\N
5ceb698a-8c58-463e-b41d-0c3c0f0b33dc	2018-02-28 08:38:00.57615-06	2	[4285] IC-348A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
d2da86f4-8f71-46e7-8172-260ac79f83fc	2018-02-28 08:38:00.579151-06	2	[4286] IC-349A Connect	[4] DLarrabee	[21062] a	\N	\N
ff628e28-7916-496d-a6c4-a64cba78063a	2018-02-28 08:38:00.583151-06	2	[4287] IC-349A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
ff81dbd6-f9a3-4a9b-ad14-d4fdf8da1baa	2018-02-28 08:38:00.586151-06	2	[4313] IC-346A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
eb84b414-0960-4428-9525-252a91d65f01	2018-02-28 08:38:00.590152-06	2	[4314] IC-346A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f317e08b-5ffc-4c81-930b-9d764bd21aa3	2018-02-28 08:38:00.594152-06	2	[4315] IC-347A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
aecf7480-ec96-49bb-9256-18dccd7eb5b1	2018-02-28 08:38:00.599153-06	2	[4316] IC-347A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
83123534-cb0c-437a-b4b0-d2ac70259add	2018-02-28 08:38:00.604153-06	2	[4317] IC-348A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
165bec75-9b71-496f-8345-bc6bf5c4f0f3	2018-02-28 08:38:00.607153-06	2	[4318] IC-348A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9097db22-3247-4e2a-9ba6-0c43213745ce	2018-02-28 08:38:00.611154-06	2	[4319] IC-349A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d8fc9498-734b-46c3-b6ff-7604a9146615	2018-02-28 08:38:00.617154-06	2	[4320] IC-349A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
700f0963-4aa3-43ff-aa87-2d6d3bd29b35	2018-02-28 08:38:00.620155-06	2	[4332] IC-346A Call	[4] DLarrabee	[21062] a	\N	\N
b2066cc7-935b-4583-8bda-0df6e59c8685	2018-02-28 08:38:00.623155-06	2	[4333] IC-346A-outB Call	[4] DLarrabee	[21062] a	\N	\N
36bcc66c-bc97-46c3-bbd8-b5e9067bc795	2018-02-28 08:38:00.627155-06	2	[4334] IC-347A Call	[4] DLarrabee	[21062] a	\N	\N
64f869b0-fc4f-4ffd-8c95-8d21c985f7d8	2018-02-28 08:38:00.630156-06	2	[4335] IC-347A-outB Call	[4] DLarrabee	[21062] a	\N	\N
8a8c4183-f1a7-4bac-af55-31a6a6881165	2018-02-28 08:38:00.632156-06	2	[4336] IC-348A Call	[4] DLarrabee	[21062] a	\N	\N
8530cd37-75d7-40d6-8d65-015a042e1731	2018-02-28 08:38:00.635156-06	2	[4337] IC-348A-outB Call	[4] DLarrabee	[21062] a	\N	\N
1c03e129-069c-4749-8937-7480ff1e9f22	2018-02-28 08:38:00.638157-06	2	[4338] IC-349A Call	[4] DLarrabee	[21062] a	\N	\N
604a0764-2691-4723-9970-bda5c3c159a9	2018-02-28 08:38:00.641157-06	2	[4339] IC-349A-outB Call	[4] DLarrabee	[21062] a	\N	\N
de7bf439-de3f-4705-8157-bbe1eb1c6059	2018-02-28 08:38:00.766169-06	2	[4700] R2C5-8IC	[4] DLarrabee	[21062] a	\N	\N
a74d39eb-82fa-4651-b172-f9e0d3c5bc32	2018-02-28 08:38:00.780171-06	2	[4702] IC-351A Call Button	[4] DLarrabee	[21062] a	\N	\N
44eedc0f-5301-466d-9f98-f71a7d412e58	2018-02-28 08:38:00.792172-06	2	[4703] IC-351A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
95051040-7839-43c5-a8f0-2528ed4b0217	2018-02-28 08:38:00.805173-06	2	[4704] IC-351B Call Button	[4] DLarrabee	[21062] a	\N	\N
8eb29c1d-f532-4f43-8b5b-5eaf081ed401	2018-02-28 08:38:00.824175-06	2	[4705] IC-351B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
d8233131-9719-4081-bd7e-ca27e37e3d50	2018-02-28 08:38:00.839177-06	2	[4706] IC-352A Call Button	[4] DLarrabee	[21062] a	\N	\N
bc9b4708-9e3e-40cb-a304-7768d4445e70	2018-02-28 08:38:00.853178-06	2	[4707] IC-352A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
3e940ebc-f014-4e03-ba8d-789a6e33d92f	2018-02-28 08:38:00.867179-06	2	[4708] IC-405A Call Button	[4] DLarrabee	[21062] a	\N	\N
184fd4f3-e676-4957-9828-6d48df354ade	2018-02-28 08:38:00.885181-06	2	[4709] IC-405A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
d1daea1d-cc64-4486-be0b-b09e6a598e21	2018-02-28 08:38:00.905183-06	2	[4711] IC-351A Relay	[4] DLarrabee	[21062] a	\N	\N
35d4ebd4-8b96-42f7-89e9-4653f68528a9	2018-02-28 08:38:00.924185-06	2	[4712] IC-351A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
b82e2b73-d0c3-4156-af95-984a8f5da7d0	2018-02-28 08:38:00.941187-06	2	[4713] IC-351B Relay	[4] DLarrabee	[21062] a	\N	\N
87930ee8-f4f4-4e3d-906d-417c303fa325	2018-02-28 08:38:00.954188-06	2	[4714] IC-351B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
7eced790-58c2-4305-9dfc-1a8929ca4f00	2018-02-28 08:38:00.96919-06	2	[4715] IC-352A Relay	[4] DLarrabee	[21062] a	\N	\N
d3828ddd-1ec8-4854-88ab-485a1c5147e8	2018-02-28 08:38:00.982191-06	2	[4716] IC-352A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
2c0be271-78bf-428c-9424-9683b77aba2e	2018-02-28 08:38:00.997192-06	2	[4717] IC-405A Relay	[4] DLarrabee	[21062] a	\N	\N
018b07d3-cd94-42b2-be50-a4d0df68d289	2018-02-28 08:38:01.016194-06	2	[4718] IC-405A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
872d4f56-dfe0-4ccf-bdb2-6f695987dcb0	2018-02-28 08:38:01.020195-06	2	[4720] IC-351A Connect	[4] DLarrabee	[21062] a	\N	\N
b9473487-0825-4851-9d4c-c39d466f7d1f	2018-02-28 08:38:01.024195-06	2	[4721] IC-351A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
8f9a8955-5c49-4178-8a47-b8531a09a074	2018-02-28 08:38:01.027195-06	2	[4722] IC-351B Connect	[4] DLarrabee	[21062] a	\N	\N
7daab42a-ccd5-432b-9500-2e87803a5fa6	2018-02-28 08:38:01.029196-06	2	[4723] IC-351B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
8ffbe9de-e2fd-48ad-adf8-b50459e357b6	2018-02-28 08:38:01.032196-06	2	[4724] IC-352A Connect	[4] DLarrabee	[21062] a	\N	\N
bfd51ce0-1dcb-427d-a21a-0ecdc6c01ff7	2018-02-28 08:38:01.035196-06	2	[4725] IC-352A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
786a0379-aaa0-48ca-9b34-d9a4435cf612	2018-02-28 08:38:01.039197-06	2	[4726] IC-405A Connect	[4] DLarrabee	[21062] a	\N	\N
9e1f0f89-ea3d-4b4b-9025-59b8e12516ef	2018-02-28 08:38:01.042197-06	2	[4727] IC-405A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
f62f464f-63dd-4596-871e-2235df38fb78	2018-02-28 08:38:01.046197-06	2	[4753] IC-351A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f95a2cf1-cf46-428a-94cf-c5767dc0d66d	2018-02-28 08:38:01.050198-06	2	[4754] IC-351A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6d6978d6-3411-48ee-93ce-95723995f2a1	2018-02-28 08:38:01.053198-06	2	[4755] IC-351B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
334a38f5-1f44-4b73-8d43-8fca5e14f8cc	2018-02-28 08:38:01.057198-06	2	[4756] IC-351B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3a8c8c5a-b335-4376-8bc0-a25adf4a3534	2018-02-28 08:38:01.061199-06	2	[4757] IC-352A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
15363011-7173-4e8c-a66d-4bdb0a723575	2018-02-28 08:38:01.064199-06	2	[4758] IC-352A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
767b05b7-072a-41fd-b040-baf911e787d2	2018-02-28 08:38:01.067199-06	2	[4759] IC-405A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2148081d-129f-41e3-b799-887d49b67afa	2018-02-28 08:38:01.0692-06	2	[4760] IC-405A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
16d13ef9-7be8-498d-8a2c-82f1c027d5c6	2018-02-28 08:38:01.0722-06	2	[4772] IC-351A Call	[4] DLarrabee	[21062] a	\N	\N
c6c58daf-3f24-43ec-9459-bb1c4810ae58	2018-02-28 08:38:01.0752-06	2	[4773] IC-351A-outB Call	[4] DLarrabee	[21062] a	\N	\N
6412be3c-e710-4304-8d90-606e37c45ca4	2018-02-28 08:38:01.078201-06	2	[4774] IC-351B Call	[4] DLarrabee	[21062] a	\N	\N
04b2cef3-d95b-4ae2-b65a-7b3f0da56803	2018-02-28 08:38:01.081201-06	2	[4775] IC-351B-outB Call	[4] DLarrabee	[21062] a	\N	\N
eff8035e-6fb6-41b7-aa1f-ba3d60c6f91a	2018-02-28 08:38:01.084201-06	2	[4776] IC-352A Call	[4] DLarrabee	[21062] a	\N	\N
5eff1b8c-0ad3-456e-b0a1-a56503639fff	2018-02-28 08:38:01.088202-06	2	[4777] IC-352A-outB Call	[4] DLarrabee	[21062] a	\N	\N
e04ec09a-b691-464f-b693-13c064184d9f	2018-02-28 08:38:01.091202-06	2	[4778] IC-405A Call	[4] DLarrabee	[21062] a	\N	\N
d6ecbc62-78c9-4d54-97e3-b3a54064f8cf	2018-02-28 08:38:01.094202-06	2	[4779] IC-405A-outB Call	[4] DLarrabee	[21062] a	\N	\N
94606c44-d444-4af1-9589-e53038d21525	2018-02-28 08:38:01.210214-06	2	[5140] R2C6-8IC	[4] DLarrabee	[21062] a	\N	\N
56ff47eb-166e-4e01-9cf5-f66f19d46c99	2018-02-28 08:38:01.226215-06	2	[5142] IC-414A Call Button	[4] DLarrabee	[21062] a	\N	\N
8888ca4f-6283-4a15-abcc-f4e67f86b960	2018-02-28 08:38:01.245217-06	2	[5143] IC-414A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
20ff18be-9ae2-40a5-b2bd-b214717181f6	2018-02-28 08:38:01.265219-06	2	[5144] IC-414B Call Button	[4] DLarrabee	[21062] a	\N	\N
f9543643-896e-499f-bb78-cfd8492e14a3	2018-02-28 08:38:01.279221-06	2	[5145] IC-414B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
eabb1337-fc34-4713-b9c4-3ad1ee2a3011	2018-02-28 08:38:01.295222-06	2	[5146] IC-422A Call Button	[4] DLarrabee	[21062] a	\N	\N
7d7659b7-b033-4db2-93af-c4ca901c6276	2018-02-28 08:38:01.313224-06	2	[5147] IC-422A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
3e086884-d43e-4bb5-aea0-e6915de18126	2018-02-28 08:38:01.326225-06	2	[5148] IC-422B Call Button	[4] DLarrabee	[21062] a	\N	\N
83a713c7-7bba-4027-826d-e143fdb8b79c	2018-02-28 08:38:01.342227-06	2	[5149] IC-422B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
94d641a2-ac1e-4637-b6de-13351d6c0b03	2018-02-28 08:38:01.353228-06	2	[5151] IC-414A Relay	[4] DLarrabee	[21062] a	\N	\N
3f103c5e-5412-4d72-a0af-33c9c4651529	2018-02-28 08:38:01.37023-06	2	[5152] IC-414A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
4b406ff1-10db-4d4f-9899-c74a17829434	2018-02-28 08:38:01.387231-06	2	[5153] IC-414B Relay	[4] DLarrabee	[21062] a	\N	\N
fa4275e3-9f4c-48eb-8c6c-24dcee6bb888	2018-02-28 08:38:01.406233-06	2	[5154] IC-414B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
45d07b8f-e4dc-442b-9e5a-af46fbaf695f	2018-02-28 08:38:01.424235-06	2	[5155] IC-422A Relay	[4] DLarrabee	[21062] a	\N	\N
7710f780-8be7-4eb9-9ad8-62511f42e178	2018-02-28 08:38:01.440237-06	2	[5156] IC-422A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
89d2289c-212b-4e99-a22b-1469aee8a7e3	2018-02-28 08:38:01.457238-06	2	[5157] IC-422B Relay	[4] DLarrabee	[21062] a	\N	\N
d84074b3-8ec7-4d15-b308-92ddd2e5ace2	2018-02-28 08:38:01.47224-06	2	[5158] IC-422B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
0cebf4fc-6f6c-478d-b912-ba1b78312177	2018-02-28 08:38:01.47624-06	2	[5160] IC-414A Connect	[4] DLarrabee	[21062] a	\N	\N
d6e3a7a0-9ebd-4fd5-9f19-6bd71ccbd66f	2018-02-28 08:38:01.478241-06	2	[5161] IC-414A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
8b28934d-94df-4494-af1f-df9a95904a8d	2018-02-28 08:38:01.482241-06	2	[5162] IC-414B Connect	[4] DLarrabee	[21062] a	\N	\N
aa54e978-9582-42c5-835a-f4268c24a95f	2018-02-28 08:38:01.485241-06	2	[5163] IC-414B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
d7d9a9d2-802f-432f-a61e-d347179813fa	2018-02-28 08:38:01.488242-06	2	[5164] IC-422A Connect	[4] DLarrabee	[21062] a	\N	\N
ef6adc38-227d-4380-a49a-9ab8ea67f917	2018-02-28 08:38:01.493242-06	2	[5165] IC-422A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
a068659b-5c39-4a99-bc97-4331cdd02287	2018-02-28 08:38:01.496242-06	2	[5166] IC-422B Connect	[4] DLarrabee	[21062] a	\N	\N
ea3cadb3-2fb9-4793-b21b-3b580eb5bc53	2018-02-28 08:38:01.500243-06	2	[5167] IC-422B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
3aff06eb-0d36-487d-b08c-bc8446e6b743	2018-02-28 08:38:01.503243-06	2	[5193] IC-414A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3c0f1e0a-9aca-47b3-a93c-4e65b08d6749	2018-02-28 08:38:01.507243-06	2	[5194] IC-414A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3c49af48-f8fd-46a7-b960-71e23f8555f2	2018-02-28 08:38:01.511244-06	2	[5195] IC-414B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6761fd86-4a3a-4608-afbb-f461092af634	2018-02-28 08:38:01.514244-06	2	[5196] IC-414B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
11b0a40e-dcda-4e73-947d-81568a9bf2f4	2018-02-28 08:38:01.518245-06	2	[5197] IC-422A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
599826e7-f890-45db-91fb-063ff6518489	2018-02-28 08:38:01.522245-06	2	[5198] IC-422A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e815b00e-b9da-4166-9c8e-0ac912fd43b1	2018-02-28 08:38:01.526245-06	2	[5199] IC-422B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
584571ca-74a6-444d-b184-a10d415458da	2018-02-28 08:38:01.530246-06	2	[5200] IC-422B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fc7d3e28-17cb-4276-8671-5f1ba88eb896	2018-02-28 08:38:01.534246-06	2	[5212] IC-414A Call	[4] DLarrabee	[21062] a	\N	\N
f5fd1c28-b2d6-43e8-8799-560950b40ae6	2018-02-28 08:38:01.538247-06	2	[5213] IC-414A-outB Call	[4] DLarrabee	[21062] a	\N	\N
248257b9-72ef-4ddd-89e5-81f62d6781a7	2018-02-28 08:38:01.542247-06	2	[5214] IC-414B Call	[4] DLarrabee	[21062] a	\N	\N
d469dba9-f06a-49e7-a7c8-15078ecc45ac	2018-02-28 08:38:01.545247-06	2	[5215] IC-414B-outB Call	[4] DLarrabee	[21062] a	\N	\N
c442dd9f-08da-4cda-86c0-78f088d27461	2018-02-28 08:38:01.549248-06	2	[5216] IC-422A Call	[4] DLarrabee	[21062] a	\N	\N
6b84d67f-24f2-4120-a428-8ba7a3363f52	2018-02-28 08:38:01.552248-06	2	[5217] IC-422A-outB Call	[4] DLarrabee	[21062] a	\N	\N
1c8c6f81-4729-4136-9ec7-36def0f36947	2018-02-28 08:38:01.556248-06	2	[5218] IC-422B Call	[4] DLarrabee	[21062] a	\N	\N
a695ced1-a07f-46b8-8c97-70bec5e0ce0d	2018-02-28 08:38:01.560249-06	2	[5219] IC-422B-outB Call	[4] DLarrabee	[21062] a	\N	\N
1e19814f-2d74-488b-8bd1-7b16da991a07	2018-02-28 08:38:01.684261-06	2	[5580] R2C7-8IC	[4] DLarrabee	[21062] a	\N	\N
48cff619-179e-45cd-b993-6c5fd4e66fd8	2018-02-28 08:38:01.699263-06	2	[5582] IC-438A Call Button	[4] DLarrabee	[21062] a	\N	\N
957a4929-8d46-4700-a681-13b121f81bee	2018-02-28 08:38:01.716264-06	2	[5583] IC-438A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
8e9b628e-c144-42fd-8497-191f01202710	2018-02-28 08:38:01.733266-06	2	[5584] IC-439A Call Button	[4] DLarrabee	[21062] a	\N	\N
71f72bc5-a0a3-43fe-8de3-fe51e976904f	2018-02-28 08:38:01.748268-06	2	[5585] IC-439A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
ef7b9037-1314-46ca-928d-0b7574eeb7fe	2018-02-28 08:38:01.761269-06	2	[5586] IC-443A Call Button	[4] DLarrabee	[21062] a	\N	\N
9866c2f4-8e7d-40b8-9077-eed61fab6d18	2018-02-28 08:38:01.77627-06	2	[5587] IC-443A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
a74bcc3d-f340-4300-96c4-e1631574567b	2018-02-28 08:38:01.791272-06	2	[5588] IC-443B Call Button	[4] DLarrabee	[21062] a	\N	\N
b1b65f9a-e731-4637-aeda-ba4c72920231	2018-02-28 08:38:01.805273-06	2	[5589] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
4475af5e-6709-4916-91f6-f1320a659fb6	2018-02-28 08:38:01.821275-06	2	[5591] IC-438A Relay	[4] DLarrabee	[21062] a	\N	\N
d1c8675d-25e5-45b6-9845-cb08062ffb57	2018-02-28 08:38:01.839277-06	2	[5592] IC-438A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
ad5cca84-509e-4eb7-b91d-500df1f5275b	2018-02-28 08:38:01.857278-06	2	[5593] IC-439A Relay	[4] DLarrabee	[21062] a	\N	\N
04cb7a28-8099-4c39-be09-1c817635396e	2018-02-28 08:38:01.87628-06	2	[5594] IC-439A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
a54ab875-291c-4af8-a275-2529fe6af94b	2018-02-28 08:38:01.892282-06	2	[5595] IC-443A Relay	[4] DLarrabee	[21062] a	\N	\N
355b75aa-2f81-489e-9ac1-e080479051f8	2018-02-28 08:38:01.909284-06	2	[5596] IC-443A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
eabbd778-85d8-4f9c-945d-22700d81e73f	2018-02-28 08:38:01.921285-06	2	[5597] IC-443B Relay	[4] DLarrabee	[21062] a	\N	\N
e54cce88-a333-4a3b-a437-1f5a2bed5daa	2018-02-28 08:38:01.937286-06	2	[5598] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
a6a6cc8d-b429-4ac0-bcf2-a1c0a984ab24	2018-02-28 08:38:01.940287-06	2	[5600] IC-438A Connect	[4] DLarrabee	[21062] a	\N	\N
90e8a76e-c85e-49ff-91b0-a389898fa5df	2018-02-28 08:38:01.943287-06	2	[5601] IC-438A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
460c50f2-0cc4-4f03-847f-59b6f7a55c4c	2018-02-28 08:38:01.946287-06	2	[5602] IC-439A Connect	[4] DLarrabee	[21062] a	\N	\N
9f1952f1-7379-4205-958d-e826782ae586	2018-02-28 08:38:01.950288-06	2	[5603] IC-439A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
702621fe-193b-47e7-8554-f4a02952eed2	2018-02-28 08:38:01.953288-06	2	[5604] IC-443A Connect	[4] DLarrabee	[21062] a	\N	\N
c357224f-be82-4404-91a2-c4b66a4b26b4	2018-02-28 08:38:01.955288-06	2	[5605] IC-443A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
dc6d347d-e45e-4be3-81b3-200c2c0a0a70	2018-02-28 08:38:01.958289-06	2	[5606] IC-443B Connect	[4] DLarrabee	[21062] a	\N	\N
7c25a2c9-1fd5-4108-b813-6b4bd22bcf9f	2018-02-28 08:38:01.962289-06	2	[5607] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
91599add-fd3b-4b07-9781-1938ed320fa9	2018-02-28 08:38:01.965289-06	2	[5633] IC-438A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
50c27162-711f-4fb6-a728-70633aa0a651	2018-02-28 08:38:01.96829-06	2	[5634] IC-438A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
76f996fa-35bb-4d68-9456-ac71f9445e7f	2018-02-28 08:38:01.97129-06	2	[5635] IC-439A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
35f825bc-d434-4468-baca-988c0b096264	2018-02-28 08:38:01.97529-06	2	[5636] IC-439A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
5c0d97b4-96a0-4312-81cc-f0a360111855	2018-02-28 08:38:01.978291-06	2	[5637] IC-443A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
130c753d-3802-4f9a-9927-e243ed79e9de	2018-02-28 08:38:01.981291-06	2	[5638] IC-443A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8e8a28e0-c578-4ffd-a50a-bb2081c924c4	2018-02-28 08:38:01.984291-06	2	[5639] IC-443B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2111bdae-e1b0-48b2-b190-e5fb405b17df	2018-02-28 08:38:01.988292-06	2	[5640] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
804f4677-dde2-4d05-a17c-1c3d32f07b7d	2018-02-28 08:38:01.991292-06	2	[5652] IC-438A Call	[4] DLarrabee	[21062] a	\N	\N
1ddab802-9c1c-456e-829c-1e9a6f3e6448	2018-02-28 08:38:01.995292-06	2	[5653] IC-438A-outB Call	[4] DLarrabee	[21062] a	\N	\N
a9e981f6-0d1a-48a5-ad0e-5d5c4f732a7d	2018-02-28 08:38:01.998293-06	2	[5654] IC-439A Call	[4] DLarrabee	[21062] a	\N	\N
2ec41304-d475-4503-849d-e8b34ad293c5	2018-02-28 08:38:02.001293-06	2	[5655] IC-439A-outB Call	[4] DLarrabee	[21062] a	\N	\N
31b43435-3b68-4407-8f9c-edc1ba7a97f3	2018-02-28 08:38:02.004293-06	2	[5656] IC-443A Call	[4] DLarrabee	[21062] a	\N	\N
9a2b26b5-3341-43c8-9c56-d339055770d5	2018-02-28 08:38:02.007293-06	2	[5657] IC-443A-outB Call	[4] DLarrabee	[21062] a	\N	\N
94c0ed0e-ae5c-449c-8b0e-c3a745000f56	2018-02-28 08:38:02.010294-06	2	[5658] IC-443B Call	[4] DLarrabee	[21062] a	\N	\N
d44b587a-e238-4128-a21a-30277cb784c5	2018-02-28 08:38:02.013294-06	2	[5659] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
174487b4-774c-4f30-8c43-49acd6e4488e	2018-02-28 08:38:02.157308-06	2	[6020] R3C1-8IC	[4] DLarrabee	[21062] a	\N	\N
b00dad46-b416-4f79-9327-eb8af800fb26	2018-02-28 08:38:02.17731-06	2	[6022] IC-443B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
1b8673c8-d0b3-49b4-b32a-98631fd26369	2018-02-28 08:38:02.197312-06	2	[6023] IC-444A Call Button	[4] DLarrabee	[21062] a	\N	\N
8409d5d0-cbf8-4641-b4df-5b2e63a931a1	2018-02-28 08:38:02.211314-06	2	[6024] IC-444A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
230569cb-e37e-41b7-a10e-4f4ccf1ec49b	2018-02-28 08:38:02.226315-06	2	[6025] IC-444B Call Button	[4] DLarrabee	[21062] a	\N	\N
24bc13f1-d520-436b-83ef-2f58bc4d5f25	2018-02-28 08:38:02.244317-06	2	[6026] IC-444B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
7d4ea3e0-766d-4735-9a0c-7987a0d3329c	2018-02-28 08:38:02.257318-06	2	[6027] IC-447A Call Button	[4] DLarrabee	[21062] a	\N	\N
7f1258d3-ad0f-4ea6-800f-eb1dcaca4a5f	2018-02-28 08:38:02.27332-06	2	[6028] IC-447A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
e8945eed-f553-4e4c-9fb9-fe843011f1fc	2018-02-28 08:38:02.290322-06	2	[6029] IC-447B Call Button	[4] DLarrabee	[21062] a	\N	\N
fe594e15-a8fa-493f-a529-ae2133515ee0	2018-02-28 08:38:02.304323-06	2	[6031] IC-443B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
9ad1a843-33be-4ddd-a3b3-81edc09ff4fe	2018-02-28 08:38:02.319325-06	2	[6032] IC-444A Relay	[4] DLarrabee	[21062] a	\N	\N
19397b5a-0b42-4f85-b76c-94eddd066df0	2018-02-28 08:38:02.334326-06	2	[6033] IC-444A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
7eda4698-3ec9-426b-a097-c13203f2102d	2018-02-28 08:38:02.352328-06	2	[6034] IC-444B Relay	[4] DLarrabee	[21062] a	\N	\N
734e7d6f-dad6-4a04-8798-2315d1baca8f	2018-02-28 08:38:02.366329-06	2	[6035] IC-444B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
bd2fb235-c623-490f-8fa1-ca05ca235aeb	2018-02-28 08:38:02.385331-06	2	[6036] IC-447A Relay	[4] DLarrabee	[21062] a	\N	\N
c89aae02-8e65-4e97-b0d3-1c603df6f45b	2018-02-28 08:38:02.405333-06	2	[6037] IC-447A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
274f3053-6c4c-4f4b-9355-09b11b3aa47e	2018-02-28 08:38:02.424335-06	2	[6038] IC-447B Relay	[4] DLarrabee	[21062] a	\N	\N
6646f9c4-2036-46ba-b874-f644fa9eacab	2018-02-28 08:38:02.428336-06	2	[6040] IC-443B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
acd8597d-77b3-491f-984d-8cb5554b2dc2	2018-02-28 08:38:02.432336-06	2	[6041] IC-444A Connect	[4] DLarrabee	[21062] a	\N	\N
9f2d03c5-c2dc-4dff-83f3-384f5c5a6bb8	2018-02-28 08:38:02.436336-06	2	[6042] IC-444A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
8f39e3c7-3d1c-4e29-b799-8ab3d89f83f6	2018-02-28 08:38:02.440337-06	2	[6043] IC-444B Connect	[4] DLarrabee	[21062] a	\N	\N
bf3a94f6-c707-492f-a7ba-1caa892d13a1	2018-02-28 08:38:02.444337-06	2	[6044] IC-444B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
229ec178-c4ea-411b-86ac-2a38317b2a59	2018-02-28 08:38:02.448338-06	2	[6045] IC-447A Connect	[4] DLarrabee	[21062] a	\N	\N
752ab55c-7e0b-4627-8e57-059671289ecd	2018-02-28 08:38:02.452338-06	2	[6046] IC-447A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
c5663eed-d9b4-43aa-a00f-e04ac37db78c	2018-02-28 08:38:02.455338-06	2	[6047] IC-447B Connect	[4] DLarrabee	[21062] a	\N	\N
fbd79a9c-f407-44cb-bc83-9cf79aa7cb7f	2018-02-28 08:38:02.458339-06	2	[6073] IC-443B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cc4a5bb0-bd17-4db6-9c10-8a48fc1c7d63	2018-02-28 08:38:02.461339-06	2	[6074] IC-444A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e94fcc01-0959-48f4-b9f7-0378a841653a	2018-02-28 08:38:02.464339-06	2	[6075] IC-444A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e4357725-759b-4c01-a0a7-39aa9163f830	2018-02-28 08:38:02.46834-06	2	[6076] IC-444B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2a8c9eda-eec7-4ac3-a7b2-827d8715f216	2018-02-28 08:38:02.47234-06	2	[6077] IC-444B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
942e35e5-11db-4924-bc39-932daca337ef	2018-02-28 08:38:02.47534-06	2	[6078] IC-447A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
db7aef93-0722-49b5-9597-3c2fc5761cdd	2018-02-28 08:38:02.478341-06	2	[6079] IC-447A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c02b3aec-5a06-4ad3-807a-35d71247072d	2018-02-28 08:38:02.481341-06	2	[6080] IC-447B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
34973709-d826-441b-9968-8bd2b5edd2ef	2018-02-28 08:38:02.484341-06	2	[6092] IC-443B-outB Call	[4] DLarrabee	[21062] a	\N	\N
dacc3e12-4218-4886-9a32-d62c4cf6465a	2018-02-28 08:38:02.487341-06	2	[6093] IC-444A Call	[4] DLarrabee	[21062] a	\N	\N
dbc87629-87d9-4099-97a8-93d9981809ae	2018-02-28 08:38:02.491342-06	2	[6094] IC-444A-outB Call	[4] DLarrabee	[21062] a	\N	\N
7ff7b169-dbfb-4b10-9057-4c6e022ff6a4	2018-02-28 08:38:02.493342-06	2	[6095] IC-444B Call	[4] DLarrabee	[21062] a	\N	\N
afff0b2f-58ec-40e6-9868-51c25dd6105d	2018-02-28 08:38:02.496342-06	2	[6096] IC-444B-outB Call	[4] DLarrabee	[21062] a	\N	\N
608efab6-e4a4-421f-9c8e-60a50e16e5c9	2018-02-28 08:38:02.500343-06	2	[6097] IC-447A Call	[4] DLarrabee	[21062] a	\N	\N
ed4de1af-52e5-464c-af79-dc9f80b9358d	2018-02-28 08:38:02.504343-06	2	[6098] IC-447A-outB Call	[4] DLarrabee	[21062] a	\N	\N
47b0315e-3d91-4833-a803-e857f2982cf2	2018-02-28 08:38:02.507343-06	2	[6099] IC-447B Call	[4] DLarrabee	[21062] a	\N	\N
99cdc431-257a-4546-850f-64e166c9a4f5	2018-02-28 08:38:02.625355-06	2	[6460] R3C2-8IC	[4] DLarrabee	[21062] a	\N	\N
07eaa3ef-50a7-4008-95da-ce7b8da81c61	2018-02-28 08:38:02.644357-06	2	[6462] IC-447B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
8d4ad009-83b0-41b8-a6ba-593e6be7906d	2018-02-28 08:38:02.656358-06	2	[6463] IC-448A Call Button	[4] DLarrabee	[21062] a	\N	\N
320ae2eb-00a2-4ea1-95b5-e136ab99875e	2018-02-28 08:38:02.66936-06	2	[6464] IC-448A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
9e4b58ca-8d8a-4a0f-857a-876bdeb5f97f	2018-02-28 08:38:02.684361-06	2	[6465] IC-455A Call Button	[4] DLarrabee	[21062] a	\N	\N
2576f237-6c08-4479-9c9d-8a6dd6bd4a44	2018-02-28 08:38:02.697362-06	2	[6466] IC-455A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
e248c02f-d686-46ce-b6f2-6287c75b9731	2018-02-28 08:38:02.709364-06	2	[6467] IC-455B Call Button	[4] DLarrabee	[21062] a	\N	\N
955982ce-c92d-478e-86a4-08e477e542bd	2018-02-28 08:38:02.728366-06	2	[6468] IC-455B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
b9ab1156-b8ef-48fb-879b-e714061c34fd	2018-02-28 08:38:02.744367-06	2	[6469] IC-455D Call Button	[4] DLarrabee	[21062] a	\N	\N
fbbc3249-1987-45c2-a9ec-1d3d6e31263e	2018-02-28 08:38:02.761369-06	2	[6471] IC-447B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
b50b8038-89b6-4187-a54b-cb16bce340e2	2018-02-28 08:38:02.77537-06	2	[6472] IC-448A Relay	[4] DLarrabee	[21062] a	\N	\N
00eb9927-ec57-46c8-b07b-b210aadd640a	2018-02-28 08:38:02.794372-06	2	[6473] IC-448A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
e9afdeba-dcc1-4888-8f0c-b27e2bd384f1	2018-02-28 08:38:02.811374-06	2	[6474] IC-455A Relay	[4] DLarrabee	[21062] a	\N	\N
f924dd0e-1f35-446c-9a09-e9efecdb6b0a	2018-02-28 08:38:02.830376-06	2	[6475] IC-455A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
aa0b49b5-14a0-4147-b89f-b3b3355165c8	2018-02-28 08:38:02.846377-06	2	[6476] IC-455B Relay	[4] DLarrabee	[21062] a	\N	\N
2195aa33-7ac5-49fa-87e6-cbb993a6d277	2018-02-28 08:38:02.865379-06	2	[6477] IC-455B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
188860f6-eeaa-4553-a05e-67668d22cbe9	2018-02-28 08:38:02.882381-06	2	[6478] IC-455D Relay	[4] DLarrabee	[21062] a	\N	\N
7dfb65c3-303f-4a8d-beaa-cdcd046cbff4	2018-02-28 08:38:02.885381-06	2	[6480] IC-447B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
02b2ad13-1db4-4e9c-ae06-94a7471078ba	2018-02-28 08:38:02.889382-06	2	[6481] IC-448A Connect	[4] DLarrabee	[21062] a	\N	\N
ffc739bf-d403-472b-a7f0-b597021bbbcd	2018-02-28 08:38:02.892382-06	2	[6482] IC-448A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
42e69cdb-9e15-4033-b5d1-36f964cd9f10	2018-02-28 08:38:02.896382-06	2	[6483] IC-455A Connect	[4] DLarrabee	[21062] a	\N	\N
73dfaf08-f0b5-47d8-ab28-d2492a03bd68	2018-02-28 08:38:02.900383-06	2	[6484] IC-455A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
7e3c00c3-45dd-44a6-9946-3045dcf4f870	2018-02-28 08:38:02.903383-06	2	[6485] IC-455B Connect	[4] DLarrabee	[21062] a	\N	\N
aff41ac8-02b0-4218-9558-3bafe5936edc	2018-02-28 08:38:02.907383-06	2	[6486] IC-455B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
3fae09c2-73dd-444c-9c49-4756b5a5f0f4	2018-02-28 08:38:02.910384-06	2	[6487] IC-455D Connect	[4] DLarrabee	[21062] a	\N	\N
213d07e5-c907-4c37-861a-b04e1bdcfdb2	2018-02-28 08:38:02.913384-06	2	[6513] IC-447B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
392e18b0-6b90-465e-a487-dc1b5b4ef372	2018-02-28 08:38:02.916384-06	2	[6514] IC-448A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
84e5e767-da7a-4291-aa63-a700e0e8e615	2018-02-28 08:38:02.920385-06	2	[6515] IC-448A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2cde1c63-3d56-487a-abfb-87250a469b0c	2018-02-28 08:38:02.923385-06	2	[6516] IC-455A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
98df24d0-cacd-4c9e-8a7d-ecfde54eee5d	2018-02-28 08:38:02.927385-06	2	[6517] IC-455A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
13f7f283-b572-4452-92cd-e5c4d8a2bece	2018-02-28 08:38:02.930386-06	2	[6518] IC-455B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2cfddf72-5edb-4881-b581-272f5d7c1431	2018-02-28 08:38:02.934386-06	2	[6519] IC-455B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8561d7cf-9ee4-4e65-9981-da907c8eb56c	2018-02-28 08:38:02.938387-06	2	[6520] IC-455D Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f740279d-ed10-4717-90df-6281204ae669	2018-02-28 08:38:02.941387-06	2	[6532] IC-447B-outB Call	[4] DLarrabee	[21062] a	\N	\N
16ebcfc2-619a-4ab2-a5ee-0e49949f93cd	2018-02-28 08:38:02.945387-06	2	[6533] IC-448A Call	[4] DLarrabee	[21062] a	\N	\N
cc19aac4-a869-4443-852f-15e4e2bfedec	2018-02-28 08:38:02.948388-06	2	[6534] IC-448A-outB Call	[4] DLarrabee	[21062] a	\N	\N
af13fe31-8286-4507-88c4-bb8bbfb1feb5	2018-02-28 08:38:02.952388-06	2	[6535] IC-455A Call	[4] DLarrabee	[21062] a	\N	\N
828b6a49-d3b2-4bb4-9623-ebf275ba827d	2018-02-28 08:38:02.955388-06	2	[6536] IC-455A-outB Call	[4] DLarrabee	[21062] a	\N	\N
78d23bc7-373a-49cd-819f-1b87094dd109	2018-02-28 08:38:02.959389-06	2	[6537] IC-455B Call	[4] DLarrabee	[21062] a	\N	\N
effdea55-738b-44f5-bbe6-fb7e1cd0da12	2018-02-28 08:38:02.962389-06	2	[6538] IC-455B-outB Call	[4] DLarrabee	[21062] a	\N	\N
38ffb9b3-10da-4ad3-9445-e194c62a9353	2018-02-28 08:38:02.965389-06	2	[6539] IC-455D Call	[4] DLarrabee	[21062] a	\N	\N
9b63039e-1525-4fa3-894c-905c71e15094	2018-02-28 08:38:03.085401-06	2	[6900] R3C3-8IC	[4] DLarrabee	[21062] a	\N	\N
221c0b40-3787-4e50-8799-9a2022102629	2018-02-28 08:38:03.098403-06	2	[6902] IC-455D-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
f9aa7345-476b-4174-aae2-1a4f127257e5	2018-02-28 08:38:03.112404-06	2	[6903] IC-316B Call Button	[4] DLarrabee	[21062] a	\N	\N
1c6a5b80-a2dd-46da-aef5-63ac5e23d478	2018-02-28 08:38:03.126405-06	2	[6904] IC-316B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
e5e101c5-cadb-4b58-92e8-42e4eeb40b75	2018-02-28 08:38:03.143407-06	2	[6905] IC-326A Call Button	[4] DLarrabee	[21062] a	\N	\N
d167fe3c-4002-4ed3-8a23-f4031e9b116b	2018-02-28 08:38:03.161409-06	2	[6906] IC-326A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
1cf3ece8-ee20-4fb8-b865-978890c493e0	2018-02-28 08:38:03.17441-06	2	[6907] IC-327A Call Button	[4] DLarrabee	[21062] a	\N	\N
66387084-6fca-4cb7-a739-cf5c99ea1ce2	2018-02-28 08:38:03.190412-06	2	[6908] IC-327A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
38d0bea2-a882-48e4-bdb8-eeaaf8dc49bb	2018-02-28 08:38:03.207413-06	2	[6909] IC-329A Call Button	[4] DLarrabee	[21062] a	\N	\N
29012d96-22bf-4d59-a2d5-7e35d3f424d0	2018-02-28 08:38:03.221415-06	2	[6911] IC-455D-outB Relay	[4] DLarrabee	[21062] a	\N	\N
232defd3-f788-48df-9cd4-497b2acedb92	2018-02-28 08:38:03.235416-06	2	[6912] IC-316B Relay	[4] DLarrabee	[21062] a	\N	\N
cda93c2d-c0f2-4aa9-9027-a90ba17a6f71	2018-02-28 08:38:03.252418-06	2	[6913] IC-316B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
1ac62f52-dfcc-48b9-83e3-a6a7f87290df	2018-02-28 08:38:03.27142-06	2	[6914] IC-326A Relay	[4] DLarrabee	[21062] a	\N	\N
aad01469-205b-4969-8278-fc7adfcd05aa	2018-02-28 08:38:03.286421-06	2	[6915] IC-326A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
81d5f1c1-d18a-4571-9e22-10bd71dcdb6d	2018-02-28 08:38:03.300423-06	2	[6916] IC-327A Relay	[4] DLarrabee	[21062] a	\N	\N
5f327392-8d69-434d-85a8-67715483acff	2018-02-28 08:38:03.316424-06	2	[6917] IC-327A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
74e421fd-4cc3-4c03-a9f6-886dcacb7f99	2018-02-28 08:38:03.336426-06	2	[6918] IC-329A Relay	[4] DLarrabee	[21062] a	\N	\N
4416c331-ce28-4e1f-9e00-3c46c8f7d9e0	2018-02-28 08:38:03.339427-06	2	[6920] IC-455D-outB Connect	[4] DLarrabee	[21062] a	\N	\N
18bbc61a-a0b9-424e-a151-4cfaa2c63029	2018-02-28 08:38:03.343427-06	2	[6921] IC-316B Connect	[4] DLarrabee	[21062] a	\N	\N
22b41bf8-6dfd-44c7-a825-240b0cd47ae0	2018-02-28 08:38:03.346427-06	2	[6922] IC-316B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
c999d093-f5df-4550-8675-c063bb2904bd	2018-02-28 08:38:03.350428-06	2	[6923] IC-326A Connect	[4] DLarrabee	[21062] a	\N	\N
5d6a288a-5759-4fca-9be8-d586d67752c7	2018-02-28 08:38:03.354428-06	2	[6924] IC-326A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
a441137c-b49e-4be9-88d8-165348fba6e0	2018-02-28 08:38:03.358429-06	2	[6925] IC-327A Connect	[4] DLarrabee	[21062] a	\N	\N
f522a429-1831-4225-a610-963ba5f0b758	2018-02-28 08:38:03.362429-06	2	[6926] IC-327A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
a45b2c7d-9c8c-4de4-b7d6-e49792e36d6f	2018-02-28 08:38:03.37043-06	2	[6927] IC-329A Connect	[4] DLarrabee	[21062] a	\N	\N
6a77a1ec-2534-487b-9252-5e15ca1706ca	2018-02-28 08:38:03.37443-06	2	[6953] IC-455D-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f2a92ea0-9ac9-407f-aadf-eb71217e4779	2018-02-28 08:38:03.379431-06	2	[6954] IC-316B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9fa4c043-8d78-4fb3-8533-b72f7d4c91dc	2018-02-28 08:38:03.385431-06	2	[6955] IC-316B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4a518fd7-5ecd-46f7-806f-deaaf681669b	2018-02-28 08:38:03.389432-06	2	[6956] IC-326A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8ade60d1-143f-4fcf-8b45-895012d43041	2018-02-28 08:38:03.392432-06	2	[6957] IC-326A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
348597d0-1080-481a-a12a-370d02771e1f	2018-02-28 08:38:03.396432-06	2	[6958] IC-327A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9d21adb3-aaae-42ea-b7ba-6a49ea34f7db	2018-02-28 08:38:03.400433-06	2	[6959] IC-327A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3122d14d-6066-4775-8bb5-a2f10122711a	2018-02-28 08:38:03.402433-06	2	[6960] IC-329A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3096f3ba-c61d-4164-8e63-2dcedbd00c4b	2018-02-28 08:38:03.405433-06	2	[6972] IC-455D-outB Call	[4] DLarrabee	[21062] a	\N	\N
a7adf7a5-b87c-4522-9c83-67de8d56817b	2018-02-28 08:38:03.410434-06	2	[6973] IC-316B Call	[4] DLarrabee	[21062] a	\N	\N
eb38dc08-da45-4aff-b475-50d4ebfbc452	2018-02-28 08:38:03.413434-06	2	[6974] IC-316B-outB Call	[4] DLarrabee	[21062] a	\N	\N
36f3f197-4541-4a47-ae55-dddd58ecd4cf	2018-02-28 08:38:03.417434-06	2	[6975] IC-326A Call	[4] DLarrabee	[21062] a	\N	\N
9b45fe07-f705-4790-a242-bc0fbc9475d3	2018-02-28 08:38:03.421435-06	2	[6976] IC-326A-outB Call	[4] DLarrabee	[21062] a	\N	\N
942cd4d8-ab63-4560-8665-791d085a7b43	2018-02-28 08:38:03.425435-06	2	[6977] IC-327A Call	[4] DLarrabee	[21062] a	\N	\N
5b1babcd-b62c-4581-b09a-e9540158de18	2018-02-28 08:38:03.428436-06	2	[6978] IC-327A-outB Call	[4] DLarrabee	[21062] a	\N	\N
a824680c-b90b-485d-8baa-6048ef8819ab	2018-02-28 08:38:03.433436-06	2	[6979] IC-329A Call	[4] DLarrabee	[21062] a	\N	\N
ad3b9771-abd5-462f-beb2-76b6049740af	2018-02-28 08:38:03.563449-06	2	[7340] R3C4-8IC	[4] DLarrabee	[21062] a	\N	\N
aa5ea962-9b60-412f-9987-7f535f801f45	2018-02-28 08:38:03.583451-06	2	[7342] IC-329A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
9d109318-a23d-4395-ac54-7fa347cb061b	2018-02-28 08:38:03.603453-06	2	[7343] IC-329B Call Button	[4] DLarrabee	[21062] a	\N	\N
6d50f046-28cc-4b7d-8a8e-782da76dfb63	2018-02-28 08:38:03.622455-06	2	[7344] IC-329B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
6153a7a2-1747-4287-af84-a44d643c9aec	2018-02-28 08:38:03.637456-06	2	[7345] IC-334A Call Button	[4] DLarrabee	[21062] a	\N	\N
006d8d56-aa8a-4c00-8f04-6095b158095b	2018-02-28 08:38:03.656458-06	2	[7346] IC-334A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
35ff7c87-f48f-493b-b703-30e29e8b1423	2018-02-28 08:38:03.67346-06	2	[7347] IC-415IC Call Button	[4] DLarrabee	[21062] a	\N	\N
f5a718ba-cc23-40e8-a354-d093e0e32931	2018-02-28 08:38:03.691462-06	2	[7348] IC-418IC Call Button	[4] DLarrabee	[21062] a	\N	\N
89be9052-27f7-447a-851f-9fc33b31d147	2018-02-28 08:38:03.707463-06	2	[7349] IC-425IC Call Button	[4] DLarrabee	[21062] a	\N	\N
53af1632-dd0d-43b7-8096-43ae6a474ddb	2018-02-28 08:38:03.720465-06	2	[7351] IC-329A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
ab3a2fe3-8f0f-4ccb-9d72-ec16a3c26d9f	2018-02-28 08:38:03.740467-06	2	[7352] IC-329B Relay	[4] DLarrabee	[21062] a	\N	\N
5ceb6408-d137-492b-a428-360645b5123d	2018-02-28 08:38:03.757468-06	2	[7353] IC-329B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
0b98ae12-08cb-4043-a23e-00fba8b3011b	2018-02-28 08:38:03.77247-06	2	[7354] IC-334A Relay	[4] DLarrabee	[21062] a	\N	\N
b7b9dd4b-4327-4b1a-9603-fab532bcf4bf	2018-02-28 08:38:03.786471-06	2	[7355] IC-334A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
a49b0726-6a3c-4471-bf46-4b151c1677cf	2018-02-28 08:38:03.805473-06	2	[7356] IC-415IC Relay	[4] DLarrabee	[21062] a	\N	\N
c0c9db0c-d4d4-4e13-b072-c01681701cc6	2018-02-28 08:38:03.825475-06	2	[7357] IC-418IC Relay	[4] DLarrabee	[21062] a	\N	\N
3578819d-7643-47fb-a9e5-6ffc00fc50f7	2018-02-28 08:38:03.846477-06	2	[7358] IC-425IC Relay	[4] DLarrabee	[21062] a	\N	\N
dd7f6fc5-3b95-466d-86cc-0f2aa76f234e	2018-02-28 08:38:03.849478-06	2	[7360] IC-329A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
93c54f70-91d1-468a-827c-82276903a0bd	2018-02-28 08:38:03.854478-06	2	[7361] IC-329B Connect	[4] DLarrabee	[21062] a	\N	\N
eb0a9668-ae64-4a44-9774-29816c74619a	2018-02-28 08:38:03.859479-06	2	[7362] IC-329B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
d8e4ad26-3f06-416d-b254-16f1ddb0cbf3	2018-02-28 08:38:03.863479-06	2	[7363] IC-334A Connect	[4] DLarrabee	[21062] a	\N	\N
53c598e7-7f57-40c1-8da5-29e6b73193d6	2018-02-28 08:38:03.86848-06	2	[7364] IC-334A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
36301edf-627d-4cad-b202-f6143a90fa91	2018-02-28 08:38:03.87248-06	2	[7365] IC-415IC Connect	[4] DLarrabee	[21062] a	\N	\N
2db98e3f-59eb-4595-b954-2682f9389523	2018-02-28 08:38:03.879481-06	2	[7366] IC-418IC Connect	[4] DLarrabee	[21062] a	\N	\N
7587245e-48e5-44c7-a560-d4fad7594a45	2018-02-28 08:38:03.883481-06	2	[7367] IC-425IC Connect	[4] DLarrabee	[21062] a	\N	\N
a86febfe-ffe3-4fc0-b978-de036edcb1b7	2018-02-28 08:38:03.887481-06	2	[7393] IC-329A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c2eea92b-abb3-4f22-9d39-43aad6dc7362	2018-02-28 08:38:03.890482-06	2	[7394] IC-329B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cf381c3d-207c-4906-80f7-cdc886febc96	2018-02-28 08:38:03.894482-06	2	[7395] IC-329B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f750ec90-473d-4e44-91fa-250bb49d557d	2018-02-28 08:38:03.897482-06	2	[7396] IC-334A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9fc9884c-4048-462a-98cd-3005d3817da2	2018-02-28 08:38:03.901483-06	2	[7397] IC-334A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b0a7a396-eb83-403b-8abe-14b265acb829	2018-02-28 08:38:03.905483-06	2	[7398] IC-415IC Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b0e6997f-1a35-4973-89c3-f1612b39d466	2018-02-28 08:38:03.909484-06	2	[7399] IC-418IC Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8cec7751-4270-4229-836f-b2cc7cf8cbbf	2018-02-28 08:38:03.912484-06	2	[7400] IC-425IC Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
76c02944-59ba-420b-9ece-5aeaac0ee0e7	2018-02-28 08:38:03.916484-06	2	[7412] IC-329A-outB Call	[4] DLarrabee	[21062] a	\N	\N
7157ece5-e5ad-4583-90f4-b800371ecada	2018-02-28 08:38:03.919485-06	2	[7413] IC-329B Call	[4] DLarrabee	[21062] a	\N	\N
6b1f12f6-9864-446d-b874-bd5417bc4a7b	2018-02-28 08:38:03.923485-06	2	[7414] IC-329B-outB Call	[4] DLarrabee	[21062] a	\N	\N
5caa7cb4-e267-47fe-851c-f435e9b91ff6	2018-02-28 08:38:03.927485-06	2	[7415] IC-334A Call	[4] DLarrabee	[21062] a	\N	\N
73996785-a057-4cd5-9b55-54221011b39a	2018-02-28 08:38:03.931486-06	2	[7416] IC-334A-outB Call	[4] DLarrabee	[21062] a	\N	\N
9a94ad90-d43f-4cf6-9604-99486bbb1d21	2018-02-28 08:38:03.936486-06	2	[7417] IC-415IC Call	[4] DLarrabee	[21062] a	\N	\N
7cd7bf07-82b3-4990-8919-831a6c9ebb77	2018-02-28 08:38:03.940487-06	2	[7418] IC-418IC Call	[4] DLarrabee	[21062] a	\N	\N
a9309fed-7149-4495-9979-7bdb1b83b608	2018-02-28 08:38:03.944487-06	2	[7419] IC-425IC Call	[4] DLarrabee	[21062] a	\N	\N
a5e28494-30c0-424c-969e-088da2c16cc8	2018-02-28 08:38:04.082501-06	2	[7780] R3C5-8IC	[4] DLarrabee	[21062] a	\N	\N
6523803b-8d18-4239-a10e-a049326d0394	2018-02-28 08:38:04.102503-06	2	[7782] IC-446IC Call Button	[4] DLarrabee	[21062] a	\N	\N
b4a4c0c3-e369-4385-b631-f241faa8e513	2018-02-28 08:38:04.142507-06	2	[7783] IC-448IC Call Button	[4] DLarrabee	[21062] a	\N	\N
d421b8b6-f2c1-4ee2-955d-ae61ea07660b	2018-02-28 08:38:04.157508-06	2	[7784] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
9ec38efe-7587-4919-8710-1b1176bb0b77	2018-02-28 08:38:04.17351-06	2	[7785] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
c88aa82d-583e-4636-a156-ac490a5caff5	2018-02-28 08:38:04.193512-06	2	[7786] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
8d9e188d-f59f-4117-b6fd-75e72f247c63	2018-02-28 08:38:04.208514-06	2	[7787] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
d2eea9f8-6979-4217-bea4-180004694e78	2018-02-28 08:38:04.221515-06	2	[7788] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
9d3a4dcf-72ea-489a-b81a-8cfbdc7c859d	2018-02-28 08:38:04.236516-06	2	[7789] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
91f884d4-aebf-49fd-be9d-ab526b53808f	2018-02-28 08:38:04.248518-06	2	[7791] IC-446IC Relay	[4] DLarrabee	[21062] a	\N	\N
49647e38-82ed-4b13-bfe2-5c7a3a119d85	2018-02-28 08:38:04.264519-06	2	[7792] IC-448IC Relay	[4] DLarrabee	[21062] a	\N	\N
01ed2483-737d-4b79-8f03-66f6b0d9c210	2018-02-28 08:38:04.278521-06	2	[7793] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
0ea652b7-14dc-4390-8eed-5bad3928455d	2018-02-28 08:38:04.298523-06	2	[7794] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
a285fa35-328b-422c-835c-525df8ebaec4	2018-02-28 08:38:04.313524-06	2	[7795] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
2147b7b4-7c73-44e5-9f92-8ac65c223caf	2018-02-28 08:38:04.325525-06	2	[7796] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
8fcb9eeb-8b51-4239-9b44-f65f135cd304	2018-02-28 08:38:04.339527-06	2	[7797] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
5f74644d-77af-4d60-bb08-4852be19b9b6	2018-02-28 08:38:04.359529-06	2	[7798] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
7696c0c8-464a-42a7-83f7-231088ffa6fb	2018-02-28 08:38:04.362529-06	2	[7800] IC-446IC Connect	[4] DLarrabee	[21062] a	\N	\N
95199862-5e3d-4e0d-b9f3-f2fb1123fa11	2018-02-28 08:38:04.365529-06	2	[7801] IC-448IC Connect	[4] DLarrabee	[21062] a	\N	\N
91fc5b88-cef9-4636-9be6-03ce53274eed	2018-02-28 08:38:04.36953-06	2	[7802] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
01588b70-2049-4629-98eb-0d4cf46c21b9	2018-02-28 08:38:04.37253-06	2	[7803] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
ba85eba9-868d-4282-bc79-f3ebd42126b6	2018-02-28 08:38:04.37653-06	2	[7804] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
bfde1388-aab5-4648-b1ac-b15f101a0d92	2018-02-28 08:38:04.378531-06	2	[7805] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
655be03e-f9f2-4a93-8151-86ffca60a1b3	2018-02-28 08:38:04.382531-06	2	[7806] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
27435ad6-1b35-42aa-959d-e138b1dd30ad	2018-02-28 08:38:04.385531-06	2	[7807] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
ae492a4f-3e53-40e1-a995-14918bdb1c54	2018-02-28 08:38:04.389532-06	2	[7833] IC-446IC Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
54f8cc11-83e5-4c0f-99db-4c81fd8e6ecf	2018-02-28 08:38:04.393532-06	2	[7834] IC-448IC Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2b2a19b5-f1c3-49e2-8f70-238648ca70fd	2018-02-28 08:38:04.397532-06	2	[7835] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
96143b87-6b37-4152-ad37-c9b4186bcbab	2018-02-28 08:38:04.401533-06	2	[7836] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d960e680-03d7-4038-a570-3ea15b5b07fc	2018-02-28 08:38:04.404533-06	2	[7837] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ac11f6f4-851a-4a72-b5b9-f7bf5bb1e7d6	2018-02-28 08:38:04.409534-06	2	[7838] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6c733718-00c8-4d8c-843d-c26d6d0a0944	2018-02-28 08:38:04.412534-06	2	[7839] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cdcc9d7d-91c4-4498-9ef5-e9e1ebec9e6b	2018-02-28 08:38:04.415534-06	2	[7840] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b0208619-aa1c-4a6f-a24c-3c18bc8019dc	2018-02-28 08:38:04.418535-06	2	[7852] IC-446IC Call	[4] DLarrabee	[21062] a	\N	\N
b44747de-5366-4755-a39e-c7e2fc69d17b	2018-02-28 08:38:04.421535-06	2	[7853] IC-448IC Call	[4] DLarrabee	[21062] a	\N	\N
ca2f6c3c-f9fe-414d-bf4e-d3bbe00ad53d	2018-02-28 08:38:04.424535-06	2	[7854] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
19728b55-2733-4b59-b689-361f9fb5ab1c	2018-02-28 08:38:04.428536-06	2	[7855] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
83ada74e-e8af-4bae-8b8b-de38fdbd5d75	2018-02-28 08:38:04.432536-06	2	[7856] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
183030eb-c71a-4d00-86f9-0ab5bd5eae1f	2018-02-28 08:38:04.436536-06	2	[7857] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
ee528b4b-d1fa-4223-b628-1e72ec5d7562	2018-02-28 08:38:04.439537-06	2	[7858] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
64598b00-1cea-4b13-93b5-2805297b2caf	2018-02-28 08:38:04.442537-06	2	[7859] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
7e58c63b-116c-4aef-85b1-bfd922803716	2018-02-28 08:41:37.715862-06	2	[1048] DPIS-326A Call Button	[4] DLarrabee	[21062] a	\N	\N
453f986d-4da6-4434-ab4c-0cb1a5881c59	2018-02-28 08:41:37.749866-06	2	[1049] DPIS-327A Call Button	[4] DLarrabee	[21062] a	\N	\N
8f894f35-22ed-494d-a6d2-174dd42d09f6	2018-02-28 08:41:37.764867-06	2	[1050] DPIS-329A Call Button	[4] DLarrabee	[21062] a	\N	\N
f89d9f31-5bc4-46e9-a3d6-3c63a1f2ccfb	2018-02-28 08:41:37.786869-06	2	[1051] DPIS-329B Call Button	[4] DLarrabee	[21062] a	\N	\N
ac31dcc7-e17c-4646-ac79-a083970a3e3e	2018-02-28 08:41:37.804871-06	2	[1052] DPIS-334A Call Button	[4] DLarrabee	[21062] a	\N	\N
d71b7f62-c336-4f74-a875-0ac192c57c2e	2018-02-28 08:41:37.819873-06	2	[1053] DPIS-335A Call Button	[4] DLarrabee	[21062] a	\N	\N
068b804c-8e8b-4da0-a078-e4577d1b2aca	2018-02-28 08:41:37.832874-06	2	[1054] DPIS-336A Call Button	[4] DLarrabee	[21062] a	\N	\N
29fbbf80-e93e-4207-974f-2ede6457bb40	2018-02-28 08:41:37.845875-06	2	[1063] DPIS-351A Call Button	[4] DLarrabee	[21062] a	\N	\N
a1442e51-9072-4cd5-bfac-1975426f4649	2018-02-28 08:41:37.860877-06	2	[1064] DPIS-351B Call Button	[4] DLarrabee	[21062] a	\N	\N
98da1e99-127b-4931-a870-ca1e4004ba8a	2018-02-28 08:41:37.875878-06	2	[1065] DPIS-352A Call Button	[4] DLarrabee	[21062] a	\N	\N
3d654c62-9795-4359-bb28-34c4cbb68fee	2018-02-28 08:41:37.88988-06	2	[1066] DPIS-405A Call Button	[4] DLarrabee	[21062] a	\N	\N
e2e0df57-c8cb-4ab1-950f-f6e36477f69f	2018-02-28 08:41:37.908881-06	2	[1067] DPIS-414A Call Button	[4] DLarrabee	[21062] a	\N	\N
29a57936-bd91-4750-8430-e1f6b8ed09ad	2018-02-28 08:41:37.924883-06	2	[1068] DPIS-414B Call Button	[4] DLarrabee	[21062] a	\N	\N
04d39611-8d40-4d92-9cb1-e9c4d17a52ea	2018-02-28 08:41:37.940885-06	2	[1069] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
f4ea1224-aaa6-45a8-bfda-e920bf970122	2018-02-28 08:41:37.959887-06	2	[1070] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
50cc65a3-0c2d-4c05-9830-b1917ab9cee4	2018-02-28 08:41:37.972888-06	2	[1071] DPIS-422A Call Button	[4] DLarrabee	[21062] a	\N	\N
78284296-0c61-4d78-9363-2da8cdc14763	2018-02-28 08:41:37.987889-06	2	[1072] DPIS-422B Call Button	[4] DLarrabee	[21062] a	\N	\N
9905840e-3228-4f95-bf2d-11a1a023feb3	2018-02-28 08:41:38.002891-06	2	[1073] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
d02d2652-5de3-49ab-a0ac-ae67f6a64eed	2018-02-28 08:41:38.019893-06	2	[1074] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
ad23f6f4-f247-444f-93ea-3017d068e731	2018-02-28 08:41:38.033894-06	2	[1075] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
0fce1c35-77ea-4449-8c38-d6134fad61a4	2018-02-28 08:41:38.064897-06	2	[1076] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
139b55a7-4bcd-4455-84b3-18abc77b1d6f	2018-02-28 08:41:38.080899-06	2	[1077] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
4bdfbe39-2164-4eb5-a6c1-550ac578c4e4	2018-02-28 08:41:38.103901-06	2	[1078] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
5bc09d4f-1ee6-47b7-9966-7ddc3a08e344	2018-02-28 08:44:42.560345-06	2	[8223] IC-134A-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
25de1809-6b96-4c72-a5ea-12286908fafd	2018-02-28 08:44:42.598349-06	2	[8232] IC-134A-InB Relay	[4] DLarrabee	[21062] a	\N	\N
ef1de0b2-fcdb-4ac6-97af-a09b3d91b391	2018-02-28 08:44:42.61535-06	2	[8233] IC-134A-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
3f82da78-63a2-4760-8a23-fe2229bbe3b0	2018-02-28 08:44:42.631352-06	2	[8234] IC-134B-InB Relay	[4] DLarrabee	[21062] a	\N	\N
38d8d2a3-55eb-4290-9ec0-4051fbcf9595	2018-02-28 08:44:42.647353-06	2	[8235] IC-134B-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
6192fad1-8c58-43d0-a7f8-8c83191974a6	2018-02-28 08:44:42.661355-06	2	[8236] IC-122-InB Relay	[4] DLarrabee	[21062] a	\N	\N
bb873ef8-649d-448f-8310-1a7df18a53fc	2018-02-28 08:44:42.678357-06	2	[8237] IC-122-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
a9ec6993-b7c5-4bf1-80d2-ae0e8225f816	2018-02-28 08:44:42.695358-06	2	[8238] IC-123-InB Relay	[4] DLarrabee	[21062] a	\N	\N
d0db335d-2bad-4d58-84d1-cb713fddc7b8	2018-02-28 08:44:42.71436-06	2	[8239] IC-123-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
c387a876-aa04-426c-b0b2-23e7a7b2ae3b	2018-02-28 08:44:42.718361-06	2	[8241] IC-134A-InB Connect	[4] DLarrabee	[21062] a	\N	\N
a7bfeae7-f61e-48e2-8584-4bd2293888b5	2018-02-28 08:44:42.722361-06	2	[8242] IC-134A-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
ad62d7b9-1365-4ff8-a6d1-15db93e0c318	2018-02-28 08:44:42.726361-06	2	[8243] IC-134B-InB Connect	[4] DLarrabee	[21062] a	\N	\N
eef35c7a-dd8b-45f0-93d7-b8d8514bad1c	2018-02-28 08:44:42.729362-06	2	[8244] IC-134B-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
631ff407-eed9-4643-bd7d-53907e9f4c3b	2018-02-28 08:44:42.733362-06	2	[8245] IC-122-InB Connect	[4] DLarrabee	[21062] a	\N	\N
7ff63ca2-6364-447c-944d-777a82af3a3a	2018-02-28 08:44:42.736362-06	2	[8246] IC-122-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
fc92533c-86ce-4962-8bde-08cd134efcf2	2018-02-28 08:44:42.741363-06	2	[8247] IC-123-InB Connect	[4] DLarrabee	[21062] a	\N	\N
1bb1b386-b194-4a0f-b961-376b1d3bca1f	2018-02-28 08:44:42.745363-06	2	[8248] IC-123-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
38f5cefb-f89f-4dc3-ae8c-e32ef8be53aa	2018-02-28 08:44:42.749364-06	2	[8274] IC-134A-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2d7e19ba-abcf-4751-957c-ea1504b66dde	2018-02-28 08:44:42.753364-06	2	[8275] IC-134A-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
222a3907-a7bc-4e05-ad89-f949b879d1ec	2018-02-28 08:44:42.756364-06	2	[8276] IC-134B-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f2502396-9394-44fc-a653-7e3d3857457b	2018-02-28 08:44:42.760365-06	2	[8277] IC-134B-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ff5c523b-3e90-40ec-b178-5798aa290a0e	2018-02-28 08:44:42.764365-06	2	[8278] IC-122-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fa5f7e0d-5367-4976-93b8-161df2d7ed43	2018-02-28 08:44:42.767365-06	2	[8279] IC-122-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6ea65e01-a24a-4983-a97c-7c0fb7b8e5c8	2018-02-28 08:44:42.771366-06	2	[8280] IC-123-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
03bb802e-5dc8-4969-bdbd-619ff3c0ffc9	2018-02-28 08:44:42.775366-06	2	[8281] IC-123-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
430877eb-9d0d-473f-b2fc-1dd5fab61490	2018-02-28 08:44:42.779367-06	2	[8293] IC-134A-InB Call	[4] DLarrabee	[21062] a	\N	\N
f7edcd66-b751-4c8d-b0d5-a9f0abbfe1b3	2018-02-28 08:44:42.783367-06	2	[8294] IC-134A-OutB Call	[4] DLarrabee	[21062] a	\N	\N
d7e7896d-9526-4591-8074-d307f9d05503	2018-02-28 08:44:42.786367-06	2	[8295] IC-134B-InB Call	[4] DLarrabee	[21062] a	\N	\N
654e04f2-3551-42ac-a171-3811d0e86382	2018-02-28 08:44:42.790368-06	2	[8296] IC-134B-OutB Call	[4] DLarrabee	[21062] a	\N	\N
cce654d6-3337-411b-a1b1-e215f73f36ff	2018-02-28 08:44:42.792368-06	2	[8297] IC-122-InB Call	[4] DLarrabee	[21062] a	\N	\N
d713d54e-46d1-4dda-9e7c-0cc2c114354b	2018-02-28 08:44:42.796368-06	2	[8298] IC-122-OutB Call	[4] DLarrabee	[21062] a	\N	\N
503de9e4-cf08-445b-8d67-d0d786af1b65	2018-02-28 08:44:42.799369-06	2	[8299] IC-123-InB Call	[4] DLarrabee	[21062] a	\N	\N
b31cece6-9684-4bea-b612-cd9613e6a208	2018-02-28 08:44:42.803369-06	2	[8300] IC-123-OutB Call	[4] DLarrabee	[21062] a	\N	\N
def61c08-627b-4ab9-913d-3cef8561b5d4	2018-02-28 08:44:42.931382-06	2	[8662] R4C2-8IC	[4] DLarrabee	[21062] a	\N	\N
4ec80233-85f5-461b-bbb6-07a91ff9d212	2018-02-28 08:44:42.947383-06	2	[8664] IC-136 Call Button	[4] DLarrabee	[21062] a	\N	\N
18551fc3-d2ea-4be5-8148-9448e0174e63	2018-02-28 08:44:42.963385-06	2	[8665] IC-137 Call Button	[4] DLarrabee	[21062] a	\N	\N
a76ed84f-5206-4e88-8c71-4ad8bf80a527	2018-02-28 08:44:42.981387-06	2	[8666] IC-138 Call Button	[4] DLarrabee	[21062] a	\N	\N
b90d94e3-9837-4b23-a94a-8b5a0c1d5a93	2018-02-28 08:44:42.996388-06	2	[8667] IC-141 Call Button	[4] DLarrabee	[21062] a	\N	\N
c67cb316-5a32-435b-9c34-eccadc13dd4c	2018-02-28 08:44:43.01039-06	2	[8668] IC-142 Call Button	[4] DLarrabee	[21062] a	\N	\N
0c5b5a3b-bc10-4797-a5a4-4455ee244e7f	2018-02-28 08:44:43.024391-06	2	[8669] IC-124 Call Button	[4] DLarrabee	[21062] a	\N	\N
86e79fe8-33bc-43a5-b433-ed3063475be2	2018-02-28 08:44:43.039393-06	2	[8670] IC-125 Call Button	[4] DLarrabee	[21062] a	\N	\N
46680fb5-e09c-4981-a341-4a6e62fdfc0c	2018-02-28 08:44:43.054394-06	2	[8671] IC-126 Call Button	[4] DLarrabee	[21062] a	\N	\N
29fca687-c578-4734-8a05-d3d0020e79ed	2018-02-28 08:44:43.071396-06	2	[8673] IC-136 Relay	[4] DLarrabee	[21062] a	\N	\N
b401e403-5fc8-4806-a751-42532f995ad5	2018-02-28 08:44:43.086397-06	2	[8674] IC-137 Relay	[4] DLarrabee	[21062] a	\N	\N
617e1b8e-3b78-44ee-8497-fda84ca6a4b1	2018-02-28 08:44:43.102399-06	2	[8675] IC-138 Relay	[4] DLarrabee	[21062] a	\N	\N
0291bc73-414d-488c-a97f-68e4bb99d9ce	2018-02-28 08:44:43.123401-06	2	[8676] IC-141 Relay	[4] DLarrabee	[21062] a	\N	\N
c788041f-b2ba-4cc3-ad19-d0552a7d14b1	2018-02-28 08:44:43.141403-06	2	[8677] IC-142 Relay	[4] DLarrabee	[21062] a	\N	\N
f2f1d20f-fedf-421d-9173-d9694332df76	2018-02-28 08:44:43.160405-06	2	[8678] IC-124 Relay	[4] DLarrabee	[21062] a	\N	\N
89b6ec9a-7999-4065-ac4b-7bc47ea97342	2018-02-28 08:44:43.178407-06	2	[8679] IC-125 Relay	[4] DLarrabee	[21062] a	\N	\N
e66a6484-b51d-4844-973a-588bd25f9d77	2018-02-28 08:44:43.194408-06	2	[8680] IC-126 Relay	[4] DLarrabee	[21062] a	\N	\N
4c000832-3909-4758-aaef-8594afe63564	2018-02-28 08:44:43.199409-06	2	[8682] IC-136 Connect	[4] DLarrabee	[21062] a	\N	\N
486e7501-0ccd-4bc4-af94-429c130d323a	2018-02-28 08:44:43.203409-06	2	[8683] IC-137 Connect	[4] DLarrabee	[21062] a	\N	\N
2a9f2055-8033-4b6b-af2a-3d4d7a2066ac	2018-02-28 08:44:43.20841-06	2	[8684] IC-138 Connect	[4] DLarrabee	[21062] a	\N	\N
96709a2d-5dd7-40fd-a714-ed7bf77db219	2018-02-28 08:44:43.21241-06	2	[8685] IC-141 Connect	[4] DLarrabee	[21062] a	\N	\N
c30cbeb0-13ea-4813-bd71-73a39e4dad90	2018-02-28 08:44:43.21641-06	2	[8686] IC-142 Connect	[4] DLarrabee	[21062] a	\N	\N
8613584e-3d00-46c0-a852-083a7c75d01f	2018-02-28 08:44:43.219411-06	2	[8687] IC-124 Connect	[4] DLarrabee	[21062] a	\N	\N
30a515d7-3a26-4278-8bea-5662cc4c7b3c	2018-02-28 08:44:43.222411-06	2	[8688] IC-125 Connect	[4] DLarrabee	[21062] a	\N	\N
b9e401e2-b3ac-4eba-9fa6-3493903686fc	2018-02-28 08:44:43.225411-06	2	[8689] IC-126 Connect	[4] DLarrabee	[21062] a	\N	\N
9887604f-064f-4e13-bbd0-c7c794ad3f9c	2018-02-28 08:44:43.227411-06	2	[8715] IC-136 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9fa6c8a8-c3b6-4f6e-a69c-081338d9adaa	2018-02-28 08:44:43.231412-06	2	[8716] IC-137 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3579cbbb-64b9-4e5e-af19-17d709b08346	2018-02-28 08:44:43.234412-06	2	[8717] IC-138 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
77bd38a5-214d-420c-bddb-b7474bc199c3	2018-02-28 08:44:43.237412-06	2	[8718] IC-141 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b287b424-3ec1-4a4f-85a2-832cbfe6b518	2018-02-28 08:44:43.240413-06	2	[8719] IC-142 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
70c67933-6926-4031-be9c-28858be4076f	2018-02-28 08:44:43.244413-06	2	[8720] IC-124 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
bccc9592-0548-49cf-b99a-a0efa95dea61	2018-02-28 08:44:43.247413-06	2	[8721] IC-125 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b2e79e15-26a3-4f61-a351-b651ed901799	2018-02-28 08:44:43.251414-06	2	[8722] IC-126 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
092c4d28-6205-44c8-b1a0-af9513ffbb32	2018-02-28 08:44:43.254414-06	2	[8734] IC-136 Call	[4] DLarrabee	[21062] a	\N	\N
8968cc00-1837-46f9-b8e7-1b5d6070da82	2018-02-28 08:44:43.256414-06	2	[8735] IC-137 Call	[4] DLarrabee	[21062] a	\N	\N
40b09a7e-e0e4-4535-8f07-b4621b3de225	2018-02-28 08:44:43.259415-06	2	[8736] IC-138 Call	[4] DLarrabee	[21062] a	\N	\N
75b0a372-ddcf-47d1-807b-287d07aa42d4	2018-02-28 08:44:43.263415-06	2	[8737] IC-141 Call	[4] DLarrabee	[21062] a	\N	\N
422344b1-b528-4a65-b821-f08b7db65702	2018-02-28 08:44:43.267415-06	2	[8738] IC-142 Call	[4] DLarrabee	[21062] a	\N	\N
45865b52-95f1-461f-9548-32aca062251d	2018-02-28 08:44:43.271416-06	2	[8739] IC-124 Call	[4] DLarrabee	[21062] a	\N	\N
a67321a2-acff-4289-a583-ad0c903bd7c5	2018-02-28 08:44:43.274416-06	2	[8740] IC-125 Call	[4] DLarrabee	[21062] a	\N	\N
b6b7b4fb-ae5a-42d2-a053-1de97862ec74	2018-02-28 08:44:43.278417-06	2	[8741] IC-126 Call	[4] DLarrabee	[21062] a	\N	\N
a696e455-7e47-48a1-847f-7a94f8851e2d	2018-02-28 08:44:43.429432-06	2	[9102] R4C3-8IC	[4] DLarrabee	[21062] a	\N	\N
93a83dc8-b62f-40a4-8cd6-f8e7e5ed322c	2018-02-28 08:44:43.448434-06	2	[9104] IC-128 Call Button	[4] DLarrabee	[21062] a	\N	\N
7e87835c-12c1-439e-8eb9-bef1e29db49d	2018-02-28 08:44:43.461435-06	2	[9105] IC-129 Call Button	[4] DLarrabee	[21062] a	\N	\N
df08cc8f-a13f-4e94-8565-7d3d823b6b87	2018-02-28 08:44:43.480437-06	2	[9106] IC-131 Call Button	[4] DLarrabee	[21062] a	\N	\N
a34aa477-f1e6-4f72-bfba-2bb8523fb335	2018-02-28 08:44:43.495438-06	2	[9107] IC-132 Call Button	[4] DLarrabee	[21062] a	\N	\N
08be0a7f-44f6-421d-8062-0db4a039a3a5	2018-02-28 08:44:43.51344-06	2	[9108] IC-115 Call Button	[4] DLarrabee	[21062] a	\N	\N
bad083d4-ce9e-4e8c-a267-2bff0edc9e64	2018-02-28 08:44:43.528442-06	2	[9109] IC-116 Call Button	[4] DLarrabee	[21062] a	\N	\N
60978938-ef48-4420-84ba-442ffe3c1c20	2018-02-28 08:44:43.543443-06	2	[9110] IC-117 Call Button	[4] DLarrabee	[21062] a	\N	\N
e41e1bc2-d1c7-446a-96d7-223f3a7024db	2018-02-28 08:44:43.559445-06	2	[9111] IC-119 Call Button	[4] DLarrabee	[21062] a	\N	\N
dd17286a-8a7e-43b0-8a1c-f0ebf76155bc	2018-02-28 08:44:43.577446-06	2	[9113] IC-128 Relay	[4] DLarrabee	[21062] a	\N	\N
d3c73223-77ec-4d57-9a30-808cf56a45a7	2018-02-28 08:44:43.592448-06	2	[9114] IC-129 Relay	[4] DLarrabee	[21062] a	\N	\N
a64e110e-d932-44a6-a76b-bbdd08bd9589	2018-02-28 08:44:43.60945-06	2	[9115] IC-131 Relay	[4] DLarrabee	[21062] a	\N	\N
1c48b455-40f1-4bae-bc57-6249e4cec753	2018-02-28 08:44:43.625451-06	2	[9116] IC-132 Relay	[4] DLarrabee	[21062] a	\N	\N
e0bfc60e-028d-4f54-a75a-c428871dd6d2	2018-02-28 08:44:43.637452-06	2	[9117] IC-115 Relay	[4] DLarrabee	[21062] a	\N	\N
e0932a2e-636e-4e63-b92d-84bdb342673d	2018-02-28 08:44:43.655454-06	2	[9118] IC-116 Relay	[4] DLarrabee	[21062] a	\N	\N
f4e2bc21-b99c-4b04-9261-c2bbf94432f0	2018-02-28 08:44:43.669456-06	2	[9119] IC-117 Relay	[4] DLarrabee	[21062] a	\N	\N
d1118b3c-ef47-4826-99c0-9685136a9228	2018-02-28 08:44:43.684457-06	2	[9120] IC-119 Relay	[4] DLarrabee	[21062] a	\N	\N
d29279ea-f211-49d0-856f-9c9c7bedd4eb	2018-02-28 08:44:43.688458-06	2	[9122] IC-128 Connect	[4] DLarrabee	[21062] a	\N	\N
87c9b8d6-b6e6-4b87-accf-14b5d45a64fd	2018-02-28 08:44:43.691458-06	2	[9123] IC-129 Connect	[4] DLarrabee	[21062] a	\N	\N
0c04efbc-ad99-45c3-ae75-d03486ec8272	2018-02-28 08:44:43.694458-06	2	[9124] IC-131 Connect	[4] DLarrabee	[21062] a	\N	\N
499f3dde-7961-4e19-bd8f-2615e22d7638	2018-02-28 08:44:43.698459-06	2	[9125] IC-132 Connect	[4] DLarrabee	[21062] a	\N	\N
acf85a82-742e-47d1-b70c-e9a971e7b039	2018-02-28 08:44:43.702459-06	2	[9126] IC-115 Connect	[4] DLarrabee	[21062] a	\N	\N
14494606-b2f9-4e0e-bfab-e4816f2dc2ca	2018-02-28 08:44:43.705459-06	2	[9127] IC-116 Connect	[4] DLarrabee	[21062] a	\N	\N
ef773ce4-a43b-4eca-ba8a-da4b4da1aa2a	2018-02-28 08:44:43.70946-06	2	[9128] IC-117 Connect	[4] DLarrabee	[21062] a	\N	\N
a52781a5-75dc-45ac-848d-e674330e3cfc	2018-02-28 08:44:43.71346-06	2	[9129] IC-119 Connect	[4] DLarrabee	[21062] a	\N	\N
148f2faf-3459-4f3d-bdd6-b0c0488bda55	2018-02-28 08:44:43.71746-06	2	[9155] IC-128 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a6762b7e-13c3-48cf-9152-e71da7ffc8ef	2018-02-28 08:44:43.720461-06	2	[9156] IC-129 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c7bf6f74-125d-496f-85b4-d34a830580db	2018-02-28 08:44:43.723461-06	2	[9157] IC-131 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0a9eb90e-838f-4598-bb04-2e1181ad4fcf	2018-02-28 08:44:43.726461-06	2	[9158] IC-132 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ce83eaef-2097-4c46-abc6-eaa42278eaaa	2018-02-28 08:44:43.729462-06	2	[9159] IC-115 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cadb4027-1173-4a36-8f82-c4cb5a0a8ac4	2018-02-28 08:44:43.732462-06	2	[9160] IC-116 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e68956c5-fa5e-4502-b7e4-7fbdd11b1bbe	2018-02-28 08:44:43.735462-06	2	[9161] IC-117 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0964c517-ca48-4256-893d-791361f7847b	2018-02-28 08:44:43.738463-06	2	[9162] IC-119 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e7d53b1e-5f65-4927-8a35-b54097aba38a	2018-02-28 08:44:43.741463-06	2	[9174] IC-128 Call	[4] DLarrabee	[21062] a	\N	\N
10d4a672-82b0-4fdd-b5bd-be0c5364e785	2018-02-28 08:44:43.744463-06	2	[9175] IC-129 Call	[4] DLarrabee	[21062] a	\N	\N
31f40b11-950c-48eb-8769-839661c63c46	2018-02-28 08:44:43.748464-06	2	[9176] IC-131 Call	[4] DLarrabee	[21062] a	\N	\N
40cbd762-a9bd-4540-99d4-d437474d8ed3	2018-02-28 08:44:43.751464-06	2	[9177] IC-132 Call	[4] DLarrabee	[21062] a	\N	\N
a0e5a0d5-e08f-4953-9973-4d59fb31f52c	2018-02-28 08:44:43.755464-06	2	[9178] IC-115 Call	[4] DLarrabee	[21062] a	\N	\N
9963a2bd-288e-432d-b29b-7b74c5ca9d85	2018-02-28 08:44:43.759465-06	2	[9179] IC-116 Call	[4] DLarrabee	[21062] a	\N	\N
8998fb21-f6db-4a14-9a5e-031abf829350	2018-02-28 08:44:43.762465-06	2	[9180] IC-117 Call	[4] DLarrabee	[21062] a	\N	\N
c0dd3326-4de1-4f9d-ac4d-17f8f638d743	2018-02-28 08:44:43.764465-06	2	[9181] IC-119 Call	[4] DLarrabee	[21062] a	\N	\N
b9e63ab0-c825-49ad-b138-79770bcad670	2018-02-28 08:44:43.901479-06	2	[9542] R4C4-8IC	[4] DLarrabee	[21062] a	\N	\N
904ccd6e-1451-48b9-8d09-ca1ccba06ae7	2018-02-28 08:44:43.91648-06	2	[9544] IC-121 Call Button	[4] DLarrabee	[21062] a	\N	\N
e3421032-fb77-4cd8-9ce0-2065a0b556f3	2018-02-28 08:44:43.928482-06	2	[9545] IC-114A-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
e5d49bf7-942a-40cf-840b-e9056f4f3fbf	2018-02-28 08:44:43.942483-06	2	[9546] IC-114A-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
2a4ee9e0-0192-40d7-a8d3-51d33aaad5f7	2018-02-28 08:44:43.958485-06	2	[9547] IC-114B-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
ffeffe8b-e0c6-4a37-892a-8f2120e9086f	2018-02-28 08:44:43.976486-06	2	[9548] IC-114B-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
63c89944-37e6-4c2a-b2f2-d116311600c6	2018-02-28 08:44:43.995488-06	2	[9549] IC-103 Call Button	[4] DLarrabee	[21062] a	\N	\N
424686f8-209d-4522-8722-92d341ce074a	2018-02-28 08:44:44.00849-06	2	[9550] IC-104 Call Button	[4] DLarrabee	[21062] a	\N	\N
f3840db6-3936-4e93-ba6b-312571c147e9	2018-02-28 08:44:44.021491-06	2	[9551] IC-105 Call Button	[4] DLarrabee	[21062] a	\N	\N
d97251ef-484e-46ad-ad90-49631ed16f9c	2018-02-28 08:44:44.034492-06	2	[9553] IC-121 Relay	[4] DLarrabee	[21062] a	\N	\N
a97567fc-f04d-41b2-b72a-c98c91be4622	2018-02-28 08:44:44.049494-06	2	[9554] IC-114A-InB Relay	[4] DLarrabee	[21062] a	\N	\N
c8208413-7615-4efa-a1f9-731b482343bd	2018-02-28 08:44:44.066495-06	2	[9555] IC-114A-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
c7b1b5e9-1be1-4288-a256-2876d2a2fec4	2018-02-28 08:44:44.081497-06	2	[9556] IC-114B-InB Relay	[4] DLarrabee	[21062] a	\N	\N
29585c15-2441-44d0-9097-81e3be18c07f	2018-02-28 08:44:44.098499-06	2	[9557] IC-114B-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
f76f6eeb-42ba-46d9-982f-6486cf52b44b	2018-02-28 08:44:44.1155-06	2	[9558] IC-103 Relay	[4] DLarrabee	[21062] a	\N	\N
cffb846c-2a45-41f1-b2db-25abbd6c1cfe	2018-02-28 08:44:44.178507-06	2	[9559] IC-104 Relay	[4] DLarrabee	[21062] a	\N	\N
30045a33-0ade-47f6-9252-0d1fc2550866	2018-02-28 08:44:44.192508-06	2	[9560] IC-105 Relay	[4] DLarrabee	[21062] a	\N	\N
14995abf-176e-4851-a6cb-1591d73b64ec	2018-02-28 08:44:44.197508-06	2	[9562] IC-121 Connect	[4] DLarrabee	[21062] a	\N	\N
b46b1e1b-0862-4c0a-a141-3c1179fa7955	2018-02-28 08:44:44.200509-06	2	[9563] IC-114A-InB Connect	[4] DLarrabee	[21062] a	\N	\N
7690cdb9-7375-4c54-9ecd-7030ef4eae70	2018-02-28 08:44:44.204509-06	2	[9564] IC-114A-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
346d55ba-1cfa-4b8b-a858-91b208315f6a	2018-02-28 08:44:44.20951-06	2	[9565] IC-114B-InB Connect	[4] DLarrabee	[21062] a	\N	\N
15cd0886-2caf-426c-a38a-fed31b14a857	2018-02-28 08:44:44.21451-06	2	[9566] IC-114B-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
15f14470-4075-4b3c-9f51-c447e3209133	2018-02-28 08:44:44.219511-06	2	[9567] IC-103 Connect	[4] DLarrabee	[21062] a	\N	\N
bc11fe12-1f14-45b3-811d-898df091eea5	2018-02-28 08:44:44.223511-06	2	[9568] IC-104 Connect	[4] DLarrabee	[21062] a	\N	\N
e09d296c-45b3-48c1-ba92-c1afb59be09e	2018-02-28 08:44:44.227511-06	2	[9569] IC-105 Connect	[4] DLarrabee	[21062] a	\N	\N
1c42d3af-c68c-4614-8707-91e325eeb2ad	2018-02-28 08:44:44.231512-06	2	[9595] IC-121 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
75a9726e-82fe-41a9-9281-85d8db095e09	2018-02-28 08:44:44.234512-06	2	[9596] IC-114A-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f6422463-f573-44e9-ab7e-51c3fa3db53c	2018-02-28 08:44:44.237512-06	2	[9597] IC-114A-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a04d13a5-584f-482e-91ff-28f8f1b70a8b	2018-02-28 08:44:44.240513-06	2	[9598] IC-114B-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2a56fe57-b6b0-480f-a767-0fb274da36e0	2018-02-28 08:44:44.243513-06	2	[9599] IC-114B-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4b91a2c7-ddc3-4afe-8f8f-82fe305a6f83	2018-02-28 08:44:44.246513-06	2	[9600] IC-103 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9d17ee03-3e8f-408f-b042-5b36e34592a5	2018-02-28 08:44:44.250514-06	2	[9601] IC-104 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fda1d173-03aa-4b55-89ac-12e018d53f90	2018-02-28 08:44:44.253514-06	2	[9602] IC-105 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
414000ff-13fb-4ccd-a7aa-c4b06790abdb	2018-02-28 08:44:44.257514-06	2	[9614] IC-121 Call	[4] DLarrabee	[21062] a	\N	\N
18915b57-ffc7-4a3e-be0e-acdf09542f8a	2018-02-28 08:44:44.260515-06	2	[9615] IC-114A-InB Call	[4] DLarrabee	[21062] a	\N	\N
0fc52616-7ea9-4acc-aee8-cd9f599924fc	2018-02-28 08:44:44.263515-06	2	[9616] IC-114A-OutB Call	[4] DLarrabee	[21062] a	\N	\N
f17fcbad-b984-456b-8877-8d6e256e6435	2018-02-28 08:44:44.266515-06	2	[9617] IC-114B-InB Call	[4] DLarrabee	[21062] a	\N	\N
613b4825-fa4c-45ed-8dab-38a0d193a1d6	2018-02-28 08:44:44.270516-06	2	[9618] IC-114B-OutB Call	[4] DLarrabee	[21062] a	\N	\N
26c1ff72-71f8-4a5e-98df-c2f684d881c8	2018-02-28 08:44:44.273516-06	2	[9619] IC-103 Call	[4] DLarrabee	[21062] a	\N	\N
55792135-3e2d-49cd-a2e0-2bd9cc00ef8a	2018-02-28 08:44:44.277516-06	2	[9620] IC-104 Call	[4] DLarrabee	[21062] a	\N	\N
c297d73a-46a3-4d58-8800-1f4a69c866b3	2018-02-28 08:44:44.280517-06	2	[9621] IC-105 Call	[4] DLarrabee	[21062] a	\N	\N
c6d2a1fb-421a-4b97-b2c3-0b8a956655fd	2018-02-28 08:44:44.422531-06	2	[9982] R4C5-8IC	[4] DLarrabee	[21062] a	\N	\N
616b6294-e540-4980-b467-f763f0e1bd02	2018-02-28 08:44:44.437532-06	2	[9984] IC-107 Call Button	[4] DLarrabee	[21062] a	\N	\N
11e624e8-bada-49bd-9b2f-dcd1094cfa7f	2018-02-28 08:44:44.454534-06	2	[9985] IC-108 Call Button	[4] DLarrabee	[21062] a	\N	\N
c25fdc9c-ca6c-4034-b7ed-df51aa1987fc	2018-02-28 08:44:44.469536-06	2	[9986] IC-109 Call Button	[4] DLarrabee	[21062] a	\N	\N
bacf1ecc-3316-4d0c-8f52-a618733ae45b	2018-02-28 08:44:44.482537-06	2	[9987] IC-112 Call Button	[4] DLarrabee	[21062] a	\N	\N
0f97733c-8515-4736-8ef2-f03b4cebe06b	2018-02-28 08:44:44.496538-06	2	[9988] IC-113-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
e6f0ca27-2912-42c5-a4e2-edd6379e09b7	2018-02-28 08:44:44.51254-06	2	[9989] IC-113-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
f7eb21c4-c519-434f-91ec-d24e3d30a257	2018-02-28 08:44:44.526541-06	2	[9990] IC-133-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
1264bc79-0243-45b0-96b6-dd09b874370d	2018-02-28 08:44:44.546543-06	2	[9991] IC-133-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
a85b1993-0e1f-410f-babd-04795f0da03e	2018-02-28 08:44:44.563545-06	2	[9993] IC-107 Relay	[4] DLarrabee	[21062] a	\N	\N
6ab8a8a4-1989-4aef-9d08-ce9ff230f28b	2018-02-28 08:44:44.579547-06	2	[9994] IC-108 Relay	[4] DLarrabee	[21062] a	\N	\N
9ad59b98-b8df-48c2-a02a-56a3b518bb71	2018-02-28 08:44:44.596548-06	2	[9995] IC-109 Relay	[4] DLarrabee	[21062] a	\N	\N
d3590a4a-3116-4785-9f7e-4473964cb909	2018-02-28 08:44:44.61355-06	2	[9996] IC-112 Relay	[4] DLarrabee	[21062] a	\N	\N
92184bcb-f391-469f-99b8-36da4c09da1b	2018-02-28 08:44:44.629552-06	2	[9997] IC-113-InB Relay	[4] DLarrabee	[21062] a	\N	\N
34ecaf7a-5f10-4091-97e1-6d4b766cfc15	2018-02-28 08:44:44.643553-06	2	[9998] IC-113-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
07a21975-2fd6-45c3-8f21-21732a2f87f2	2018-02-28 08:44:44.658555-06	2	[9999] IC-133-InB Relay	[4] DLarrabee	[21062] a	\N	\N
150a7ad5-9038-40c5-a5d7-4aaf51fdc345	2018-02-28 08:44:44.672556-06	2	[10000] IC-133-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
5a37b404-801a-4796-94a0-261d7662c090	2018-02-28 08:44:44.675556-06	2	[10002] IC-107 Connect	[4] DLarrabee	[21062] a	\N	\N
9096d066-2f5d-491f-955a-00b62e81386e	2018-02-28 08:44:44.678557-06	2	[10003] IC-108 Connect	[4] DLarrabee	[21062] a	\N	\N
8e6e6897-a2e1-4f94-8628-b64395af1037	2018-02-28 08:44:44.681557-06	2	[10004] IC-109 Connect	[4] DLarrabee	[21062] a	\N	\N
eb0fcff1-02d4-467d-8163-9f3eec953869	2018-02-28 08:44:44.684557-06	2	[10005] IC-112 Connect	[4] DLarrabee	[21062] a	\N	\N
5c3d31e7-1e84-4937-8856-beed8880cc4f	2018-02-28 08:44:44.688558-06	2	[10006] IC-113-InB Connect	[4] DLarrabee	[21062] a	\N	\N
990aee83-2823-4b7a-985c-a04de31f86ae	2018-02-28 08:44:44.691558-06	2	[10007] IC-113-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
5365feeb-d2de-4af4-b5ee-26a9bf55558b	2018-02-28 08:44:44.695558-06	2	[10008] IC-133-InB Connect	[4] DLarrabee	[21062] a	\N	\N
de2d733d-c20e-4442-ad92-2c6ccc3cc865	2018-02-28 08:44:44.699559-06	2	[10009] IC-133-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
f7ec6718-8b68-484b-bfdd-b261c2bcf55a	2018-02-28 08:44:44.702559-06	2	[10035] IC-107 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b35156da-0712-4669-856e-c20f699c082a	2018-02-28 08:44:44.706559-06	2	[10036] IC-108 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a2bc88b7-7967-4615-aa59-724a763b73d3	2018-02-28 08:44:44.70956-06	2	[10037] IC-109 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8591ad2a-442b-41b8-bfcf-f5ad863b690f	2018-02-28 08:44:44.71256-06	2	[10038] IC-112 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0678256d-77ab-4ed8-82cc-0de8e833ea7f	2018-02-28 08:44:44.71556-06	2	[10039] IC-113-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2334eec8-b616-4f58-9819-b9548027b23b	2018-02-28 08:44:44.718561-06	2	[10040] IC-113-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
11fff6de-37ef-4044-806b-a3d9c849ea49	2018-02-28 08:44:44.722561-06	2	[10041] IC-133-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
584b35d1-f30b-44bd-90b3-dc0c924da9c9	2018-02-28 08:44:44.725561-06	2	[10042] IC-133-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ab9bffcf-98af-48d4-b69d-f6b535a1df51	2018-02-28 08:44:44.729562-06	2	[10054] IC-107 Call	[4] DLarrabee	[21062] a	\N	\N
f70cdcb7-7b85-403b-880e-9a8ba839ae3b	2018-02-28 08:44:44.733562-06	2	[10055] IC-108 Call	[4] DLarrabee	[21062] a	\N	\N
c5d97ba8-34ce-41ab-958c-0745f080cac7	2018-02-28 08:44:44.736562-06	2	[10056] IC-109 Call	[4] DLarrabee	[21062] a	\N	\N
18ed9e8e-2db5-46a7-87e2-6e7f4f210a9c	2018-02-28 08:44:44.739563-06	2	[10057] IC-112 Call	[4] DLarrabee	[21062] a	\N	\N
714dae5f-1daf-4a0c-b0d0-7547058a61c2	2018-02-28 08:44:44.742563-06	2	[10058] IC-113-InB Call	[4] DLarrabee	[21062] a	\N	\N
343c4531-6c6a-40bc-80ab-63ad9e20ab01	2018-02-28 08:44:44.745563-06	2	[10059] IC-113-OutB Call	[4] DLarrabee	[21062] a	\N	\N
1cc11edf-0746-4013-b6c4-d9a5581acf9b	2018-02-28 08:44:44.748564-06	2	[10060] IC-133-InB Call	[4] DLarrabee	[21062] a	\N	\N
61db83f3-7202-40d1-b6f8-99a51a7cfdc8	2018-02-28 08:44:44.752564-06	2	[10061] IC-133-OutB Call	[4] DLarrabee	[21062] a	\N	\N
ee915394-4f06-4d29-acdb-6764918ee663	2018-02-28 08:44:44.869576-06	2	[10422] R4C6-8IC	[4] DLarrabee	[21062] a	\N	\N
a5069bd0-f9e1-4977-b005-6e1a3e620928	2018-02-28 08:44:44.888578-06	2	[10424] IC-145-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
d95b0f35-7564-43bd-b451-cea7431c7c2d	2018-02-28 08:44:44.902579-06	2	[10425] IC-145-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
07a9a4a4-b2e4-46d4-9dae-849fb12d8cbf	2018-02-28 08:44:44.91758-06	2	[10426] IC-146-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
7239ba96-81a8-4b0d-a418-6cf6ac89bef4	2018-02-28 08:44:44.931582-06	2	[10427] IC-146-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
21e0dd8f-2bf7-4a48-99e0-551a0e305f77	2018-02-28 08:44:44.945583-06	2	[10428] IC-156-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
ff717d59-f1ab-4c79-b1b9-60734efebfcf	2018-02-28 08:44:44.962585-06	2	[10429] IC-156-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
a8460964-a450-431e-8b36-bd3dab6d6975	2018-02-28 08:44:44.979587-06	2	[10430] IC-201 Call Button	[4] DLarrabee	[21062] a	\N	\N
b7a30e67-b906-43a2-9b98-000c0715b457	2018-02-28 08:44:44.994588-06	2	[10431] IC-202 Call Button	[4] DLarrabee	[21062] a	\N	\N
83a746a2-985f-4395-bfec-16137f340ce2	2018-02-28 08:44:45.00859-06	2	[10433] IC-145-InB Relay	[4] DLarrabee	[21062] a	\N	\N
5b03cea9-4ec4-43ec-bea7-3abe6c647df4	2018-02-28 08:44:45.023591-06	2	[10434] IC-145-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
65129bb0-146a-432f-85f2-15ff2171add4	2018-02-28 08:44:45.036592-06	2	[10435] IC-146-InB Relay	[4] DLarrabee	[21062] a	\N	\N
42b0ca2f-0b3c-40ad-a30c-661f9f8c3eae	2018-02-28 08:44:45.049594-06	2	[10436] IC-146-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
7b3b048d-8074-4497-88cc-957551758d9c	2018-02-28 08:44:45.064595-06	2	[10437] IC-156-InB Relay	[4] DLarrabee	[21062] a	\N	\N
ef98e28a-6dba-44c2-a1d1-0c3c3e634b65	2018-02-28 08:44:45.078597-06	2	[10438] IC-156-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
0566abcb-5aaf-4291-8d47-d9bcb8b309ea	2018-02-28 08:44:45.096598-06	2	[10439] IC-201 Relay	[4] DLarrabee	[21062] a	\N	\N
061fd55d-e01d-4fd0-b816-63434a5d95eb	2018-02-28 08:44:45.1116-06	2	[10440] IC-202 Relay	[4] DLarrabee	[21062] a	\N	\N
fa88885a-58e0-4369-b42f-a72d88e8ab46	2018-02-28 08:44:45.1156-06	2	[10442] IC-145-InB Connect	[4] DLarrabee	[21062] a	\N	\N
58617c43-ce80-406f-a0cd-ccfab57782a6	2018-02-28 08:44:45.118601-06	2	[10443] IC-145-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
2543f374-4aa9-441f-ba0e-dfa30043a66a	2018-02-28 08:44:45.122601-06	2	[10444] IC-146-InB Connect	[4] DLarrabee	[21062] a	\N	\N
9a2ebd97-9e15-43c8-92f3-9e002b98adc7	2018-02-28 08:44:45.125601-06	2	[10445] IC-146-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
fd09e0ed-8fab-48ca-afe7-8f3234098d5a	2018-02-28 08:44:45.129602-06	2	[10446] IC-156-InB Connect	[4] DLarrabee	[21062] a	\N	\N
c7214e04-46c7-4a19-82c3-b0834dbd4c07	2018-02-28 08:44:45.133602-06	2	[10447] IC-156-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
94531dbd-b005-4733-b522-5d45bdb449a5	2018-02-28 08:44:45.137602-06	2	[10448] IC-201 Connect	[4] DLarrabee	[21062] a	\N	\N
0152238a-a618-4102-bf09-4751b10b2107	2018-02-28 08:44:45.141603-06	2	[10449] IC-202 Connect	[4] DLarrabee	[21062] a	\N	\N
de496376-32c4-4637-bed3-cde85b58e8bf	2018-02-28 08:44:45.144603-06	2	[10475] IC-145-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
758612e7-3c8d-4777-90fd-eeb60ab1d97b	2018-02-28 08:44:45.148604-06	2	[10476] IC-145-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
00ce260f-4214-4c54-a302-69a3155e1757	2018-02-28 08:44:45.151604-06	2	[10477] IC-146-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
bfab769d-84a1-4eff-97d3-7d7504f0e4bc	2018-02-28 08:44:45.154604-06	2	[10478] IC-146-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c3153e38-4841-4b59-b2a7-b54f71119ffc	2018-02-28 08:44:45.158605-06	2	[10479] IC-156-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7d989f41-4174-431b-9daa-d1682df4a9ca	2018-02-28 08:44:45.161605-06	2	[10480] IC-156-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6ba02ff9-f2cf-4597-8ee5-541cb2b77dc2	2018-02-28 08:44:45.165605-06	2	[10481] IC-201 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b7a2ef54-2ffe-4485-936e-657a7b7b056f	2018-02-28 08:44:45.168606-06	2	[10482] IC-202 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b5863fe4-693e-401a-8924-22c80e237179	2018-02-28 08:44:45.171606-06	2	[10494] IC-145-InB Call	[4] DLarrabee	[21062] a	\N	\N
5385d66b-b8be-4f5f-beb3-55f6c583eb23	2018-02-28 08:44:45.175606-06	2	[10495] IC-145-OutB Call	[4] DLarrabee	[21062] a	\N	\N
c8bcc1d9-de6c-47a0-b0c9-a17e9e0df467	2018-02-28 08:44:45.179607-06	2	[10496] IC-146-InB Call	[4] DLarrabee	[21062] a	\N	\N
dac10462-9cf9-4731-929c-5c65d8253dba	2018-02-28 08:44:45.182607-06	2	[10497] IC-146-OutB Call	[4] DLarrabee	[21062] a	\N	\N
8db34b67-baca-4a92-bd03-f60b8ec0b997	2018-02-28 08:44:45.185607-06	2	[10498] IC-156-InB Call	[4] DLarrabee	[21062] a	\N	\N
18635f78-0003-4dc6-ac6f-b7e2aa9f495f	2018-02-28 08:44:45.188608-06	2	[10499] IC-156-OutB Call	[4] DLarrabee	[21062] a	\N	\N
1b0a3f70-970b-429d-a606-3f9e54b54e3e	2018-02-28 08:44:45.192608-06	2	[10500] IC-201 Call	[4] DLarrabee	[21062] a	\N	\N
3d8d042c-cc9a-40fb-acaf-cb8f8244f0bd	2018-02-28 08:44:45.195608-06	2	[10501] IC-202 Call	[4] DLarrabee	[21062] a	\N	\N
553d5827-8dae-4c94-ba7d-47e51dd859bb	2018-02-28 08:44:45.30962-06	2	[10862] R4C7-8IC	[4] DLarrabee	[21062] a	\N	\N
b7558bde-2e95-4b82-b46a-559e8ffa40f8	2018-02-28 08:44:45.325621-06	2	[10864] IC-203 Call Button	[4] DLarrabee	[21062] a	\N	\N
991393fe-8ea9-404b-ad86-d2a6dfdc4b54	2018-02-28 08:44:45.337622-06	2	[10865] IC-205 Call Button	[4] DLarrabee	[21062] a	\N	\N
44aa6c2e-692f-4c4e-9ebe-b779983b4d8a	2018-02-28 08:44:45.355624-06	2	[10866] IC-206 Call Button	[4] DLarrabee	[21062] a	\N	\N
b48c3822-1cbb-4278-b927-7b2eeb44aa3e	2018-02-28 08:44:45.369626-06	2	[10867] IC-207 Call Button	[4] DLarrabee	[21062] a	\N	\N
d0faa390-8db0-4fc9-a755-0f9734addecf	2018-02-28 08:44:45.384627-06	2	[10868] IC-209A-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
8faa3985-66e2-4eaa-9aa4-959c9c36df54	2018-02-28 08:44:45.404629-06	2	[10869] IC-209A-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
4c7cd888-a4ce-4925-b374-a68a73a09b9f	2018-02-28 08:44:45.41663-06	2	[10870] IC-209B-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
1b451575-8af6-49cc-8546-cac8c1c22683	2018-02-28 08:44:45.434632-06	2	[10871] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
2a920963-b1c0-4a33-bbd6-47ceb47d045d	2018-02-28 08:44:45.449634-06	2	[10873] IC-203 Relay	[4] DLarrabee	[21062] a	\N	\N
81f4eec0-4920-41ba-a76f-996a40296b7f	2018-02-28 08:44:45.469636-06	2	[10874] IC-205 Relay	[4] DLarrabee	[21062] a	\N	\N
c38edd66-b63d-421c-852a-c207074a6a08	2018-02-28 08:44:45.488638-06	2	[10875] IC-206 Relay	[4] DLarrabee	[21062] a	\N	\N
0064ee4c-bc1c-4cd5-809a-e50299d5ca3c	2018-02-28 08:44:45.504639-06	2	[10876] IC-207 Relay	[4] DLarrabee	[21062] a	\N	\N
3b70cb40-a300-4fcb-b69d-2fc2af43622a	2018-02-28 08:44:45.518641-06	2	[10877] IC-209A-InB Relay	[4] DLarrabee	[21062] a	\N	\N
e6379008-32f5-45bf-8b95-9fcb63511d39	2018-02-28 08:44:45.534642-06	2	[10878] IC-209A-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
1fb0f4d6-9d81-419a-b231-73e11a34857a	2018-02-28 08:44:45.554644-06	2	[10879] IC-209B-InB Relay	[4] DLarrabee	[21062] a	\N	\N
18c83d94-b3a5-448c-8922-930e65d3ce8e	2018-02-28 08:44:45.568646-06	2	[10880] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
5a9435b4-e389-4367-ab06-cc5a55cab158	2018-02-28 08:44:45.571646-06	2	[10882] IC-203 Connect	[4] DLarrabee	[21062] a	\N	\N
0cc0cad3-883f-480e-8121-3c18d03b1901	2018-02-28 08:44:45.574646-06	2	[10883] IC-205 Connect	[4] DLarrabee	[21062] a	\N	\N
7f411a07-0f52-415e-a29e-f1adde731f79	2018-02-28 08:44:45.577646-06	2	[10884] IC-206 Connect	[4] DLarrabee	[21062] a	\N	\N
f7a9396f-500d-4792-92da-a294f2d06d90	2018-02-28 08:44:45.580647-06	2	[10885] IC-207 Connect	[4] DLarrabee	[21062] a	\N	\N
d71311b8-af69-43bf-a5c4-a57611e21807	2018-02-28 08:44:45.583647-06	2	[10886] IC-209A-InB Connect	[4] DLarrabee	[21062] a	\N	\N
b7ecf4ee-eb76-49c0-aad9-36ba8b408d77	2018-02-28 08:44:45.587647-06	2	[10887] IC-209A-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
900d48a5-a855-42df-9d5e-c24ba1392fc6	2018-02-28 08:44:45.591648-06	2	[10888] IC-209B-InB Connect	[4] DLarrabee	[21062] a	\N	\N
9f74a8fb-c110-408e-a356-3ebcbe79a2c1	2018-02-28 08:44:45.599649-06	2	[10889] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
0f805f33-d538-427b-9482-2accdd21a1ec	2018-02-28 08:44:45.60965-06	2	[10915] IC-203 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
090a3ce8-976c-4c42-9275-639037ae2a5e	2018-02-28 08:44:45.61465-06	2	[10916] IC-205 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c5793553-6749-4a96-9772-2158aba65dad	2018-02-28 08:44:45.61765-06	2	[10917] IC-206 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
91e71cc2-664c-463a-9d86-e29179214b18	2018-02-28 08:44:45.621651-06	2	[10918] IC-207 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
458e27d0-d1b8-429f-a4c3-ff9d649933b8	2018-02-28 08:44:45.624651-06	2	[10919] IC-209A-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7795b6e5-94a5-4ea3-9531-76d2956a0488	2018-02-28 08:44:45.628652-06	2	[10920] IC-209A-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
97cf10bf-2fe9-45ad-8dd3-e69441c151d2	2018-02-28 08:44:45.632652-06	2	[10921] IC-209B-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
edb4d635-d2dd-46bb-97a9-f0f3b6697456	2018-02-28 08:44:45.637652-06	2	[10922] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
10f84db5-1006-4ac0-a23e-8ad9f4f42512	2018-02-28 08:44:45.641653-06	2	[10934] IC-203 Call	[4] DLarrabee	[21062] a	\N	\N
593ce223-4268-4428-b8c2-237950213203	2018-02-28 08:44:45.645653-06	2	[10935] IC-205 Call	[4] DLarrabee	[21062] a	\N	\N
7b8bbfff-1f73-4ec9-ae80-5e130a3bd790	2018-02-28 08:44:45.648654-06	2	[10936] IC-206 Call	[4] DLarrabee	[21062] a	\N	\N
c2418ebe-1751-458b-8373-ada38072b9e6	2018-02-28 08:44:45.651654-06	2	[10937] IC-207 Call	[4] DLarrabee	[21062] a	\N	\N
0ce5edd8-c5f6-4fc8-8666-cddf36af9e7d	2018-02-28 08:44:45.655654-06	2	[10938] IC-209A-InB Call	[4] DLarrabee	[21062] a	\N	\N
ccccfcfd-4b61-4f67-bafe-d879ce913be9	2018-02-28 08:44:45.658655-06	2	[10939] IC-209A-OutB Call	[4] DLarrabee	[21062] a	\N	\N
45e89fc4-c858-45c8-a248-9f06e9905a6d	2018-02-28 08:44:45.662655-06	2	[10940] IC-209B-InB Call	[4] DLarrabee	[21062] a	\N	\N
68bb3051-b365-4da1-8184-30b16661c956	2018-02-28 08:44:45.665655-06	2	[10941] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
65eb500c-18b3-4cb5-b7ec-c810a5b8d592	2018-02-28 08:44:45.782667-06	2	[11302] R5C8-8IC	[4] DLarrabee	[21062] a	\N	\N
8e858dab-5e84-4eb2-9737-f2664b108f62	2018-02-28 08:44:45.795668-06	2	[11304] IC-209B-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
6cab28a5-45a8-49e8-a668-4228f937a3d8	2018-02-28 08:44:45.80967-06	2	[11305] IC-211-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
27ead6a3-61f1-45b8-a7c4-905c3a8e5d7e	2018-02-28 08:44:45.824671-06	2	[11306] IC-211-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
187dd0a0-223c-4eda-ad97-ec52416b8a39	2018-02-28 08:44:45.839673-06	2	[11307] IC-213 Call Button	[4] DLarrabee	[21062] a	\N	\N
2627a0f3-2f4a-43a0-9f77-418c1cb6cf6b	2018-02-28 08:44:45.854674-06	2	[11308] IC-214 Call Button	[4] DLarrabee	[21062] a	\N	\N
8cd6bbbe-1f9b-4c40-8542-687e05383894	2018-02-28 08:44:45.867675-06	2	[11309] IC-215 Call Button	[4] DLarrabee	[21062] a	\N	\N
db23fe9e-97b3-47f4-96c4-59a3a3c84f3b	2018-02-28 08:44:45.882677-06	2	[11310] IC-216 Call Button	[4] DLarrabee	[21062] a	\N	\N
27fcacfb-e3a1-4e27-9cbe-699bda56716b	2018-02-28 08:44:45.900679-06	2	[11311] IC-218 Call Button	[4] DLarrabee	[21062] a	\N	\N
94f1afc8-cd1d-4d9c-8ecd-3198266912f1	2018-02-28 08:44:45.921681-06	2	[11313] IC-209B-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
907d4374-8494-45fe-b676-1d9510e229a5	2018-02-28 08:44:45.939683-06	2	[11314] IC-211-InB Relay	[4] DLarrabee	[21062] a	\N	\N
1930eb6c-f53f-44f8-ac41-1a10986240d4	2018-02-28 08:44:45.953684-06	2	[11315] IC-211-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
0eba95c3-c59f-484d-9982-6453ddc03148	2018-02-28 08:44:45.968686-06	2	[11316] IC-213 Relay	[4] DLarrabee	[21062] a	\N	\N
9c40910d-b896-4ddd-afe9-439ca80e8923	2018-02-28 08:44:45.981687-06	2	[11317] IC-214 Relay	[4] DLarrabee	[21062] a	\N	\N
34cc3710-7a72-4d71-9183-218a30f5973a	2018-02-28 08:44:45.997688-06	2	[11318] IC-215 Relay	[4] DLarrabee	[21062] a	\N	\N
92f242a1-44b2-4f81-9f9c-a05fea5925fb	2018-02-28 08:44:46.01269-06	2	[11319] IC-216 Relay	[4] DLarrabee	[21062] a	\N	\N
26434c97-e3d2-4e19-b7b6-059493774f4d	2018-02-28 08:44:46.025691-06	2	[11320] IC-218 Relay	[4] DLarrabee	[21062] a	\N	\N
f253d4a9-3b3d-4eb5-b6d5-6b9e4ab7e43a	2018-02-28 08:44:46.028692-06	2	[11322] IC-209B-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
b93429b3-caa7-4844-bf3a-6b94241cae42	2018-02-28 08:44:46.033692-06	2	[11323] IC-211-InB Connect	[4] DLarrabee	[21062] a	\N	\N
1ac9c9a7-bb63-4f7b-9de4-41dc1b44565d	2018-02-28 08:44:46.036692-06	2	[11324] IC-211-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
0b87e505-fe54-474e-ab57-c65c04fc0c86	2018-02-28 08:44:46.039693-06	2	[11325] IC-213 Connect	[4] DLarrabee	[21062] a	\N	\N
e1569dab-86f0-4185-955c-4bd06143b19c	2018-02-28 08:44:46.042693-06	2	[11326] IC-214 Connect	[4] DLarrabee	[21062] a	\N	\N
4567598d-d515-4780-a88f-30c086be8d33	2018-02-28 08:44:46.045693-06	2	[11327] IC-215 Connect	[4] DLarrabee	[21062] a	\N	\N
a2477d28-40e5-4eca-b4b3-f2b0a522e432	2018-02-28 08:44:46.049694-06	2	[11328] IC-216 Connect	[4] DLarrabee	[21062] a	\N	\N
6a05e2fc-c83b-460a-8e94-6f30bc5d091e	2018-02-28 08:44:46.052694-06	2	[11329] IC-218 Connect	[4] DLarrabee	[21062] a	\N	\N
983d2acc-42d4-4d6a-a0b5-ed946de6cb1f	2018-02-28 08:44:46.055694-06	2	[11355] IC-209B-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e854220d-9cac-44ef-b80f-69133036341c	2018-02-28 08:44:46.059695-06	2	[11356] IC-211-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9bf30d8c-650a-4c97-80b9-4868722119dc	2018-02-28 08:44:46.062695-06	2	[11357] IC-211-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b55c2165-d264-4299-9b3e-214895cdeef9	2018-02-28 08:44:46.066695-06	2	[11358] IC-213 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
66f30ad5-0d10-4f6d-a810-95d981093867	2018-02-28 08:44:46.070696-06	2	[11359] IC-214 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f8784466-584e-4887-80d3-7fdf88ec5411	2018-02-28 08:44:46.073696-06	2	[11360] IC-215 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4906c257-bb54-4cd4-8f72-7d4341092f03	2018-02-28 08:44:46.077696-06	2	[11361] IC-216 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7b1e9e4b-298f-472c-94c9-960152895472	2018-02-28 08:44:46.080697-06	2	[11362] IC-218 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0dc30d7a-5c2b-4c50-b6e2-9415861efeef	2018-02-28 08:44:46.083697-06	2	[11374] IC-209B-OutB Call	[4] DLarrabee	[21062] a	\N	\N
dcf6a1f9-bbbe-4590-950c-36e802219bf0	2018-02-28 08:44:46.087697-06	2	[11375] IC-211-InB Call	[4] DLarrabee	[21062] a	\N	\N
458e9c4d-e7f5-44f6-9ad4-3da719ffeb2b	2018-02-28 08:44:46.090698-06	2	[11376] IC-211-OutB Call	[4] DLarrabee	[21062] a	\N	\N
41d86418-9514-498e-b7fe-2e394dc227e3	2018-02-28 08:44:46.093698-06	2	[11377] IC-213 Call	[4] DLarrabee	[21062] a	\N	\N
db1b5baa-5e36-41de-a0bb-3a18e8aba3f2	2018-02-28 08:44:46.097698-06	2	[11378] IC-214 Call	[4] DLarrabee	[21062] a	\N	\N
2579971c-9c9a-461e-a77f-974f8c8f6192	2018-02-28 08:44:46.101699-06	2	[11379] IC-215 Call	[4] DLarrabee	[21062] a	\N	\N
42c5bd27-1cfb-4427-9d5e-2428818d0d7f	2018-02-28 08:44:46.104699-06	2	[11380] IC-216 Call	[4] DLarrabee	[21062] a	\N	\N
caf3fe7b-a932-400c-be06-3037c4c45e5f	2018-02-28 08:44:46.126701-06	2	[11381] IC-218 Call	[4] DLarrabee	[21062] a	\N	\N
cf272df9-3f30-4fb6-aa32-8b9cfd839f8f	2018-02-28 08:44:46.257714-06	2	[11742] R5C9-8IC	[4] DLarrabee	[21062] a	\N	\N
13a0501c-3536-4138-9025-8d42022c6249	2018-02-28 08:44:46.272716-06	2	[11744] IC-219 Call Button	[4] DLarrabee	[21062] a	\N	\N
0730f963-8cec-4491-bf9f-141cc71e440d	2018-02-28 08:44:46.292718-06	2	[11745] IC-221 Call Button	[4] DLarrabee	[21062] a	\N	\N
051d48ff-597e-439d-b24f-49c3b2a2a91c	2018-02-28 08:44:46.31172-06	2	[11746] IC-222 Call Button	[4] DLarrabee	[21062] a	\N	\N
1a08fa2f-892d-4fdd-88c0-a15cae34fa0e	2018-02-28 08:44:46.329722-06	2	[11747] IC-223-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
8edecc98-72cc-4082-a12b-cb949f22a389	2018-02-28 08:44:46.349724-06	2	[11748] IC-223-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
ce588580-1173-4113-b190-80303e86f1e6	2018-02-28 08:44:46.365725-06	2	[11749] IC-224-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
af98779b-b684-422e-a3f1-4e053bef5cf5	2018-02-28 08:44:46.384727-06	2	[11750] IC-224-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
7354f730-fe20-4b13-8799-5eedcca0dd8b	2018-02-28 08:44:46.404729-06	2	[11751] IC-225 Call Button	[4] DLarrabee	[21062] a	\N	\N
7de1977d-45e3-48b1-b928-765ed7417ff6	2018-02-28 08:44:46.418731-06	2	[11753] IC-219 Relay	[4] DLarrabee	[21062] a	\N	\N
ee0e3e5a-0a2b-4f48-bf11-0782dafd70b4	2018-02-28 08:44:46.433732-06	2	[11754] IC-221 Relay	[4] DLarrabee	[21062] a	\N	\N
3ce3da79-2a64-4c63-a6c6-3c198817f458	2018-02-28 08:44:46.451734-06	2	[11755] IC-222 Relay	[4] DLarrabee	[21062] a	\N	\N
f80b10cb-2f43-44d6-b05b-64aca05d1a2e	2018-02-28 08:44:46.468736-06	2	[11756] IC-223-InB Relay	[4] DLarrabee	[21062] a	\N	\N
649117e4-31a9-476b-b7d0-662d91ea6d52	2018-02-28 08:44:46.483737-06	2	[11757] IC-223-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
fd55d47e-8696-4bbb-8411-5cca4da206eb	2018-02-28 08:44:46.496738-06	2	[11758] IC-224-InB Relay	[4] DLarrabee	[21062] a	\N	\N
a026fd05-250d-4112-a721-7ef6c5018ec2	2018-02-28 08:44:46.50974-06	2	[11759] IC-224-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
a83c1085-592f-465f-947c-033d9900ac62	2018-02-28 08:44:46.521741-06	2	[11760] IC-225 Relay	[4] DLarrabee	[21062] a	\N	\N
bc640058-ee6d-4061-b10b-787c3bb06651	2018-02-28 08:44:46.525741-06	2	[11762] IC-219 Connect	[4] DLarrabee	[21062] a	\N	\N
ace402a4-6c8a-4bf3-a012-234ed81791b8	2018-02-28 08:44:46.527741-06	2	[11763] IC-221 Connect	[4] DLarrabee	[21062] a	\N	\N
750a79a2-f3fc-47fb-a6e5-d17130c1c1a8	2018-02-28 08:44:46.530742-06	2	[11764] IC-222 Connect	[4] DLarrabee	[21062] a	\N	\N
3ae180c4-2ef6-4859-8e85-f4b594b8103e	2018-02-28 08:44:46.533742-06	2	[11765] IC-223-InB Connect	[4] DLarrabee	[21062] a	\N	\N
a03bfeaf-13de-4971-939f-b0fd8195ad9c	2018-02-28 08:44:46.537742-06	2	[11766] IC-223-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
d0c11f40-9e75-4e66-a905-4fd3bd3b7ebd	2018-02-28 08:44:46.539743-06	2	[11767] IC-224-InB Connect	[4] DLarrabee	[21062] a	\N	\N
485230a2-132e-4109-9da0-e4f36d27bd14	2018-02-28 08:44:46.542743-06	2	[11768] IC-224-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
dc2991de-157b-44e9-8bfb-3a9d12175cdb	2018-02-28 08:44:46.545743-06	2	[11769] IC-225 Connect	[4] DLarrabee	[21062] a	\N	\N
dcc7371b-ba9c-4e88-a4f1-acb9e111b3ef	2018-02-28 08:44:46.549744-06	2	[11795] IC-219 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
671192cb-876b-4199-bebd-06be0fc8a20a	2018-02-28 08:44:46.552744-06	2	[11796] IC-221 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
51cbb7be-614f-4aa6-8998-933cc0b381c6	2018-02-28 08:44:46.556744-06	2	[11797] IC-222 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d5dbf1fd-c8c5-43d5-a7ba-2019e07b8441	2018-02-28 08:44:46.560745-06	2	[11798] IC-223-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
27ac93b1-2be1-47ef-8919-e95ec6bde829	2018-02-28 08:44:46.563745-06	2	[11799] IC-223-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
98418af0-51b3-4fad-abc3-6274417333ed	2018-02-28 08:44:46.567745-06	2	[11800] IC-224-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6882e702-157a-4520-8fb8-633ecea82eb7	2018-02-28 08:44:46.571746-06	2	[11801] IC-224-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
adef2f5a-a45a-4146-8125-a511066e976b	2018-02-28 08:44:46.575746-06	2	[11802] IC-225 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f21818f6-1ed2-4d76-ab8e-d404c543a8d5	2018-02-28 08:44:46.578747-06	2	[11814] IC-219 Call	[4] DLarrabee	[21062] a	\N	\N
da4e912f-070b-44f3-9460-f5f0fd5eeae9	2018-02-28 08:44:46.581747-06	2	[11815] IC-221 Call	[4] DLarrabee	[21062] a	\N	\N
79a71266-6222-47b3-92ef-6d3763c3a825	2018-02-28 08:44:46.584747-06	2	[11816] IC-222 Call	[4] DLarrabee	[21062] a	\N	\N
469839bf-91e0-4ce8-bee6-ee58318354b0	2018-02-28 08:44:46.587747-06	2	[11817] IC-223-InB Call	[4] DLarrabee	[21062] a	\N	\N
e3db93b2-d280-40ba-be7f-574ed655a943	2018-02-28 08:44:46.590748-06	2	[11818] IC-223-OutB Call	[4] DLarrabee	[21062] a	\N	\N
5e7af152-b830-4694-ad6b-8b105388eb0b	2018-02-28 08:44:46.593748-06	2	[11819] IC-224-InB Call	[4] DLarrabee	[21062] a	\N	\N
20b2a64a-9e79-455d-8ff9-e74bee7e40f5	2018-02-28 08:44:46.596748-06	2	[11820] IC-224-OutB Call	[4] DLarrabee	[21062] a	\N	\N
e1307581-e9f2-42b5-a8e0-0ccf9dc86cce	2018-02-28 08:44:46.600749-06	2	[11821] IC-225 Call	[4] DLarrabee	[21062] a	\N	\N
10418aa7-6d1f-4656-8822-50b0ff431f11	2018-02-28 08:44:46.729762-06	2	[12182] R5C10-8IC	[4] DLarrabee	[21062] a	\N	\N
96051f4f-fb7e-4168-8549-c9a0d05755c3	2018-02-28 08:44:46.744763-06	2	[12184] IC-226 Call Button	[4] DLarrabee	[21062] a	\N	\N
5e3cfb0e-0bb0-4b91-826b-cd21c26d8a7d	2018-02-28 08:44:46.759765-06	2	[12185] IC-227 Call Button	[4] DLarrabee	[21062] a	\N	\N
ce530faa-2764-4ff2-9dd9-f9aa5fad1abc	2018-02-28 08:44:46.775766-06	2	[12186] IC-228 Call Button	[4] DLarrabee	[21062] a	\N	\N
1c3ad15c-7a65-45f0-9640-7b025a24ac51	2018-02-28 08:44:46.789768-06	2	[12187] IC-231 Call Button	[4] DLarrabee	[21062] a	\N	\N
2b87db70-05a3-434f-9438-27283b7cb306	2018-02-28 08:44:46.804769-06	2	[12188] IC-232 Call Button	[4] DLarrabee	[21062] a	\N	\N
422131b0-9e5e-4811-8041-68b79f1b5f34	2018-02-28 08:44:46.820771-06	2	[12189] IC-233 Call Button	[4] DLarrabee	[21062] a	\N	\N
96b71497-4cf0-43aa-888a-d6d9cec1dd02	2018-02-28 08:44:46.835772-06	2	[12190] IC-235 Call Button	[4] DLarrabee	[21062] a	\N	\N
8d00bcbe-6b85-4cc1-b4c9-8ea5e09d2879	2018-02-28 08:44:46.848774-06	2	[12191] IC-236-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
ee01d9d3-f4ce-4334-afba-7b25ba3c9c77	2018-02-28 08:44:46.862775-06	2	[12193] IC-226 Relay	[4] DLarrabee	[21062] a	\N	\N
5253cb18-a0ef-4916-b0a2-1a6b0e716919	2018-02-28 08:44:46.876776-06	2	[12194] IC-227 Relay	[4] DLarrabee	[21062] a	\N	\N
25750030-08a6-4247-86b7-e7155c8a4c11	2018-02-28 08:44:46.892778-06	2	[12195] IC-228 Relay	[4] DLarrabee	[21062] a	\N	\N
c3d37c98-8c41-4e5d-aeb4-10bf65fa0cba	2018-02-28 08:44:46.907779-06	2	[12196] IC-231 Relay	[4] DLarrabee	[21062] a	\N	\N
654e9234-40ce-4517-9df1-03565e830efe	2018-02-28 08:44:46.922781-06	2	[12197] IC-232 Relay	[4] DLarrabee	[21062] a	\N	\N
4941bd73-8904-47ce-a4d6-8441dba7c89a	2018-02-28 08:44:46.941783-06	2	[12198] IC-233 Relay	[4] DLarrabee	[21062] a	\N	\N
2d46d0f6-b68d-42a7-8d2a-611691e032a0	2018-02-28 08:44:46.957784-06	2	[12199] IC-235 Relay	[4] DLarrabee	[21062] a	\N	\N
c1fe346e-6f57-41d2-9803-a5177819df57	2018-02-28 08:44:46.973786-06	2	[12200] IC-236-InB Relay	[4] DLarrabee	[21062] a	\N	\N
abca8c31-c382-4596-a4ef-4a1abe980014	2018-02-28 08:44:46.978787-06	2	[12202] IC-226 Connect	[4] DLarrabee	[21062] a	\N	\N
c68d041c-1a27-4c5b-8d69-aec6ae00356d	2018-02-28 08:44:46.981787-06	2	[12203] IC-227 Connect	[4] DLarrabee	[21062] a	\N	\N
736928b2-a45d-42f9-ad59-59eb3e7b3dbd	2018-02-28 08:44:46.985787-06	2	[12204] IC-228 Connect	[4] DLarrabee	[21062] a	\N	\N
c8bf4d39-7efb-40ce-891d-50d4ea3f175f	2018-02-28 08:44:46.988788-06	2	[12205] IC-231 Connect	[4] DLarrabee	[21062] a	\N	\N
e1d8c7f2-412d-4b05-ba28-30c3338e50ca	2018-02-28 08:44:46.991788-06	2	[12206] IC-232 Connect	[4] DLarrabee	[21062] a	\N	\N
65e6d80d-b360-46aa-b020-9378150745dd	2018-02-28 08:44:46.994788-06	2	[12207] IC-233 Connect	[4] DLarrabee	[21062] a	\N	\N
88dadf70-6c39-42f1-bcd9-e05bd0557145	2018-02-28 08:44:46.997788-06	2	[12208] IC-235 Connect	[4] DLarrabee	[21062] a	\N	\N
276cd9fb-b50a-406b-b1aa-10828d5c45fe	2018-02-28 08:44:47.001789-06	2	[12209] IC-236-InB Connect	[4] DLarrabee	[21062] a	\N	\N
5387c21b-d027-4863-a15f-644d7266e5cb	2018-02-28 08:44:47.004789-06	2	[12235] IC-226 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
979bb92b-272a-4792-92d5-583e2e51a360	2018-02-28 08:44:47.007789-06	2	[12236] IC-227 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cfd24cb4-6f0f-44c4-9138-703a61a16319	2018-02-28 08:44:47.01179-06	2	[12237] IC-228 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4d72e55d-fbd8-4369-8207-26209d3053f9	2018-02-28 08:44:47.01479-06	2	[12238] IC-231 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0abc2757-fbf7-4352-bcbb-779b4b79c831	2018-02-28 08:44:47.018791-06	2	[12239] IC-232 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1ec614dd-dc1d-4193-8d14-5a54cf93d77d	2018-02-28 08:44:47.022791-06	2	[12240] IC-233 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
65acb96c-b1f6-47a0-988f-832b8bafc98e	2018-02-28 08:44:47.025791-06	2	[12241] IC-235 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
30016fee-92a5-475f-a07b-b7c2579e4a81	2018-02-28 08:44:47.028792-06	2	[12242] IC-236-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
203d915b-86ac-41e7-b5e7-6e5bf4e327fa	2018-02-28 08:44:47.031792-06	2	[12254] IC-226 Call	[4] DLarrabee	[21062] a	\N	\N
af53cf15-f11c-48f9-ae8c-30458b6d5ccf	2018-02-28 08:44:47.034792-06	2	[12255] IC-227 Call	[4] DLarrabee	[21062] a	\N	\N
22f7552a-1e9b-4580-a45d-eaf9b67f848c	2018-02-28 08:44:47.038793-06	2	[12256] IC-228 Call	[4] DLarrabee	[21062] a	\N	\N
785c002c-51e5-4d41-b975-09e0a0153eb2	2018-02-28 08:44:47.042793-06	2	[12257] IC-231 Call	[4] DLarrabee	[21062] a	\N	\N
284353a6-2f18-4151-a33a-33411b1a86d8	2018-02-28 08:44:47.045793-06	2	[12258] IC-232 Call	[4] DLarrabee	[21062] a	\N	\N
c7b8865b-8e83-46c3-b78e-1ebf97e91645	2018-02-28 08:44:47.049794-06	2	[12259] IC-233 Call	[4] DLarrabee	[21062] a	\N	\N
781548e1-165e-4fa5-950b-f9535c273f8e	2018-02-28 08:44:47.052794-06	2	[12260] IC-235 Call	[4] DLarrabee	[21062] a	\N	\N
7d60efdb-6321-4e21-a33f-b49ae881377d	2018-02-28 08:44:47.055794-06	2	[12261] IC-236-InB Call	[4] DLarrabee	[21062] a	\N	\N
5ebe9d69-c1cd-4cfc-b260-d5eac29a9d82	2018-02-28 08:44:47.171806-06	2	[12622] R5C11-8IC	[4] DLarrabee	[21062] a	\N	\N
50eaf267-701d-4609-9df2-6d77aea2eb34	2018-02-28 08:44:47.186807-06	2	[12624] IC-236-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
41cf3511-f5c0-442b-bd29-30249552ee2f	2018-02-28 08:44:47.200809-06	2	[12625] IC-237A-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
841824c6-dd94-42d2-8883-772097115fff	2018-02-28 08:44:47.21281-06	2	[12626] IC-237A-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
5a2bfe28-d333-4f24-ae3f-700aff41b781	2018-02-28 08:44:47.227811-06	2	[12627] IC-237B-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
e681c9ff-47e7-4e40-9cbd-79fbf5ec5832	2018-02-28 08:44:47.246813-06	2	[12628] IC-237B-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
171d07ef-15a0-4d35-9e68-0bf4637f6eb1	2018-02-28 08:44:47.265815-06	2	[12629] IC-239 Call Button	[4] DLarrabee	[21062] a	\N	\N
bc99a7c4-99ba-4a70-8f47-0df2be52bb48	2018-02-28 08:44:47.285817-06	2	[12630] IC-241 Call Button	[4] DLarrabee	[21062] a	\N	\N
c2ba8d77-476b-483b-886e-4a316defc73c	2018-02-28 08:44:47.303819-06	2	[12631] IC-242 Call Button	[4] DLarrabee	[21062] a	\N	\N
c6166419-b175-418c-ad18-d3331e0d066a	2018-02-28 08:44:47.318821-06	2	[12633] IC-236-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
0657df6b-4f51-4d36-bb22-eaf1e230da7e	2018-02-28 08:44:47.335822-06	2	[12634] IC-237A-InB Relay	[4] DLarrabee	[21062] a	\N	\N
3c15f7d4-daaa-4b73-88b0-30f8015f933a	2018-02-28 08:44:47.351824-06	2	[12635] IC-237A-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
6cd4f4c3-8c82-41d5-8a94-e6b1f8adb21b	2018-02-28 08:44:47.366825-06	2	[12636] IC-237B-InB Relay	[4] DLarrabee	[21062] a	\N	\N
cf77f4b2-5989-422c-af8a-fe3554630592	2018-02-28 08:44:47.385827-06	2	[12637] IC-237B-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
65abcb2a-c99a-4fc4-a404-3a752ae2ffb8	2018-02-28 08:44:47.405829-06	2	[12638] IC-239 Relay	[4] DLarrabee	[21062] a	\N	\N
030da0ea-313d-4851-bc5e-68d6bf8e83ea	2018-02-28 08:44:47.418831-06	2	[12639] IC-241 Relay	[4] DLarrabee	[21062] a	\N	\N
f73fb1b0-4aee-4b11-bdc3-652c7c17a325	2018-02-28 08:44:47.436832-06	2	[12640] IC-242 Relay	[4] DLarrabee	[21062] a	\N	\N
9b943ddc-b947-40c4-ae48-460f0eeb45ae	2018-02-28 08:44:47.439833-06	2	[12642] IC-236-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
73a61714-46f2-4cf9-9545-3cd0e1536bc0	2018-02-28 08:44:47.442833-06	2	[12643] IC-237A-InB Connect	[4] DLarrabee	[21062] a	\N	\N
5aaba650-5fd4-42f2-9165-fec0e53956c3	2018-02-28 08:44:47.445833-06	2	[12644] IC-237A-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
17da4933-0499-4825-905f-e352e9ed5ed8	2018-02-28 08:44:47.449834-06	2	[12645] IC-237B-InB Connect	[4] DLarrabee	[21062] a	\N	\N
b8185096-160a-4618-b2cd-e6cd896edeb3	2018-02-28 08:44:47.453834-06	2	[12646] IC-237B-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
6fd7be84-2e5f-4272-be1d-f1907812cf03	2018-02-28 08:44:47.457834-06	2	[12647] IC-239 Connect	[4] DLarrabee	[21062] a	\N	\N
8d56c29d-07d6-4181-abc1-4e5b8e7b1258	2018-02-28 08:44:47.461835-06	2	[12648] IC-241 Connect	[4] DLarrabee	[21062] a	\N	\N
0cdd6e49-e8af-419d-8a86-916853d6c09b	2018-02-28 08:44:47.465835-06	2	[12649] IC-242 Connect	[4] DLarrabee	[21062] a	\N	\N
dfbf3ed4-fe91-4eee-bf70-4c3e702ad74e	2018-02-28 08:44:47.468836-06	2	[12675] IC-236-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ceef82e5-5371-4991-9c7c-567c8465e5f1	2018-02-28 08:44:47.471836-06	2	[12676] IC-237A-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cc3aff40-ae81-4d98-a70e-c1c903c339aa	2018-02-28 08:44:47.474836-06	2	[12677] IC-237A-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
eb0842a3-c61a-477d-9acd-17579e401648	2018-02-28 08:44:47.479837-06	2	[12678] IC-237B-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f2825ecb-b1b1-4335-ad34-a1459bcf5b8b	2018-02-28 08:44:47.482837-06	2	[12679] IC-237B-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2b8281a2-eb18-42c7-b2bb-99ada8ab8638	2018-02-28 08:44:47.484837-06	2	[12680] IC-239 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8fbb726b-70b7-44fa-a32a-0ea6950a9179	2018-02-28 08:44:47.488838-06	2	[12681] IC-241 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
318b010c-7dee-4d5c-ae7b-bd48f1caf0ba	2018-02-28 08:44:47.492838-06	2	[12682] IC-242 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a538ff11-bcbe-4af2-82cd-68c822b412b9	2018-02-28 08:44:47.495838-06	2	[12694] IC-236-OutB Call	[4] DLarrabee	[21062] a	\N	\N
f4a6f73c-f46f-47d9-82a7-0dcedd3c7764	2018-02-28 08:44:47.499839-06	2	[12695] IC-237A-InB Call	[4] DLarrabee	[21062] a	\N	\N
a07a67a7-8251-4ff7-b8be-98895a3a69b1	2018-02-28 08:44:47.503839-06	2	[12696] IC-237A-OutB Call	[4] DLarrabee	[21062] a	\N	\N
6235497e-fecb-4dd7-a3a1-4e112ef2f57f	2018-02-28 08:44:47.507839-06	2	[12697] IC-237B-InB Call	[4] DLarrabee	[21062] a	\N	\N
d26cd23d-7116-4310-b717-f60610732296	2018-02-28 08:44:47.51184-06	2	[12698] IC-237B-OutB Call	[4] DLarrabee	[21062] a	\N	\N
0281c239-f81e-46ef-84db-2d49ed608065	2018-02-28 08:44:47.51584-06	2	[12699] IC-239 Call	[4] DLarrabee	[21062] a	\N	\N
280f5baf-ba8d-4642-9778-17d3bcf57d98	2018-02-28 08:44:47.518841-06	2	[12700] IC-241 Call	[4] DLarrabee	[21062] a	\N	\N
9f6a6a7c-ebac-4410-a76c-656dfae81ad5	2018-02-28 08:44:47.521841-06	2	[12701] IC-242 Call	[4] DLarrabee	[21062] a	\N	\N
1181c81f-2d32-4121-98ec-8996b407b190	2018-02-28 08:44:47.642853-06	2	[13062] R5C12-8IC	[4] DLarrabee	[21062] a	\N	\N
b9c0a114-5d0a-43b0-96d0-a90155b21af8	2018-02-28 08:44:47.655854-06	2	[13064] IC-243 Call Button	[4] DLarrabee	[21062] a	\N	\N
651899f3-0304-41b6-8541-c7edc17dd7c4	2018-02-28 08:44:47.669856-06	2	[13065] IC-245 Call Button	[4] DLarrabee	[21062] a	\N	\N
6ff68f36-5fa4-46f6-be7b-2ca691512fb0	2018-02-28 08:44:47.681857-06	2	[13066] IC-246-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
c6f8c973-713a-44e9-bebe-e9bf569fbecf	2018-02-28 08:44:47.694858-06	2	[13067] IC-246-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
f6e6cd3e-0644-4f1f-b8c4-a8f0758f328c	2018-02-28 08:44:47.71286-06	2	[13068] IC-247-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
697221bc-415e-4bb1-8496-f2b04fe7f980	2018-02-28 08:44:47.729862-06	2	[13069] IC-247-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
7d3c17e9-ad73-464e-9b59-9d4ec860e7bc	2018-02-28 08:44:47.744863-06	2	[13070] IC-248-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
69f17218-157c-415b-819d-f6608c18cbc9	2018-02-28 08:44:47.759865-06	2	[13071] IC-248-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
eeb42a3f-3c80-4095-8242-80d58f1f0b9e	2018-02-28 08:44:47.772866-06	2	[13073] IC-243 Relay	[4] DLarrabee	[21062] a	\N	\N
160b536c-790c-42e3-b644-9fa99a6b930c	2018-02-28 08:44:47.787867-06	2	[13074] IC-245 Relay	[4] DLarrabee	[21062] a	\N	\N
3ba976a2-32ee-46d1-b2ad-e2a9266ca2af	2018-02-28 08:44:47.805869-06	2	[13075] IC-246-InB Relay	[4] DLarrabee	[21062] a	\N	\N
e75bfbb1-742f-4719-9e71-1168153c8c0e	2018-02-28 08:44:47.822871-06	2	[13076] IC-246-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
c7008c44-f539-4bbf-bbf4-31a6bcfcd43d	2018-02-28 08:44:47.836872-06	2	[13077] IC-247-InB Relay	[4] DLarrabee	[21062] a	\N	\N
e1866f33-40e9-4399-afec-eb4fbc80b780	2018-02-28 08:44:47.886877-06	2	[13078] IC-247-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
dbba5b33-1c0f-4471-a12b-9e1aab14dc7d	2018-02-28 08:44:47.907879-06	2	[13079] IC-248-InB Relay	[4] DLarrabee	[21062] a	\N	\N
1ce10d51-d7cc-4569-a597-961201fe9672	2018-02-28 08:44:47.927881-06	2	[13080] IC-248-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
bf1a8b54-3da5-4819-a6c6-4097fcaa0f06	2018-02-28 08:44:47.935882-06	2	[13082] IC-243 Connect	[4] DLarrabee	[21062] a	\N	\N
e25749f4-67e8-47ad-86a2-7fdf93745169	2018-02-28 08:44:47.939883-06	2	[13083] IC-245 Connect	[4] DLarrabee	[21062] a	\N	\N
37e4c705-22c9-4484-b235-718894f3f156	2018-02-28 08:44:47.943883-06	2	[13084] IC-246-InB Connect	[4] DLarrabee	[21062] a	\N	\N
afa6adf4-2568-45c8-a59e-6d889b85f12e	2018-02-28 08:44:47.947883-06	2	[13085] IC-246-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
94f03042-82e0-4347-acfb-b8c079847efc	2018-02-28 08:44:47.952884-06	2	[13086] IC-247-InB Connect	[4] DLarrabee	[21062] a	\N	\N
ca96e616-0a81-42fd-a88c-53dfe65ebf78	2018-02-28 08:44:47.956884-06	2	[13087] IC-247-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
411e6d05-48b9-4531-a504-d4d03c4ebfc1	2018-02-28 08:44:47.960885-06	2	[13088] IC-248-InB Connect	[4] DLarrabee	[21062] a	\N	\N
e42641ed-388c-41ba-b66e-b1909dc9e10d	2018-02-28 08:44:47.963885-06	2	[13089] IC-248-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
aa311b8c-3f5d-4b87-92dc-015aa92a8479	2018-02-28 08:44:47.968886-06	2	[13115] IC-243 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
286235e8-500f-4d8b-87f2-f56edb6523b3	2018-02-28 08:44:47.973886-06	2	[13116] IC-245 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a797836a-ec0f-4d1d-841a-472deda58b4b	2018-02-28 08:44:47.976886-06	2	[13117] IC-246-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
afaf9730-1ac6-4c7a-8bdf-ff73269e2873	2018-02-28 08:44:47.979887-06	2	[13118] IC-246-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e427a165-674c-4621-8fe5-968a1bff9edf	2018-02-28 08:44:47.984887-06	2	[13119] IC-247-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
960b5107-dca2-4c78-a62a-736a9306cf94	2018-02-28 08:44:47.987887-06	2	[13120] IC-247-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
141e46bd-ca18-4415-9a13-d9384369adfe	2018-02-28 08:44:47.990888-06	2	[13121] IC-248-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c83fc147-eda8-429e-b0a2-7abb06c8db52	2018-02-28 08:44:47.994888-06	2	[13122] IC-248-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0639f4b6-74c1-4442-b5e7-ea4bd7a54a7a	2018-02-28 08:44:47.997888-06	2	[13134] IC-243 Call	[4] DLarrabee	[21062] a	\N	\N
6574f679-ca14-4838-8f04-1fbcb5dd3110	2018-02-28 08:44:47.999889-06	2	[13135] IC-245 Call	[4] DLarrabee	[21062] a	\N	\N
a219aad7-7ae7-41d8-9ba0-3e6c3816dad7	2018-02-28 08:44:48.003889-06	2	[13136] IC-246-InB Call	[4] DLarrabee	[21062] a	\N	\N
ed678721-9810-4e49-ba6e-a0b0600c4850	2018-02-28 08:44:48.007889-06	2	[13137] IC-246-OutB Call	[4] DLarrabee	[21062] a	\N	\N
884768e1-77bf-4238-92f7-992e7a00be64	2018-02-28 08:44:48.00989-06	2	[13138] IC-247-InB Call	[4] DLarrabee	[21062] a	\N	\N
e4a7fbd0-a128-4eca-af6d-495e280e6413	2018-02-28 08:44:48.01389-06	2	[13139] IC-247-OutB Call	[4] DLarrabee	[21062] a	\N	\N
2f4b32af-3780-4a35-866c-ddc602118310	2018-02-28 08:44:48.01789-06	2	[13140] IC-248-InB Call	[4] DLarrabee	[21062] a	\N	\N
bfa70ea3-14c0-4a04-bc41-c2b67c4b0972	2018-02-28 08:44:48.020891-06	2	[13141] IC-248-OutB Call	[4] DLarrabee	[21062] a	\N	\N
8c7c4d3b-1c3c-459b-bc0a-27ab6ff50a8f	2018-02-28 08:44:48.148904-06	2	[13502] R5C13-8IC	[4] DLarrabee	[21062] a	\N	\N
869ef515-3f04-4729-bda3-2ed2b6d0fd70	2018-02-28 08:44:48.161905-06	2	[13504] IC-252-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
1ad59bf7-758d-4a70-ac9b-6b346ccf8876	2018-02-28 08:44:48.176906-06	2	[13505] IC-252-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
a1ab24a9-f8fc-41a2-b956-8e64d674610d	2018-02-28 08:44:48.193908-06	2	[13506] IC-253-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
b14e32cd-4008-4cd9-b833-8afa80578615	2018-02-28 08:44:48.21391-06	2	[13507] IC-253-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
419b1fce-1b50-4823-9da5-b27ccbe577ac	2018-02-28 08:44:48.225911-06	2	[13508] IC-259-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
bc0002c0-f688-445e-9826-7067b091f83a	2018-02-28 08:44:48.249914-06	2	[13509] IC-259-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
3b38ce95-29a0-40b0-9825-56134335ed17	2018-02-28 08:44:48.264915-06	2	[13510] IC-261-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
9383d767-7f52-4eeb-88e6-57c4cae02bd1	2018-02-28 08:44:48.91098-06	2	[14020] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
3a890c35-7fa2-41e3-b336-eb07b75f3364	2018-02-28 08:44:48.278917-06	2	[13511] IC-261-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
63f7df78-f905-42c8-b40f-ff59ef0c6f26	2018-02-28 08:44:48.291918-06	2	[13513] IC-252-InB Relay	[4] DLarrabee	[21062] a	\N	\N
aa5e1d06-79cb-43ce-b5f1-61f2dc63e9c6	2018-02-28 08:44:48.302919-06	2	[13514] IC-252-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
0affa18a-281f-4083-91d6-e59577cdb63b	2018-02-28 08:44:48.31492-06	2	[13515] IC-253-InB Relay	[4] DLarrabee	[21062] a	\N	\N
ad1ad388-6c14-41a9-a863-b5ffd4d15be6	2018-02-28 08:44:48.331922-06	2	[13516] IC-253-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
f3f63439-6202-4354-aa8f-70c0680a41d5	2018-02-28 08:44:48.348924-06	2	[13517] IC-259-InB Relay	[4] DLarrabee	[21062] a	\N	\N
3f216149-a0cb-4d64-a256-31845f73e9f5	2018-02-28 08:44:48.367925-06	2	[13518] IC-259-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
63e0624f-0f3e-4a20-a2b4-0d0cd81208e9	2018-02-28 08:44:48.385927-06	2	[13519] IC-261-InB Relay	[4] DLarrabee	[21062] a	\N	\N
68509f94-8090-4504-92c4-d72b58766a01	2018-02-28 08:44:48.400929-06	2	[13520] IC-261-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
8c023afc-7344-42d2-8057-44c839654695	2018-02-28 08:44:48.403929-06	2	[13522] IC-252-InB Connect	[4] DLarrabee	[21062] a	\N	\N
6deac0de-dcbe-46e8-bdd6-35ba23bc05a2	2018-02-28 08:44:48.406929-06	2	[13523] IC-252-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
bc0af506-88df-414e-a357-d0b1bc896b5d	2018-02-28 08:44:48.41093-06	2	[13524] IC-253-InB Connect	[4] DLarrabee	[21062] a	\N	\N
915b9d78-ec4c-4f0f-8386-f1afc72f91e8	2018-02-28 08:44:48.41393-06	2	[13525] IC-253-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
3f1355cb-88ae-46bc-be01-3b5bee607bcf	2018-02-28 08:44:48.41793-06	2	[13526] IC-259-InB Connect	[4] DLarrabee	[21062] a	\N	\N
86ce15e5-66e0-4013-a328-4eaecdb5285b	2018-02-28 08:44:48.421931-06	2	[13527] IC-259-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
b50dacda-d887-4558-bbac-2a7fd7219a55	2018-02-28 08:44:48.424931-06	2	[13528] IC-261-InB Connect	[4] DLarrabee	[21062] a	\N	\N
9922885c-8aa5-42c8-8c22-d17d7a1593f1	2018-02-28 08:44:48.428932-06	2	[13529] IC-261-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
dbc18ed7-c566-41b8-b0a2-a050d92d9e74	2018-02-28 08:44:48.431932-06	2	[13555] IC-252-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3b212414-c90c-4408-94db-ace54043d456	2018-02-28 08:44:48.434932-06	2	[13556] IC-252-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7f7aba00-431e-4230-a154-56cfb76d192e	2018-02-28 08:44:48.436932-06	2	[13557] IC-253-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
96896048-8f12-4f29-96e9-9938f3209574	2018-02-28 08:44:48.440933-06	2	[13558] IC-253-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
df756367-1d15-4a31-bb1c-436f4bb2ce8f	2018-02-28 08:44:48.443933-06	2	[13559] IC-259-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
987f6960-e083-440c-9d1d-0bca18b0be75	2018-02-28 08:44:48.446933-06	2	[13560] IC-259-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
74ce4408-afd6-44cf-b03b-1b45fd731f75	2018-02-28 08:44:48.449934-06	2	[13561] IC-261-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
80f0eacd-9261-43be-ba26-1dc08317a35a	2018-02-28 08:44:48.453934-06	2	[13562] IC-261-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
90dcb64d-602b-4324-a6c3-d792ff040b4c	2018-02-28 08:44:48.455934-06	2	[13574] IC-252-InB Call	[4] DLarrabee	[21062] a	\N	\N
c96e0829-8235-4095-80b8-e458dd63a824	2018-02-28 08:44:48.458935-06	2	[13575] IC-252-OutB Call	[4] DLarrabee	[21062] a	\N	\N
d5fde55d-1076-40ff-aac8-370acf41f5a1	2018-02-28 08:44:48.462935-06	2	[13576] IC-253-InB Call	[4] DLarrabee	[21062] a	\N	\N
6ea03e26-d61b-4ab4-a098-bf164216b8e0	2018-02-28 08:44:48.466935-06	2	[13577] IC-253-OutB Call	[4] DLarrabee	[21062] a	\N	\N
856044d5-efbf-42b7-b3ec-41cf0afe513d	2018-02-28 08:44:48.469936-06	2	[13578] IC-259-InB Call	[4] DLarrabee	[21062] a	\N	\N
90199e66-ccd9-44f6-9275-1836ea316225	2018-02-28 08:44:48.471936-06	2	[13579] IC-259-OutB Call	[4] DLarrabee	[21062] a	\N	\N
fd7521cb-6103-4624-ad9a-5047a3fc33b1	2018-02-28 08:44:48.475936-06	2	[13580] IC-261-InB Call	[4] DLarrabee	[21062] a	\N	\N
70aa68af-5747-4b39-a717-89152eddddea	2018-02-28 08:44:48.479937-06	2	[13581] IC-261-OutB Call	[4] DLarrabee	[21062] a	\N	\N
6fb8276b-bf5f-4190-b577-8e807b050a4c	2018-02-28 08:44:48.597948-06	2	[13942] R5C14-8IC	[4] DLarrabee	[21062] a	\N	\N
9aa3914f-3aaa-4560-b7e6-30ac51a4004e	2018-02-28 08:44:48.60995-06	2	[13944] IC-301A-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
984fa3ea-bfa6-49e2-a995-21f3f77c98af	2018-02-28 08:44:48.622951-06	2	[13945] IC-301A-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
6092e7cb-0e78-4876-83fb-0299b6a7f60c	2018-02-28 08:44:48.634952-06	2	[13946] IC-301B-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
044e08ea-1ca6-4fae-9db4-2155771092f9	2018-02-28 08:44:48.649954-06	2	[13947] IC-301B-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
2e20104a-ccc9-48f7-b587-7ab75aeb0e58	2018-02-28 08:44:48.663955-06	2	[13948] IC-306-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
aee25318-0601-442d-a1ce-ecec5f766590	2018-02-28 08:44:48.676956-06	2	[13949] IC-306-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
e3200054-9920-46d8-8b41-3d9374b9ad42	2018-02-28 08:44:48.691958-06	2	[13950] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
3def4f7f-5771-4656-ac94-40531d5aa1c3	2018-02-28 08:44:48.704959-06	2	[13951] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
6bf10415-d4f9-44f8-9ba4-69563dbfd1ef	2018-02-28 08:44:48.719961-06	2	[13953] IC-301A-InB Relay	[4] DLarrabee	[21062] a	\N	\N
7afbf4df-ab3b-499a-ad54-61db75bf6897	2018-02-28 08:44:48.736962-06	2	[13954] IC-301A-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
03769987-c294-4a38-b322-8491f6223556	2018-02-28 08:44:48.751964-06	2	[13955] IC-301B-InB Relay	[4] DLarrabee	[21062] a	\N	\N
d0450c15-89f0-4993-971c-c08e900e6ceb	2018-02-28 08:44:48.764965-06	2	[13956] IC-301B-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
78d6f0c6-1cbd-46e9-830e-313299b44996	2018-02-28 08:44:48.779967-06	2	[13957] IC-306-InB Relay	[4] DLarrabee	[21062] a	\N	\N
525043c7-e2ca-4873-b05f-e0097ab68ed6	2018-02-28 08:44:48.796968-06	2	[13958] IC-306-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
a058e3c4-2e76-452d-8b79-46169d958266	2018-02-28 08:44:48.81397-06	2	[13959] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
9ce3f917-151b-432d-b3db-7b0cd1584090	2018-02-28 08:44:48.831972-06	2	[13960] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
dc21e49a-625a-48bc-a6ef-b3040af45ee0	2018-02-28 08:44:48.834972-06	2	[13962] IC-301A-InB Connect	[4] DLarrabee	[21062] a	\N	\N
f18ef73f-bcf0-48c3-b3ba-07f041f9cce8	2018-02-28 08:44:48.838973-06	2	[13963] IC-301A-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
3325bee5-48fb-4925-b1a3-0e9bc53c5539	2018-02-28 08:44:48.840973-06	2	[13964] IC-301B-InB Connect	[4] DLarrabee	[21062] a	\N	\N
4d5afe1f-30f0-424c-9fab-58e77ec923be	2018-02-28 08:44:48.845973-06	2	[13965] IC-301B-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
3d18cf21-433d-4418-8f5a-d59224045f9a	2018-02-28 08:44:48.848974-06	2	[13966] IC-306-InB Connect	[4] DLarrabee	[21062] a	\N	\N
52b324ae-ec26-4165-95b0-19e5893651a2	2018-02-28 08:44:48.852974-06	2	[13967] IC-306-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
34b46eaf-c92c-4e5a-b1e7-5b6c4be47fbb	2018-02-28 08:44:48.855974-06	2	[13968] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
37891ec2-98d0-4d19-8f61-335e356f8859	2018-02-28 08:44:48.859975-06	2	[13969] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
2cb8deb0-e553-4da2-a34d-38d547de4bd0	2018-02-28 08:44:48.863975-06	2	[13995] IC-301A-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b55d3ab9-1e92-415b-9a3c-4a515d17ec96	2018-02-28 08:44:48.867975-06	2	[13996] IC-301A-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
08da4b65-df8b-44f5-b35f-f65d0e6fa7be	2018-02-28 08:44:48.870976-06	2	[13997] IC-301B-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
895f1d47-9aff-44ac-aae4-c52c2e1c8fa4	2018-02-28 08:44:48.873976-06	2	[13998] IC-301B-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e775298b-7ab1-43b2-9ac4-bdd9792200bf	2018-02-28 08:44:48.877976-06	2	[13999] IC-306-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
021bcd20-8118-48c5-82e6-3c770dbd933d	2018-02-28 08:44:48.880977-06	2	[14000] IC-306-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6fbb9219-f6d1-4f89-991b-8f799aa5f6a5	2018-02-28 08:44:48.884977-06	2	[14001] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
aaf86521-baaf-4da4-9c12-7d86ad47f1b9	2018-02-28 08:44:48.887977-06	2	[14002] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
79d40cc0-06d8-4501-b9aa-78f4dfe49351	2018-02-28 08:44:48.890978-06	2	[14014] IC-301A-InB Call	[4] DLarrabee	[21062] a	\N	\N
d5394f77-782f-4976-bade-c8cd793153d2	2018-02-28 08:44:48.894978-06	2	[14015] IC-301A-OutB Call	[4] DLarrabee	[21062] a	\N	\N
76608e10-c94d-46d4-8296-1e306dc8c35d	2018-02-28 08:44:48.897978-06	2	[14016] IC-301B-InB Call	[4] DLarrabee	[21062] a	\N	\N
0d0bd695-eac0-4f44-9d43-5ed77ec6ef30	2018-02-28 08:44:48.901979-06	2	[14017] IC-301B-OutB Call	[4] DLarrabee	[21062] a	\N	\N
8b46ce9f-c0a9-4c46-af51-4d3812d39ced	2018-02-28 08:44:48.904979-06	2	[14018] IC-306-InB Call	[4] DLarrabee	[21062] a	\N	\N
7c005262-7c9f-483a-9bb0-c7aef473b803	2018-02-28 08:44:48.907979-06	2	[14019] IC-306-OutB Call	[4] DLarrabee	[21062] a	\N	\N
dcf47283-4522-405c-b26f-c24a435d594c	2018-02-28 08:44:48.91498-06	2	[14021] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
a92d0ab5-0649-467c-af3e-243e9d410f83	2018-02-28 08:44:48.932982-06	2	[14382] R6C1-32I	[4] DLarrabee	[21062] a	\N	\N
8f70c4a1-7b07-45a3-8c0c-379c4e5f05df	2018-02-28 08:44:48.950984-06	2	[14384] DPIS-103 Call Button	[4] DLarrabee	[21062] a	\N	\N
a40f7213-53b1-41af-8121-893d2fd80f36	2018-02-28 08:44:48.966985-06	2	[14385] DPIS-104 Call Button	[4] DLarrabee	[21062] a	\N	\N
90339d9d-965e-4a27-a7b0-6f4bb04c01fb	2018-02-28 08:44:48.984987-06	2	[14386] DPIS-105 Call Button	[4] DLarrabee	[21062] a	\N	\N
bcd666d2-a840-4c52-abad-b8b9519492ab	2018-02-28 08:44:48.998989-06	2	[14387] DPIS-107 Call Button	[4] DLarrabee	[21062] a	\N	\N
ff0c8666-8f1a-43c8-a09b-15017b8448b5	2018-02-28 08:44:49.01499-06	2	[14388] DPIS-108 Call Button	[4] DLarrabee	[21062] a	\N	\N
694593ae-7db5-49da-b8e8-36abd441d1da	2018-02-28 08:44:49.029992-06	2	[14389] DPIS-109 Call Button	[4] DLarrabee	[21062] a	\N	\N
cfe3b1ff-f086-4b36-ae98-bf481c3990d0	2018-02-28 08:44:49.043993-06	2	[14390] DPIS-112 Call Button	[4] DLarrabee	[21062] a	\N	\N
36d3b0bd-3eb7-41a6-bffa-ccbda6dfccdc	2018-02-28 08:44:49.058995-06	2	[14391] DPIS-113 Call Button	[4] DLarrabee	[21062] a	\N	\N
7f363c25-c6b0-4d85-91a4-e03927a23d4a	2018-02-28 08:44:49.072996-06	2	[14392] DPIS-114A Call Button	[4] DLarrabee	[21062] a	\N	\N
b65be589-4010-4fc7-b7b2-d24913996e38	2018-02-28 08:44:49.085997-06	2	[14393] DPIS-114B Call Button	[4] DLarrabee	[21062] a	\N	\N
84f363e4-16e0-4515-85ac-90aa78880b2e	2018-02-28 08:44:49.101999-06	2	[14394] DPIS-115 Call Button	[4] DLarrabee	[21062] a	\N	\N
0e151550-25f1-488b-8757-814c085e52e2	2018-02-28 08:44:49.120001-06	2	[14395] DPIS-116 Call Button	[4] DLarrabee	[21062] a	\N	\N
fe21c550-fb37-4c93-bf60-a363a47f7bac	2018-02-28 08:44:49.137002-06	2	[14396] DPIS-117 Call Button	[4] DLarrabee	[21062] a	\N	\N
947874b1-0cff-4e37-a4ad-b4f60326b3b5	2018-02-28 08:44:49.152004-06	2	[14397] DPIS-119 Call Button	[4] DLarrabee	[21062] a	\N	\N
20c6d9c7-c134-4f8c-b5f1-1704e234b88e	2018-02-28 08:44:49.170006-06	2	[14398] DPIS-121 Call Button	[4] DLarrabee	[21062] a	\N	\N
37c717ab-08b0-4a6e-bc75-884c08dc4973	2018-02-28 08:44:49.185007-06	2	[14399] DPIS-122 Call Button	[4] DLarrabee	[21062] a	\N	\N
dc3ef3c4-eada-488c-bb00-b92c65b8621c	2018-02-28 08:44:49.205009-06	2	[14400] DPIS-123 Call Button	[4] DLarrabee	[21062] a	\N	\N
d5958e4d-0ffe-494c-8977-797bbe8ab394	2018-02-28 08:44:49.224011-06	2	[14401] DPIS-124 Call Button	[4] DLarrabee	[21062] a	\N	\N
cf5f0cc5-d308-4bee-ba7e-83c32a6e9d8b	2018-02-28 08:44:49.238012-06	2	[14402] DPIS-125 Call Button	[4] DLarrabee	[21062] a	\N	\N
d5939e77-8a73-426a-9c01-75bf056b6356	2018-02-28 08:44:49.254014-06	2	[14403] DPIS-126 Call Button	[4] DLarrabee	[21062] a	\N	\N
8a81be04-6f76-435a-9ca6-0889568dd8ec	2018-02-28 08:44:49.270016-06	2	[14404] DPIS-128 Call Button	[4] DLarrabee	[21062] a	\N	\N
4e8dbd8f-2ca7-4297-a2e1-ffed120c43bb	2018-02-28 08:44:49.284017-06	2	[14405] DPIS-129 Call Button	[4] DLarrabee	[21062] a	\N	\N
6a0782bf-b1c1-49a8-9db4-98ed85be776e	2018-02-28 08:44:49.300019-06	2	[14406] DPIS-131 Call Button	[4] DLarrabee	[21062] a	\N	\N
ba0cde73-a5c2-48ea-b646-2dafa579ba4f	2018-02-28 08:44:49.31802-06	2	[14407] DPIS-132 Call Button	[4] DLarrabee	[21062] a	\N	\N
244ab338-346d-421d-b30b-c21b2361a0ff	2018-02-28 08:44:49.337022-06	2	[14408] DPIS-133 Call Button	[4] DLarrabee	[21062] a	\N	\N
863533d9-5746-429c-a497-1715b23d320d	2018-02-28 08:44:49.354024-06	2	[14409] DPIS-134A Call Button	[4] DLarrabee	[21062] a	\N	\N
085e4fb6-84d2-4906-bc97-3f896659c551	2018-02-28 08:44:49.371026-06	2	[14410] DPIS-134B Call Button	[4] DLarrabee	[21062] a	\N	\N
74b951d4-5738-4ad7-9642-61c7bc02c098	2018-02-28 08:44:49.391028-06	2	[14411] DPIS-136 Call Button	[4] DLarrabee	[21062] a	\N	\N
d7f3506e-9f7b-44c4-9a59-90f1742fc2e8	2018-02-28 08:44:49.40903-06	2	[14412] DPIS-137 Call Button	[4] DLarrabee	[21062] a	\N	\N
cabac291-cf92-44e0-adf3-19df6286a453	2018-02-28 08:44:49.427031-06	2	[14413] DPIS-138 Call Button	[4] DLarrabee	[21062] a	\N	\N
b67647cb-df76-4720-bbbc-259ef127262a	2018-02-28 08:44:49.442033-06	2	[14414] INPUT 31 Call Button	[4] DLarrabee	[21062] a	\N	\N
73c14506-c08c-4caa-99e8-a98b04fc2b56	2018-02-28 08:44:49.456034-06	2	[14415] DPIS-141 Call Button	[4] DLarrabee	[21062] a	\N	\N
89fa32fe-f9cf-4a5c-bf41-ed750e2a3781	2018-02-28 08:44:49.460035-06	2	[14451] DPIS-103 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1438b03a-b94e-46b6-beb7-3bdae34b8581	2018-02-28 08:44:49.465035-06	2	[14452] DPIS-104 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b4eca65b-1055-46ac-9d17-74e06fe27339	2018-02-28 08:44:49.469036-06	2	[14453] DPIS-105 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e0845c42-f711-48b5-ae91-2ab65be94b03	2018-02-28 08:44:49.472036-06	2	[14454] DPIS-107 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
94f7a580-31e3-4484-b336-9b462397049c	2018-02-28 08:44:49.475036-06	2	[14455] DPIS-108 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a14d94a9-2695-4133-ae33-f2c6e27267db	2018-02-28 08:44:49.478036-06	2	[14456] DPIS-109 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
5ee3b899-b76f-4324-9538-895516139eb9	2018-02-28 08:44:49.482037-06	2	[14457] DPIS-112 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
43b21d27-3d9c-4eaa-bbc9-b684926c78ee	2018-02-28 08:44:49.486037-06	2	[14458] DPIS-113 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1f905245-6fa1-4d61-af67-d0d3f90dc3c1	2018-02-28 08:44:49.490038-06	2	[14459] DPIS-114A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
10ba8983-5cb5-460f-8bb0-17dcfca10a08	2018-02-28 08:44:49.494038-06	2	[14460] DPIS-114B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b6ea9a62-17b9-4641-b912-7820b81ba978	2018-02-28 08:44:49.498038-06	2	[14461] DPIS-115 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
5a6704a3-e293-409b-9265-9d7e42363e4a	2018-02-28 08:44:49.502039-06	2	[14462] DPIS-116 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2e5f6943-5f24-4707-b66f-8e5e95a03e30	2018-02-28 08:44:49.506039-06	2	[14463] DPIS-117 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
bb1d447b-17d1-46d6-822e-8bc4affbac05	2018-02-28 08:44:49.51004-06	2	[14464] DPIS-119 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c1532011-9a33-4d1c-9d6c-dd84586be8cd	2018-02-28 08:44:49.51304-06	2	[14465] DPIS-121 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7d7ea78e-ca6e-408e-912c-cfd05fbfb920	2018-02-28 08:44:49.51704-06	2	[14466] DPIS-122 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
576165c0-7f0d-4ce6-8412-4db21ec0059b	2018-02-28 08:44:49.521041-06	2	[14467] DPIS-123 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b309d79d-d920-4c53-9b62-6e950fd50e82	2018-02-28 08:44:49.525041-06	2	[14468] DPIS-124 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3c5ade2a-fb04-48b1-8ec6-503db2b0d733	2018-02-28 08:44:49.528041-06	2	[14469] DPIS-125 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7a9dfd91-e2e9-4ebc-a25f-f202ca9edd15	2018-02-28 08:44:49.530042-06	2	[14470] DPIS-126 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4c459a4b-21d5-438f-9094-ccf075ae8324	2018-02-28 08:44:49.534042-06	2	[14471] DPIS-128 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6517690e-c014-4b11-bd85-824ad756c0fa	2018-02-28 08:44:49.536042-06	2	[14472] DPIS-129 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
05382080-f19b-4d69-bb2c-ec995ca0052c	2018-02-28 08:44:49.539043-06	2	[14473] DPIS-131 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
04f185d8-4553-4a98-90e1-9419ede5ffff	2018-02-28 08:44:49.543043-06	2	[14474] DPIS-132 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
816878f5-43ae-4394-93b1-8e89d54f6c25	2018-02-28 08:44:49.546043-06	2	[14475] DPIS-133 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a0015d2a-4a7c-45a5-891f-249c63a3fbad	2018-02-28 08:44:49.548043-06	2	[14476] DPIS-134A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8a532f95-2f0f-4db2-9a1d-abb7cba5c559	2018-02-28 08:44:49.551044-06	2	[14477] DPIS-134B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3fc9e5b5-4a3a-45ab-a97e-e38755b00837	2018-02-28 08:44:49.554044-06	2	[14478] DPIS-136 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c71831e7-6bde-4970-ba18-1b57d450a417	2018-02-28 08:44:49.557044-06	2	[14479] DPIS-137 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
accfb7ec-f9d1-43a4-88ca-6f1fb6c91e3f	2018-02-28 08:44:49.560045-06	2	[14480] DPIS-138 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
dd34a4f3-32a6-457c-8438-ce8b76d67d47	2018-02-28 08:44:49.563045-06	2	[14481] INPUT 31 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9f45c28e-2bdf-4fc6-9d4b-6c1d7a214fc3	2018-02-28 08:44:49.567045-06	2	[14482] DPIS-141 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a55daacb-45ae-4fc4-8c81-dbd557f509ff	2018-02-28 08:44:49.582047-06	2	[14849] R6C2-32I	[4] DLarrabee	[21062] a	\N	\N
d3923564-9470-4c75-8939-57c6182fa5bf	2018-02-28 08:44:49.595048-06	2	[14851] DPIS-142 Call Button	[4] DLarrabee	[21062] a	\N	\N
25a9a1f9-87bb-4da3-aef4-2b6c4e15e4c1	2018-02-28 08:44:49.61505-06	2	[14852] DPIS-145 Call Button	[4] DLarrabee	[21062] a	\N	\N
f962bfde-f2a0-47d0-9366-ad3dd2e488f9	2018-02-28 08:44:49.629052-06	2	[14853] DPIS-146 Call Button	[4] DLarrabee	[21062] a	\N	\N
4e7195b5-a4e4-43c8-b18a-35cce44a46f4	2018-02-28 08:44:49.647053-06	2	[14854] DPIS-201 Call Button	[4] DLarrabee	[21062] a	\N	\N
a9e7bd79-4e60-4314-b447-188609d50560	2018-02-28 08:44:49.660055-06	2	[14855] DPIS-202 Call Button	[4] DLarrabee	[21062] a	\N	\N
db7078d9-b3d1-4bb0-b0fe-302393c32406	2018-02-28 08:44:49.674056-06	2	[14856] DPIS-203 Call Button	[4] DLarrabee	[21062] a	\N	\N
40689b8d-db33-47d4-8b0e-2f8911ff5018	2018-02-28 08:44:49.689058-06	2	[14857] DPIS-205 Call Button	[4] DLarrabee	[21062] a	\N	\N
374302d3-8fec-4446-896d-30c7d8aa5033	2018-02-28 08:44:49.708059-06	2	[14858] DPIS-206 Call Button	[4] DLarrabee	[21062] a	\N	\N
422932eb-cda6-44b0-b5ec-90de9ffbe622	2018-02-28 08:44:49.720061-06	2	[14859] DPIS-207 Call Button	[4] DLarrabee	[21062] a	\N	\N
e1f47527-8474-4c67-9341-061068a2d0ab	2018-02-28 08:44:49.735062-06	2	[14860] DPIS-209A Call Button	[4] DLarrabee	[21062] a	\N	\N
ea1c33b4-9a34-4569-a38d-335f0972d614	2018-02-28 08:44:49.754064-06	2	[14861] DPIS-209B Call Button	[4] DLarrabee	[21062] a	\N	\N
d4294db5-d1a7-4d31-a199-7697f58837cf	2018-02-28 08:44:49.769066-06	2	[14862] DPIS-211 Call Button	[4] DLarrabee	[21062] a	\N	\N
2f28f16c-6128-4daf-8068-ca72678ea7c2	2018-02-28 08:44:49.784067-06	2	[14863] DPIS-213 Call Button	[4] DLarrabee	[21062] a	\N	\N
d7bbbca9-907c-40a8-9d56-023cd7b3fce7	2018-02-28 08:44:49.802069-06	2	[14864] DPIS-214 Call Button	[4] DLarrabee	[21062] a	\N	\N
e409d195-5c2f-4c04-a666-88a416de7c15	2018-02-28 08:44:49.81607-06	2	[14865] DPIS-215 Call Button	[4] DLarrabee	[21062] a	\N	\N
40dd2ffc-0629-4d94-9ff6-3ac07f1cdf79	2018-02-28 08:44:49.835072-06	2	[14866] DPIS-216 Call Button	[4] DLarrabee	[21062] a	\N	\N
24783416-0ddb-49c3-bf83-002857dfa501	2018-02-28 08:44:49.849074-06	2	[14867] DPIS-218 Call Button	[4] DLarrabee	[21062] a	\N	\N
ae900e3e-a037-49fb-9548-b0e1afe8c578	2018-02-28 08:44:49.862075-06	2	[14868] DPIS-219 Call Button	[4] DLarrabee	[21062] a	\N	\N
1ab10291-9fc4-4149-bf6c-9934dd035871	2018-02-28 08:44:49.875076-06	2	[14869] DPIS-221 Call Button	[4] DLarrabee	[21062] a	\N	\N
2a00107d-bfef-4faf-8c13-25ae3d9c000e	2018-02-28 08:44:49.887077-06	2	[14870] DPIS-222 Call Button	[4] DLarrabee	[21062] a	\N	\N
d1f24953-2b29-4be1-880a-507118b1a62b	2018-02-28 08:44:49.900079-06	2	[14871] DPIS-223 Call Button	[4] DLarrabee	[21062] a	\N	\N
d329db8b-96c1-4328-bdfd-4d309182cd28	2018-02-28 08:44:49.91108-06	2	[14872] DPIS-224 Call Button	[4] DLarrabee	[21062] a	\N	\N
2d42353d-3664-43f5-a1ef-ecd5f09331b5	2018-02-28 08:44:49.931082-06	2	[14873] DPIS-225 Call Button	[4] DLarrabee	[21062] a	\N	\N
1a320053-36a7-46e0-8d47-805b1dd364a8	2018-02-28 08:44:49.947083-06	2	[14874] DPIS-226 Call Button	[4] DLarrabee	[21062] a	\N	\N
72e9cd6f-4814-45bd-9d93-9d7ae2478cdb	2018-02-28 08:44:49.962085-06	2	[14875] DPIS-227 Call Button	[4] DLarrabee	[21062] a	\N	\N
27c85e94-3c84-4465-a1cd-8a1294ddff28	2018-02-28 08:44:49.979087-06	2	[14876] DPIS-228 Call Button	[4] DLarrabee	[21062] a	\N	\N
b6274cc6-c282-4fe2-be70-5744aaee1914	2018-02-28 08:44:49.994088-06	2	[14877] DPIS-231 Call Button	[4] DLarrabee	[21062] a	\N	\N
671903a0-7e48-43dd-a5bc-e7b6ba763ad2	2018-02-28 08:44:50.008089-06	2	[14878] DPIS-232 Call Button	[4] DLarrabee	[21062] a	\N	\N
9559ef7d-1307-441e-8496-ffece17c276d	2018-02-28 08:44:50.024091-06	2	[14879] DPIS-233 Call Button	[4] DLarrabee	[21062] a	\N	\N
287bae1b-a45b-47cf-b3db-6f22c855118a	2018-02-28 08:44:50.038092-06	2	[14880] DPIS-235 Call Button	[4] DLarrabee	[21062] a	\N	\N
7d43ec6d-6c46-4b4a-add7-41fca3e22366	2018-02-28 08:44:50.054094-06	2	[14881] DPIS-236 Call Button	[4] DLarrabee	[21062] a	\N	\N
07bbf3da-6d4d-40ae-8037-3550f880a7a9	2018-02-28 08:44:50.067095-06	2	[14882] DPIS-237A Call Button	[4] DLarrabee	[21062] a	\N	\N
fd03c095-bd20-4da8-8953-5d1f14b18b91	2018-02-28 08:44:50.071096-06	2	[14918] DPIS-142 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a6573647-99e7-4d1a-bdea-17e529e486e1	2018-02-28 08:44:50.075096-06	2	[14919] DPIS-145 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ad37d71e-062c-44bc-9264-27c6f225c9bd	2018-02-28 08:44:50.078096-06	2	[14920] DPIS-146 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e855b1fd-4bee-449a-a417-da06095c4476	2018-02-28 08:44:50.083097-06	2	[14921] DPIS-201 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
028d7f02-4a7a-4d49-b2f2-4b0764a53d7c	2018-02-28 08:44:50.087097-06	2	[14922] DPIS-202 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d0399781-ddef-4a55-b3f2-e32205d56693	2018-02-28 08:44:50.090098-06	2	[14923] DPIS-203 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4354ca48-0d88-4927-84e5-40b5e378df5a	2018-02-28 08:44:50.094098-06	2	[14924] DPIS-205 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7d3c40ed-6d6e-43a6-90b7-1fcb182d863e	2018-02-28 08:44:50.098098-06	2	[14925] DPIS-206 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9ee5bd50-7ea0-428a-91b2-2b096cfd036c	2018-02-28 08:44:50.101099-06	2	[14926] DPIS-207 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ccbf213e-ca67-4988-a34c-6870e3ac183b	2018-02-28 08:44:50.105099-06	2	[14927] DPIS-209A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
083f5a38-0a20-4c6f-bc25-832e4fd876bd	2018-02-28 08:44:50.132102-06	2	[14928] DPIS-209B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
df0a967e-4838-4272-ae77-c6d84a6e72cd	2018-02-28 08:44:50.136102-06	2	[14929] DPIS-211 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
aea0005f-1580-4e5b-a8c1-f99aa1f0006a	2018-02-28 08:44:50.139103-06	2	[14930] DPIS-213 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ed54d3fe-da69-448d-bd09-fa28793eec16	2018-02-28 08:44:50.143103-06	2	[14931] DPIS-214 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c6139fc0-5c53-454e-8c22-ccc46a51846a	2018-02-28 08:44:50.147103-06	2	[14932] DPIS-215 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
df0f91c5-c890-4468-87db-3c2b2ef844e3	2018-02-28 08:44:50.150104-06	2	[14933] DPIS-216 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7c4f7b6b-fb0b-4827-a603-a72fc14b626e	2018-02-28 08:44:50.154104-06	2	[14934] DPIS-218 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0a3b2a2a-2fa8-466a-9510-a6cd7eb9ffc3	2018-02-28 08:44:50.158104-06	2	[14935] DPIS-219 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9ed9a8c9-f9e9-4e1d-8f12-3e147775239c	2018-02-28 08:44:50.161105-06	2	[14936] DPIS-221 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d59bce2c-fef5-4c89-be5f-21bc018fd153	2018-02-28 08:44:50.165105-06	2	[14937] DPIS-222 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
dabb4df6-6c82-4d23-ab70-2c1bce1873a1	2018-02-28 08:44:50.168105-06	2	[14938] DPIS-223 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
75a035f1-6f1b-4a8f-a298-8ed3a0bc055c	2018-02-28 08:44:50.172106-06	2	[14939] DPIS-224 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cc9c8b2e-f7eb-40bd-9bbd-16f11c82eae6	2018-02-28 08:44:50.175106-06	2	[14940] DPIS-225 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e98eece2-5ba8-4a0b-a765-727e5d5b225c	2018-02-28 08:44:50.179107-06	2	[14941] DPIS-226 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d313c569-08e4-4621-8eed-79441646ad96	2018-02-28 08:44:50.181107-06	2	[14942] DPIS-227 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6d01a785-48ef-4735-aed2-4895c0cf1ed7	2018-02-28 08:44:50.184107-06	2	[14943] DPIS-228 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
40290ee3-f3b7-4b18-85e5-61c28c4d0321	2018-02-28 08:44:50.187107-06	2	[14944] DPIS-231 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7f44418b-f46e-4d0a-80c5-c5b7c0cd1aca	2018-02-28 08:44:50.190108-06	2	[14945] DPIS-232 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
addf6b62-5909-4ef6-9ece-286afe2393c1	2018-02-28 08:44:50.193108-06	2	[14946] DPIS-233 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e86f8bd1-0586-4fe7-9c9f-f287f3849a96	2018-02-28 08:44:50.197108-06	2	[14947] DPIS-235 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
db94f3e6-15ae-4dc9-89b4-5c99b1c1f239	2018-02-28 08:44:50.201109-06	2	[14948] DPIS-236 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f15c62db-8dce-4096-8ab7-e59daaa34b01	2018-02-28 08:44:50.204109-06	2	[14949] DPIS-237A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a15f0c9b-8088-45c1-8f10-fc82ba5f9a8d	2018-02-28 08:44:50.223111-06	2	[15316] R6C3-32I	[4] DLarrabee	[21062] a	\N	\N
1b453839-677f-4d1c-9670-1f473d519974	2018-02-28 08:44:50.237112-06	2	[15318] DPIS-237B Call Button	[4] DLarrabee	[21062] a	\N	\N
2b703ca9-b5be-4877-ba45-281b0ba2541c	2018-02-28 08:44:50.251114-06	2	[15319] DPIS-239 Call Button	[4] DLarrabee	[21062] a	\N	\N
23b87505-3e2c-4149-9c68-8d69a3a41ac2	2018-02-28 08:44:50.265115-06	2	[15320] DPIS-241 Call Button	[4] DLarrabee	[21062] a	\N	\N
535eaab5-c18b-45d3-bb6e-50686bc635ab	2018-02-28 08:44:50.281117-06	2	[15321] DPIS-242 Call Button	[4] DLarrabee	[21062] a	\N	\N
0f95d9a9-a65a-4197-9fa5-dbfdb29da46a	2018-02-28 08:44:50.298118-06	2	[15322] DPIS-243 Call Button	[4] DLarrabee	[21062] a	\N	\N
2a73858c-c176-4396-9ba0-f3f1207a515f	2018-02-28 08:44:50.31412-06	2	[15323] DPIS-245 Call Button	[4] DLarrabee	[21062] a	\N	\N
ae754a4c-71c3-4e25-9f0c-b038357f5ed6	2018-02-28 08:44:50.328121-06	2	[15324] DPIS-246 Call Button	[4] DLarrabee	[21062] a	\N	\N
0da41e71-8dc9-4390-91f3-42d207da6b1e	2018-02-28 08:44:50.345123-06	2	[15325] DPIS-247 Call Button	[4] DLarrabee	[21062] a	\N	\N
2f033106-3dea-42e3-a3ec-02a2143f23a7	2018-02-28 08:44:50.360125-06	2	[15326] DPIS-248 Call Button	[4] DLarrabee	[21062] a	\N	\N
6da2c54f-f769-4afc-ab1d-edd0d4c0fa5d	2018-02-28 10:11:26.895726-06	2	[3820] R2C3-8IC	[4] DLarrabee	[21062] a	\N	\N
dad12c6d-278a-44f1-9ca9-5455ffa87350	2018-02-28 08:44:50.375126-06	2	[15327] DPIS-252 Call Button	[4] DLarrabee	[21062] a	\N	\N
69770508-3a16-4dfa-9ff2-76a65b58f423	2018-02-28 08:44:50.389128-06	2	[15328] DPIS-253 Call Button	[4] DLarrabee	[21062] a	\N	\N
3e018281-5a10-4442-8121-56a34796f24f	2018-02-28 08:44:50.404129-06	2	[15329] DPIS-259 Call Button	[4] DLarrabee	[21062] a	\N	\N
e633db6c-1b88-4457-9db9-ab8d7be67179	2018-02-28 08:44:50.422131-06	2	[15330] DPIS-261 Call Button	[4] DLarrabee	[21062] a	\N	\N
fe93d5bc-34ee-4fa2-966b-5a2c4032a467	2018-02-28 08:44:50.437132-06	2	[15331] DPIS-301A Call Button	[4] DLarrabee	[21062] a	\N	\N
095e16a3-4441-48b7-b748-6b61c676edc4	2018-02-28 08:44:50.458134-06	2	[15332] DPIS-301B Call Button	[4] DLarrabee	[21062] a	\N	\N
20e42c32-73fc-4f29-8e54-bd37caa7de3e	2018-02-28 08:44:50.479137-06	2	[15333] DPIS-306 Call Button	[4] DLarrabee	[21062] a	\N	\N
0308931b-cd79-47bc-a979-3b0a25a197ea	2018-02-28 08:44:50.496138-06	2	[15334] DPIS-102 Call Button	[4] DLarrabee	[21062] a	\N	\N
3710f2b3-ae4c-488f-a32f-a30b49509409	2018-02-28 08:44:50.51814-06	2	[15335] DPIS-111 Call Button	[4] DLarrabee	[21062] a	\N	\N
9d4fc0a9-34ba-4133-9cf4-d0ba19a32689	2018-02-28 08:44:50.538142-06	2	[15336] DPIS-135 Call Button	[4] DLarrabee	[21062] a	\N	\N
34d4bdea-9ef6-4dbf-a0c1-9505cb276248	2018-02-28 08:44:50.557144-06	2	[15337] DPIS-143 Call Button	[4] DLarrabee	[21062] a	\N	\N
d4df8d43-3fdf-435f-b8fc-9ee3e488c1da	2018-02-28 08:44:50.576146-06	2	[15338] DPIS-208 Call Button	[4] DLarrabee	[21062] a	\N	\N
79938503-9c8e-4e54-90a6-0fa9eebd2f9f	2018-02-28 08:44:50.592148-06	2	[15339] DPIS-212 Call Button	[4] DLarrabee	[21062] a	\N	\N
c8032406-94d0-4e8f-83e0-ccd20008f758	2018-02-28 08:44:50.607149-06	2	[15340] DPIS-234 Call Button	[4] DLarrabee	[21062] a	\N	\N
1d1c6702-a631-4944-8f9b-4644aaaf07a7	2018-02-28 08:44:50.626151-06	2	[15341] DPIS-238 Call Button	[4] DLarrabee	[21062] a	\N	\N
a4e236c4-d75d-4d5e-a03d-80cff517991a	2018-02-28 08:44:50.644153-06	2	[15342] DURESS-113 Call Button	[4] DLarrabee	[21062] a	\N	\N
585d77cb-eaa3-4fb4-8c2c-552f5d80bef3	2018-02-28 08:44:50.664155-06	2	[15343] DURESS-133 Call Button	[4] DLarrabee	[21062] a	\N	\N
d06e7cb0-939b-40c5-abf2-e64eeb63186c	2018-02-28 08:44:50.683157-06	2	[15344] DURESS-211 Call Button	[4] DLarrabee	[21062] a	\N	\N
30897f6b-60ba-481e-ad83-3bd0c3ea7cd1	2018-02-28 08:44:50.703159-06	2	[15345] DURESS-236 Call Button	[4] DLarrabee	[21062] a	\N	\N
c303aaa7-92b5-441d-8e20-65a3cc9c5dd5	2018-02-28 08:44:50.725161-06	2	[15346] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
92f58ed5-d282-4d88-b383-9e187f9c48b9	2018-02-28 08:44:50.741163-06	2	[15347] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
b3b32201-5394-4e99-bf1c-bfcbddf55b7e	2018-02-28 08:44:50.758164-06	2	[15348] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
7ec493de-5829-4146-89ab-8f82eeeef169	2018-02-28 08:44:50.775166-06	2	[15349] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
16cf4056-d1b9-49a1-9a64-0efb91afcb71	2018-02-28 08:44:50.779167-06	2	[15385] DPIS-237B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c02d7377-ccf8-457e-b7ab-431caa38daed	2018-02-28 08:44:50.783167-06	2	[15386] DPIS-239 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3bf55576-bf83-41e7-a5d5-a28bab0a3e55	2018-02-28 08:44:50.786167-06	2	[15387] DPIS-241 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cb121cf5-25d1-40f5-93e9-d068485e763a	2018-02-28 08:44:50.790168-06	2	[15388] DPIS-242 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e18ac1d6-bd59-430a-8cc6-ae090852da68	2018-02-28 08:44:50.794168-06	2	[15389] DPIS-243 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2ea7f91e-2aeb-4ba8-bd87-c6ae9e5e8236	2018-02-28 08:44:50.797168-06	2	[15390] DPIS-245 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c31ef77f-d9dd-42fb-942a-ff049b7e68ef	2018-02-28 08:44:50.801169-06	2	[15391] DPIS-246 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0c11b388-dd7f-4bdb-8323-79306103ac35	2018-02-28 08:44:50.805169-06	2	[15392] DPIS-247 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fc84f6d0-95a1-43d4-87c3-428ba966fc28	2018-02-28 08:44:50.80917-06	2	[15393] DPIS-248 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f3f87582-f0b5-4435-bc63-bf5c9c46d450	2018-02-28 08:44:50.81217-06	2	[15394] DPIS-252 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b4cfb5e9-b44e-4e4f-9a50-32f372170801	2018-02-28 08:44:50.81617-06	2	[15395] DPIS-253 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0f437c1d-d419-4477-830a-a2b372a68e46	2018-02-28 08:44:50.820171-06	2	[15396] DPIS-259 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
96939acc-310f-4edc-a03e-fab6e11540ac	2018-02-28 08:44:50.824171-06	2	[15397] DPIS-261 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
afd6e0f7-f30b-4ba5-9608-0861c2e6b28f	2018-02-28 08:44:50.828171-06	2	[15398] DPIS-301A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fe2a4c8c-3d8d-4c17-a16a-9b8adab9d7ec	2018-02-28 08:44:50.832172-06	2	[15399] DPIS-301B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ab293d67-03a7-425c-94e0-209b699b69ff	2018-02-28 08:44:50.835172-06	2	[15400] DPIS-306 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d238f675-282f-4c48-8c6f-6d987f26f28a	2018-02-28 08:44:50.850174-06	2	[15401] DPIS-102 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7a10f79f-13e2-47da-b6ff-4e1442d7e08f	2018-02-28 08:44:50.853174-06	2	[15402] DPIS-111 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9389f6a5-469f-4652-9610-8c090b0a7905	2018-02-28 08:44:50.857174-06	2	[15403] DPIS-135 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2371fe03-5c4a-4341-a532-e94ef05fcf74	2018-02-28 08:44:50.861175-06	2	[15404] DPIS-143 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b8ef0ab1-53e8-4c71-bd88-30e26cd1df6e	2018-02-28 08:44:50.865175-06	2	[15405] DPIS-208 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
01c3989d-2cf4-4348-b68b-b20013213af7	2018-02-28 08:44:50.869176-06	2	[15406] DPIS-212 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
087aebf3-f04e-43b6-98e4-74813366f0b7	2018-02-28 08:44:50.872176-06	2	[15407] DPIS-234 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1214c3a4-c36c-4c74-a0d3-40cf52c22c16	2018-02-28 08:44:50.876176-06	2	[15408] DPIS-238 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2e282557-d922-4fe2-8d13-a49471d5f60f	2018-02-28 08:44:50.880177-06	2	[15409] DURESS-113 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2ee08a9d-9693-431c-92e0-ff0e4ee4757e	2018-02-28 08:44:50.884177-06	2	[15410] DURESS-133 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
965c5b3c-e54f-4fba-a609-1b874ac1d7a4	2018-02-28 08:44:50.887177-06	2	[15411] DURESS-211 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d55108aa-5b76-4372-97c7-0ea28feb1d94	2018-02-28 08:44:50.891178-06	2	[15412] DURESS-236 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d0454746-5404-4b11-96e3-88d378718218	2018-02-28 08:44:50.894178-06	2	[15413] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f721d54f-5d42-4be2-adcb-c33d5d2977f2	2018-02-28 08:44:50.898178-06	2	[15414] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1822d75d-76c3-4546-afa4-8df91f205059	2018-02-28 08:44:50.901179-06	2	[15415] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2837e193-88af-45b1-b07b-aff3a96dd6f1	2018-02-28 08:44:50.905179-06	2	[15416] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
120f2534-f6c8-45b4-9dc9-dcf7fbb2eacf	2018-02-28 08:44:50.926181-06	2	[15783] R7C1-16R	[4] DLarrabee	[21062] a	\N	\N
561b9b78-2a4e-40bf-85cf-0ace367093c7	2018-02-28 08:44:50.944183-06	2	[15786] Lock Relay-103 Relay	[4] DLarrabee	[21062] a	\N	\N
d3d1d421-0392-4932-bcb2-3f83c1d5c3c1	2018-02-28 08:44:50.964185-06	2	[15787] Lock Relay-104 Relay	[4] DLarrabee	[21062] a	\N	\N
e7c3670f-a5eb-4a82-aeb0-f51f595ed895	2018-02-28 08:44:50.982187-06	2	[15788] Lock Relay-105 Relay	[4] DLarrabee	[21062] a	\N	\N
65c7738d-5375-402b-bf7e-be17c4326726	2018-02-28 08:44:50.995188-06	2	[15789] Lock Relay-107 Relay	[4] DLarrabee	[21062] a	\N	\N
36efe552-c88f-40e5-9043-012e478b0091	2018-02-28 08:44:51.00919-06	2	[15790] Lock Relay-108 Relay	[4] DLarrabee	[21062] a	\N	\N
6fd9859d-4464-4f8f-968a-35d39806ddc1	2018-02-28 08:44:51.027191-06	2	[15791] Lock Relay-109 Relay	[4] DLarrabee	[21062] a	\N	\N
a12a998b-ed9b-44f7-a6d2-df944a5cc8f7	2018-02-28 08:44:51.040193-06	2	[15792] Lock Relay-112 Relay	[4] DLarrabee	[21062] a	\N	\N
0830e090-0e6b-4b59-aa81-947453f5d672	2018-02-28 08:44:51.052194-06	2	[15793] Lock Relay-113 Relay	[4] DLarrabee	[21062] a	\N	\N
28824490-5e38-4bdf-beeb-3dcceab95845	2018-02-28 08:44:51.066195-06	2	[15794] Lock Relay-114A Relay	[4] DLarrabee	[21062] a	\N	\N
801b37b6-df14-4d44-8706-d62dbb288e15	2018-02-28 08:44:51.084197-06	2	[15795] Lock Relay-114B Relay	[4] DLarrabee	[21062] a	\N	\N
795419f0-bd05-4974-80a9-91f3542ed932	2018-02-28 08:44:51.103199-06	2	[15796] Lock Relay-115 Relay	[4] DLarrabee	[21062] a	\N	\N
f9ce60b3-c8d4-4f7f-80ae-c10f64c0d34c	2018-02-28 08:44:51.123201-06	2	[15797] Lock Relay-116 Relay	[4] DLarrabee	[21062] a	\N	\N
527d9e94-4032-4d1c-9d1b-0bd791254d44	2018-02-28 08:44:51.135202-06	2	[15798] Lock Relay-117 Relay	[4] DLarrabee	[21062] a	\N	\N
bf19ae6b-ff8e-4fe6-9fdc-8bdf14240a48	2018-02-28 08:44:51.148203-06	2	[15799] Lock Relay-119 Relay	[4] DLarrabee	[21062] a	\N	\N
dc8edaae-bd22-47f9-a53e-60021c5d9877	2018-02-28 08:44:51.160205-06	2	[15800] Lock Relay-121 Relay	[4] DLarrabee	[21062] a	\N	\N
efc1b451-6d32-4193-84ce-a19a8d6e7146	2018-02-28 08:44:51.174206-06	2	[15801] Lock Relay-122 Relay	[4] DLarrabee	[21062] a	\N	\N
7a8988b6-86aa-4454-b715-80b63e354bff	2018-02-28 08:44:51.189208-06	2	[16103] R7C2-16R	[4] DLarrabee	[21062] a	\N	\N
3c31138b-10c3-4e6f-bffc-e294d4b70cb1	2018-02-28 08:44:51.206209-06	2	[16106] Lock Relay-123 Relay	[4] DLarrabee	[21062] a	\N	\N
04e4ca70-ca79-4f65-baa0-7f0b9be0faed	2018-02-28 08:44:51.219211-06	2	[16107] Lock Relay-124 Relay	[4] DLarrabee	[21062] a	\N	\N
006438ed-27ce-405d-85e6-fd459b6ecf6c	2018-02-28 08:44:51.232212-06	2	[16108] Lock Relay-125 Relay	[4] DLarrabee	[21062] a	\N	\N
b7fdeb88-d61b-4dc8-90dd-86f71394695f	2018-02-28 08:44:51.244213-06	2	[16109] Lock Relay-126 Relay	[4] DLarrabee	[21062] a	\N	\N
cdd43357-b0b0-4c1f-95de-f7763811ec61	2018-02-28 08:44:51.257214-06	2	[16110] Lock Relay-128 Relay	[4] DLarrabee	[21062] a	\N	\N
a7fa431e-3dde-4cb8-b15a-b8a3869ba613	2018-02-28 08:44:51.275216-06	2	[16111] Lock Relay-129 Relay	[4] DLarrabee	[21062] a	\N	\N
54c58a76-df83-4a6d-b89d-0e083b36a762	2018-02-28 08:44:51.287217-06	2	[16112] Lock Relay-131 Relay	[4] DLarrabee	[21062] a	\N	\N
e8496893-b5eb-404b-bd07-55367ce853df	2018-02-28 08:44:51.299219-06	2	[16113] Lock Relay-132 Relay	[4] DLarrabee	[21062] a	\N	\N
e680ef5d-e6f0-4d5e-bafc-65aa19d537a2	2018-02-28 08:44:51.31422-06	2	[16114] Lock Relay-133 Relay	[4] DLarrabee	[21062] a	\N	\N
0650d150-0ba9-47a5-bcc3-6d996d1f77b2	2018-02-28 08:44:51.328221-06	2	[16115] Lock Relay-134A Relay	[4] DLarrabee	[21062] a	\N	\N
b70a647a-26ae-4e49-ba50-9fb9f604b143	2018-02-28 08:44:51.343223-06	2	[16116] Lock Relay-134B Relay	[4] DLarrabee	[21062] a	\N	\N
7a6c437b-ed1d-43d8-b5b0-73d7cdb0fad1	2018-02-28 08:44:51.358224-06	2	[16117] Lock Relay-136 Relay	[4] DLarrabee	[21062] a	\N	\N
e1997fd2-a297-43f1-8cbc-efa1ecb48f85	2018-02-28 08:44:51.378226-06	2	[16118] Lock Relay-137 Relay	[4] DLarrabee	[21062] a	\N	\N
78b8979a-7c9d-45a9-8ed6-e9be07e7c294	2018-02-28 08:44:51.392228-06	2	[16119] Lock Relay-138 Relay	[4] DLarrabee	[21062] a	\N	\N
ed4146dc-a7dd-4aa0-9b67-4ce9663e407f	2018-02-28 08:44:51.41023-06	2	[16120] Lock Relay-141 Relay	[4] DLarrabee	[21062] a	\N	\N
c86f8907-ce43-4a0b-aeba-8eb119714fad	2018-02-28 08:44:51.428231-06	2	[16121] Lock Relay-142 Relay	[4] DLarrabee	[21062] a	\N	\N
657a3b80-f3c2-46b5-8c55-7ab269496645	2018-02-28 08:44:51.444233-06	2	[16423] R7C3-16R	[4] DLarrabee	[21062] a	\N	\N
f575b61d-73fe-4e53-914f-2b1261f9239e	2018-02-28 08:44:51.459235-06	2	[16426] Lock Relay-145 Relay	[4] DLarrabee	[21062] a	\N	\N
503df045-8168-4112-a093-ba76ea16902a	2018-02-28 08:44:51.475236-06	2	[16427] Lock Relay-146 Relay	[4] DLarrabee	[21062] a	\N	\N
a57643d0-c5eb-4256-a1e8-204d18b6ed45	2018-02-28 08:44:51.490238-06	2	[16428] Lock Relay-201 Relay	[4] DLarrabee	[21062] a	\N	\N
cb9f6d3a-71a6-4c80-a4f9-abb29b07107c	2018-02-28 08:44:51.507239-06	2	[16429] Lock Relay-202 Relay	[4] DLarrabee	[21062] a	\N	\N
861749ca-e36e-4ffc-91d2-b56629e7b1bb	2018-02-28 08:44:51.520241-06	2	[16430] Lock Relay-203 Relay	[4] DLarrabee	[21062] a	\N	\N
3dde91a5-ca4b-4a51-bc63-6bf1203a2357	2018-02-28 08:44:51.534242-06	2	[16431] Lock Relay-205 Relay	[4] DLarrabee	[21062] a	\N	\N
66055264-c5c3-47bd-8bf1-c13f8a985c23	2018-02-28 08:44:51.549244-06	2	[16432] Lock Relay-206 Relay	[4] DLarrabee	[21062] a	\N	\N
47ea1b7e-2a1a-495b-b24e-ca6174049aa6	2018-02-28 08:44:51.562245-06	2	[16433] Lock Relay-207 Relay	[4] DLarrabee	[21062] a	\N	\N
a8df1cd9-d19b-4919-bab5-9e78085ff8fe	2018-02-28 08:44:51.582247-06	2	[16434] Lock Relay-209A Relay	[4] DLarrabee	[21062] a	\N	\N
4c05d720-f9e3-4c82-9b23-03ddf52542f5	2018-02-28 08:44:51.597248-06	2	[16435] Lock Relay-209B Relay	[4] DLarrabee	[21062] a	\N	\N
5b619376-6adf-4f6f-914a-13ae7bf21e5f	2018-02-28 08:44:51.61425-06	2	[16436] Lock Relay-211 Relay	[4] DLarrabee	[21062] a	\N	\N
dd90e5b9-fd45-4cd2-adf7-f3c92e6a7d6e	2018-02-28 08:44:51.629252-06	2	[16437] Lock Relay-213 Relay	[4] DLarrabee	[21062] a	\N	\N
0ddf5f42-db99-4f1c-893d-70bf69c02e6a	2018-02-28 08:44:51.647253-06	2	[16438] Lock Relay-214 Relay	[4] DLarrabee	[21062] a	\N	\N
13630d8b-875f-4c0b-9763-3e4f6ca629da	2018-02-28 08:44:51.660255-06	2	[16439] Lock Relay-215 Relay	[4] DLarrabee	[21062] a	\N	\N
9d5f9a3a-75fe-4709-bab6-f27dbc58263d	2018-02-28 08:44:51.677256-06	2	[16440] Lock Relay-216 Relay	[4] DLarrabee	[21062] a	\N	\N
5f27795e-1a9d-45f2-ba4a-1437b7bcc3c8	2018-02-28 08:44:51.690258-06	2	[16441] Lock Relay-218 Relay	[4] DLarrabee	[21062] a	\N	\N
77d63f2f-d0b8-4253-b5a6-32d9015cfa5f	2018-02-28 08:44:51.707259-06	2	[16743] R7C4-16R	[4] DLarrabee	[21062] a	\N	\N
95dca945-b7c7-4229-ba30-02bc3b908d93	2018-02-28 08:44:51.720261-06	2	[16746] Lock Relay-219 Relay	[4] DLarrabee	[21062] a	\N	\N
fd3248fe-4b5e-4e91-859b-fa2ca240d0bd	2018-02-28 08:44:51.736262-06	2	[16747] Lock Relay-221 Relay	[4] DLarrabee	[21062] a	\N	\N
0569cfbc-3859-479f-857f-c4f4add677ca	2018-02-28 08:44:51.752264-06	2	[16748] Lock Relay-222 Relay	[4] DLarrabee	[21062] a	\N	\N
bd02f04c-67ea-4686-8f72-4591b4639148	2018-02-28 08:44:51.765265-06	2	[16749] Lock Relay-223 Relay	[4] DLarrabee	[21062] a	\N	\N
eaa6123a-8c33-42c0-9458-3384257f5b2a	2018-02-28 08:44:51.778266-06	2	[16750] Lock Relay-224 Relay	[4] DLarrabee	[21062] a	\N	\N
53fccf2d-8aad-417f-b5e9-b6a374deebf3	2018-02-28 08:44:51.790268-06	2	[16751] Lock Relay-225 Relay	[4] DLarrabee	[21062] a	\N	\N
64289b52-4ae0-45c5-8b1e-fa1e5fa203ba	2018-02-28 08:44:51.81027-06	2	[16752] Lock Relay-226 Relay	[4] DLarrabee	[21062] a	\N	\N
559b7636-4f62-4c37-97b7-401aa43871f1	2018-02-28 08:44:51.827271-06	2	[16753] Lock Relay-227 Relay	[4] DLarrabee	[21062] a	\N	\N
fc99349f-969a-4c2a-bcc2-7042e9defff2	2018-02-28 08:44:51.844273-06	2	[16754] Lock Relay-228 Relay	[4] DLarrabee	[21062] a	\N	\N
e30ce8fc-09ab-4c2d-b296-7534e043fa5d	2018-02-28 08:44:51.857274-06	2	[16755] Lock Relay-231 Relay	[4] DLarrabee	[21062] a	\N	\N
b0fe3b56-994e-4fe2-a2f9-0b932b1da530	2018-02-28 08:44:51.871276-06	2	[16756] Lock Relay-232 Relay	[4] DLarrabee	[21062] a	\N	\N
15c5b8d5-4f7b-46f6-b2f5-9e657eb6620d	2018-02-28 08:44:51.886277-06	2	[16757] Lock Relay-233 Relay	[4] DLarrabee	[21062] a	\N	\N
822c322a-bf3b-4b15-b6d0-1b1feecd08d8	2018-02-28 08:44:51.901279-06	2	[16758] Lock Relay-235 Relay	[4] DLarrabee	[21062] a	\N	\N
bb9f17cd-2d29-48f2-8711-c3ed56f94c54	2018-02-28 08:44:51.91528-06	2	[16759] Lock Relay-236 Relay	[4] DLarrabee	[21062] a	\N	\N
c23536fb-a322-45c2-8758-9bb4e16c9b12	2018-02-28 08:44:51.931282-06	2	[16760] Lock Relay-237A Relay	[4] DLarrabee	[21062] a	\N	\N
157707a6-785a-41a3-a239-ec615212f6ba	2018-02-28 08:44:51.945283-06	2	[16761] Lock Relay-237B Relay	[4] DLarrabee	[21062] a	\N	\N
96fd86f9-ab07-4d78-b7ff-6a9f02d18fbb	2018-02-28 08:44:51.961285-06	2	[17063] R7C5-16R	[4] DLarrabee	[21062] a	\N	\N
d2680c60-a460-4b35-83d2-0132b1389de9	2018-02-28 08:44:51.976286-06	2	[17066] Lock Relay-239 Relay	[4] DLarrabee	[21062] a	\N	\N
eaf93e81-1ad1-45c8-91f0-b0be272bf77a	2018-02-28 08:44:51.991288-06	2	[17067] Lock Relay-241 Relay	[4] DLarrabee	[21062] a	\N	\N
d5a4ee71-2305-4f54-b128-ebea9e4851aa	2018-02-28 08:44:52.006289-06	2	[17068] Lock Relay-242 Relay	[4] DLarrabee	[21062] a	\N	\N
86c18b6e-1a4f-4edb-bb3d-fbb1a277c0af	2018-02-28 08:44:52.035292-06	2	[17069] Lock Relay-243 Relay	[4] DLarrabee	[21062] a	\N	\N
58047327-d603-467c-aba4-36a53d66c4d0	2018-02-28 08:44:52.050294-06	2	[17070] Lock Relay-245 Relay	[4] DLarrabee	[21062] a	\N	\N
1eb9efa2-96ee-4ab0-84aa-71c2ca3113ba	2018-02-28 08:44:52.064295-06	2	[17071] Lock Relay-246 Relay	[4] DLarrabee	[21062] a	\N	\N
9a4e4c05-8eeb-4877-93bb-dab9ffc899e3	2018-02-28 08:44:52.075296-06	2	[17072] Lock Relay-247 Relay	[4] DLarrabee	[21062] a	\N	\N
54919ccd-09d8-4a0b-9c41-144a51708c76	2018-02-28 08:44:52.088297-06	2	[17073] Lock Relay-248 Relay	[4] DLarrabee	[21062] a	\N	\N
94a2793a-92c6-4a34-8f45-061c62682a1a	2018-02-28 08:44:52.104299-06	2	[17074] Lock Relay-252 Relay	[4] DLarrabee	[21062] a	\N	\N
faf0529c-4d60-466e-87db-c8b219a96c2e	2018-02-28 08:44:52.119301-06	2	[17075] Lock Relay-253 Relay	[4] DLarrabee	[21062] a	\N	\N
f79fcbe3-5846-4d42-92ac-9b61e6a76914	2018-02-28 08:44:52.134302-06	2	[17076] Lock Relay-259 Relay	[4] DLarrabee	[21062] a	\N	\N
36b541c0-64db-45a0-a934-44c2a8c47699	2018-02-28 08:44:52.153304-06	2	[17077] Lock Relay-261 Relay	[4] DLarrabee	[21062] a	\N	\N
6edcb973-c96d-4567-a45f-44e55c77a24e	2018-02-28 08:44:52.171306-06	2	[17078] Lock Relay-301A Relay	[4] DLarrabee	[21062] a	\N	\N
2f122ef1-5de3-4b33-878e-3926b1531506	2018-02-28 08:44:52.193308-06	2	[17079] Lock Relay-301B Relay	[4] DLarrabee	[21062] a	\N	\N
0510ec12-e236-4fee-b5a5-2ffc74abc52e	2018-02-28 08:44:52.206309-06	2	[17080] Lock Relay-306 Relay	[4] DLarrabee	[21062] a	\N	\N
995cc6a2-0554-4add-851d-732a5cf2b0c4	2018-02-28 08:44:52.229312-06	2	[17081] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
b25a2d43-bc61-4e40-b267-498cd39ad3a9	2018-02-28 08:47:44.876575-06	2	[8224] IC-134A-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
5677c5fd-4cfb-4e21-a771-367d3112d52e	2018-02-28 08:47:44.905577-06	2	[8225] IC-134B-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
0b2bb1cb-5811-4879-8747-36e077173950	2018-02-28 08:47:44.919579-06	2	[8226] IC-134B-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
d97bbae4-16e3-4a6f-868f-6ba6dcd4a17b	2018-02-28 08:47:44.938581-06	2	[8227] IC-122-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
41e3a626-c96e-498b-9368-90dccb106dc6	2018-02-28 08:47:44.954582-06	2	[8228] IC-122-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
633b0246-158f-4b57-8160-cd2195d484fa	2018-02-28 08:47:44.969584-06	2	[8229] IC-123-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
e4c12334-cfe1-40c5-a290-ce5349f6f164	2018-02-28 08:47:44.985585-06	2	[8230] IC-123-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
2c7f672e-8f74-485a-be4b-d3e107166ce2	2018-02-28 08:49:26.326719-06	2	[17386] IC-307-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
3176b28e-d502-4276-a70b-fa0213e1d773	2018-02-28 08:49:26.363722-06	2	[17395] IC-307-InB Relay	[4] DLarrabee	[21062] a	\N	\N
f59dfa95-0e76-4b30-bf78-fec8507cbfaf	2018-02-28 08:49:26.381724-06	2	[17396] IC-307-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
a76fc45e-e1a6-4a05-b32e-d4a74d29a1cb	2018-02-28 08:49:26.401726-06	2	[17397] IC-309-InB Relay	[4] DLarrabee	[21062] a	\N	\N
04f94ccb-0a8e-42f5-9ec4-97c645227f17	2018-02-28 08:49:26.416728-06	2	[17398] IC-309-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
cc07d2fb-c246-4057-9595-8b2fa943b6c6	2018-02-28 08:49:26.433729-06	2	[17399] IC-314-InB Relay	[4] DLarrabee	[21062] a	\N	\N
9c64d390-30da-4bae-991f-ea7aea8626e1	2018-02-28 08:49:26.448731-06	2	[17400] IC-314-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
4f6c2cc3-fff9-425d-9588-3c8fcc1acf26	2018-02-28 08:49:26.465732-06	2	[17401] IC-322-InB Relay	[4] DLarrabee	[21062] a	\N	\N
5d8d7e6b-d599-4ab1-911f-38e7db461bf9	2018-02-28 08:49:26.480734-06	2	[17402] IC-322-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
c0455b75-ce65-43be-be20-fbec21257c00	2018-02-28 08:49:26.484734-06	2	[17404] IC-307-InB Connect	[4] DLarrabee	[21062] a	\N	\N
26f75a88-3007-46ba-958a-821b3bf18fad	2018-02-28 08:49:26.489735-06	2	[17405] IC-307-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
06e1228c-7b29-4574-a0a9-2e8d82a3e830	2018-02-28 08:49:26.492735-06	2	[17406] IC-309-InB Connect	[4] DLarrabee	[21062] a	\N	\N
56c7137f-deaa-4ddc-b693-e32915c90094	2018-02-28 08:49:26.496736-06	2	[17407] IC-309-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
08bfcd9c-a8a9-4bb3-abde-84661bda985d	2018-02-28 08:49:26.500736-06	2	[17408] IC-314-InB Connect	[4] DLarrabee	[21062] a	\N	\N
6644e383-8df6-4f49-88c3-e5b9c962cd8e	2018-02-28 08:49:26.504736-06	2	[17409] IC-314-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
5061343f-2da9-44cc-b32c-a1733540c575	2018-02-28 08:49:26.509737-06	2	[17410] IC-322-InB Connect	[4] DLarrabee	[21062] a	\N	\N
bd90b7d8-15f7-4966-9146-13fe40951239	2018-02-28 08:49:26.512737-06	2	[17411] IC-322-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
fe93e7ba-76bc-44f0-b914-5083f61bdeb6	2018-02-28 08:49:26.516738-06	2	[17437] IC-307-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
12f5ba35-351b-43e5-9c0a-570ced45afe8	2018-02-28 08:49:26.521738-06	2	[17438] IC-307-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
54baee6d-ed9f-4564-aeda-4996c95c3382	2018-02-28 08:49:26.524738-06	2	[17439] IC-309-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7394a743-6df4-4666-b254-fbad27a6342a	2018-02-28 08:49:26.528739-06	2	[17440] IC-309-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d20b51e1-2010-4d66-9d85-15f029b15ef0	2018-02-28 08:49:26.533739-06	2	[17441] IC-314-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
77d7010e-2c12-456e-962e-75d386a39a9f	2018-02-28 08:49:26.53674-06	2	[17442] IC-314-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3fb8cd9d-f93b-47cd-901d-78e43065ae16	2018-02-28 08:49:26.54074-06	2	[17443] IC-322-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
49b1d132-6eb7-42dd-b269-8531ab568fdf	2018-02-28 08:49:26.54374-06	2	[17444] IC-322-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
43dd3365-b5c7-4eeb-aaf0-b25a27d0f560	2018-02-28 08:49:26.546741-06	2	[17456] IC-307-InB Call	[4] DLarrabee	[21062] a	\N	\N
768914b5-33af-4c60-8ca3-0486a3535f5f	2018-02-28 08:49:26.549741-06	2	[17457] IC-307-OutB Call	[4] DLarrabee	[21062] a	\N	\N
e5298c89-1779-4400-b460-06f2542f6686	2018-02-28 08:49:26.552741-06	2	[17458] IC-309-InB Call	[4] DLarrabee	[21062] a	\N	\N
48590441-1369-4315-bf06-370442460d23	2018-02-28 08:49:26.555741-06	2	[17459] IC-309-OutB Call	[4] DLarrabee	[21062] a	\N	\N
3c9a56e2-1c78-4987-8f25-0ff6f8b9fb51	2018-02-28 08:49:26.558742-06	2	[17460] IC-314-InB Call	[4] DLarrabee	[21062] a	\N	\N
3b432241-2304-4f72-8927-91b8b0691a51	2018-02-28 08:49:26.562742-06	2	[17461] IC-314-OutB Call	[4] DLarrabee	[21062] a	\N	\N
21031bf8-97fd-4bbd-9236-82f0b4db2e2f	2018-02-28 08:49:26.565742-06	2	[17462] IC-322-InB Call	[4] DLarrabee	[21062] a	\N	\N
1a9f5b75-0302-4ae6-b4d4-01d357006976	2018-02-28 08:49:26.568743-06	2	[17463] IC-322-OutB Call	[4] DLarrabee	[21062] a	\N	\N
d2d059aa-8685-4735-8694-7837bfa72ec9	2018-02-28 08:49:26.688755-06	2	[17825] R8C2-8IC	[4] DLarrabee	[21062] a	\N	\N
53acc688-e3a9-4c5b-baaa-c8b5678edcba	2018-02-28 08:49:26.703756-06	2	[17827] IC-324A-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
e47b3cb1-a8be-46e5-a55c-6695c10ddad7	2018-02-28 08:49:26.718758-06	2	[17828] IC-324A-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
5bd419c8-c437-43fc-9794-f2c3d4489558	2018-02-28 08:49:26.73676-06	2	[17829] IC-324B-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
efc8990a-e7e9-42ed-aedc-170768c2faf8	2018-02-28 08:49:26.750761-06	2	[17830] IC-324B-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
82bc2765-5b3b-4aa1-8ad9-214f2c74f313	2018-02-28 08:49:26.766763-06	2	[17831] IC-324C-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
77ae2870-2dbb-4526-baef-864b14d21558	2018-02-28 08:49:26.784764-06	2	[17832] IC-324C-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
a38aaf76-6f26-4139-b23c-6e5123ea30eb	2018-02-28 08:49:26.798766-06	2	[17833] IC-333-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
32a27192-407d-4c1b-8c0a-296ba0781778	2018-02-28 08:49:26.813767-06	2	[17834] IC-333-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
a823dd4e-faa5-44e7-ae0b-4e64b8ad1085	2018-02-28 08:49:26.828769-06	2	[17836] IC-324A-InB Relay	[4] DLarrabee	[21062] a	\N	\N
48382ad0-d134-49e1-8120-fb3321188d5a	2018-02-28 08:49:26.847771-06	2	[17837] IC-324A-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
b3be6d58-853a-474c-9147-4544759db389	2018-02-28 08:49:26.862772-06	2	[17838] IC-324B-InB Relay	[4] DLarrabee	[21062] a	\N	\N
84822b54-4765-4d37-8b16-013c19f7acc0	2018-02-28 08:49:26.880774-06	2	[17839] IC-324B-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
44dd8784-71d3-4648-ae05-2f32ffa01ff4	2018-02-28 08:49:26.898776-06	2	[17840] IC-324C-InB Relay	[4] DLarrabee	[21062] a	\N	\N
148e2563-9e48-4fda-9d67-87deef108135	2018-02-28 08:49:26.913777-06	2	[17841] IC-324C-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
c6d253ee-5099-473a-a7a2-c5e5539c5117	2018-02-28 08:49:26.932779-06	2	[17842] IC-333-InB Relay	[4] DLarrabee	[21062] a	\N	\N
e9a14c8a-b671-4239-8133-ed54159f2be7	2018-02-28 08:49:26.946781-06	2	[17843] IC-333-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
b9bb6f00-cf91-4a5b-8619-7d5864cd9b70	2018-02-28 08:49:26.949781-06	2	[17845] IC-324A-InB Connect	[4] DLarrabee	[21062] a	\N	\N
56076059-5005-4863-b1ad-abc8632a9da5	2018-02-28 08:49:26.952781-06	2	[17846] IC-324A-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
98c18fbe-4995-4aab-bfb6-ad9273c7e0d3	2018-02-28 08:49:26.956782-06	2	[17847] IC-324B-InB Connect	[4] DLarrabee	[21062] a	\N	\N
f29916ee-06fb-4330-8ab2-ea2d1d2addb7	2018-02-28 08:49:26.960782-06	2	[17848] IC-324B-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
65016e7a-5d1a-400f-a465-d95ae76d07b8	2018-02-28 08:49:26.963782-06	2	[17849] IC-324C-InB Connect	[4] DLarrabee	[21062] a	\N	\N
e9a975f4-8d07-4571-8dff-332427b2a1f6	2018-02-28 08:49:26.968783-06	2	[17850] IC-324C-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
7dcd9e3e-a361-4b82-b749-16094becaa1d	2018-02-28 08:49:26.971783-06	2	[17851] IC-333-InB Connect	[4] DLarrabee	[21062] a	\N	\N
be9abc4c-b013-499c-8657-3d4324c1dc77	2018-02-28 08:49:26.975783-06	2	[17852] IC-333-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
7c4f1aab-72bf-4e7c-9217-525119d681df	2018-02-28 08:49:26.978784-06	2	[17878] IC-324A-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
59b81082-20a2-4f7d-8082-0ceef1027542	2018-02-28 08:49:26.980784-06	2	[17879] IC-324A-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7b7eab47-b6b6-47cf-8e7a-a9e5df166b30	2018-02-28 08:49:26.984784-06	2	[17880] IC-324B-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1830a341-b822-4db0-9fc9-a51e928ca18e	2018-02-28 08:49:26.988785-06	2	[17881] IC-324B-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4ca1e9dd-da8b-43cc-af9b-91fa8cdc4a5f	2018-02-28 08:49:26.992785-06	2	[17882] IC-324C-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1c5ddcd7-11dd-4a25-98cc-db7d706cbe67	2018-02-28 08:49:26.996786-06	2	[17883] IC-324C-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3c419b5a-ef2f-4caf-a41f-f4ef2589ba88	2018-02-28 08:49:27.000786-06	2	[17884] IC-333-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
495eb224-e9cf-4f64-83e8-85b3f667d560	2018-02-28 08:49:27.004786-06	2	[17885] IC-333-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9241f98b-ab4c-4d38-a672-e37871194760	2018-02-28 08:49:27.008787-06	2	[17897] IC-324A-InB Call	[4] DLarrabee	[21062] a	\N	\N
85304745-95ac-4bfd-806b-389ce868dfe9	2018-02-28 08:49:27.011787-06	2	[17898] IC-324A-OutB Call	[4] DLarrabee	[21062] a	\N	\N
b3f7f5b3-bfd2-41e2-8b7f-5cbc85656e52	2018-02-28 08:49:27.014787-06	2	[17899] IC-324B-InB Call	[4] DLarrabee	[21062] a	\N	\N
b92da8e9-9273-46e4-8617-3c9b82eb610b	2018-02-28 08:49:27.018788-06	2	[17900] IC-324B-OutB Call	[4] DLarrabee	[21062] a	\N	\N
4c5cc692-5dcd-4bf7-8341-2dc7434a56a1	2018-02-28 08:49:27.022788-06	2	[17901] IC-324C-InB Call	[4] DLarrabee	[21062] a	\N	\N
fe9a597c-c65a-4560-8b14-b7690ca46835	2018-02-28 08:49:27.026789-06	2	[17902] IC-324C-OutB Call	[4] DLarrabee	[21062] a	\N	\N
08a4b84e-0418-4cee-807f-2e7a4f3c785b	2018-02-28 08:49:27.030789-06	2	[17903] IC-333-InB Call	[4] DLarrabee	[21062] a	\N	\N
6ce5a4d9-dad8-4308-94c3-53a557c58107	2018-02-28 08:49:27.033789-06	2	[17904] IC-333-OutB Call	[4] DLarrabee	[21062] a	\N	\N
153ec5cc-eb62-448e-8875-14e365b8aeff	2018-02-28 08:49:27.148801-06	2	[18265] R8C3-8IC	[4] DLarrabee	[21062] a	\N	\N
9faddd63-86f5-48de-8fc1-f69baee2d4b9	2018-02-28 08:49:27.160802-06	2	[18267] IC-330A-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
dd01642f-c40e-43db-b0cd-4a0f64811d7d	2018-02-28 08:49:27.173803-06	2	[18268] IC-330A-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
69e72b75-dd28-4375-a720-49bde530b090	2018-02-28 08:49:27.186805-06	2	[18269] IC-330B-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
85de22ad-a274-4490-ab77-308817dc781b	2018-02-28 08:49:27.198806-06	2	[18270] IC-330B-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
fa56df9a-d563-47cb-a715-b2e8b6beb7a7	2018-02-28 08:49:27.211807-06	2	[18271] IC-378-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
af8a9a26-0cf4-4e2a-aa45-6d3a82b6c3b9	2018-02-28 08:49:27.226809-06	2	[18272] IC-378-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
57a85a9d-0061-49fe-81db-3ef7fd35edeb	2018-02-28 08:49:27.24081-06	2	[18273] IC-448-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
b5f2eafd-9e23-4c32-890f-00db32002c65	2018-02-28 08:49:27.252811-06	2	[18274] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
68c89330-10d2-45a4-a936-bbfcdd648fe4	2018-02-28 08:49:27.265812-06	2	[18276] IC-330A-InB Relay	[4] DLarrabee	[21062] a	\N	\N
48a05d77-2c4d-4fe4-a4dd-98b3de460e1c	2018-02-28 08:49:27.279814-06	2	[18277] IC-330A-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
9ec5f304-42f6-4c99-9132-c262452a70fd	2018-02-28 08:49:27.296816-06	2	[18278] IC-330B-InB Relay	[4] DLarrabee	[21062] a	\N	\N
5ef040d2-c109-4d1b-b1c3-69aa844bb16c	2018-02-28 08:49:27.318818-06	2	[18279] IC-330B-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
9033ceec-9594-4958-8ddd-6f2d7ae8b02c	2018-02-28 08:49:27.331819-06	2	[18280] IC-378-InB Relay	[4] DLarrabee	[21062] a	\N	\N
5a17c8f6-fc04-4ce8-951b-a50938b400c2	2018-02-28 08:49:27.346821-06	2	[18281] IC-378-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
43619f27-170b-44b7-b189-90ef1fb877c1	2018-02-28 08:49:27.365822-06	2	[18282] IC-448-InB Relay	[4] DLarrabee	[21062] a	\N	\N
d9b53394-8e95-46ba-b1c9-98aaa23c73fe	2018-02-28 08:49:27.379824-06	2	[18283] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
6414af9d-4ca6-46c9-b91d-724957ada5df	2018-02-28 08:49:27.382824-06	2	[18285] IC-330A-InB Connect	[4] DLarrabee	[21062] a	\N	\N
11cca620-bd85-4eb5-baa9-ebe85518deb7	2018-02-28 08:49:27.386825-06	2	[18286] IC-330A-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
a304a32d-4371-4058-88db-f71b4b4e881a	2018-02-28 08:49:27.389825-06	2	[18287] IC-330B-InB Connect	[4] DLarrabee	[21062] a	\N	\N
b5fd0abf-d9f3-4c28-b0d4-f90a5ed731f2	2018-02-28 08:49:27.392825-06	2	[18288] IC-330B-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
a9dc3b1e-13c1-4e69-8776-40a5781a97fa	2018-02-28 08:49:27.395825-06	2	[18289] IC-378-InB Connect	[4] DLarrabee	[21062] a	\N	\N
50aa9096-a65e-44c7-b6b1-9054c222fd06	2018-02-28 08:49:27.398826-06	2	[18290] IC-378-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
d743a42e-e446-4b3a-b7cd-f88805182492	2018-02-28 08:49:27.401826-06	2	[18291] IC-448-InB Connect	[4] DLarrabee	[21062] a	\N	\N
0b69d8bc-967d-4d4e-87b1-183493fb0d2f	2018-02-28 08:49:27.406827-06	2	[18292] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
7a3eba2a-13ba-4a2e-b698-94b44a0283a5	2018-02-28 08:49:27.409827-06	2	[18318] IC-330A-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f9657eb2-f6ba-4182-96b1-e36b7f02c880	2018-02-28 08:49:27.412827-06	2	[18319] IC-330A-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
dc4471d4-3d04-413e-8cba-6df6e1d4cd73	2018-02-28 08:49:27.417828-06	2	[18320] IC-330B-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
5bc23778-7b82-49d1-88a9-610e04c22e6f	2018-02-28 08:49:27.421828-06	2	[18321] IC-330B-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a8d79d07-4f66-4959-aa74-5ab62c2f228f	2018-02-28 08:49:27.424828-06	2	[18322] IC-378-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f60118e9-4cb9-4966-8d71-5528d2c029d9	2018-02-28 08:49:27.427829-06	2	[18323] IC-378-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f83630d1-529b-49c0-a1a6-d6b5991c410d	2018-02-28 08:49:27.430829-06	2	[18324] IC-448-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f0faed20-8f27-4c56-a46c-63b4e4741cc5	2018-02-28 08:49:27.433829-06	2	[18325] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3ea4adff-c77f-4947-bf64-524b5f265275	2018-02-28 08:49:27.43683-06	2	[18337] IC-330A-InB Call	[4] DLarrabee	[21062] a	\N	\N
405e342f-4223-41f4-a802-3554bf30c63f	2018-02-28 08:49:27.43983-06	2	[18338] IC-330A-OutB Call	[4] DLarrabee	[21062] a	\N	\N
5a115ea4-2f24-4400-ae7f-9c49c85929b7	2018-02-28 08:49:27.44283-06	2	[18339] IC-330B-InB Call	[4] DLarrabee	[21062] a	\N	\N
7d0ec597-de05-4c59-aa44-bd0d7c27cb38	2018-02-28 08:49:27.44583-06	2	[18340] IC-330B-OutB Call	[4] DLarrabee	[21062] a	\N	\N
0c56386c-3eed-432a-ab71-8a9d5362a754	2018-02-28 08:49:27.448831-06	2	[18341] IC-378-InB Call	[4] DLarrabee	[21062] a	\N	\N
507cee11-0013-4250-b406-40e73c5bc5fa	2018-02-28 08:49:27.451831-06	2	[18342] IC-378-OutB Call	[4] DLarrabee	[21062] a	\N	\N
844a815d-c52c-489e-ba7d-ed2c1c449f67	2018-02-28 08:49:27.454831-06	2	[18343] IC-448-InB Call	[4] DLarrabee	[21062] a	\N	\N
3e2312eb-dc29-4257-8758-83ef7865417a	2018-02-28 08:49:27.456832-06	2	[18344] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
fe23b7ed-6339-42fd-b063-837469cb101d	2018-02-28 08:49:27.477834-06	2	[18705] R8C4-32I	[4] DLarrabee	[21062] a	\N	\N
d9b1c07d-832e-4f5d-9c73-6308279925ed	2018-02-28 08:49:27.495835-06	2	[18707] DPIS-307 Call Button	[4] DLarrabee	[21062] a	\N	\N
6f499cf9-5f0b-4e96-9363-6fb0771c0988	2018-02-28 08:49:27.509837-06	2	[18708] DPIS-309 Call Button	[4] DLarrabee	[21062] a	\N	\N
84c319f8-6476-4b0e-988d-35d1eb65e9d4	2018-02-28 08:49:27.528839-06	2	[18709] DPIS-314 Call Button	[4] DLarrabee	[21062] a	\N	\N
bd32b303-6c18-4cb7-925e-e62338b9d9f6	2018-02-28 08:49:27.54384-06	2	[18710] DPIS-322 Call Button	[4] DLarrabee	[21062] a	\N	\N
118f9a1c-fa77-4dcc-b68a-6c2414580afd	2018-02-28 08:49:27.557842-06	2	[18711] DPIS-324A Call Button	[4] DLarrabee	[21062] a	\N	\N
ce7f0bd7-c864-4dd5-9151-e1b3cbdfec3a	2018-02-28 08:49:27.572843-06	2	[18712] DPIS-324B Call Button	[4] DLarrabee	[21062] a	\N	\N
e8088dbc-4cc3-417f-99bb-41893c735e73	2018-02-28 08:49:27.589845-06	2	[18713] DPIS-324C Call Button	[4] DLarrabee	[21062] a	\N	\N
eb891e86-2bc7-4022-901c-fe789a5e0cb9	2018-02-28 08:49:27.605846-06	2	[18714] DPIS-333 Call Button	[4] DLarrabee	[21062] a	\N	\N
1f13f7f2-77ff-4332-a1c8-bdf74d16a20a	2018-02-28 08:49:27.619848-06	2	[18715] DPIS-330A Call Button	[4] DLarrabee	[21062] a	\N	\N
cfc41f3a-0026-4cae-a55b-0b9bd44d9ebb	2018-02-28 08:49:27.633849-06	2	[18716] DPIS-330B Call Button	[4] DLarrabee	[21062] a	\N	\N
da7d616c-7a6a-48f2-8e1d-d05152e9813e	2018-02-28 08:49:27.647851-06	2	[18717] DPIS-378 Call Button	[4] DLarrabee	[21062] a	\N	\N
8a84242d-a315-4bcc-ab73-b4e045c817d3	2018-02-28 08:49:27.660852-06	2	[18718] DPIS-414A Call Button	[4] DLarrabee	[21062] a	\N	\N
0fabcb94-c959-4275-859e-5176f318830e	2018-02-28 08:49:27.675853-06	2	[18719] DPIS-414B Call Button	[4] DLarrabee	[21062] a	\N	\N
3ad42578-6912-485c-aef5-a7241441f2b8	2018-02-28 08:49:27.689855-06	2	[18720] DPIS-323OHD Call Button	[4] DLarrabee	[21062] a	\N	\N
3d56b5a1-5b10-492d-a9c7-41ab5c50bd45	2018-02-28 08:49:27.704856-06	2	[18721] DPIS-324OHDE Call Button	[4] DLarrabee	[21062] a	\N	\N
29f3878e-2cb3-4ce8-854e-e5036d3e7c42	2018-02-28 08:49:27.719858-06	2	[18722] DPIS-324OHDW Call Button	[4] DLarrabee	[21062] a	\N	\N
93eff471-b4eb-4485-bcf6-74a45ae21ec5	2018-02-28 08:49:27.732859-06	2	[18723] DPIS-342 Call Button	[4] DLarrabee	[21062] a	\N	\N
b75199e4-9d7c-4a16-aef2-7f7e19f764cf	2018-02-28 08:49:27.747861-06	2	[18724] DURESS-415 Call Button	[4] DLarrabee	[21062] a	\N	\N
fa7d8932-3123-4125-b07c-21a55a46eef0	2018-02-28 08:49:27.764862-06	2	[18725] DURESS-418 Call Button	[4] DLarrabee	[21062] a	\N	\N
8c5c64e9-6f3a-4b72-8215-82557c8f34c2	2018-02-28 08:49:27.778864-06	2	[18726] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
3abb801d-6cc4-43fb-98a1-acc75ef2a7e7	2018-02-28 08:49:27.796866-06	2	[18727] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
169e42b1-26a6-4c29-9be4-5b73e46c8dc8	2018-02-28 08:49:27.811867-06	2	[18728] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
9fd03a52-8f6a-4228-bd77-863c090142f0	2018-02-28 08:49:27.826869-06	2	[18729] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
98f0be94-6c34-4d3d-8b03-7394c9b2a514	2018-02-28 08:49:27.84087-06	2	[18730] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
56a34ff7-f902-4f5a-a4d7-af05152c79f3	2018-02-28 08:49:27.854871-06	2	[18731] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
3539ef6b-9175-494c-bf42-66f4398e0540	2018-02-28 08:49:27.872873-06	2	[18732] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
3d0f1874-8d1e-4527-99b6-fb79a494d156	2018-02-28 08:49:27.887875-06	2	[18733] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
0ce6f1f7-5ff8-43a5-a102-aa78d19072ca	2018-02-28 08:49:27.899876-06	2	[18734] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
1f87f613-ff9d-475a-9cae-a5e4d2ee31c8	2018-02-28 08:49:27.914877-06	2	[18735] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
6c1bb293-e980-40c0-9890-90c184b80bc8	2018-02-28 08:49:27.929879-06	2	[18736] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
9d6035f5-b134-4856-a6b2-9de64ed2787f	2018-02-28 08:49:27.94388-06	2	[18737] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
4b8b31bb-c9c5-401d-bbd4-2f5b5642b2bf	2018-02-28 08:49:27.960882-06	2	[18738] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
b7779b86-3027-416a-95ce-7b7b99620e20	2018-02-28 08:49:27.963882-06	2	[18774] DPIS-307 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b021e795-f533-463d-b710-ddd0d0484818	2018-02-28 08:49:27.967883-06	2	[18775] DPIS-309 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7da22d96-9765-411f-9fbf-a6ab0377d560	2018-02-28 08:49:27.970883-06	2	[18776] DPIS-314 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9765b78b-4dc4-4b2c-a132-9bba027f38b9	2018-02-28 08:49:27.974883-06	2	[18777] DPIS-322 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
36596b15-3a13-4c46-a4d3-7e2118cd24b3	2018-02-28 08:49:27.977884-06	2	[18778] DPIS-324A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
bb00fb76-ac78-4ae5-adf8-85633ebbc6a6	2018-02-28 08:49:27.981884-06	2	[18779] DPIS-324B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d7957e56-8dd9-4764-ac78-88863455dc46	2018-02-28 08:49:27.985884-06	2	[18780] DPIS-324C Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
83b3e59a-5952-40ad-9cb3-734808ea119f	2018-02-28 08:49:27.989885-06	2	[18781] DPIS-333 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cf87df75-d6bf-4efc-b64d-ff8d905081e0	2018-02-28 08:49:27.992885-06	2	[18782] DPIS-330A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
40622772-0c2d-4e6b-98f8-fe9160ba6a69	2018-02-28 08:49:27.996886-06	2	[18783] DPIS-330B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0a28a3f3-6229-40b9-ab2a-1c9f7ae24677	2018-02-28 08:49:27.999886-06	2	[18784] DPIS-378 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
46647e70-e933-4227-bdf7-958c8445b826	2018-02-28 08:49:28.003886-06	2	[18785] DPIS-414A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3457204f-3ee5-4998-b9f1-cbcf5ea614d4	2018-02-28 08:49:28.007887-06	2	[18786] DPIS-414B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f63acc80-4d7f-4b77-9838-00f96c90a42d	2018-02-28 08:49:28.011887-06	2	[18787] DPIS-323OHD Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
75f67e13-1f6f-4e1d-bf83-e5a238679fde	2018-02-28 08:49:28.014887-06	2	[18788] DPIS-324OHDE Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
448044a5-3651-46bb-9a77-eae3a6c9a014	2018-02-28 08:49:28.018888-06	2	[18789] DPIS-324OHDW Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
444a95ec-0c79-481b-91ba-594c51bbca83	2018-02-28 08:49:28.022888-06	2	[18790] DPIS-342 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
95f556c6-f7b9-40c7-ac82-58c19f8794c2	2018-02-28 08:49:28.025888-06	2	[18791] DURESS-415 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0312bbd6-5894-438f-8cd3-b655c2311e40	2018-02-28 08:49:28.029889-06	2	[18792] DURESS-418 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f6558712-555a-43a3-baee-d476357bf2ae	2018-02-28 08:49:28.033889-06	2	[18793] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2277e472-a6e1-4074-95b6-bbd4e3e88001	2018-02-28 08:49:28.03689-06	2	[18794] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fec53df9-b6ab-4f1e-9cd0-7d13c6f3091e	2018-02-28 08:49:28.03989-06	2	[18795] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fe50715c-645d-431c-9045-ca1e72e29a4b	2018-02-28 08:49:28.04389-06	2	[18796] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
38b59018-d773-41a5-8fd5-bc1f4714bc1d	2018-02-28 08:49:28.047891-06	2	[18797] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3c728caa-3455-4c9a-8d72-a9ba9834163e	2018-02-28 08:49:28.050891-06	2	[18798] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c9b1ef30-5c79-4fdf-8861-fbe58ff20a5b	2018-02-28 08:49:28.053891-06	2	[18799] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fb52ab96-ff81-4847-841c-05de8aad10e6	2018-02-28 08:49:28.057892-06	2	[18800] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1a83f043-62b3-49d7-a509-5a3283da50f5	2018-02-28 08:49:28.060892-06	2	[18801] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
671fe295-98f3-4dff-8073-b123edc3a8df	2018-02-28 08:49:28.064892-06	2	[18802] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8b8db511-4ab1-4a52-9651-d34620c98d81	2018-02-28 08:49:28.068893-06	2	[18803] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f954f6c0-ca60-4af9-9e01-d6e9a9b2145f	2018-02-28 08:49:28.073893-06	2	[18804] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8cff4b54-253c-4ee8-a104-39d222cf5a53	2018-02-28 08:49:28.076894-06	2	[18805] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
19dbbeb2-e0a3-4ea7-9e68-f73b8536002b	2018-02-28 08:49:28.097896-06	2	[19172] R8C5-16R	[4] DLarrabee	[21062] a	\N	\N
1f1666d3-aca7-4cc6-a1ec-0ef338084953	2018-02-28 08:49:28.111897-06	2	[19175] Lock Relay-307 Relay	[4] DLarrabee	[21062] a	\N	\N
dc703218-33b3-4ee5-85d5-b39607dd1d1e	2018-02-28 08:49:28.127899-06	2	[19176] Lock Relay-309 Relay	[4] DLarrabee	[21062] a	\N	\N
306663c1-4039-41f9-b9d3-1443342d1f10	2018-02-28 08:49:28.164902-06	2	[19177] Lock Relay-314 Relay	[4] DLarrabee	[21062] a	\N	\N
18dc8973-302f-4684-85bd-b99fe90aae88	2018-02-28 08:49:28.180904-06	2	[19178] Lock Relay-322 Relay	[4] DLarrabee	[21062] a	\N	\N
2631a38b-95b3-4220-a534-ebc74fe26818	2018-02-28 08:49:28.195905-06	2	[19179] Lock Relay-324A Relay	[4] DLarrabee	[21062] a	\N	\N
78290819-4b9c-4e8a-88cb-2df2545741b6	2018-02-28 08:49:28.213907-06	2	[19180] Lock Relay-324B Relay	[4] DLarrabee	[21062] a	\N	\N
755b8c7f-ca94-4f58-97d5-f7fc64841dbd	2018-02-28 08:49:28.225908-06	2	[19181] Lock Relay-324C Relay	[4] DLarrabee	[21062] a	\N	\N
b79791e9-d42d-4d6b-91f2-eba9545e0fd8	2018-02-28 08:49:28.24091-06	2	[19182] Lock Relay-333 Relay	[4] DLarrabee	[21062] a	\N	\N
aa49bd99-30de-4e72-b772-051098fc384f	2018-02-28 08:49:28.255911-06	2	[19183] Lock Relay-330A Relay	[4] DLarrabee	[21062] a	\N	\N
cfdbc989-19f9-4778-b6e7-e9f24f5c28c7	2018-02-28 08:49:28.270913-06	2	[19184] Lock Relay-330B Relay	[4] DLarrabee	[21062] a	\N	\N
8ac1bac8-374f-4e30-ad12-d06c8083e512	2018-02-28 08:49:28.289915-06	2	[19185] Lock Relay-378 Relay	[4] DLarrabee	[21062] a	\N	\N
8cf41944-bd7e-47a5-8c32-c20604c708ac	2018-02-28 08:49:28.305916-06	2	[19186] Lock Relay-414A Relay	[4] DLarrabee	[21062] a	\N	\N
94b16024-5b19-4d3f-b7fe-03de628f738d	2018-02-28 08:49:28.321918-06	2	[19187] Lock Relay-414B Relay	[4] DLarrabee	[21062] a	\N	\N
970464ad-aaf6-4c42-9980-0b9f2a84e11d	2018-02-28 08:49:28.33992-06	2	[19188] OPEN Relay-323OHD Relay	[4] DLarrabee	[21062] a	\N	\N
085f9ba8-0195-40ac-8075-7b8e37924615	2018-02-28 08:49:28.354921-06	2	[19189] CLOSE Relay-323OHD Relay	[4] DLarrabee	[21062] a	\N	\N
798c17d8-cd18-45e8-a066-ff8b38195735	2018-02-28 08:49:28.368923-06	2	[19190] OPEN Relay-324OHDE Relay	[4] DLarrabee	[21062] a	\N	\N
131ee065-c33d-410e-b3ec-4fb215324a49	2018-02-28 08:49:28.384924-06	2	[19492] R8C6-16R	[4] DLarrabee	[21062] a	\N	\N
7eb9c3bf-e67f-4106-8d69-838a135bee77	2018-02-28 08:49:28.398926-06	2	[19495] CLOSE Relay-324OHDE Relay	[4] DLarrabee	[21062] a	\N	\N
1861836e-90ae-4094-a865-772061e1e30e	2018-02-28 08:49:28.411927-06	2	[19496] OPEN Relay-324OHDW Relay	[4] DLarrabee	[21062] a	\N	\N
c52e2ba0-2653-4e29-b8ae-42d2bade3579	2018-02-28 08:49:28.431929-06	2	[19497] CLOSE Relay-324OHDW Relay	[4] DLarrabee	[21062] a	\N	\N
cdb8b266-5852-4c53-a881-18e8f4358d91	2018-02-28 08:49:28.447931-06	2	[19498] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
3481996d-a29c-4682-9548-921206799b9a	2018-02-28 08:49:28.462932-06	2	[19499] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
9f945148-833a-49d0-a5a4-10a5030087d5	2018-02-28 08:49:28.476934-06	2	[19500] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
09cc6728-00e7-4c2d-ae52-80efaa0c2cd0	2018-02-28 08:49:28.493935-06	2	[19501] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
ae83b064-83df-4ce6-a8c6-4e97762961ca	2018-02-28 08:49:28.511937-06	2	[19502] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
a2a0fb22-c5e5-4f27-84b9-1418fb6b06e8	2018-02-28 08:49:28.527939-06	2	[19503] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
6d88ff37-9363-4da3-826d-2a70dde3a046	2018-02-28 08:49:28.54494-06	2	[19504] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
924fcb8c-cabd-4b43-adaa-a7eb841748ce	2018-02-28 08:49:28.560942-06	2	[19505] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
94095587-fa34-429a-a656-fc8e2a2da02c	2018-02-28 08:49:28.573943-06	2	[19506] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
fba7cd39-3d48-41f8-9466-f891df002867	2018-02-28 08:49:28.586945-06	2	[19507] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
a469a232-9e87-4c6f-bfff-53ffd5c0e376	2018-02-28 08:49:28.602946-06	2	[19508] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
c7644cee-baab-4427-b111-6182282762e9	2018-02-28 08:49:28.618948-06	2	[19509] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
a8b0cab4-4e3a-4624-8368-2f034d86e020	2018-02-28 08:49:28.635949-06	2	[19510] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
9fe0ea68-1164-456c-aa1f-49ff02f02364	2018-02-28 08:51:01.129198-06	2	[17387] IC-307-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
be680401-2912-42af-9653-091322051dc5	2018-02-28 08:51:01.145199-06	2	[17388] IC-309-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
4589694d-acf9-4478-b8ff-0a6e8992265d	2018-02-28 08:51:01.185203-06	2	[17389] IC-309-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
421f7bab-874c-4621-ad06-8ad6721aff4c	2018-02-28 08:51:01.197205-06	2	[17390] IC-314-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
0ec05b1f-829a-46da-bb16-18733f45e316	2018-02-28 08:51:01.214206-06	2	[17391] IC-314-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
85257160-be79-4982-9ee6-daecf38e74e0	2018-02-28 08:51:01.231208-06	2	[17392] IC-322-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
b24982d2-f1b5-448a-a17a-e614c125353e	2018-02-28 08:51:01.25221-06	2	[17393] IC-322-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
154e9a0f-34bf-4399-889b-6b6bbe103313	2018-02-28 08:53:50.774161-06	2	[19815] DPIS-429A Call Button	[4] DLarrabee	[21062] a	\N	\N
792c0058-ccaa-447d-938c-e9b1e4495ef2	2018-02-28 08:53:50.795163-06	2	[19823] DURESS-428 Call Button	[4] DLarrabee	[21062] a	\N	\N
3783283b-7797-4873-8e13-f1402970edbc	2018-02-28 08:53:50.812164-06	2	[19824] DURESS-463 Call Button	[4] DLarrabee	[21062] a	\N	\N
7228b789-63dd-4d11-b518-9336fba3e3a6	2018-02-28 08:53:50.831166-06	2	[19825] DURESS-465 Call Button	[4] DLarrabee	[21062] a	\N	\N
575fe924-63aa-4fe8-af43-223e00e5ed38	2018-02-28 08:53:50.849168-06	2	[19826] DURESS-514 Call Button	[4] DLarrabee	[21062] a	\N	\N
b1886a28-c389-4a0d-9e86-d53cb583f6bc	2018-02-28 08:53:50.86517-06	2	[19827] DURESS-529 Call Button	[4] DLarrabee	[21062] a	\N	\N
7ff05f67-e714-4541-bf53-aa67e91d2d51	2018-02-28 08:53:50.881171-06	2	[19828] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
63c64c14-81df-4509-a356-7903cd27d7ef	2018-02-28 08:53:50.897173-06	2	[19829] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
b28d176a-0449-4393-beb1-e36d9de24290	2018-02-28 08:53:50.914175-06	2	[19830] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
2df45bf9-1ee9-4282-a7bf-32c01285b6ff	2018-02-28 08:53:50.917175-06	2	[19882] DPIS-429A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d872861b-6148-475f-9bef-88c1b32bb713	2018-02-28 08:53:50.921175-06	2	[19883] DPIS-429B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4ac343ff-8330-4738-83b6-39f5a88d0cff	2018-02-28 08:53:50.925176-06	2	[19884] DPIS-429C Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a4560df6-d4b0-42c0-b784-23cf8b65dd35	2018-02-28 08:53:50.929176-06	2	[19885] DPIS-456 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
df0b6f84-16dc-44a2-8a46-36d70265e5d4	2018-02-28 08:53:50.932176-06	2	[19886] DPIS-461 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b202b66c-0eaf-4ba8-bca4-a45344e99664	2018-02-28 08:53:50.936177-06	2	[19887] DPIS-514 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
93e5730b-b17d-4f9e-817e-f493cd1032ef	2018-02-28 08:53:50.942177-06	2	[19888] DPIS-529 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e3ffbbc8-fab8-4d37-81de-572e490c16c1	2018-02-28 08:53:50.948178-06	2	[19889] DURESS-425 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
32bd6f1a-29fc-4bf9-a3bf-b8db8306c2c8	2018-02-28 08:53:50.952178-06	2	[19890] DURESS-428 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
03122984-7dd3-4b1e-a9bc-dc30598a73cb	2018-02-28 08:53:50.956179-06	2	[19891] DURESS-463 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d85c212f-d33e-4c2b-b5e9-47a146fe71e6	2018-02-28 08:53:50.961179-06	2	[19892] DURESS-465 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
be5c74eb-77f7-45d2-bf53-917bc2f9dce0	2018-02-28 08:53:50.96518-06	2	[19893] DURESS-514 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
97be0c19-0f1d-4d27-975e-fc698c03d647	2018-02-28 08:53:50.96818-06	2	[19894] DURESS-529 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
5d94d7de-1290-463b-8c7d-9fe7a622be55	2018-02-28 08:53:50.97218-06	2	[19895] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7aaaddb9-e83e-48de-a40f-98286fe1fd6a	2018-02-28 08:53:50.976181-06	2	[19896] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7aca3d19-f791-411b-928f-d8353b535e89	2018-02-28 08:53:50.979181-06	2	[19897] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b3f9a28d-a9bf-4082-8510-78cc96194592	2018-02-28 08:53:50.983182-06	2	[19898] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cf757eb9-fa56-4b99-bb34-080db6ac2b2e	2018-02-28 08:53:50.986182-06	2	[19899] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
aca73be8-ba7b-4812-b1c0-1a1b0fb484f7	2018-02-28 08:53:50.990182-06	2	[19900] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3ade715b-c2d7-492f-b4aa-9b953451e82f	2018-02-28 08:53:50.993183-06	2	[19901] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
12615925-e2a8-4ac5-ba75-88ef28aaf9c2	2018-02-28 08:53:50.998183-06	2	[19902] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
77edcb70-5d87-4822-b879-159b0fe10cb1	2018-02-28 08:53:51.003184-06	2	[19903] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
180802ef-83c0-49ec-9a07-7be2e2060aae	2018-02-28 08:53:51.008184-06	2	[19904] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a8a7b97b-a827-413a-b807-a1370f84631e	2018-02-28 08:53:51.012184-06	2	[19905] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cd6a499e-f750-438c-9eb1-7f71e780a01f	2018-02-28 08:53:51.016185-06	2	[19906] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b0c2d8c5-218a-41a2-bad8-cd17f353c511	2018-02-28 08:53:51.021185-06	2	[19907] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
536b27e2-a896-478a-a6af-2b2330332b0c	2018-02-28 08:53:51.025186-06	2	[19908] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
83dc7cd5-6474-48c0-9f39-2c81f39c25c8	2018-02-28 08:53:51.028186-06	2	[19909] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c99656a8-22d5-4d20-a559-5685c896d11a	2018-02-28 08:53:51.032186-06	2	[19910] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6f321ecc-16df-466b-ae40-954c2fcb4509	2018-02-28 08:53:51.035187-06	2	[19911] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d5b6ab0a-ddf4-4085-aa47-fb7adfe6dfae	2018-02-28 08:53:51.039187-06	2	[19912] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
36ef5097-a800-4f99-b93e-c6096590d6e2	2018-02-28 08:53:51.042187-06	2	[19913] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
509c05f2-18c4-48f0-8e19-2dd6aeed8d03	2018-02-28 08:53:51.059189-06	2	[20281] 9C2-16R	[4] DLarrabee	[21062] a	\N	\N
5f93ba0d-cee8-486c-ac97-4f2d3d87b90d	2018-02-28 08:53:51.073191-06	2	[20284] Lock Relay-429A Relay	[4] DLarrabee	[21062] a	\N	\N
35b6846d-0626-4437-8c73-6ff7205b4a95	2018-02-28 08:53:51.088192-06	2	[20285] Lock Relay-429B Relay	[4] DLarrabee	[21062] a	\N	\N
ca301e3b-ccc5-479c-920e-930c059adbaf	2018-02-28 08:53:51.103194-06	2	[20286] Lock Relay-429C Relay	[4] DLarrabee	[21062] a	\N	\N
04ec9d76-c5cb-4771-b76a-18c68ba43844	2018-02-28 08:53:51.118195-06	2	[20287] Lock Relay-456 Relay	[4] DLarrabee	[21062] a	\N	\N
db6da50a-16f7-4b88-9e54-6870b6dd74f3	2018-02-28 08:53:51.136197-06	2	[20288] Lock Relay-461 Relay	[4] DLarrabee	[21062] a	\N	\N
5875b1e0-0541-4c46-941c-e8be74eb712b	2018-02-28 08:53:51.155199-06	2	[20289] Lock Relay-514 Relay	[4] DLarrabee	[21062] a	\N	\N
91240c7d-f43d-4406-9cfc-1ee6f5056af7	2018-02-28 08:53:51.1702-06	2	[20290] Lock Relay-529 Relay	[4] DLarrabee	[21062] a	\N	\N
da61152c-e152-4435-86ec-19eaecfd26c9	2018-02-28 08:53:51.184202-06	2	[20291] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
708408bd-3744-4e0a-9745-0293d8ddb592	2018-02-28 08:53:51.203204-06	2	[20292] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
ae78cf98-57f9-43c0-9428-6e9163529942	2018-02-28 08:53:51.218205-06	2	[20293] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
69795e86-3c09-4f00-a9cf-d9fca63da6da	2018-02-28 08:53:51.232206-06	2	[20294] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
9358186b-09e5-4b19-bce2-ee57518ce68f	2018-02-28 08:53:51.247208-06	2	[20295] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
58f34282-301b-439f-b037-fa6c287a9a13	2018-02-28 08:53:51.26721-06	2	[20296] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
525a1191-62fc-4495-945d-ba875b2f2fea	2018-02-28 08:53:51.282211-06	2	[20297] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
7d047920-8fbb-4866-8fb3-9267bdc94f8a	2018-02-28 08:53:51.295213-06	2	[20298] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
ec6b9d96-d76c-439a-aa67-4c9d4ce123b9	2018-02-28 08:53:51.308214-06	2	[20299] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
002a556a-dd98-40ab-8cb2-9b501a882212	2018-02-28 08:53:51.440227-06	2	[20601] 9C3-8IC	[4] DLarrabee	[21062] a	\N	\N
0ef09080-7e20-4569-ba71-3724d9b7309d	2018-02-28 08:53:51.460229-06	2	[20603] IC-429A Call Button	[4] DLarrabee	[21062] a	\N	\N
ef5b0ee8-98d8-4331-8c2d-51ab3e741e2e	2018-02-28 08:53:51.475231-06	2	[20604] IC-429B Call Button	[4] DLarrabee	[21062] a	\N	\N
a986351a-eb02-4093-b177-a834ba481167	2018-02-28 08:53:51.492232-06	2	[20605] IC-429C Call Button	[4] DLarrabee	[21062] a	\N	\N
484fd5fa-a0f1-4257-a5d6-5aa892478c09	2018-02-28 08:53:51.511234-06	2	[20606] IC-456 Call Button	[4] DLarrabee	[21062] a	\N	\N
1cc880b3-402c-40a5-8dfd-92e4b95a6da6	2018-02-28 08:53:51.527236-06	2	[20607] IC-461 Call Button	[4] DLarrabee	[21062] a	\N	\N
6ae6b3fb-2f99-4d15-a6dc-d891f9532e8d	2018-02-28 08:53:51.547238-06	2	[20608] IC-514 Call Button	[4] DLarrabee	[21062] a	\N	\N
dbd959a8-5c53-499a-b021-fc6e7849f35f	2018-02-28 08:53:51.562239-06	2	[20609] IC-529 Call Button	[4] DLarrabee	[21062] a	\N	\N
391fc5e2-1f29-4a36-a5bf-13a22080213e	2018-02-28 08:53:51.577241-06	2	[20610] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
28d2c684-2277-498c-b5f5-c36360d051a9	2018-02-28 08:53:51.591242-06	2	[20612] IC-429A Relay	[4] DLarrabee	[21062] a	\N	\N
318725be-9031-4f21-8833-89f7f4481ec5	2018-02-28 08:53:51.605244-06	2	[20613] IC-429B Relay	[4] DLarrabee	[21062] a	\N	\N
d0e66387-db4b-4556-b624-3ac6d1b852af	2018-02-28 08:53:51.617245-06	2	[20614] IC-429C Relay	[4] DLarrabee	[21062] a	\N	\N
e02e514d-d0e9-4de4-9bff-4dafa31883ee	2018-02-28 08:53:51.630246-06	2	[20615] IC-456 Relay	[4] DLarrabee	[21062] a	\N	\N
e61d8280-37ab-4a42-97f7-77fb5cda9be1	2018-02-28 08:53:51.644248-06	2	[20616] IC-461 Relay	[4] DLarrabee	[21062] a	\N	\N
0c15f750-5946-4a58-a2d7-ba900be44f76	2018-02-28 08:53:51.657249-06	2	[20617] IC-514 Relay	[4] DLarrabee	[21062] a	\N	\N
7125415c-08e2-4b19-b76e-102b75279935	2018-02-28 08:53:51.675251-06	2	[20618] IC-529 Relay	[4] DLarrabee	[21062] a	\N	\N
1f253830-5006-42b7-bcf5-ee912bde3047	2018-02-28 08:53:51.689252-06	2	[20619] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
476a2999-d6ac-46f1-8a16-b8a175b4e47e	2018-02-28 08:53:51.692252-06	2	[20621] IC-429A Connect	[4] DLarrabee	[21062] a	\N	\N
4ff8abbc-495a-41ea-a57c-bde329d8a01d	2018-02-28 08:53:51.696253-06	2	[20622] IC-429B Connect	[4] DLarrabee	[21062] a	\N	\N
974a52d3-c8a1-476e-b470-98861c6f8499	2018-02-28 08:53:51.699253-06	2	[20623] IC-429C Connect	[4] DLarrabee	[21062] a	\N	\N
6f4d7a87-5edc-41a2-83bc-1a825e2f2e19	2018-02-28 08:53:51.701253-06	2	[20624] IC-456 Connect	[4] DLarrabee	[21062] a	\N	\N
f065f4fb-2406-4137-b2da-24dc761705e6	2018-02-28 08:53:51.704254-06	2	[20625] IC-461 Connect	[4] DLarrabee	[21062] a	\N	\N
61273c86-a3d6-4c11-bd7d-1ba822491f1e	2018-02-28 08:53:51.707254-06	2	[20626] IC-514 Connect	[4] DLarrabee	[21062] a	\N	\N
831f98a3-0e99-4ee5-92ca-e2dc6d372410	2018-02-28 08:53:51.710254-06	2	[20627] IC-529 Connect	[4] DLarrabee	[21062] a	\N	\N
87f41903-7c30-4ca9-a507-3c3244209fb9	2018-02-28 08:53:51.713255-06	2	[20628] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
fd17b03d-ed72-4196-99e9-8f6d81ba3018	2018-02-28 08:53:51.716255-06	2	[20654] IC-429A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d7353274-babf-4be7-a050-13fe0244595d	2018-02-28 08:53:51.720255-06	2	[20655] IC-429B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
47ab9547-2eb4-4dac-88df-7dcfb48c493c	2018-02-28 08:53:51.724256-06	2	[20656] IC-429C Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
aa62a4b0-339b-4d18-ab4e-4fba45b02717	2018-02-28 08:53:51.727256-06	2	[20657] IC-456 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7b5a6777-e653-4dcd-9525-c403c2c55eac	2018-02-28 08:53:51.731256-06	2	[20658] IC-461 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ddf6c821-8179-4b28-b784-d5f872e38fed	2018-02-28 08:53:51.735257-06	2	[20659] IC-514 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f302caeb-4e4c-46db-b728-3c66e5c1bd9b	2018-02-28 08:53:51.739257-06	2	[20660] IC-529 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
aee0ed60-51d8-42c1-baa8-ce63543e9940	2018-02-28 08:53:51.742257-06	2	[20661] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f8dc717d-2efc-465e-8027-4d108d7bc97a	2018-02-28 08:53:51.745258-06	2	[20673] IC-429A Call	[4] DLarrabee	[21062] a	\N	\N
425ed275-f41f-4e82-b1ba-023b503a1c2d	2018-02-28 08:53:51.749258-06	2	[20674] IC-429B Call	[4] DLarrabee	[21062] a	\N	\N
4aaf2dd5-2131-4610-8249-bacf055f342e	2018-02-28 08:53:51.752258-06	2	[20675] IC-429C Call	[4] DLarrabee	[21062] a	\N	\N
f79f2589-7eb0-4f58-9dc5-dbdabee240e8	2018-02-28 08:53:51.755259-06	2	[20676] IC-456 Call	[4] DLarrabee	[21062] a	\N	\N
fe2ffb87-74fa-43ed-84e9-5f93e87a9244	2018-02-28 08:53:51.759259-06	2	[20677] IC-461 Call	[4] DLarrabee	[21062] a	\N	\N
92a8fbf4-5f6c-4547-81f6-ac82aee287d6	2018-02-28 08:53:51.762259-06	2	[20678] IC-514 Call	[4] DLarrabee	[21062] a	\N	\N
95e9b49e-6fc7-412f-97cf-da49f103b37c	2018-02-28 08:53:51.76526-06	2	[20679] IC-529 Call	[4] DLarrabee	[21062] a	\N	\N
07f7acda-43e1-43eb-8fa2-388031f365eb	2018-02-28 08:53:51.76826-06	2	[20680] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
edf2ee37-b27b-40fb-9d09-74d0ec419328	2018-02-28 08:54:18.400923-06	2	[19816] DPIS-429B Call Button	[4] DLarrabee	[21062] a	\N	\N
ea8d69e4-6f5b-4a0d-ae56-a797c76b2245	2018-02-28 08:54:18.439927-06	2	[19817] DPIS-429C Call Button	[4] DLarrabee	[21062] a	\N	\N
3ff6ee28-98aa-4a91-b370-b6484f3e4a9c	2018-02-28 08:54:18.483931-06	2	[19818] DPIS-456 Call Button	[4] DLarrabee	[21062] a	\N	\N
5f6ea9ae-f894-47b5-a3a0-61cd566892e3	2018-02-28 08:54:18.519935-06	2	[19819] DPIS-461 Call Button	[4] DLarrabee	[21062] a	\N	\N
7b42acc5-a5d6-4f53-b284-e0f872b85272	2018-02-28 08:54:18.546938-06	2	[19820] DPIS-514 Call Button	[4] DLarrabee	[21062] a	\N	\N
bb193c5e-351b-4e97-9353-d2923574372d	2018-02-28 08:54:18.56894-06	2	[19821] DPIS-529 Call Button	[4] DLarrabee	[21062] a	\N	\N
911d81a8-d37d-4986-b577-4ec2ed87d122	2018-02-28 08:54:18.588942-06	2	[19822] DURESS-425 Call Button	[4] DLarrabee	[21062] a	\N	\N
679562a5-6897-4bba-9415-6e4d813ee67e	2018-02-28 08:54:18.606944-06	2	[19831] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
2040415b-041e-4482-81d5-98a7ed2bac4f	2018-02-28 08:54:18.624945-06	2	[19832] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
48a3656d-f294-412a-817d-f142f973aef3	2018-02-28 08:54:18.645948-06	2	[19833] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
24ea7f03-9690-43e9-bf06-3b2f46473ae9	2018-02-28 08:54:18.66595-06	2	[19834] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
2a5a0909-f587-445f-8c96-553c62c3360b	2018-02-28 08:54:18.686952-06	2	[19835] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
d446051c-d1a5-42d0-a411-bbbf350cbac0	2018-02-28 08:54:18.707954-06	2	[19836] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
f7c77d5e-7848-43da-a327-b6cba738ef84	2018-02-28 08:54:18.728956-06	2	[19837] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
db6f3bc8-aeef-4664-a617-7f58aa9b8457	2018-02-28 08:54:18.752958-06	2	[19838] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
dd243bea-97cb-4f93-ba3c-fcbd8e22464d	2018-02-28 08:54:18.780961-06	2	[19839] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
2cf73e21-65d0-475f-aad6-44025d5dff90	2018-02-28 08:54:18.810964-06	2	[19840] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
e6e5b7b9-064a-44c4-b9c3-94d1fe30b256	2018-02-28 08:54:18.831966-06	2	[19841] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
7bb6d82c-aeca-4e6a-91a6-e703f5d7b1cb	2018-02-28 08:54:18.850968-06	2	[19842] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
72acd0ef-8982-44c3-9029-ccd6e19c5334	2018-02-28 08:54:18.87097-06	2	[19843] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
5c7c5f80-a60b-4ef7-ab4d-5533734e82cd	2018-02-28 08:54:18.893972-06	2	[19844] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
5baa31cf-e5cb-4cb1-ab4c-3b9472d35480	2018-02-28 08:54:18.908974-06	2	[19845] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
6d68689a-d7ca-4456-8530-e1d79a80e0a8	2018-02-28 08:54:18.929976-06	2	[19846] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
84dd4814-9942-4dc3-b93e-e836966e7318	2018-02-28 08:54:49.588041-06	2	[19813] 9C1-32I	[4] DLarrabee	[21062] a	\N	\N
f701090c-cb92-44fd-954f-050c78bccf3a	2018-02-28 08:55:16.919774-06	2	[17384] R8C1-8IC	[4] DLarrabee	[21062] a	\N	\N
30992d70-2e72-4768-b519-e6813bbf2384	2018-02-28 08:55:17.447827-06	2	[17384] R8C1-8IC	[4] DLarrabee	[21062] a	\N	\N
5f3d271a-56de-4a53-9c2e-2c07d9d0a499	2018-02-28 08:55:39.044987-06	2	[8221] R4C1-8IC	[4] DLarrabee	[21062] a	\N	\N
e0bba9ea-f1a9-4991-8dfc-bc8881e52bf4	2018-02-28 08:55:49.018984-06	2	[1513] R1C2-32I	[4] DLarrabee	[21062] a	\N	\N
ef5a180e-03a8-466b-b907-23531f31db72	2018-02-28 08:55:59.467029-06	2	[1045] R1C1-32I	[4] DLarrabee	[21062] a	\N	\N
034bfd16-087d-4f02-9871-ad65ba8b958d	2018-02-28 09:04:04.498527-06	2	[290] LeadIn	[4] DLarrabee	[293] master	\N	\N
0f6b9785-eb5b-4cca-ab37-01b65c8405a5	2018-02-28 09:34:56.01266-06	2	[1042] Control RM MAC I/O Driver	[4] DLarrabee	[293] master	\N	\N
727cc583-9ff6-4a29-9df5-dd3897227456	2018-02-28 09:35:05.764635-06	1	[21063] New MAC Driver	[4] DLarrabee	[293] master	\N	\N
b8e56a6f-cc94-488c-9710-a5ecfc2bb0c1	2018-02-28 09:35:08.184877-06	2	[21063] New MAC Driver	[4] DLarrabee	[293] master	\N	\N
94b1292a-2520-4b7c-9b0e-f095bc4dd2e1	2018-02-28 09:35:49.02296-06	2	[21063] Control RM 8iC MAC Driver	[4] DLarrabee	[293] master	\N	\N
6b28907d-ee6b-415e-b54b-ab4893fc87d1	2018-02-28 10:09:24.609499-06	2	[1042] Control RM MAC I/O Driver	[4] DLarrabee	[21062] a	\N	\N
1529046c-54d2-4fa3-907c-494ad2c87785	2018-02-28 10:11:26.718709-06	2	[21063] Control RM 8iC MAC Driver	[4] DLarrabee	[21062] a	\N	\N
0e1bb896-21f8-4f38-b5ae-02ff282a5d84	2018-02-28 10:11:26.766713-06	2	[2940] R2C1-8IC	[4] DLarrabee	[21062] a	\N	\N
6cdca4cf-22c1-48cd-9c81-992e2d715e49	2018-02-28 10:11:26.82972-06	2	[3380] R2C2-8IC	[4] DLarrabee	[21062] a	\N	\N
9b8ca66a-e28b-41b1-843b-d6b5a4390991	2018-02-28 10:11:26.966733-06	2	[4260] R2C4-8IC	[4] DLarrabee	[21062] a	\N	\N
09b9c7e0-18d3-4ec9-a7c3-2e18af8a7af9	2018-02-28 10:11:27.044741-06	2	[4700] R2C5-8IC	[4] DLarrabee	[21062] a	\N	\N
ec9301c4-470d-44a7-b070-70ef4536c599	2018-02-28 10:11:27.117748-06	2	[5140] R2C6-8IC	[4] DLarrabee	[21062] a	\N	\N
49544cb9-ca2f-4681-ac65-37761bbdf118	2018-02-28 10:11:27.190756-06	2	[5580] R2C7-8IC	[4] DLarrabee	[21062] a	\N	\N
615ab9b9-ddbb-4dc9-91fc-31e7cc5041b2	2018-02-28 10:11:27.252762-06	2	[6020] R3C1-8IC	[4] DLarrabee	[21062] a	\N	\N
bd52cfb4-4962-4afa-ae68-fbdd03bd76d1	2018-02-28 10:11:27.312768-06	2	[6460] R3C2-8IC	[4] DLarrabee	[21062] a	\N	\N
356ef9cb-9ce0-478f-a806-aeae76a96755	2018-02-28 10:11:27.378775-06	2	[6900] R3C3-8IC	[4] DLarrabee	[21062] a	\N	\N
df907452-db09-4644-b1ff-8f268844c3ab	2018-02-28 10:11:27.439781-06	2	[7340] R3C4-8IC	[4] DLarrabee	[21062] a	\N	\N
5b5b2f1d-378b-450b-82ee-f5f88015423d	2018-02-28 10:11:27.493786-06	2	[7780] R3C5-8IC	[4] DLarrabee	[21062] a	\N	\N
\.


SET search_path = core, pg_catalog;

--
-- Name: AccessEntry_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AccessEntry"
    ADD CONSTRAINT "AccessEntry_pkey" PRIMARY KEY (id);


--
-- Name: AccessSet_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AccessSet"
    ADD CONSTRAINT "AccessSet_pkey" PRIMARY KEY (id);


--
-- Name: AccessSetsToAccessEntries_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AccessSetsToAccessEntries"
    ADD CONSTRAINT "AccessSetsToAccessEntries_pkey" PRIMARY KEY (access_set_id, access_entry_id);


--
-- Name: AccessSetsToTokens_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AccessSetsToTokens"
    ADD CONSTRAINT "AccessSetsToTokens_pkey" PRIMARY KEY (access_set_id, token_id);


--
-- Name: AlterTableInformation_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AlterTableInformation"
    ADD CONSTRAINT "AlterTableInformation_pkey" PRIMARY KEY (id);


--
-- Name: BlobType_abbrev_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "BlobType"
    ADD CONSTRAINT "BlobType_abbrev_key" UNIQUE (abbrev);


--
-- Name: BlobType_mime_type_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "BlobType"
    ADD CONSTRAINT "BlobType_mime_type_key" UNIQUE (mime_type);


--
-- Name: BlobType_name_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "BlobType"
    ADD CONSTRAINT "BlobType_name_key" UNIQUE (name);


--
-- Name: BlobType_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "BlobType"
    ADD CONSTRAINT "BlobType_pkey" PRIMARY KEY (id);

ALTER TABLE "BlobType" CLUSTER ON "BlobType_pkey";


--
-- Name: Card_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Card"
    ADD CONSTRAINT "Card_pkey" PRIMARY KEY (token_id);


--
-- Name: Parameter_name_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Parameter"
    ADD CONSTRAINT "Parameter_name_key" UNIQUE (name);


--
-- Name: Parameter_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Parameter"
    ADD CONSTRAINT "Parameter_pkey" PRIMARY KEY (id);


--
-- Name: Personnel_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_pkey" PRIMARY KEY (id);


--
-- Name: Reader_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Reader"
    ADD CONSTRAINT "Reader_pkey" PRIMARY KEY (id);


--
-- Name: ReadersToAccessEntries_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "ReadersToAccessEntries"
    ADD CONSTRAINT "ReadersToAccessEntries_pkey" PRIMARY KEY (reader_id, access_entry_id);


--
-- Name: RfidTag_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "RfidTag"
    ADD CONSTRAINT "RfidTag_pkey" PRIMARY KEY (token_id);


--
-- Name: RfidTag_tag_number_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "RfidTag"
    ADD CONSTRAINT "RfidTag_tag_number_key" UNIQUE (tag_number);


--
-- Name: ScheduledEvent_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "ScheduledEvent"
    ADD CONSTRAINT "ScheduledEvent_pkey" PRIMARY KEY (id);


--
-- Name: SystemInformationItem_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "SystemInformationItem"
    ADD CONSTRAINT "SystemInformationItem_pkey" PRIMARY KEY (sysinfo_id, item_id);


--
-- Name: SystemInformation_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "SystemInformation"
    ADD CONSTRAINT "SystemInformation_pkey" PRIMARY KEY (id);


--
-- Name: TokenType_name_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "TokenType"
    ADD CONSTRAINT "TokenType_name_key" UNIQUE (name);


--
-- Name: TokenType_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "TokenType"
    ADD CONSTRAINT "TokenType_pkey" PRIMARY KEY (id);

ALTER TABLE "TokenType" CLUSTER ON "TokenType_pkey";


--
-- Name: TokenType_table_name_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "TokenType"
    ADD CONSTRAINT "TokenType_table_name_key" UNIQUE (table_name);


--
-- Name: Token_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Token"
    ADD CONSTRAINT "Token_pkey" PRIMARY KEY (id);


--
-- Name: Vehicle_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Vehicle"
    ADD CONSTRAINT "Vehicle_pkey" PRIMARY KEY (id);


SET search_path = extra, pg_catalog;

--
-- Name: AccessSet_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "AccessSet"
    ADD CONSTRAINT "AccessSet_pkey" PRIMARY KEY (id);


--
-- Name: Blob_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "Blob"
    ADD CONSTRAINT "Blob_pkey" PRIMARY KEY (id);


--
-- Name: Card_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "Card"
    ADD CONSTRAINT "Card_pkey" PRIMARY KEY (token_id);


--
-- Name: Notes_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "Notes"
    ADD CONSTRAINT "Notes_pkey" PRIMARY KEY (id);


--
-- Name: Personnel_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_pkey" PRIMARY KEY (id);


--
-- Name: Vehicle_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "Vehicle"
    ADD CONSTRAINT "Vehicle_pkey" PRIMARY KEY (id);


SET search_path = history, pg_catalog;

--
-- Name: Activity_Statistics_pkey; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Activity_Statistics"
    ADD CONSTRAINT "Activity_Statistics_pkey" PRIMARY KEY (id);


--
-- Name: Activity_pkey; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Activity"
    ADD CONSTRAINT "Activity_pkey" PRIMARY KEY (id);


--
-- Name: ChangeType_name_key; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "ChangeType"
    ADD CONSTRAINT "ChangeType_name_key" UNIQUE (name);


--
-- Name: ChangeType_pkey; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "ChangeType"
    ADD CONSTRAINT "ChangeType_pkey" PRIMARY KEY (id);


--
-- Name: EventType_name_key; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "EventType"
    ADD CONSTRAINT "EventType_name_key" UNIQUE (name);


--
-- Name: EventType_pkey; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "EventType"
    ADD CONSTRAINT "EventType_pkey" PRIMARY KEY (id);


--
-- Name: ProjectChange_pkey; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "ProjectChange"
    ADD CONSTRAINT "ProjectChange_pkey" PRIMARY KEY (id);


--
-- Name: pk_history.AccutechTagChange; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AccutechTagChange"
    ADD CONSTRAINT "pk_history.AccutechTagChange" PRIMARY KEY (id);


SET search_path = core, pg_catalog;

--
-- Name: AccessSetsToAccessEntries_access_entry_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "AccessSetsToAccessEntries_access_entry_id_idx" ON "AccessSetsToAccessEntries" USING btree (access_entry_id);


--
-- Name: AccessSetsToAccessEntries_access_set_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "AccessSetsToAccessEntries_access_set_id_idx" ON "AccessSetsToAccessEntries" USING btree (access_set_id);


--
-- Name: AccessSetsToTokens_access_set_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "AccessSetsToTokens_access_set_id_idx" ON "AccessSetsToTokens" USING btree (access_set_id);


--
-- Name: AccessSetsToTokens_token_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "AccessSetsToTokens_token_id_idx" ON "AccessSetsToTokens" USING btree (token_id);


--
-- Name: Card_unique_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE UNIQUE INDEX "Card_unique_idx" ON "Card" USING btree (card_number, site_code, card_format) WHERE (deleted IS NULL);


--
-- Name: Personnel_existing_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE UNIQUE INDEX "Personnel_existing_idx" ON "Personnel" USING btree (id) WHERE (deleted IS NULL);


--
-- Name: ReadersToAccessEntries_access_entry_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "ReadersToAccessEntries_access_entry_id_idx" ON "ReadersToAccessEntries" USING btree (access_entry_id);


--
-- Name: ReadersToAccessEntries_reader_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "ReadersToAccessEntries_reader_id_idx" ON "ReadersToAccessEntries" USING btree (reader_id);


--
-- Name: Token_existing_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE UNIQUE INDEX "Token_existing_idx" ON "Token" USING btree (id) WHERE (deleted IS NULL);


--
-- Name: Token_personnel_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "Token_personnel_id_idx" ON "Token" USING btree (personnel_id) WHERE (deleted IS NULL);


--
-- Name: Token_type_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "Token_type_id_idx" ON "Token" USING btree (type_id);


SET search_path = extra, pg_catalog;

--
-- Name: AccessSet_notes_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "AccessSet_notes_id_idx" ON "AccessSet" USING btree (notes_id);


--
-- Name: Blob_blob_type_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Blob_blob_type_id_idx" ON "Blob" USING btree (type_id);


--
-- Name: Personnel_fingerprint_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Personnel_fingerprint_id_idx" ON "Personnel" USING btree (fingerprint_id);


--
-- Name: Personnel_notes_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Personnel_notes_id_idx" ON "Personnel" USING btree (notes_id);


--
-- Name: Personnel_photo_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Personnel_photo_id_idx" ON "Personnel" USING btree (photo_id);


--
-- Name: Personnel_signature_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Personnel_signature_id_idx" ON "Personnel" USING btree (signature_id);


--
-- Name: Vehicle_notes_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Vehicle_notes_id_idx" ON "Vehicle" USING btree (notes_id);


SET search_path = history, pg_catalog;

--
-- Name: Activity_event_type_id_idx; Type: INDEX; Schema: history; Owner: core; Tablespace: 
--

CREATE INDEX "Activity_event_type_id_idx" ON "Activity" USING btree (event_type_id);


--
-- Name: Activity_time_idx; Type: INDEX; Schema: history; Owner: core; Tablespace: 
--

CREATE INDEX "Activity_time_idx" ON "Activity" USING btree ("time");


--
-- Name: ProjectChange_change_type_id_idx; Type: INDEX; Schema: history; Owner: core; Tablespace: 
--

CREATE INDEX "ProjectChange_change_type_id_idx" ON "ProjectChange" USING btree (change_type_id);


--
-- Name: ProjectChange_time_idx; Type: INDEX; Schema: history; Owner: core; Tablespace: 
--

CREATE INDEX "ProjectChange_time_idx" ON "ProjectChange" USING btree ("time");


SET search_path = core, pg_catalog;

--
-- Name: AllPersonnel_trigger_delete; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "AllPersonnel_trigger_delete" INSTEAD OF DELETE ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoDelete"();


--
-- Name: AllPersonnel_trigger_insert; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "AllPersonnel_trigger_insert" INSTEAD OF INSERT ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoInsert"();


--
-- Name: AllPersonnel_trigger_update; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "AllPersonnel_trigger_update" INSTEAD OF UPDATE ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoUpdate"();


--
-- Name: CardToken_trigger_delete; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "CardToken_trigger_delete" INSTEAD OF DELETE ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoDelete"();


--
-- Name: CardToken_trigger_insert; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "CardToken_trigger_insert" INSTEAD OF INSERT ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoInsert"();


--
-- Name: CardToken_trigger_update; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "CardToken_trigger_update" INSTEAD OF UPDATE ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoUpdate"();


SET search_path = extra, pg_catalog;

--
-- Name: AllAccessSet_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllAccessSet_trigger_delete" INSTEAD OF DELETE ON "AllAccessSet" FOR EACH ROW EXECUTE PROCEDURE "AllAccessSet_DoDelete"();


--
-- Name: AllAccessSet_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllAccessSet_trigger_insert" INSTEAD OF INSERT ON "AllAccessSet" FOR EACH ROW EXECUTE PROCEDURE "AllAccessSet_DoInsert"();


--
-- Name: AllAccessSet_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllAccessSet_trigger_update" INSTEAD OF UPDATE ON "AllAccessSet" FOR EACH ROW EXECUTE PROCEDURE "AllAccessSet_DoUpdate"();


--
-- Name: AllPersonnel_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllPersonnel_trigger_delete" INSTEAD OF DELETE ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoDelete"();


--
-- Name: AllPersonnel_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllPersonnel_trigger_insert" INSTEAD OF INSERT ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoInsert"();


--
-- Name: AllPersonnel_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllPersonnel_trigger_update" INSTEAD OF UPDATE ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoUpdate"();


--
-- Name: AllVehicle_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllVehicle_trigger_delete" INSTEAD OF DELETE ON "AllVehicle" FOR EACH ROW EXECUTE PROCEDURE "AllVehicle_DoDelete"();


--
-- Name: AllVehicle_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllVehicle_trigger_insert" INSTEAD OF INSERT ON "AllVehicle" FOR EACH ROW EXECUTE PROCEDURE "AllVehicle_DoInsert"();


--
-- Name: AllVehicle_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllVehicle_trigger_update" INSTEAD OF UPDATE ON "AllVehicle" FOR EACH ROW EXECUTE PROCEDURE "AllVehicle_DoUpdate"();


--
-- Name: CardToken_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "CardToken_trigger_delete" INSTEAD OF DELETE ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoDelete"();


--
-- Name: CardToken_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "CardToken_trigger_insert" INSTEAD OF INSERT ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoInsert"();


--
-- Name: CardToken_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "CardToken_trigger_update" INSTEAD OF UPDATE ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoUpdate"();


--
-- Name: MultiCard_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "MultiCard_trigger_delete" INSTEAD OF DELETE ON "MultiCard" FOR EACH ROW EXECUTE PROCEDURE "MultiCard_DoDelete"();


--
-- Name: MultiCard_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "MultiCard_trigger_insert" INSTEAD OF INSERT ON "MultiCard" FOR EACH ROW EXECUTE PROCEDURE "MultiCard_DoInsert"();


--
-- Name: MultiCard_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "MultiCard_trigger_update" INSTEAD OF UPDATE ON "MultiCard" FOR EACH ROW EXECUTE PROCEDURE "MultiCard_DoUpdate"();


--
-- Name: SingleCard_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "SingleCard_trigger_delete" INSTEAD OF DELETE ON "SingleCard" FOR EACH ROW EXECUTE PROCEDURE "SingleCard_DoDelete"();


--
-- Name: SingleCard_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "SingleCard_trigger_insert" INSTEAD OF INSERT ON "SingleCard" FOR EACH ROW EXECUTE PROCEDURE "SingleCard_DoInsert"();


--
-- Name: SingleCard_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "SingleCard_trigger_update" INSTEAD OF UPDATE ON "SingleCard" FOR EACH ROW EXECUTE PROCEDURE "SingleCard_DoUpdate"();


SET search_path = history, pg_catalog;

--
-- Name: Activity_trigger_insert; Type: TRIGGER; Schema: history; Owner: core
--

CREATE TRIGGER "Activity_trigger_insert" AFTER INSERT ON "Activity" FOR EACH ROW EXECUTE PROCEDURE "Activity_Insert_Statistics"();


SET search_path = core, pg_catalog;

--
-- Name: AccessSetsToAccessEntries_access_entry_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AccessSetsToAccessEntries"
    ADD CONSTRAINT "AccessSetsToAccessEntries_access_entry_id_fkey" FOREIGN KEY (access_entry_id) REFERENCES "AccessEntry"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: AccessSetsToAccessEntries_access_set_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AccessSetsToAccessEntries"
    ADD CONSTRAINT "AccessSetsToAccessEntries_access_set_id_fkey" FOREIGN KEY (access_set_id) REFERENCES "AccessSet"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: AccessSetsToTokens_access_set_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AccessSetsToTokens"
    ADD CONSTRAINT "AccessSetsToTokens_access_set_id_fkey" FOREIGN KEY (access_set_id) REFERENCES "AccessSet"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: AccessSetsToTokens_token_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AccessSetsToTokens"
    ADD CONSTRAINT "AccessSetsToTokens_token_id_fkey" FOREIGN KEY (token_id) REFERENCES "Token"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: Card_token_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "Card"
    ADD CONSTRAINT "Card_token_id_fkey" FOREIGN KEY (token_id) REFERENCES "Token"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: ReadersToAccessEntries_access_entry_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "ReadersToAccessEntries"
    ADD CONSTRAINT "ReadersToAccessEntries_access_entry_id_fkey" FOREIGN KEY (access_entry_id) REFERENCES "AccessEntry"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: ReadersToAccessEntries_reader_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "ReadersToAccessEntries"
    ADD CONSTRAINT "ReadersToAccessEntries_reader_id_fkey" FOREIGN KEY (reader_id) REFERENCES "Reader"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: RfidTag_token_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "RfidTag"
    ADD CONSTRAINT "RfidTag_token_id_fkey" FOREIGN KEY (token_id) REFERENCES "Token"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: SystemInformationItem_sysinfo_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "SystemInformationItem"
    ADD CONSTRAINT "SystemInformationItem_sysinfo_id_fkey" FOREIGN KEY (sysinfo_id) REFERENCES "SystemInformation"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: Token_personnel_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "Token"
    ADD CONSTRAINT "Token_personnel_id_fkey" FOREIGN KEY (personnel_id) REFERENCES "Personnel"(id) ON UPDATE CASCADE DEFERRABLE INITIALLY DEFERRED;


--
-- Name: Token_type_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "Token"
    ADD CONSTRAINT "Token_type_id_fkey" FOREIGN KEY (type_id) REFERENCES "TokenType"(id);


--
-- Name: Vehicle_personnel_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "Vehicle"
    ADD CONSTRAINT "Vehicle_personnel_id_fkey" FOREIGN KEY (personnel_id) REFERENCES "Personnel"(id) ON UPDATE CASCADE ON DELETE CASCADE;


SET search_path = extra, pg_catalog;

--
-- Name: AccessSet_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "AccessSet"
    ADD CONSTRAINT "AccessSet_id_fkey" FOREIGN KEY (id) REFERENCES core."AccessSet"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: AccessSet_notes_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "AccessSet"
    ADD CONSTRAINT "AccessSet_notes_id_fkey" FOREIGN KEY (notes_id) REFERENCES "Notes"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Blob_blob_type_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Blob"
    ADD CONSTRAINT "Blob_blob_type_id_fkey" FOREIGN KEY (type_id) REFERENCES core."BlobType"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Card_token_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Card"
    ADD CONSTRAINT "Card_token_id_fkey" FOREIGN KEY (token_id) REFERENCES core."Card"(token_id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: Personnel_fingerprint_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_fingerprint_id_fkey" FOREIGN KEY (fingerprint_id) REFERENCES "Blob"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Personnel_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_id_fkey" FOREIGN KEY (id) REFERENCES core."Personnel"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: Personnel_notes_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_notes_id_fkey" FOREIGN KEY (notes_id) REFERENCES "Notes"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Personnel_photo_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_photo_id_fkey" FOREIGN KEY (photo_id) REFERENCES "Blob"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Personnel_signature_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_signature_id_fkey" FOREIGN KEY (signature_id) REFERENCES "Blob"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Vehicle_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Vehicle"
    ADD CONSTRAINT "Vehicle_id_fkey" FOREIGN KEY (id) REFERENCES core."Vehicle"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: Vehicle_notes_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Vehicle"
    ADD CONSTRAINT "Vehicle_notes_id_fkey" FOREIGN KEY (notes_id) REFERENCES "Notes"(id) ON UPDATE CASCADE ON DELETE SET NULL;


SET search_path = history, pg_catalog;

--
-- Name: Activity_event_type_id_fkey; Type: FK CONSTRAINT; Schema: history; Owner: core
--

ALTER TABLE ONLY "Activity"
    ADD CONSTRAINT "Activity_event_type_id_fkey" FOREIGN KEY (event_type_id) REFERENCES "EventType"(id);


--
-- Name: ProjectChange_change_type_id_fkey; Type: FK CONSTRAINT; Schema: history; Owner: core
--

ALTER TABLE ONLY "ProjectChange"
    ADD CONSTRAINT "ProjectChange_change_type_id_fkey" FOREIGN KEY (change_type_id) REFERENCES "ChangeType"(id);


--
-- Name: core; Type: ACL; Schema: -; Owner: core
--

REVOKE ALL ON SCHEMA core FROM PUBLIC;
REVOKE ALL ON SCHEMA core FROM core;
GRANT ALL ON SCHEMA core TO core;
GRANT USAGE ON SCHEMA core TO extra WITH GRANT OPTION;


--
-- Name: extra; Type: ACL; Schema: -; Owner: extra
--

REVOKE ALL ON SCHEMA extra FROM PUBLIC;
REVOKE ALL ON SCHEMA extra FROM extra;
GRANT ALL ON SCHEMA extra TO extra;
GRANT ALL ON SCHEMA extra TO core WITH GRANT OPTION;


--
-- Name: history; Type: ACL; Schema: -; Owner: core
--

REVOKE ALL ON SCHEMA history FROM PUBLIC;
REVOKE ALL ON SCHEMA history FROM core;
GRANT ALL ON SCHEMA history TO core;


--
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM postgres;
GRANT ALL ON SCHEMA public TO postgres;
GRANT ALL ON SCHEMA public TO PUBLIC;


SET search_path = core, pg_catalog;

--
-- Name: AllPersonnel_DoDelete(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "AllPersonnel_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllPersonnel_DoDelete"() FROM core;
GRANT ALL ON FUNCTION "AllPersonnel_DoDelete"() TO core;
GRANT ALL ON FUNCTION "AllPersonnel_DoDelete"() TO extra;


--
-- Name: AllPersonnel_DoInsert(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "AllPersonnel_DoInsert"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllPersonnel_DoInsert"() FROM core;
GRANT ALL ON FUNCTION "AllPersonnel_DoInsert"() TO core;
GRANT ALL ON FUNCTION "AllPersonnel_DoInsert"() TO extra;


--
-- Name: AllPersonnel_DoUpdate(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "AllPersonnel_DoUpdate"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllPersonnel_DoUpdate"() FROM core;
GRANT ALL ON FUNCTION "AllPersonnel_DoUpdate"() TO core;
GRANT ALL ON FUNCTION "AllPersonnel_DoUpdate"() TO extra;


--
-- Name: CanSwitchToSingleId(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "CanSwitchToSingleId"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CanSwitchToSingleId"() FROM core;
GRANT ALL ON FUNCTION "CanSwitchToSingleId"() TO core;
GRANT ALL ON FUNCTION "CanSwitchToSingleId"() TO extra;


--
-- Name: CardToken_DoDelete(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "CardToken_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoDelete"() FROM core;
GRANT ALL ON FUNCTION "CardToken_DoDelete"() TO core;


--
-- Name: CardToken_DoInsert(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "CardToken_DoInsert"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoInsert"() FROM core;
GRANT ALL ON FUNCTION "CardToken_DoInsert"() TO core;
GRANT ALL ON FUNCTION "CardToken_DoInsert"() TO extra;


--
-- Name: CardToken_DoUpdate(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "CardToken_DoUpdate"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoUpdate"() FROM core;
GRANT ALL ON FUNCTION "CardToken_DoUpdate"() TO core;
GRANT ALL ON FUNCTION "CardToken_DoUpdate"() TO extra;


--
-- Name: Personnel_Delete(uuid, character varying); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "Personnel_Delete"(personnel_id uuid, username character varying) FROM PUBLIC;
REVOKE ALL ON FUNCTION "Personnel_Delete"(personnel_id uuid, username character varying) FROM core;
GRANT ALL ON FUNCTION "Personnel_Delete"(personnel_id uuid, username character varying) TO core;
GRANT ALL ON FUNCTION "Personnel_Delete"(personnel_id uuid, username character varying) TO extra;


--
-- Name: Token_Delete(uuid, character varying); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "Token_Delete"(token_id uuid, username character varying) FROM PUBLIC;
REVOKE ALL ON FUNCTION "Token_Delete"(token_id uuid, username character varying) FROM core;
GRANT ALL ON FUNCTION "Token_Delete"(token_id uuid, username character varying) TO core;
GRANT ALL ON FUNCTION "Token_Delete"(token_id uuid, username character varying) TO extra;


SET search_path = extra, pg_catalog;

--
-- Name: AllAccessSet_DoDelete(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "AllAccessSet_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllAccessSet_DoDelete"() FROM extra;
GRANT ALL ON FUNCTION "AllAccessSet_DoDelete"() TO extra;
GRANT ALL ON FUNCTION "AllAccessSet_DoDelete"() TO core;


--
-- Name: AllVehicle_DoDelete(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "AllVehicle_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllVehicle_DoDelete"() FROM extra;
GRANT ALL ON FUNCTION "AllVehicle_DoDelete"() TO extra;
GRANT ALL ON FUNCTION "AllVehicle_DoDelete"() TO core;


--
-- Name: CardToken_DoDelete(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "CardToken_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoDelete"() FROM extra;
GRANT ALL ON FUNCTION "CardToken_DoDelete"() TO extra;
GRANT ALL ON FUNCTION "CardToken_DoDelete"() TO core;


--
-- Name: CardToken_DoInsert(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "CardToken_DoInsert"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoInsert"() FROM extra;
GRANT ALL ON FUNCTION "CardToken_DoInsert"() TO extra;
GRANT ALL ON FUNCTION "CardToken_DoInsert"() TO core;


--
-- Name: CardToken_DoUpdate(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "CardToken_DoUpdate"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoUpdate"() FROM extra;
GRANT ALL ON FUNCTION "CardToken_DoUpdate"() TO extra;
GRANT ALL ON FUNCTION "CardToken_DoUpdate"() TO core;


--
-- Name: MultiCard_DoDelete(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "MultiCard_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "MultiCard_DoDelete"() FROM extra;
GRANT ALL ON FUNCTION "MultiCard_DoDelete"() TO extra;
GRANT ALL ON FUNCTION "MultiCard_DoDelete"() TO core;


--
-- Name: MultiCard_DoInsert(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "MultiCard_DoInsert"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "MultiCard_DoInsert"() FROM extra;
GRANT ALL ON FUNCTION "MultiCard_DoInsert"() TO extra;
GRANT ALL ON FUNCTION "MultiCard_DoInsert"() TO core;


--
-- Name: MultiCard_DoUpdate(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "MultiCard_DoUpdate"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "MultiCard_DoUpdate"() FROM extra;
GRANT ALL ON FUNCTION "MultiCard_DoUpdate"() TO extra;
GRANT ALL ON FUNCTION "MultiCard_DoUpdate"() TO core;


--
-- Name: SingleCard_DoDelete(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "SingleCard_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "SingleCard_DoDelete"() FROM extra;
GRANT ALL ON FUNCTION "SingleCard_DoDelete"() TO extra;
GRANT ALL ON FUNCTION "SingleCard_DoDelete"() TO core;


--
-- Name: SingleCard_DoInsert(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "SingleCard_DoInsert"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "SingleCard_DoInsert"() FROM extra;
GRANT ALL ON FUNCTION "SingleCard_DoInsert"() TO extra;
GRANT ALL ON FUNCTION "SingleCard_DoInsert"() TO core;


--
-- Name: SingleCard_DoUpdate(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "SingleCard_DoUpdate"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "SingleCard_DoUpdate"() FROM extra;
GRANT ALL ON FUNCTION "SingleCard_DoUpdate"() TO extra;
GRANT ALL ON FUNCTION "SingleCard_DoUpdate"() TO core;


SET search_path = history, pg_catalog;

--
-- Name: Activity_Insert_Statistics(); Type: ACL; Schema: history; Owner: core
--

REVOKE ALL ON FUNCTION "Activity_Insert_Statistics"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "Activity_Insert_Statistics"() FROM core;
GRANT ALL ON FUNCTION "Activity_Insert_Statistics"() TO core;
GRANT ALL ON FUNCTION "Activity_Insert_Statistics"() TO extra;


SET search_path = core, pg_catalog;

--
-- Name: AccessEntry; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "AccessEntry" FROM PUBLIC;
REVOKE ALL ON TABLE "AccessEntry" FROM core;
GRANT ALL ON TABLE "AccessEntry" TO core;


--
-- Name: AccessSet; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "AccessSet" FROM PUBLIC;
REVOKE ALL ON TABLE "AccessSet" FROM core;
GRANT ALL ON TABLE "AccessSet" TO core;
GRANT SELECT,INSERT,REFERENCES,DELETE,TRIGGER,UPDATE ON TABLE "AccessSet" TO extra WITH GRANT OPTION;


--
-- Name: AccessSetsToAccessEntries; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "AccessSetsToAccessEntries" FROM PUBLIC;
REVOKE ALL ON TABLE "AccessSetsToAccessEntries" FROM core;
GRANT ALL ON TABLE "AccessSetsToAccessEntries" TO core;


--
-- Name: AccessSetsToTokens; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "AccessSetsToTokens" FROM PUBLIC;
REVOKE ALL ON TABLE "AccessSetsToTokens" FROM core;
GRANT ALL ON TABLE "AccessSetsToTokens" TO core;


--
-- Name: Personnel; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL ON TABLE "Personnel" FROM core;
GRANT ALL ON TABLE "Personnel" TO core;


--
-- Name: Personnel.id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(id) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(id) ON TABLE "Personnel" FROM core;
GRANT SELECT(id),REFERENCES(id) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.name_last; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(name_last) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(name_last) ON TABLE "Personnel" FROM core;
GRANT SELECT(name_last) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.name_first; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(name_first) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(name_first) ON TABLE "Personnel" FROM core;
GRANT SELECT(name_first) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.user_level; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(user_level) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(user_level) ON TABLE "Personnel" FROM core;
GRANT SELECT(user_level) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.days_to_log; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(days_to_log) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(days_to_log) ON TABLE "Personnel" FROM core;
GRANT SELECT(days_to_log) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.apb_type_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(apb_type_id) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(apb_type_id) ON TABLE "Personnel" FROM core;
GRANT SELECT(apb_type_id) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.apb_zone_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(apb_zone_id) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(apb_zone_id) ON TABLE "Personnel" FROM core;
GRANT SELECT(apb_zone_id) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.apb_violations; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(apb_violations) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(apb_violations) ON TABLE "Personnel" FROM core;
GRANT SELECT(apb_violations) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.created; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(created) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(created) ON TABLE "Personnel" FROM core;
GRANT SELECT(created) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.created_by; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(created_by) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(created_by) ON TABLE "Personnel" FROM core;
GRANT SELECT(created_by) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.updated; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(updated) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(updated) ON TABLE "Personnel" FROM core;
GRANT SELECT(updated) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.updated_by; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(updated_by) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(updated_by) ON TABLE "Personnel" FROM core;
GRANT SELECT(updated_by) ON TABLE "Personnel" TO extra;


--
-- Name: AllPersonnel; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "AllPersonnel" FROM PUBLIC;
REVOKE ALL ON TABLE "AllPersonnel" FROM core;
GRANT ALL ON TABLE "AllPersonnel" TO core;
GRANT SELECT,INSERT,REFERENCES,DELETE,UPDATE ON TABLE "AllPersonnel" TO extra WITH GRANT OPTION;


--
-- Name: BlobType; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "BlobType" FROM PUBLIC;
REVOKE ALL ON TABLE "BlobType" FROM core;
GRANT ALL ON TABLE "BlobType" TO core;
GRANT SELECT,REFERENCES ON TABLE "BlobType" TO extra WITH GRANT OPTION;


--
-- Name: Card; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "Card" FROM PUBLIC;
REVOKE ALL ON TABLE "Card" FROM core;
GRANT ALL ON TABLE "Card" TO core;


--
-- Name: Card.token_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(token_id) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(token_id) ON TABLE "Card" FROM core;
GRANT SELECT(token_id),REFERENCES(token_id) ON TABLE "Card" TO extra;


--
-- Name: Card.card_number; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(card_number) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(card_number) ON TABLE "Card" FROM core;
GRANT SELECT(card_number) ON TABLE "Card" TO extra;


--
-- Name: Card.site_code; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(site_code) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(site_code) ON TABLE "Card" FROM core;
GRANT SELECT(site_code) ON TABLE "Card" TO extra;


--
-- Name: Card.card_format; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(card_format) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(card_format) ON TABLE "Card" FROM core;
GRANT SELECT(card_format) ON TABLE "Card" TO extra;


--
-- Name: Card.card_type; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(card_type) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(card_type) ON TABLE "Card" FROM core;
GRANT SELECT(card_type) ON TABLE "Card" TO extra;


--
-- Name: Card.pin_number; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(pin_number) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(pin_number) ON TABLE "Card" FROM core;
GRANT SELECT(pin_number) ON TABLE "Card" TO extra;


--
-- Name: Card.card_valid; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(card_valid) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(card_valid) ON TABLE "Card" FROM core;
GRANT SELECT(card_valid) ON TABLE "Card" TO extra;


--
-- Name: Card.activate_date; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(activate_date) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(activate_date) ON TABLE "Card" FROM core;
GRANT SELECT(activate_date) ON TABLE "Card" TO extra;


--
-- Name: Card.deactivate_date; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(deactivate_date) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(deactivate_date) ON TABLE "Card" FROM core;
GRANT SELECT(deactivate_date) ON TABLE "Card" TO extra;


--
-- Name: Card.secondary_expiration_date; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(secondary_expiration_date) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(secondary_expiration_date) ON TABLE "Card" FROM core;
GRANT SELECT(secondary_expiration_date) ON TABLE "Card" TO extra;


--
-- Name: Card.expire_days; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(expire_days) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(expire_days) ON TABLE "Card" FROM core;
GRANT SELECT(expire_days) ON TABLE "Card" TO extra;


--
-- Name: Card.action_point_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(action_point_id) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(action_point_id) ON TABLE "Card" FROM core;
GRANT SELECT(action_point_id) ON TABLE "Card" TO extra;


--
-- Name: Card.threat_level; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(threat_level) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(threat_level) ON TABLE "Card" FROM core;
GRANT SELECT(threat_level) ON TABLE "Card" TO extra;


--
-- Name: Card.auto_disable; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(auto_disable) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(auto_disable) ON TABLE "Card" FROM core;
GRANT SELECT(auto_disable) ON TABLE "Card" TO extra;


--
-- Name: Card.grant_long_access_time; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(grant_long_access_time) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(grant_long_access_time) ON TABLE "Card" FROM core;
GRANT SELECT(grant_long_access_time) ON TABLE "Card" TO extra;


--
-- Name: Card.escort_visitor_capable; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(escort_visitor_capable) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(escort_visitor_capable) ON TABLE "Card" FROM core;
GRANT SELECT(escort_visitor_capable) ON TABLE "Card" TO extra;


--
-- Name: Card.access_cost_override_capable; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(access_cost_override_capable) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(access_cost_override_capable) ON TABLE "Card" FROM core;
GRANT SELECT(access_cost_override_capable) ON TABLE "Card" TO extra;


--
-- Name: Card.event_lock_override_capable; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(event_lock_override_capable) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(event_lock_override_capable) ON TABLE "Card" FROM core;
GRANT SELECT(event_lock_override_capable) ON TABLE "Card" TO extra;


--
-- Name: Card.building_passback_exemption; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(building_passback_exemption) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(building_passback_exemption) ON TABLE "Card" FROM core;
GRANT SELECT(building_passback_exemption) ON TABLE "Card" TO extra;


--
-- Name: Card.parking_passback_exemption; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(parking_passback_exemption) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(parking_passback_exemption) ON TABLE "Card" FROM core;
GRANT SELECT(parking_passback_exemption) ON TABLE "Card" TO extra;


--
-- Name: Card.card_holder_groups; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(card_holder_groups) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(card_holder_groups) ON TABLE "Card" FROM core;
GRANT SELECT(card_holder_groups) ON TABLE "Card" TO extra;


--
-- Name: Card.activation_group; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(activation_group) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(activation_group) ON TABLE "Card" FROM core;
GRANT SELECT(activation_group) ON TABLE "Card" TO extra;


--
-- Name: Card.on_access_output; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(on_access_output) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(on_access_output) ON TABLE "Card" FROM core;
GRANT SELECT(on_access_output) ON TABLE "Card" TO extra;


--
-- Name: Card.compass_command_group; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(compass_command_group) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(compass_command_group) ON TABLE "Card" FROM core;
GRANT SELECT(compass_command_group) ON TABLE "Card" TO extra;


--
-- Name: Card.low_battery; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(low_battery) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(low_battery) ON TABLE "Card" FROM core;
GRANT REFERENCES(low_battery) ON TABLE "Card" TO extra;


--
-- Name: Token; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "Token" FROM PUBLIC;
REVOKE ALL ON TABLE "Token" FROM core;
GRANT ALL ON TABLE "Token" TO core;


--
-- Name: Token.id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(id) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(id) ON TABLE "Token" FROM core;
GRANT SELECT(id),REFERENCES(id) ON TABLE "Token" TO extra;


--
-- Name: Token.user_level; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(user_level) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(user_level) ON TABLE "Token" FROM core;
GRANT SELECT(user_level) ON TABLE "Token" TO extra;


--
-- Name: Token.personnel_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(personnel_id) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(personnel_id) ON TABLE "Token" FROM core;
GRANT SELECT(personnel_id) ON TABLE "Token" TO extra;


--
-- Name: Token.badge_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(badge_id) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(badge_id) ON TABLE "Token" FROM core;
GRANT SELECT(badge_id) ON TABLE "Token" TO extra;


--
-- Name: Token.lost; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(lost) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(lost) ON TABLE "Token" FROM core;
GRANT SELECT(lost) ON TABLE "Token" TO extra;


--
-- Name: Token.last_read; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(last_read) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(last_read) ON TABLE "Token" FROM core;
GRANT SELECT(last_read) ON TABLE "Token" TO extra;


--
-- Name: Token.last_reader; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(last_reader) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(last_reader) ON TABLE "Token" FROM core;
GRANT SELECT(last_reader) ON TABLE "Token" TO extra;


--
-- Name: Token.last_read_status; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(last_read_status) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(last_read_status) ON TABLE "Token" FROM core;
GRANT SELECT(last_read_status) ON TABLE "Token" TO extra;


--
-- Name: Token.created; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(created) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(created) ON TABLE "Token" FROM core;
GRANT SELECT(created) ON TABLE "Token" TO extra;


--
-- Name: Token.created_by; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(created_by) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(created_by) ON TABLE "Token" FROM core;
GRANT SELECT(created_by) ON TABLE "Token" TO extra;


--
-- Name: Token.updated; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(updated) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(updated) ON TABLE "Token" FROM core;
GRANT SELECT(updated) ON TABLE "Token" TO extra;


--
-- Name: Token.updated_by; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(updated_by) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(updated_by) ON TABLE "Token" FROM core;
GRANT SELECT(updated_by) ON TABLE "Token" TO extra;


--
-- Name: Token.download_required; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(download_required) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(download_required) ON TABLE "Token" FROM core;
GRANT SELECT(download_required) ON TABLE "Token" TO extra WITH GRANT OPTION;


--
-- Name: CardDownload; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "CardDownload" FROM PUBLIC;
REVOKE ALL ON TABLE "CardDownload" FROM core;
GRANT ALL ON TABLE "CardDownload" TO core;


--
-- Name: CardToken; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "CardToken" FROM PUBLIC;
REVOKE ALL ON TABLE "CardToken" FROM core;
GRANT ALL ON TABLE "CardToken" TO core;
GRANT SELECT,INSERT,REFERENCES,DELETE,UPDATE ON TABLE "CardToken" TO extra WITH GRANT OPTION;


--
-- Name: PersonnelTokenCounts; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "PersonnelTokenCounts" FROM PUBLIC;
REVOKE ALL ON TABLE "PersonnelTokenCounts" FROM core;
GRANT ALL ON TABLE "PersonnelTokenCounts" TO core;
GRANT SELECT,INSERT,REFERENCES,DELETE,UPDATE ON TABLE "PersonnelTokenCounts" TO extra WITH GRANT OPTION;


--
-- Name: PersonnelWithSingleCard; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "PersonnelWithSingleCard" FROM PUBLIC;
REVOKE ALL ON TABLE "PersonnelWithSingleCard" FROM core;
GRANT ALL ON TABLE "PersonnelWithSingleCard" TO core;
GRANT SELECT,INSERT,REFERENCES,DELETE,UPDATE ON TABLE "PersonnelWithSingleCard" TO extra WITH GRANT OPTION;


--
-- Name: RfidTag; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "RfidTag" FROM PUBLIC;
REVOKE ALL ON TABLE "RfidTag" FROM core;
GRANT ALL ON TABLE "RfidTag" TO core;


--
-- Name: RfidTag.token_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(token_id) ON TABLE "RfidTag" FROM PUBLIC;
REVOKE ALL(token_id) ON TABLE "RfidTag" FROM core;
GRANT SELECT(token_id),REFERENCES(token_id) ON TABLE "RfidTag" TO extra;


--
-- Name: RfidTag.tag_number; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(tag_number) ON TABLE "RfidTag" FROM PUBLIC;
REVOKE ALL(tag_number) ON TABLE "RfidTag" FROM core;
GRANT SELECT(tag_number) ON TABLE "RfidTag" TO extra;


--
-- Name: TokenType; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "TokenType" FROM PUBLIC;
REVOKE ALL ON TABLE "TokenType" FROM core;
GRANT ALL ON TABLE "TokenType" TO core;
GRANT SELECT,REFERENCES ON TABLE "TokenType" TO extra WITH GRANT OPTION;


--
-- Name: TokenType_id_seq; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON SEQUENCE "TokenType_id_seq" FROM PUBLIC;
REVOKE ALL ON SEQUENCE "TokenType_id_seq" FROM core;
GRANT ALL ON SEQUENCE "TokenType_id_seq" TO core;


--
-- PostgreSQL database dump complete
--

