--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET lock_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SET check_function_bodies = false;
SET client_min_messages = warning;

--
-- Name: core; Type: SCHEMA; Schema: -; Owner: core
--

CREATE SCHEMA core;


ALTER SCHEMA core OWNER TO core;

--
-- Name: extra; Type: SCHEMA; Schema: -; Owner: extra
--

CREATE SCHEMA extra;


ALTER SCHEMA extra OWNER TO extra;

--
-- Name: history; Type: SCHEMA; Schema: -; Owner: core
--

CREATE SCHEMA history;


ALTER SCHEMA history OWNER TO core;

--
-- Name: plpgsql; Type: EXTENSION; Schema: -; Owner: 
--

CREATE EXTENSION IF NOT EXISTS plpgsql WITH SCHEMA pg_catalog;


--
-- Name: EXTENSION plpgsql; Type: COMMENT; Schema: -; Owner: 
--

COMMENT ON EXTENSION plpgsql IS 'PL/pgSQL procedural language';


--
-- Name: uuid-ossp; Type: EXTENSION; Schema: -; Owner: 
--

CREATE EXTENSION IF NOT EXISTS "uuid-ossp" WITH SCHEMA public;


--
-- Name: EXTENSION "uuid-ossp"; Type: COMMENT; Schema: -; Owner: 
--

COMMENT ON EXTENSION "uuid-ossp" IS 'generate universally unique identifiers (UUIDs)';


SET search_path = core, pg_catalog;

--
-- Name: AllPersonnel_DoDelete(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "AllPersonnel_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	username character varying(255);
BEGIN
	username := CURRENT_USER;

	IF core."Personnel_Delete"(OLD.id, username) THEN
		RETURN OLD;
	END IF;

	RETURN NULL;
END;
$$;


ALTER FUNCTION core."AllPersonnel_DoDelete"() OWNER TO core;

--
-- Name: AllPersonnel_DoInsert(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "AllPersonnel_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF NEW.id IS NULL THEN
		NEW.id := uuid_generate_v4();
	END IF;
	
	IF NEW.created IS NULL THEN
		NEW.created := CURRENT_TIMESTAMP;
	END IF;
	
	IF NEW.created_by IS NULL THEN
		NEW.created_by := CURRENT_USER;
	END IF;

	INSERT INTO core."Personnel" (
		id,
		name_last,
		name_first,
		user_level,
		days_to_log,
		apb_type_id,
		apb_zone_id,
		apb_violations,
		created,
		created_by,
		updated,
		updated_by)
	VALUES (
		NEW.id,
		NEW.name_last,
		NEW.name_first,
		NEW.user_level,
		NEW.days_to_log,
		NEW.apb_type_id,
		NEW.apb_zone_id,
		NEW.apb_violations,
		NEW.created,
		NEW.created_by,
		NEW.updated,
		NEW.updated_by);

	RETURN NEW;
END;
$$;


ALTER FUNCTION core."AllPersonnel_DoInsert"() OWNER TO core;

--
-- Name: AllPersonnel_DoUpdate(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "AllPersonnel_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.id := OLD.id;

	IF NEW.updated IS NULL THEN
		NEW.updated := CURRENT_TIMESTAMP;
	END IF;

	IF NEW.updated_by IS NULL THEN
		NEW.updated_by := CURRENT_USER;
	END IF;

	UPDATE core."Personnel" SET
		name_last = NEW.name_last,
		name_first = NEW.name_first,
		user_level = NEW.user_level,
		days_to_log = NEW.days_to_log,
		apb_type_id = NEW.apb_type_id,
		apb_zone_id = NEW.apb_zone_id,
		apb_violations = NEW.apb_violations,
		updated = NEW.updated,
		updated_by = NEW.updated_by
	WHERE id = OLD.id 
		AND deleted IS NULL;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION core."AllPersonnel_DoUpdate"() OWNER TO core;

--
-- Name: CanSwitchToSingleId(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "CanSwitchToSingleId"() RETURNS boolean
    LANGUAGE sql
    AS $$
SELECT NOT EXISTS (
	SELECT count(*) AS count
	FROM core."Personnel" AS cp
	LEFT JOIN core."Token" AS ct ON cp.id = ct.personnel_id AND ct.type_id = 1 AND ct.deleted IS NULL
	WHERE cp.deleted IS NULL
	GROUP BY cp.id
	HAVING count(*) <> 1
);
$$;


ALTER FUNCTION core."CanSwitchToSingleId"() OWNER TO core;

--
-- Name: CardToken_DoDelete(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "CardToken_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	username character varying(255);
BEGIN
	username := CURRENT_USER;

	IF core."Token_Delete"(OLD.token_id, username) THEN
		RETURN OLD;
	END IF;

	RETURN NULL;
END;
$$;


ALTER FUNCTION core."CardToken_DoDelete"() OWNER TO core;

--
-- Name: CardToken_DoInsert(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "CardToken_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	token_type_id smallint;
BEGIN
	IF NEW.token_id IS NULL THEN
		NEW.token_id := uuid_generate_v4();
	END IF;

	token_type_id := 1;

	IF NEW.site_code IS NULL THEN
		NEW.site_code := 0;
	END IF;

	IF NEW.card_format IS NULL THEN
		NEW.card_format := 26;
	END IF;

	IF NEW.activate_date IS NULL THEN
		NEW.activate_date := CURRENT_DATE;
	END IF;

	IF NEW.deactivate_date IS NULL THEN
		NEW.deactivate_date := CURRENT_DATE + '1 year'::interval;
	END IF;

	IF NEW.lost IS NULL THEN
		NEW.lost := false;
	END IF;

	IF NEW.created IS NULL THEN
		NEW.created := CURRENT_TIMESTAMP;
	END IF;

	IF NEW.created_by IS NULL THEN
		NEW.created_by := CURRENT_USER;
	END IF;

	INSERT INTO core."Token" (
		id,
		type_id,
		user_level,
		personnel_id,
		badge_id,
		lost,
		last_read,
		last_reader,
		last_read_status,
		created,
		created_by,
		updated,
		updated_by,
		downloaded,
		downloaded_by,
		download_required)
	VALUES (
		NEW.token_id,
		token_type_id,
		NEW.user_level,
		NEW.personnel_id,
		NEW.badge_id,
		NEW.lost,
		NEW.last_read,
		NEW.last_reader,
		NEW.last_read_status,
		NEW.created,
		NEW.created_by,
		NEW.updated,
		NEW.updated_by,
		NEW.downloaded,
		NEW.downloaded_by,
		NEW.download_required);

	INSERT INTO core."Card" (
		token_id,
		card_number,
		site_code,
		card_format,
		card_type,
		pin_number,
		card_valid,
		activate_date,
		deactivate_date,
		secondary_expiration_date,
		expire_days,
		action_point_id,
		threat_level,
		auto_disable,
		grant_long_access_time,
		escort_visitor_capable,
		access_cost_override_capable,
		event_lock_override_capable,
		building_passback_exemption,
		parking_passback_exemption,
		card_holder_groups,
		activation_group,
		on_access_output,
		compass_command_group,
		low_battery)
	VALUES (
		NEW.token_id,
		NEW.card_number,
		NEW.site_code,
		NEW.card_format,
		NEW.card_type,
		NEW.pin_number,
		NEW.card_valid,
		NEW.activate_date,
		NEW.deactivate_date,
		NEW.secondary_expiration_date,
		NEW.expire_days,
		NEW.action_point_id,
		NEW.threat_level,
		NEW.auto_disable,
		NEW.grant_long_access_time,
		NEW.escort_visitor_capable,
		NEW.access_cost_override_capable,
		NEW.event_lock_override_capable,
		NEW.building_passback_exemption,
		NEW.parking_passback_exemption,
		NEW.card_holder_groups,
		NEW.activation_group,
		NEW.on_access_output,
		NEW.compass_command_group,
		NEW.low_battery);

	RETURN NEW;
END;
$$;


ALTER FUNCTION core."CardToken_DoInsert"() OWNER TO core;

--
-- Name: CardToken_DoUpdate(); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "CardToken_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.token_id := OLD.token_id;

	IF NEW.updated IS NULL THEN
		NEW.updated := CURRENT_TIMESTAMP;
	END IF;

	IF NEW.updated_by IS NULL THEN
		NEW.updated_by := CURRENT_USER;
	END IF;

	UPDATE core."Token" SET
		user_level = NEW.user_level,
		personnel_id = NEW.personnel_id,
		badge_id = NEW.badge_id,
		lost = NEW.lost,
		last_read = NEW.last_read,
		last_reader = NEW.last_reader,
		last_read_status = NEW.last_read_status,
		updated = NEW.updated,
		updated_by = NEW.updated_by,
		downloaded = NEW.downloaded,
		downloaded_by = NEW.downloaded_by,
		download_required = NEW.download_required
	WHERE id = OLD.token_id
		AND deleted IS NULL;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	UPDATE core."Card" SET 
		card_number = NEW.card_number,
		site_code = NEW.site_code,
		card_format = NEW.card_format,
		card_type = NEW.card_type,
		pin_number = NEW.pin_number,
		card_valid = NEW.card_valid,
		activate_date = NEW.activate_date,
		deactivate_date = NEW.deactivate_date,
		secondary_expiration_date = NEW.secondary_expiration_date,
		expire_days = NEW.expire_days,
		action_point_id = NEW.action_point_id,
		threat_level = NEW.threat_level,
		auto_disable = NEW.auto_disable,
		grant_long_access_time = NEW.grant_long_access_time,
		escort_visitor_capable = NEW.escort_visitor_capable,
		access_cost_override_capable = NEW.access_cost_override_capable,
		event_lock_override_capable = NEW.event_lock_override_capable,
		building_passback_exemption = NEW.building_passback_exemption,
		parking_passback_exemption = NEW.parking_passback_exemption,
		card_holder_groups = NEW.card_holder_groups,
		activation_group = NEW.activation_group,
		on_access_output = NEW.on_access_output,
		compass_command_group = NEW.compass_command_group,
		low_battery = NEW.low_battery
	WHERE token_id = OLD.token_id;

	RETURN NEW;
END;
$$;


ALTER FUNCTION core."CardToken_DoUpdate"() OWNER TO core;

--
-- Name: Personnel_Delete(uuid, character varying); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "Personnel_Delete"(personnel_id uuid, username character varying) RETURNS boolean
    LANGUAGE plpgsql
    AS $_$
DECLARE
	delete_personnel_id ALIAS FOR $1;
	result boolean := false;
	deleted_ts timestamp with time zone;
	deleted_token_id uuid := NULL;
	rec RECORD;
BEGIN
	IF username IS NULL THEN
		username := CURRENT_USER;
	END IF;

	deleted_ts := CURRENT_TIMESTAMP;

	FOR rec in select name_first, name_last, name_middle, assigned_to, card_number, site_code, card_format, room 
	FROM extra."MultiCard" where extra."MultiCard".personnel_id = delete_personnel_id
	LOOP
	IF rec.card_number <= 256 and rec.site_code = 0 and rec.card_format = 26 THEN
	Insert into history."AccutechTagChange" (
				change_time, 
				event, 
				card_number,
				name_first,
				name_last,
				name_middle,
				assigned_to, 
				updated_by,
				room) 
				VALUES (
				NOW(),
				5037,
				rec.card_number,
				rec.name_first,
				rec.name_last,
				rec.name_middle,
				rec.assigned_to,
				username,
				rec.room);
	END IF;
	END LOOP;
	
	WITH deletedTokens AS (
		UPDATE core."Token" AS token SET
			deleted = deleted_ts,
			deleted_by = username
		WHERE token.personnel_id = delete_personnel_id AND token.deleted IS NULL
		RETURNING token.id
	)
	UPDATE core."Card" AS card SET
		deleted = deleted_ts
	WHERE card.token_id IN (SELECT id FROM deletedTokens);

	UPDATE core."Personnel" AS personnel SET
		deleted = deleted_ts,
		deleted_by = username
	WHERE personnel.id = delete_personnel_id AND personnel.deleted IS NULL;

	IF FOUND THEN
		result := true;
	END IF;
	
	RETURN result;
END;
$_$;


ALTER FUNCTION core."Personnel_Delete"(personnel_id uuid, username character varying) OWNER TO core;

--
-- Name: Token_Delete(uuid, character varying); Type: FUNCTION; Schema: core; Owner: core
--

CREATE FUNCTION "Token_Delete"(token_id uuid, username character varying) RETURNS boolean
    LANGUAGE plpgsql
    AS $_$
DECLARE
	result boolean := false;
	deleted_ts timestamp with time zone;
	deleted_token_id uuid := NULL;
BEGIN
	IF username IS NULL THEN
		username := CURRENT_USER;
	END IF;

	deleted_ts := CURRENT_TIMESTAMP;

	UPDATE core."Token" AS token SET
		deleted = deleted_ts,
		deleted_by = username
	WHERE token.id = $1 AND token.deleted IS NULL
	RETURNING token.id INTO deleted_token_id;

	IF deleted_token_id IS NOT NULL THEN
		result := true;
		UPDATE core."Card" AS card SET
			deleted = deleted_ts
		WHERE card.token_id = deleted_token_id;
	END IF;

	RETURN result;
END;
$_$;


ALTER FUNCTION core."Token_Delete"(token_id uuid, username character varying) OWNER TO core;

--
-- Name: datediff(character varying, timestamp without time zone, timestamp without time zone); Type: FUNCTION; Schema: core; Owner: postgres
--

CREATE FUNCTION datediff(units character varying, start_t timestamp without time zone, end_t timestamp without time zone) RETURNS integer
    LANGUAGE plpgsql
    AS $$
   DECLARE
     diff_interval INTERVAL; 
     diff INT = 0;
     years_diff INT = 0;
   BEGIN
     IF units IN ('yy', 'yyyy', 'year', 'mm', 'm', 'month') THEN
       years_diff = DATE_PART('year', end_t) - DATE_PART('year', start_t);
 
       IF units IN ('yy', 'yyyy', 'year') THEN
         -- SQL Server does not count full years passed (only difference between year parts)
         RETURN years_diff;
       ELSE
         -- If end month is less than start month it will subtracted
         RETURN years_diff * 12 + (DATE_PART('month', end_t) - DATE_PART('month', start_t)); 
       END IF;
     END IF;
 
     -- Minus operator returns interval 'DDD days HH:MI:SS'  
     diff_interval = end_t - start_t;
 
     diff = diff + DATE_PART('day', diff_interval);
 
     IF units IN ('wk', 'ww', 'week') THEN
       diff = diff/7;
       RETURN diff;
     END IF;
 
     IF units IN ('dd', 'd', 'day') THEN
       RETURN diff;
     END IF;
 
     diff = diff * 24 + DATE_PART('hour', diff_interval); 
 
     IF units IN ('hh', 'hour') THEN
        RETURN diff;
     END IF;
 
     diff = diff * 60 + DATE_PART('minute', diff_interval);
 
     IF units IN ('mi', 'n', 'minute') THEN
        RETURN diff;
     END IF;
 
     diff = diff * 60 + DATE_PART('second', diff_interval);
 
     RETURN diff;
   END;
   $$;


ALTER FUNCTION core.datediff(units character varying, start_t timestamp without time zone, end_t timestamp without time zone) OWNER TO postgres;

SET search_path = extra, pg_catalog;

--
-- Name: AllAccessSet_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllAccessSet_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."AccessSet"
	WHERE id = OLD.id;

	IF FOUND THEN
		extra_found := true;
	END IF;

	IF OLD.notes_id IS NOT NULL THEN
		DELETE FROM extra."Notes" WHERE id = OLD.notes_id;
	END IF;
	
	DELETE FROM core."AccessSet"
	WHERE id = OLD.id;

	IF NOT FOUND AND NOT extra_found THEN
		RETURN NULL;
	END IF;
	
	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."AllAccessSet_DoDelete"() OWNER TO extra;

--
-- Name: AllAccessSet_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllAccessSet_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF NEW.id IS NULL THEN
		NEW.id := uuid_generate_v4();
	END IF;

	INSERT INTO core."AccessSet" (
		id,
		name,
		user_level,
		download_required)
	VALUES (
		NEW.id,
		NEW.name,
		NEW.user_level,
		NEW.download_required);

	NEW.notes_id := extra."Notes_InsertOrUpdate"(NEW.notes_id, NEW.notes);

	INSERT INTO extra."AccessSet" (
		id,
		notes_id)
	VALUES (
		NEW.id,
		NEW.notes_id);

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllAccessSet_DoInsert"() OWNER TO extra;

--
-- Name: AllAccessSet_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllAccessSet_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.id := OLD.id;

	UPDATE core."AccessSet" SET
		name = NEW.name,
		user_level = NEW.user_level,
		download_required = NEW.download_required
	WHERE id = OLD.id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	NEW.notes_id := extra."Notes_Update"(OLD.notes_id, NEW.notes_id, NEW.notes);

	UPDATE extra."AccessSet" SET
		notes_id = NEW.notes_id
	WHERE id = OLD.id;

	IF NOT FOUND THEN
		INSERT INTO extra."AccessSet" (
			id,
			notes_id)
		VALUES (
			NEW.id,
			NEW.notes_id);
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllAccessSet_DoUpdate"() OWNER TO extra;

--
-- Name: AllPersonnel_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllPersonnel_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."Personnel"
	WHERE id = OLD.id;

	IF FOUND THEN
		extra_found := true;
	END IF;

	IF OLD.notes_id IS NOT NULL THEN
		DELETE FROM extra."Notes" WHERE id = OLD.notes_id;
	END IF;

	IF OLD.photo_id IS NOT NULL THEN
		DELETE FROM extra."Blob" WHERE id = OLD.photo_id;
	END IF;

	IF OLD.signature_id IS NOT NULL THEN
		DELETE FROM extra."Blob" WHERE id = OLD.signature_id;
	END IF;

	IF OLD.fingerprint_id IS NOT NULL THEN
		DELETE FROM extra."Blob" WHERE id = OLD.fingerprint_id;
	END IF;

	DELETE FROM core."AllPersonnel"
	WHERE id = OLD.id;

	IF NOT FOUND AND NOT extra_found THEN
		RETURN NULL;
	END IF;

	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."AllPersonnel_DoDelete"() OWNER TO extra;

--
-- Name: AllPersonnel_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllPersonnel_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF NEW.id IS NULL THEN
		NEW.id := uuid_generate_v4();
	END IF;

	INSERT INTO core."AllPersonnel" (
		id,
		name_last,
		name_first,
		user_level,
		days_to_log,
		apb_type_id,
		apb_zone_id,
		apb_violations,
		created,
		created_by,
		updated,
		updated_by)
	VALUES (
		NEW.id,
		NEW.name_last,
		NEW.name_first,
		NEW.user_level,
		NEW.days_to_log,
		NEW.apb_type_id,
		NEW.apb_zone_id,
		NEW.apb_violations,
		NEW.created,
		NEW.created_by,
		NEW.updated,
		NEW.updated_by);

	NEW.notes_id := extra."Notes_InsertOrUpdate"(NEW.notes_id, NEW.notes);
	NEW.photo_id := extra."Blob_InsertOrUpdate"(NEW.photo_id, NEW.photo_type, NEW.photo);
	NEW.signature_id := extra."Blob_InsertOrUpdate"(NEW.signature_id, NEW.signature_type, NEW.signature);
	NEW.fingerprint_id := extra."Blob_InsertOrUpdate"(NEW.fingerprint_id, NEW.fingerprint_type, NEW.fingerprint);

	INSERT INTO extra."Personnel" (
		id,
		name_middle,
		name_prefix,
		name_suffix,
		company,
		department,
		job_title,
		email,
		phone_work,
		phone_work_ext,
		phone_mobile,
		phone_home,
		address,
		city,
		state_or_prov,
		postal_code,
		country,
		notes_id,
		photo_id,
		signature_id,
		fingerprint_id,
		room,
		assigned_to,
		admission_date)
	VALUES (
		NEW.id,
		NEW.name_middle,
		NEW.name_prefix,
		NEW.name_suffix,
		NEW.company,
		NEW.department,
		NEW.job_title,
		NEW.email,
		NEW.phone_work,
		NEW.phone_work_ext,
		NEW.phone_mobile,
		NEW.phone_home,
		NEW.address,
		NEW.city,
		NEW.state_or_prov,
		NEW.postal_code,
		NEW.country,
		NEW.notes_id,
		NEW.photo_id,
		NEW.signature_id,
		NEW.fingerprint_id,
		NEW.room,
		NEW.assigned_to,
		NEW.admission_date);

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllPersonnel_DoInsert"() OWNER TO extra;

--
-- Name: AllPersonnel_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllPersonnel_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.id := OLD.id;

	UPDATE core."AllPersonnel" SET
		name_last = NEW.name_last,
		name_first = NEW.name_first,
		user_level = NEW.user_level,
		days_to_log = NEW.days_to_log,
		apb_type_id = NEW.apb_type_id,
		apb_zone_id = NEW.apb_zone_id,
		apb_violations = NEW.apb_violations,
		updated = NEW.updated,
		updated_by = NEW.updated_by
	WHERE id = OLD.id;
	
	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	NEW.notes_id := extra."Notes_Update"(OLD.notes_id, NEW.notes_id, NEW.notes);
	NEW.photo_id := extra."Blob_Update"(OLD.photo_id, NEW.photo_id, NEW.photo_type, NEW.photo);
	NEW.signature_id := extra."Blob_Update"(OLD.signature_id, NEW.signature_id, NEW.signature_type, NEW.signature);
	NEW.fingerprint_id := extra."Blob_Update"(OLD.fingerprint_id, NEW.fingerprint_id, NEW.fingerprint_type, NEW.fingerprint);

	UPDATE extra."Personnel" SET
		name_middle = NEW.name_middle,
		name_prefix = NEW.name_prefix,
		name_suffix = NEW.name_suffix,
		company = NEW.company,
		department = NEW.department,
		job_title = NEW.job_title,
		email = NEW.email,
		phone_work = NEW.phone_work,
		phone_work_ext = NEW.phone_work_ext,
		phone_mobile = NEW.phone_mobile,
		phone_home = NEW.phone_home,
		address = NEW.address,
		city = NEW.city,
		state_or_prov = NEW.state_or_prov,
		postal_code = NEW.postal_code,
		country = NEW.country,
		notes_id = NEW.notes_id,
		photo_id = NEW.photo_id,
		signature_id = NEW.signature_id,
		fingerprint_id = NEW.fingerprint_id,
		room = NEW.room,
		assigned_to = NEW.assigned_to,
		admission_date = NEW.admission_date
	WHERE id = OLD.id;

	IF NOT FOUND THEN
		INSERT INTO extra."Personnel" (
			id,
			name_middle,
			name_prefix,
			name_suffix,
			company,
			department,
			job_title,
			email,
			phone_work,
			phone_work_ext,
			phone_mobile,
			phone_home,
			address,
			city,
			state_or_prov,
			postal_code,
			country,
			notes_id,
			photo_id,
			signature_id,
			fingerprint_id,
			room,
			assigned_to,
			admission_date)
		VALUES (
			NEW.id,
			NEW.name_middle,
			NEW.name_prefix,
			NEW.name_suffix,
			NEW.company,
			NEW.department,
			NEW.job_title,
			NEW.email,
			NEW.phone_work,
			NEW.phone_work_ext,
			NEW.phone_mobile,
			NEW.phone_home,
			NEW.address,
			NEW.city,
			NEW.state_or_prov,
			NEW.postal_code,
			NEW.country,
			NEW.notes_id,
			NEW.photo_id,
			NEW.signature_id,
			NEW.fingerprint_id,
			NEW.room,
			NEW.assigned_to,
			NEW.admission_date);
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllPersonnel_DoUpdate"() OWNER TO extra;

--
-- Name: AllVehicle_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllVehicle_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."Vehicle"
	WHERE id = OLD.id;

	IF FOUND THEN
		extra_found := true;
	END IF;

	IF OLD.notes_id IS NOT NULL THEN
		DELETE FROM extra."Notes" WHERE id = OLD.notes_id;
	END IF;
	
	DELETE FROM core."Vehicle"
	WHERE id = OLD.id;

	IF NOT FOUND AND NOT extra_found THEN
		RETURN NULL;
	END IF;
	
	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."AllVehicle_DoDelete"() OWNER TO extra;

--
-- Name: AllVehicle_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllVehicle_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF NEW.id IS NULL THEN
		NEW.id := uuid_generate_v4();
	END IF;

	INSERT INTO core."Vehicle" (
		id,
		personnel_id,
		make,
		model,
		color,
		accent_color,
		state_or_prov,
		tag,
		sticker,
		year)
	VALUES (
		NEW.id,
		NEW.personnel_id,
		NEW.make,
		NEW.model,
		NEW.color,
		NEW.accent_color,
		NEW.state_or_prov,
		NEW.tag,
		NEW.sticker,
		NEW.year);

	NEW.notes_id := extra."Notes_InsertOrUpdate"(NEW.notes_id, NEW.notes);

	INSERT INTO extra."Vehicle" (
		id,
		notes_id)
	VALUES (
		NEW.id,
		NEW.notes_id);

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllVehicle_DoInsert"() OWNER TO extra;

--
-- Name: AllVehicle_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "AllVehicle_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.id := OLD.id;

	UPDATE core."Vehicle" SET
		personnel_id = NEW.personnel_id,
		make = NEW.make,
		model = NEW.model,
		color = NEW.color,
		accent_color = NEW.accent_color,
		state_or_prov = NEW.state_or_prov,
		tag = NEW.tag,
		sticker = NEW.sticker,
		year = NEW.year
	WHERE id = OLD.id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	NEW.notes_id := extra."Notes_Update"(OLD.notes_id, NEW.notes_id, NEW.notes);

	UPDATE extra."Vehicle" SET
		notes_id = NEW.notes_id
	WHERE id = OLD.id;

	IF NOT FOUND THEN
		INSERT INTO extra."Vehicle" (
			id,
			notes_id)
		VALUES (
			NEW.id,
			NEW.notes_id);
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."AllVehicle_DoUpdate"() OWNER TO extra;

--
-- Name: Blob_InsertOrUpdate(uuid, character varying, bytea); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "Blob_InsertOrUpdate"(id uuid, mime_type character varying, bytes bytea) RETURNS uuid
    LANGUAGE plpgsql
    AS $$
DECLARE
	new_id ALIAS FOR id;
	new_mime_type ALIAS FOR mime_type;
	new_bytes ALIAS FOR bytes;
	new_blob RECORD;
	new_blob_type RECORD;
	new_type_id smallint;
BEGIN
	IF bytes IS NULL THEN
		RETURN NULL;
	END IF;
	
	IF new_mime_type IS NULL THEN
		new_type_id := NULL;
	ELSE
		SELECT btype.id INTO new_blob_type
		FROM core."BlobType" btype
		WHERE btype.mime_type = new_mime_type;

		new_type_id := new_blob_type.id;

		IF new_type_id IS NULL THEN
			INSERT INTO core."BlobType" (mime_type)
			VALUES (new_mime_type)
			RETURNING core."BlobType".id INTO new_blob_type;

			new_type_id := new_blob_type.id;
		END IF;
	END IF;
	
	IF id IS NULL THEN
		id := uuid_generate_v4();

		INSERT INTO extra."Blob" (id, type_id, bytes)
		VALUES (new_id, new_type_id, new_bytes)
		RETURNING extra."Blob".id INTO new_blob;
	ELSE
		UPDATE extra."Blob" blob
		SET
			type_id = new_type_id,
			bytes = new_bytes
		WHERE blob.id = new_id
		RETURNING blob.id INTO new_blob;

		IF NOT FOUND THEN
			INSERT INTO extra."Blob" (id, type_id, bytes)
			VALUES (id, new_type_id, bytes)
			RETURNING extra."Blob".id INTO new_blob;
		END IF;
	END IF;
	
	RETURN new_blob.id;
END;
$$;


ALTER FUNCTION extra."Blob_InsertOrUpdate"(id uuid, mime_type character varying, bytes bytea) OWNER TO extra;

--
-- Name: Blob_Update(uuid, uuid, character varying, bytea); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "Blob_Update"(old_id uuid, new_id uuid, mime_type character varying, bytes bytea) RETURNS uuid
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF bytes IS NULL THEN
		IF old_id IS NOT NULL THEN
			DELETE FROM extra."Blob" WHERE id = old_id;
		END IF;
		new_id := NULL;
	ELSE
		IF old_id IS NOT NULL THEN
			IF new_id IS NULL THEN
				new_id := old_id;
			ELSIF new_id <> old_id THEN
				DELETE FROM extra."Blob" WHERE id = old_id;
			END IF;
		END IF;
		new_id := extra."Blob_InsertOrUpdate"(new_id, mime_type, bytes);
	END IF;
	
	RETURN new_id;
END;
$$;


ALTER FUNCTION extra."Blob_Update"(old_id uuid, new_id uuid, mime_type character varying, bytes bytea) OWNER TO extra;

--
-- Name: CardToken_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "CardToken_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."Card"
	WHERE token_id = OLD.token_id;

	IF FOUND THEN
		extra_found := true;
	END IF;
	
	DELETE FROM core."CardToken"
	WHERE token_id = OLD.token_id;

	IF NOT FOUND AND NOT extra_found THEN
		RETURN NULL;
	END IF;
	
	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."CardToken_DoDelete"() OWNER TO extra;

--
-- Name: CardToken_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "CardToken_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	core_inserted RECORD;
BEGIN
	INSERT INTO core."CardToken" (
		token_id,
		card_number,
		site_code,
		card_format,
		card_type,
		pin_number,
		card_valid,
		activate_date,
		deactivate_date,
		secondary_expiration_date,
		expire_days,
		action_point_id,
		threat_level,
		auto_disable,
		grant_long_access_time,
		escort_visitor_capable,
		access_cost_override_capable,
		event_lock_override_capable,
		building_passback_exemption,
		parking_passback_exemption,
		card_holder_groups,
		activation_group,
		on_access_output,
		compass_command_group,
		user_level,
		personnel_id,
		badge_id,
		lost,
		last_read,
		last_reader,
		last_read_status,
		created,
		created_by,
		updated,
		updated_by,
		downloaded,
		downloaded_by,
		download_required,
		low_battery)
	VALUES (
		NEW.token_id,
		NEW.card_number,
		NEW.site_code,
		NEW.card_format,
		NEW.card_type,
		NEW.pin_number,
		NEW.card_valid,
		NEW.activate_date,
		NEW.deactivate_date,
		NEW.secondary_expiration_date,
		NEW.expire_days,
		NEW.action_point_id,
		NEW.threat_level,
		NEW.auto_disable,
		NEW.grant_long_access_time,
		NEW.escort_visitor_capable,
		NEW.access_cost_override_capable,
		NEW.event_lock_override_capable,
		NEW.building_passback_exemption,
		NEW.parking_passback_exemption,
		NEW.card_holder_groups,
		NEW.activation_group,
		NEW.on_access_output,
		NEW.compass_command_group,
		NEW.user_level,
		NEW.personnel_id,
		NEW.badge_id,
		NEW.lost,
		NEW.last_read,
		NEW.last_reader,
		NEW.last_read_status,
		NEW.created,
		NEW.created_by,
		NEW.updated,
		NEW.updated_by,
		NEW.downloaded,
		NEW.downloaded_by,
		NEW.download_required,
		NEW.low_battery)
	RETURNING token_id INTO STRICT core_inserted;
	
	IF NOT FOUND OR core_inserted.token_id IS NULL THEN
		RETURN NULL;
	END IF;

	NEW.token_id := core_inserted.token_id;

	INSERT INTO extra."Card" (
		token_id,
		card_emboss_num,
		card_label)
	VALUES (
		core_inserted.token_id,
		NEW.card_emboss_num,
		NEW.card_label);

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."CardToken_DoInsert"() OWNER TO extra;

--
-- Name: CardToken_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "CardToken_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.token_id := OLD.token_id;

	UPDATE core."CardToken" SET
		card_number = NEW.card_number,
		site_code = NEW.site_code,
		card_format = NEW.card_format,
		card_type = NEW.card_type,
		pin_number = NEW.pin_number,
		card_valid = NEW.card_valid,
		activate_date = NEW.activate_date,
		deactivate_date = NEW.deactivate_date,
		secondary_expiration_date = NEW.secondary_expiration_date,
		expire_days = NEW.expire_days,
		action_point_id = NEW.action_point_id,
		threat_level = NEW.threat_level,
		auto_disable = NEW.auto_disable,
		grant_long_access_time = NEW.grant_long_access_time,
		escort_visitor_capable = NEW.escort_visitor_capable,
		access_cost_override_capable = NEW.access_cost_override_capable,
		event_lock_override_capable = NEW.event_lock_override_capable,
		building_passback_exemption = NEW.building_passback_exemption,
		parking_passback_exemption = NEW.parking_passback_exemption,
		card_holder_groups = NEW.card_holder_groups,
		activation_group = NEW.activation_group,
		on_access_output = NEW.on_access_output,
		compass_command_group = NEW.compass_command_group,
		user_level = NEW.user_level,
		personnel_id = NEW.personnel_id,
		badge_id = NEW.badge_id,
		lost = NEW.lost,
		last_read = NEW.last_read,
		last_reader = NEW.last_reader,
		last_read_status = NEW.last_read_status,
		created = NEW.created,
		created_by = NEW.created_by,
		updated = NEW.updated,
		updated_by = NEW.updated_by,
		downloaded = NEW.downloaded,
		downloaded_by = NEW.downloaded_by,
		download_required = NEW.download_required,
		low_battery = NEW.low_battery
	WHERE token_id = OLD.token_id;
	
	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	UPDATE extra."Card" SET
		card_emboss_num = NEW.card_emboss_num,
		card_label = NEW.card_label
	WHERE token_id = OLD.token_id;

	IF NOT FOUND THEN
		INSERT INTO extra."Card" (
			token_id,
			card_emboss_num,
			card_label)
		VALUES (
			NEW.token_id,
			NEW.card_emboss_num,
			NEW.card_label);
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."CardToken_DoUpdate"() OWNER TO extra;

--
-- Name: MultiCard_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "MultiCard_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."CardToken"
	WHERE token_id = OLD.token_id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."MultiCard_DoDelete"() OWNER TO extra;

--
-- Name: MultiCard_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "MultiCard_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	new_card RECORD;
	new_personnel RECORD;
	old_personnel RECORD;
	is_new_personnel BOOLEAN;
BEGIN
	is_new_personnel := true;

	IF NEW.personnel_id IS NOT NULL THEN
		SELECT personnel.id INTO old_personnel
		FROM core."Personnel" personnel
		WHERE personnel.id = NEW.personnel_id;

		IF FOUND THEN
			is_new_personnel := false;
		END IF;
	END IF;

	IF is_new_personnel THEN
		INSERT INTO extra."AllPersonnel" (
			id,
			name_last,
			name_first,
			name_middle,
			name_prefix,
			name_suffix,
			company,
			department,
			job_title,
			email,
			phone_work,
			phone_work_ext,
			phone_mobile,
			phone_home,
			address,
			city,
			state_or_prov,
			postal_code,
			country,
			notes_id,
			notes,
			photo_id,
			photo,
			photo_type,
			signature_id,
			signature,
			signature_type,
			fingerprint_id,
			fingerprint,
			fingerprint_type,
			user_level,
			days_to_log,
			apb_type_id,
			apb_zone_id,
			apb_violations,
			created,
			created_by,
			updated,
			updated_by,
			room,
			assigned_to,
			admission_date)
		VALUES (
			NEW.personnel_id,
			NEW.name_last,
			NEW.name_first,
			NEW.name_middle,
			NEW.name_prefix,
			NEW.name_suffix,
			NEW.company,
			NEW.department,
			NEW.job_title,
			NEW.email,
			NEW.phone_work,
			NEW.phone_work_ext,
			NEW.phone_mobile,
			NEW.phone_home,
			NEW.address,
			NEW.city,
			NEW.state_or_prov,
			NEW.postal_code,
			NEW.country,
			NEW.notes_id,
			NEW.notes,
			NEW.photo_id,
			NEW.photo,
			NEW.photo_type,
			NEW.signature_id,
			NEW.signature,
			NEW.signature_type,
			NEW.fingerprint_id,
			NEW.fingerprint,
			NEW.fingerprint_type,
			NEW.personnel_user_level,
			NEW.days_to_log,
			NEW.apb_type_id,
			NEW.apb_zone_id,
			NEW.apb_violations,
			NEW.personnel_created,
			NEW.personnel_created_by,
			NEW.personnel_updated,
			NEW.personnel_updated_by,
			NEW.room,
			NEW.assigned_to,
			NEW.admission_date)
			RETURNING id INTO STRICT new_personnel;

		IF NOT FOUND OR new_personnel.id IS NULL THEN
			RETURN NULL;
		END IF;

		NEW.personnel_id := new_personnel.id;
	ELSE
		NEW.personnel_id := OLD.personnel_id;

		UPDATE extra."AllPersonnel" personnel SET
			name_last = NEW.name_last,
			name_first = NEW.name_first,
			name_middle = NEW.name_middle,
			name_prefix = NEW.name_prefix,
			name_suffix = NEW.name_suffix,
			company = NEW.company,
			department = NEW.department,
			job_title = NEW.job_title,
			email = NEW.email,
			phone_work = NEW.phone_work,
			phone_work_ext = NEW.phone_work_ext,
			phone_mobile = NEW.phone_mobile,
			phone_home = NEW.phone_home,
			address = NEW.address,
			city = NEW.city,
			state_or_prov = NEW.state_or_prov,
			postal_code = NEW.postal_code,
			country = NEW.country,
			notes_id = NEW.notes_id,
			notes = NEW.notes,
			photo_id = NEW.photo_id,
			photo = NEW.photo,
			photo_type = NEW.photo_type,
			signature_id = NEW.signature_id,
			signature = NEW.signature,
			signature_type = NEW.signature_type,
			fingerprint_id = NEW.fingerprint_id,
			fingerprint = NEW.fingerprint,
			fingerprint_type = NEW.fingerprint_type,
			user_level = NEW.personnel_user_level,
			days_to_log = NEW.days_to_log,
			apb_type_id = NEW.apb_type_id,
			apb_zone_id = NEW.apb_zone_id,
			apb_violations = NEW.apb_violations,
			created = NEW.personnel_created,
			created_by = NEW.personnel_created_by,
			updated = NEW.personnel_updated,
			updated_by = NEW.personnel_updated_by,
			room = NEW.room,
			assigned_to = NEW.assigned_to,
			admission_date = NEW.admission_date
		WHERE id = OLD.personnel_id;

		IF NOT FOUND THEN
			RETURN NULL;
		END IF;
	END IF;

	INSERT INTO extra."CardToken" (
		token_id,
		personnel_id,
		card_number,
		site_code,
		card_format,
		card_type,
		card_emboss_num,
		card_label,
		pin_number,
		card_valid,
		activate_date,
		deactivate_date,
		secondary_expiration_date,
		expire_days,
		action_point_id,
		threat_level,
		auto_disable,
		grant_long_access_time,
		escort_visitor_capable,
		access_cost_override_capable,
		event_lock_override_capable,
		building_passback_exemption,
		parking_passback_exemption,
		card_holder_groups,
		activation_group,
		on_access_output,
		compass_command_group,
		user_level,
		badge_id,
		lost,
		last_read,
		last_reader,
		last_read_status,
		created,
		created_by,
		updated,
		updated_by,
		downloaded,
		downloaded_by,
		download_required,
		low_battery)
	VALUES (
		NEW.token_id,
		NEW.personnel_id,
		NEW.card_number,
		NEW.site_code,
		NEW.card_format,
		NEW.card_type,
		NEW.card_emboss_num,
		NEW.card_label,
		NEW.pin_number,
		NEW.card_valid,
		NEW.activate_date,
		NEW.deactivate_date,
		NEW.secondary_expiration_date,
		NEW.expire_days,
		NEW.action_point_id,
		NEW.threat_level,
		NEW.auto_disable,
		NEW.grant_long_access_time,
		NEW.escort_visitor_capable,
		NEW.access_cost_override_capable,
		NEW.event_lock_override_capable,
		NEW.building_passback_exemption,
		NEW.parking_passback_exemption,
		NEW.card_holder_groups,
		NEW.activation_group,
		NEW.on_access_output,
		NEW.compass_command_group,
		NEW.card_user_level,
		NEW.badge_id,
		NEW.lost,
		NEW.last_read,
		NEW.last_reader,
		NEW.last_read_status,
		NEW.card_created,
		NEW.card_created_by,
		NEW.card_updated,
		NEW.card_updated_by,
		NEW.downloaded,
		NEW.downloaded_by,
		NEW.download_required,
		NEW.low_battery)
	RETURNING token_id INTO STRICT new_card;

	IF NOT FOUND OR new_card.token_id IS NULL THEN
		RETURN NULL;
	END IF;

	NEW.token_id := new_card.token_id;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."MultiCard_DoInsert"() OWNER TO extra;

--
-- Name: MultiCard_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "MultiCard_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
BEGIN
	NEW.token_id := OLD.token_id;
	NEW.personnel_id := OLD.personnel_id;

	UPDATE extra."AllPersonnel" personnel SET
		name_last = NEW.name_last,
		name_first = NEW.name_first,
		name_middle = NEW.name_middle,
		name_prefix = NEW.name_prefix,
		name_suffix = NEW.name_suffix,
		company = NEW.company,
		department = NEW.department,
		job_title = NEW.job_title,
		email = NEW.email,
		phone_work = NEW.phone_work,
		phone_work_ext = NEW.phone_work_ext,
		phone_mobile = NEW.phone_mobile,
		phone_home = NEW.phone_home,
		address = NEW.address,
		city = NEW.city,
		state_or_prov = NEW.state_or_prov,
		postal_code = NEW.postal_code,
		country = NEW.country,
		notes_id = NEW.notes_id,
		notes = NEW.notes,
		photo_id = NEW.photo_id,
		photo = NEW.photo,
		photo_type = NEW.photo_type,
		signature_id = NEW.signature_id,
		signature = NEW.signature,
		signature_type = NEW.signature_type,
		fingerprint_id = NEW.fingerprint_id,
		fingerprint = NEW.fingerprint,
		fingerprint_type = NEW.fingerprint_type,
		user_level = NEW.personnel_user_level,
		days_to_log = NEW.days_to_log,
		apb_type_id = NEW.apb_type_id,
		apb_zone_id = NEW.apb_zone_id,
		apb_violations = NEW.apb_violations,
		created = NEW.personnel_created,
		created_by = NEW.personnel_created_by,
		updated = NEW.personnel_updated,
		updated_by = NEW.personnel_updated_by,
		room = NEW.room,
		assigned_to = NEW.assigned_to,
		admission_date = NEW.admission_date
	WHERE id = OLD.personnel_id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	UPDATE extra."CardToken" card SET
		card_number = NEW.card_number,
		site_code = NEW.site_code,
		card_format = NEW.card_format,
		card_type = NEW.card_type,
		card_emboss_num = NEW.card_emboss_num,
		card_label = NEW.card_label,
		pin_number = NEW.pin_number,
		card_valid = NEW.card_valid,
		activate_date = NEW.activate_date,
		deactivate_date = NEW.deactivate_date,
		secondary_expiration_date = NEW.secondary_expiration_date,
		expire_days = NEW.expire_days,
		action_point_id = NEW.action_point_id,
		threat_level = NEW.threat_level,
		auto_disable = NEW.auto_disable,
		grant_long_access_time = NEW.grant_long_access_time,
		escort_visitor_capable = NEW.escort_visitor_capable,
		access_cost_override_capable = NEW.access_cost_override_capable,
		event_lock_override_capable = NEW.event_lock_override_capable,
		building_passback_exemption = NEW.building_passback_exemption,
		parking_passback_exemption = NEW.parking_passback_exemption,
		card_holder_groups = NEW.card_holder_groups,
		activation_group = NEW.activation_group,
		on_access_output = NEW.on_access_output,
		compass_command_group = NEW.compass_command_group,
		user_level = NEW.card_user_level,
		badge_id = NEW.badge_id,
		lost = NEW.lost,
		last_read = NEW.last_read,
		last_reader = NEW.last_reader,
		last_read_status = NEW.last_read_status,
		created = NEW.card_created,
		created_by = NEW.card_created_by,
		updated = NEW.card_updated,
		updated_by = NEW.card_updated_by,
		downloaded = NEW.downloaded,
		downloaded_by = NEW.downloaded_by,
		download_required = NEW.download_required,
		low_battery = NEW.low_battery
	WHERE token_id = OLD.token_id;

	IF NOT FOUND THEN
		RETURN NULL;
	END IF;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."MultiCard_DoUpdate"() OWNER TO extra;

--
-- Name: Notes_InsertOrUpdate(uuid, text); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "Notes_InsertOrUpdate"(id uuid, text text) RETURNS uuid
    LANGUAGE plpgsql
    AS $$
DECLARE
	new_note RECORD;
	new_id ALIAS FOR id;
	new_text ALIAS FOR text;
BEGIN
	IF text IS NULL THEN
		RETURN NULL;
	END IF;
	
	IF new_id IS NULL THEN
		new_id := uuid_generate_v4();

		INSERT INTO extra."Notes" (id, text)
		VALUES (new_id, new_text)
		RETURNING extra."Notes".id INTO new_note;
	ELSE
		UPDATE extra."Notes" notes
		SET text = new_text
		WHERE notes.id = new_id
		RETURNING notes.id INTO new_note;

		IF NOT FOUND THEN
			INSERT INTO extra."Notes" (id, text)
			VALUES (new_id, new_text)
			RETURNING extra."Notes".id INTO new_note;
		END IF;
	END IF;
	
	RETURN new_note.id;
END;
$$;


ALTER FUNCTION extra."Notes_InsertOrUpdate"(id uuid, text text) OWNER TO extra;

--
-- Name: Notes_Update(uuid, uuid, text); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "Notes_Update"(old_id uuid, new_id uuid, text text) RETURNS uuid
    LANGUAGE plpgsql
    AS $$
BEGIN
	IF text IS NULL THEN
		IF old_id IS NOT NULL THEN
			DELETE FROM extra."Notes" WHERE id = old_id;
		END IF;
		new_id := NULL;
	ELSE
		IF old_id IS NOT NULL THEN
			IF new_id IS NULL THEN
				new_id := old_id;
			ELSIF new_id <> old_id THEN
				DELETE FROM extra."Notes" WHERE id = old_id;
			END IF;
		END IF;
		new_id := extra."Notes_InsertOrUpdate"(new_id, text);
	END IF;
	
	RETURN new_id;
END;
$$;


ALTER FUNCTION extra."Notes_Update"(old_id uuid, new_id uuid, text text) OWNER TO extra;

--
-- Name: SingleCard_DoDelete(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "SingleCard_DoDelete"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	extra_found boolean := false;
BEGIN
	DELETE FROM extra."CardToken"
	WHERE token_id = OLD.token_id;

	IF FOUND THEN
		extra_found := true;
	END IF;
	
	DELETE FROM extra."AllPersonnel"
	WHERE id = OLD.personnel_id;

	IF NOT FOUND AND NOT extra_found THEN
		RETURN NULL;
	END IF;
	
	RETURN OLD;
END;
$$;


ALTER FUNCTION extra."SingleCard_DoDelete"() OWNER TO extra;

--
-- Name: SingleCard_DoInsert(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "SingleCard_DoInsert"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	new_card RECORD;
	new_personnel RECORD;
	old_personnel RECORD;
BEGIN
	IF NEW.personnel_id IS NOT NULL THEN
		SELECT personnel.id INTO old_personnel
		FROM core."Personnel" personnel
		WHERE personnel.id = NEW.personnel_id;
		
		IF FOUND THEN
			RAISE EXCEPTION 'An existing record exists with personnel ID: %', NEW.personnel_id
				USING ERRCODE = 'integrity_constraint_violation';
		END IF;
	END IF;

	INSERT INTO extra."AllPersonnel" (
		id,
		name_last,
		name_first,
		name_middle,
		name_prefix,
		name_suffix,
		company,
		department,
		job_title,
		email,
		phone_work,
		phone_work_ext,
		phone_mobile,
		phone_home,
		address,
		city,
		state_or_prov,
		postal_code,
		country,
		notes_id,
		notes,
		photo_id,
		photo,
		photo_type,
		signature_id,
		signature,
		signature_type,
		fingerprint_id,
		fingerprint,
		fingerprint_type,
		user_level,
		days_to_log,
		apb_type_id,
		apb_zone_id,
		apb_violations,
		created,
		created_by,
		updated,
		updated_by,
		room,
		assigned_to,
		admission_date)
	VALUES (
		NEW.personnel_id,
		NEW.name_last,
		NEW.name_first,
		NEW.name_middle,
		NEW.name_prefix,
		NEW.name_suffix,
		NEW.company,
		NEW.department,
		NEW.job_title,
		NEW.email,
		NEW.phone_work,
		NEW.phone_work_ext,
		NEW.phone_mobile,
		NEW.phone_home,
		NEW.address,
		NEW.city,
		NEW.state_or_prov,
		NEW.postal_code,
		NEW.country,
		NEW.notes_id,
		NEW.notes,
		NEW.photo_id,
		NEW.photo,
		NEW.photo_type,
		NEW.signature_id,
		NEW.signature,
		NEW.signature_type,
		NEW.fingerprint_id,
		NEW.fingerprint,
		NEW.fingerprint_type,
		NEW.personnel_user_level,
		NEW.days_to_log,
		NEW.apb_type_id,
		NEW.apb_zone_id,
		NEW.apb_violations,
		NEW.personnel_created,
		NEW.personnel_created_by,
		NEW.personnel_updated,
		NEW.personnel_updated_by,
		NEW.room,
		NEW.assigned_to,
		NEW.admission_date)
	RETURNING id INTO STRICT new_personnel;

	IF NOT FOUND OR new_personnel.id IS NULL THEN
		RETURN NULL;
	END IF;
	
	NEW.personnel_id := new_personnel.id;

	INSERT INTO extra."CardToken" (
		token_id,
		personnel_id,
		card_number,
		site_code,
		card_format,
		card_type,
		card_emboss_num,
		card_label,
		pin_number,
		card_valid,
		activate_date,
		deactivate_date,
		secondary_expiration_date,
		expire_days,
		action_point_id,
		threat_level,
		auto_disable,
		grant_long_access_time,
		escort_visitor_capable,
		access_cost_override_capable,
		event_lock_override_capable,
		building_passback_exemption,
		parking_passback_exemption,
		card_holder_groups,
		activation_group,
		on_access_output,
		compass_command_group,
		user_level,
		badge_id,
		lost,
		last_read,
		last_reader,
		last_read_status,
		created,
		created_by,
		updated,
		updated_by,
		downloaded,
		downloaded_by,
		download_required,
		low_battery)
	VALUES (
		NEW.token_id,
		NEW.personnel_id,
		NEW.card_number,
		NEW.site_code,
		NEW.card_format,
		NEW.card_type,
		NEW.card_emboss_num,
		NEW.card_label,
		NEW.pin_number,
		NEW.card_valid,
		NEW.activate_date,
		NEW.deactivate_date,
		NEW.secondary_expiration_date,
		NEW.expire_days,
		NEW.action_point_id,
		NEW.threat_level,
		NEW.auto_disable,
		NEW.grant_long_access_time,
		NEW.escort_visitor_capable,
		NEW.access_cost_override_capable,
		NEW.event_lock_override_capable,
		NEW.building_passback_exemption,
		NEW.parking_passback_exemption,
		NEW.card_holder_groups,
		NEW.activation_group,
		NEW.on_access_output,
		NEW.compass_command_group,
		NEW.card_user_level,
		NEW.badge_id,
		NEW.lost,
		NEW.last_read,
		NEW.last_reader,
		NEW.last_read_status,
		NEW.card_created,
		NEW.card_created_by,
		NEW.card_updated,
		NEW.card_updated_by,
		NEW.downloaded,
		NEW.downloaded_by,
		NEW.download_required,
		NEW.low_battery)
	RETURNING token_id INTO STRICT new_card;
	
	IF NOT FOUND OR new_card.token_id IS NULL THEN
		RETURN NULL;
	END IF;
	IF NEW.card_number <= 256 and NEW.site_code = 0 and NEW.card_format = 26 THEN
				
				Insert into history."AccutechTagChange" (
				change_time, 
				event, 
				card_number, 
				name_first, 
				name_last, 
				name_middle, 
				assigned_to, 
				updated_by,
				room) 
				VALUES (
				NOW(),
				5036,
				NEW.card_number,
				NEW.name_first,
				NEW.name_last,
				NEW.name_middle,
				NEW.assigned_to,
				NEW.personnel_created_by,
				NEW.room);
	END IF;	
	NEW.token_id := new_card.token_id;

	RETURN NEW;
END;
$$;


ALTER FUNCTION extra."SingleCard_DoInsert"() OWNER TO extra;

--
-- Name: SingleCard_DoUpdate(); Type: FUNCTION; Schema: extra; Owner: extra
--

CREATE FUNCTION "SingleCard_DoUpdate"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	d_change_type smallint;
	assignToDecr int;
BEGIN
	assignToDecr = 0;
    IF NEW.assigned_to >= 100 THEN--Tag is being re - assigned
		assignToDecr = 100;
    END IF;
	NEW.token_id := OLD.token_id;
	NEW.personnel_id := OLD.personnel_id;

	UPDATE extra."AllPersonnel" personnel SET
		name_last = NEW.name_last,
		name_first = NEW.name_first,
		name_middle = NEW.name_middle,
		name_prefix = NEW.name_prefix,
		name_suffix = NEW.name_suffix,
		company = NEW.company,
		department = NEW.department,
		job_title = NEW.job_title,
		email = NEW.email,
		phone_work = NEW.phone_work,
		phone_work_ext = NEW.phone_work_ext,
		phone_mobile = NEW.phone_mobile,
		phone_home = NEW.phone_home,
		address = NEW.address,
		city = NEW.city,
		state_or_prov = NEW.state_or_prov,
		postal_code = NEW.postal_code,
		country = NEW.country,
		notes_id = NEW.notes_id,
		notes = NEW.notes,
		photo_id = NEW.photo_id,
		photo = NEW.photo,
		photo_type = NEW.photo_type,
		signature_id = NEW.signature_id,
		signature = NEW.signature,
		signature_type = NEW.signature_type,
		fingerprint_id = NEW.fingerprint_id,
		fingerprint = NEW.fingerprint,
		fingerprint_type = NEW.fingerprint_type,
		user_level = NEW.personnel_user_level,
		days_to_log = NEW.days_to_log,
		apb_type_id = NEW.apb_type_id,
		apb_zone_id = NEW.apb_zone_id,
		apb_violations = NEW.apb_violations,
		created = NEW.personnel_created,
		created_by = NEW.personnel_created_by,
		updated = NEW.personnel_updated,
		updated_by = NEW.personnel_updated_by,
		room = NEW.room,
		assigned_to = NEW.assigned_to - assignToDecr,
		admission_date = NEW.admission_date
	WHERE id = OLD.personnel_id;

				IF NOT FOUND THEN
		RETURN NULL;
				END IF;

				UPDATE extra."CardToken" card SET
		card_number = NEW.card_number,
		site_code = NEW.site_code,
		card_format = NEW.card_format,
		card_type = NEW.card_type,
		card_emboss_num = NEW.card_emboss_num,
		card_label = NEW.card_label,
		pin_number = NEW.pin_number,
		card_valid = NEW.card_valid,
		activate_date = NEW.activate_date,
		deactivate_date = NEW.deactivate_date,
		secondary_expiration_date = NEW.secondary_expiration_date,
		expire_days = NEW.expire_days,
		action_point_id = NEW.action_point_id,
		threat_level = NEW.threat_level,
		auto_disable = NEW.auto_disable,
		grant_long_access_time = NEW.grant_long_access_time,
		escort_visitor_capable = NEW.escort_visitor_capable,
		access_cost_override_capable = NEW.access_cost_override_capable,
		event_lock_override_capable = NEW.event_lock_override_capable,
		building_passback_exemption = NEW.building_passback_exemption,
		parking_passback_exemption = NEW.parking_passback_exemption,
		card_holder_groups = NEW.card_holder_groups,
		activation_group = NEW.activation_group,
		on_access_output = NEW.on_access_output,
		compass_command_group = NEW.compass_command_group,
		user_level = NEW.card_user_level,
		badge_id = NEW.badge_id,
		lost = NEW.lost,
		last_read = NEW.last_read,
		last_reader = NEW.last_reader,
		last_read_status = NEW.last_read_status,
		created = NEW.card_created,
		created_by = NEW.card_created_by,
		updated = NEW.card_updated,
		updated_by = NEW.card_updated_by,
		downloaded = NEW.downloaded,
		downloaded_by = NEW.downloaded_by,
		download_required = NEW.download_required,
		low_battery = NEW.low_battery
	WHERE token_id = OLD.token_id;

				IF NOT FOUND THEN
		RETURN NULL;
				END IF;
				d_change_type:= 5039;
				--Owner Edited
IF OLD.name_last = 'Unassigned' THEN
d_change_type := 5038;
				--Admitted
		END IF;
				IF NEW.name_last = 'Unassigned' THEN
				d_change_type := 5041;
				--Discharged
		END IF;
				IF NEW.assigned_to >= 100 THEN--Tag is being re - assigned
			IF d_change_type = 5038 THEN--The tag is being admitted after being discharged, Discharge with assigned_to >= 100 are ignored
				d_change_type:= 5040;
				--Reassigned
				Insert into history."AccutechTagChange"(
				change_time,
				event, 
				card_number, 
				name_first, 
				name_last, 
				name_middle, 
				assigned_to, 
				updated_by,
				room) 
				VALUES (
				NOW(),
				d_change_type,
				NEW.card_number,
				NEW.name_first,
				NEW.name_last,
				NEW.name_middle,
				NEW.assigned_to - assignToDecr,
				NEW.personnel_updated_by,
				NEW.room);
		END IF;
		ELSE
			IF d_change_type = 5041 THEN
				Insert into history."AccutechTagChange" (
				change_time, 
				event, 
				card_number, 
				name_first, 
				name_last, 
				name_middle, 
				assigned_to, 
				updated_by,
				room) 
				VALUES (
				NOW(),
				d_change_type,
				OLD.card_number,
				OLD.name_first,
				OLD.name_last,
				OLD.name_middle,
				OLD.assigned_to,
				OLD.personnel_updated_by,
				OLD.room);
		ELSE
			Insert into history."AccutechTagChange" (
			change_time, 
			event, 
			card_number, 
			name_first, 
			name_last, 
			name_middle, 
			assigned_to, 
			updated_by,
			room) 
			VALUES (
			NOW(),
			d_change_type,
			NEW.card_number,
			NEW.name_first,
			NEW.name_last,
			NEW.name_middle,
			NEW.assigned_to,
			NEW.personnel_updated_by,
			NEW.room);
		END IF;
		END IF;
		RETURN NEW;
		END;
$$;


ALTER FUNCTION extra."SingleCard_DoUpdate"() OWNER TO extra;

SET search_path = history, pg_catalog;

--
-- Name: Activity_Insert_Statistics(); Type: FUNCTION; Schema: history; Owner: core
--

CREATE FUNCTION "Activity_Insert_Statistics"() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
	t_activity RECORD;
			new_stats RECORD;
			l_active timestamp with time zone;
			BEGIN
			IF NEW.event_type_id in ( 1, 2, 6 ) THEN
					IF NEW.event_type_id = 2 THEN
					SELECT id INTO t_activity
					FROM history."Activity_Statistics" stats
					WHERE stats.point_id = NEW.point_id and stats.cleared_time IS NULL and stats.acked_time IS NULL;
			END IF;
			IF NEW.event_type_id = 1 THEN
			SELECT id INTO t_activity
			FROM history."Activity_Statistics" stats
			WHERE stats.point_id = NEW.point_id and stats.card_number = NEW.card_number and stats.cleared_time IS NULL and stats.acked_time IS NULL;
			END IF;
			IF NEW.event_type_id = 6 THEN
			SELECT id INTO t_activity
			FROM history."Activity_Statistics" stats
			WHERE stats.point_id = NEW.point_id and stats.cleared_time IS NULL and stats.acked_time IS NULL;
			END IF;

			IF t_activity.id IS NULL THEN
		IF NEW.event_type_id = 2 and NEW.state = 1 THEN
		NEW.id := uuid_generate_v4();
			INSERT INTO history."Activity_Statistics"(
				id, event_type_id, rtu_id, rtu_name, point_id, point_name, state, status, card_number, site_code, card_format,
						card_holder_name, computer, "user", user_comments, token_id, active_time, inactive_time, acked_time, cleared_time, last_active, total_active, active_count )
		VALUES(
			NEW.id, NEW.event_type_id, NEW.rtu_id, NEW.rtu_Name, NEW.point_id, NEW.point_name, null, null, NEW.card_number, NEW.site_code, NEW.card_format,
						NEW.card_Holder_name, NEW.computer, NEW.user, NEW.user_comments, NEW.token_id, NEW."time", NULL, NULL, NULL, NEW."time", 0, 1 );
			SELECT id INTO t_activity
		FROM history."Activity_Statistics" stats
		WHERE stats.point_id = NEW.point_id and stats.cleared_time IS NULL and stats.acked_time IS NULL;
			END IF;

			IF NEW.event_type_id = 1 THEN
		NEW.id := uuid_generate_v4();
			INSERT INTO history."Activity_Statistics"(
				id, event_type_id, rtu_id, rtu_name, point_id, point_name, state, status, card_number, site_code, card_format,
						card_holder_name, computer, "user", user_comments, token_id, active_time, inactive_time, acked_time, cleared_time, last_active, total_active, active_count )
		VALUES(
			NEW.id, NEW.event_type_id, NEW.rtu_id, NEW.rtu_Name, NEW.point_id, NEW.point_name, null, null, NEW.card_number, NEW.site_code, NEW.card_format,
						NEW.card_Holder_name, NEW.computer, NEW.user, NEW.user_comments, NEW.token_id, NEW."time", NEW."time", NULL, NULL, NEW."time", 0, 1 );
			SELECT id INTO t_activity
		FROM history."Activity_Statistics" stats
		WHERE stats.point_id = NEW.point_id and stats.cleared_time IS NULL and stats.acked_time IS NULL;
			END IF;

			END IF;
			IF NOT FOUND OR t_activity.id IS NULL THEN
		RETURN NULL;
			END IF;
			IF NEW.state = 0 and NEW.event_type_id = 2 THEN
				IF NEW.user_comments IS NULL THEN
		select last_active INTO l_active from history."Activity_Statistics" where id = t_activity.id;
			Update history."Activity_Statistics" set inactive_time = NEW."time", total_active = total_active + datediff( 'second', l_active::timestamp( 0 ), NEW."time"::timestamp( 0 ) ) where id = t_activity.id;
			END IF;
			IF NEW.user_comments IS NOT NULL THEN
			select last_active INTO l_active from history."Activity_Statistics" where id = t_activity.id;
			Update history."Activity_Statistics" set inactive_time = NEW."time", total_active = total_active + datediff( 'second', l_active::timestamp( 0 ), NEW."time"::timestamp( 0 ) ), user_comments = 'Auto Cleared', "user" = 'System' where id = t_activity.id;
			END IF;
			END IF;

			IF NEW.state = 1 and NEW.event_type_id = 2 THEN
				Update history."Activity_Statistics" set last_active = NEW."time", active_count = active_count + 1 where id = t_activity.id;
			END IF;

			IF NEW.event_type_id = 6 and NEW.status ilike 'Acked' THEN
				Update history."Activity_Statistics" set acked_time = NEW."time", "user" = NEW."user" where id = t_activity.id;
			Update history."Activity_Statistics" set inactive_time = NEW."time" where inactive_time IS NULL;
			END IF;

			IF NEW.event_type_id = 6 and NEW.status ilike 'Cleared' THEN
				Update history."Activity_Statistics" set cleared_time = NEW."time", "user" = NEW."user" where id = t_activity.id;
			Update history."Activity_Statistics" set inactive_time = NEW."time" where inactive_time IS NULL;
			END IF;
END IF;
			RETURN NEW;
			END;
$$;


ALTER FUNCTION history."Activity_Insert_Statistics"() OWNER TO core;

SET search_path = core, pg_catalog;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: AccessEntry; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "AccessEntry" (
    id integer NOT NULL,
    name character varying(255)
);


ALTER TABLE "AccessEntry" OWNER TO core;

--
-- Name: AccessSet; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "AccessSet" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    name character varying(50),
    user_level integer,
    download_required boolean
);


ALTER TABLE "AccessSet" OWNER TO core;

--
-- Name: AccessSetsToAccessEntries; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "AccessSetsToAccessEntries" (
    access_set_id uuid NOT NULL,
    access_entry_id integer NOT NULL
);


ALTER TABLE "AccessSetsToAccessEntries" OWNER TO core;

--
-- Name: AccessSetsToTokens; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "AccessSetsToTokens" (
    access_set_id uuid NOT NULL,
    token_id uuid NOT NULL
);


ALTER TABLE "AccessSetsToTokens" OWNER TO core;

--
-- Name: Personnel; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Personnel" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    name_last character varying(50),
    name_first character varying(50),
    user_level integer,
    days_to_log smallint,
    apb_type_id smallint,
    apb_zone_id integer,
    apb_violations smallint,
    created timestamp with time zone DEFAULT now(),
    created_by character varying(255) DEFAULT "current_user"(),
    updated timestamp with time zone,
    updated_by character varying(255),
    deleted timestamp with time zone,
    deleted_by character varying(255)
);


ALTER TABLE "Personnel" OWNER TO core;

--
-- Name: COLUMN "Personnel".apb_type_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Personnel".apb_type_id IS 'Anti-passback type id';


--
-- Name: COLUMN "Personnel".apb_zone_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Personnel".apb_zone_id IS 'Anti-passback zone id';


--
-- Name: COLUMN "Personnel".apb_violations; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Personnel".apb_violations IS 'Anti-passback zone violation count';


--
-- Name: AllPersonnel; Type: VIEW; Schema: core; Owner: core
--

CREATE VIEW "AllPersonnel" AS
 SELECT personnel.id,
    personnel.name_last,
    personnel.name_first,
    personnel.user_level,
    personnel.days_to_log,
    personnel.apb_type_id,
    personnel.apb_zone_id,
    personnel.apb_violations,
    personnel.created,
    personnel.created_by,
    personnel.updated,
    personnel.updated_by
   FROM "Personnel" personnel
  WHERE (personnel.deleted IS NULL);


ALTER TABLE "AllPersonnel" OWNER TO core;

--
-- Name: COLUMN "AllPersonnel".apb_type_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "AllPersonnel".apb_type_id IS 'Anti-passback type id';


--
-- Name: COLUMN "AllPersonnel".apb_zone_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "AllPersonnel".apb_zone_id IS 'Anti-passback zone id';


--
-- Name: COLUMN "AllPersonnel".apb_violations; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "AllPersonnel".apb_violations IS 'Anti-passback zone violation count';


--
-- Name: AlterTableInformation; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "AlterTableInformation" (
    id integer NOT NULL,
    tabletobealtered character varying(50) NOT NULL,
    ordertoalter integer NOT NULL,
    qryschema character varying(50) NOT NULL,
    qrytable character varying(50) NOT NULL,
    viewname character varying(50),
    functionname character varying(50),
    viewaliasname character varying(50),
    returnfield1 character varying(50) NOT NULL,
    returnfield2 character varying(50),
    returnfield3 character varying(50),
    wherefield character varying(50),
    internalfunctiontableorviewname character varying(50)
);


ALTER TABLE "AlterTableInformation" OWNER TO core;

--
-- Name: AlterTableInformation_id_seq; Type: SEQUENCE; Schema: core; Owner: core
--

CREATE SEQUENCE "AlterTableInformation_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "AlterTableInformation_id_seq" OWNER TO core;

--
-- Name: AlterTableInformation_id_seq; Type: SEQUENCE OWNED BY; Schema: core; Owner: core
--

ALTER SEQUENCE "AlterTableInformation_id_seq" OWNED BY "AlterTableInformation".id;


--
-- Name: BlobType; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "BlobType" (
    id smallint NOT NULL,
    name character varying(50),
    abbrev character varying(10),
    mime_type character varying(50)
);


ALTER TABLE "BlobType" OWNER TO core;

--
-- Name: BlobType_id_seq; Type: SEQUENCE; Schema: core; Owner: core
--

CREATE SEQUENCE "BlobType_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "BlobType_id_seq" OWNER TO core;

--
-- Name: BlobType_id_seq; Type: SEQUENCE OWNED BY; Schema: core; Owner: core
--

ALTER SEQUENCE "BlobType_id_seq" OWNED BY "BlobType".id;


--
-- Name: Card; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Card" (
    token_id uuid NOT NULL,
    card_number bigint NOT NULL,
    site_code bigint DEFAULT 0 NOT NULL,
    card_format smallint DEFAULT 26 NOT NULL,
    card_type smallint DEFAULT 1,
    pin_number character varying(50),
    card_valid boolean,
    activate_date date DEFAULT (now())::date,
    deactivate_date date DEFAULT ((now() + '1 year'::interval))::date,
    secondary_expiration_date date,
    expire_days smallint,
    action_point_id integer,
    threat_level smallint,
    auto_disable boolean,
    grant_long_access_time boolean,
    escort_visitor_capable boolean,
    access_cost_override_capable boolean,
    event_lock_override_capable boolean,
    building_passback_exemption boolean,
    parking_passback_exemption boolean,
    card_holder_groups smallint,
    activation_group smallint,
    on_access_output smallint,
    compass_command_group smallint,
    deleted timestamp with time zone,
    low_battery boolean DEFAULT false
);


ALTER TABLE "Card" OWNER TO core;

--
-- Name: COLUMN "Card".activate_date; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Card".activate_date IS 'Activate card on date';


--
-- Name: COLUMN "Card".deactivate_date; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Card".deactivate_date IS 'Deactivate card on date';


--
-- Name: COLUMN "Card".expire_days; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Card".expire_days IS 'Card expires after days unused';


--
-- Name: COLUMN "Card".action_point_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Card".action_point_id IS 'Action point to trigger in project';


--
-- Name: Token; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Token" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    type_id smallint,
    user_level integer,
    personnel_id uuid,
    badge_id integer,
    lost boolean DEFAULT false NOT NULL,
    last_read timestamp with time zone,
    last_reader character varying(255),
    last_read_status character varying(255),
    created timestamp with time zone DEFAULT now(),
    created_by character varying(255) DEFAULT "current_user"(),
    updated timestamp with time zone,
    updated_by character varying(255),
    deleted timestamp with time zone,
    deleted_by character varying(255),
    downloaded timestamp with time zone,
    downloaded_by character varying(255),
    download_required boolean
);


ALTER TABLE "Token" OWNER TO core;

--
-- Name: COLUMN "Token".badge_id; Type: COMMENT; Schema: core; Owner: core
--

COMMENT ON COLUMN "Token".badge_id IS 'Tree node id for badge template';


--
-- Name: CardDownload; Type: VIEW; Schema: core; Owner: core
--

CREATE VIEW "CardDownload" AS
 SELECT card.token_id,
    token.personnel_id,
    personnel.name_last,
    personnel.name_first,
    card.card_number,
    card.site_code,
    card.card_format,
    card.card_type,
    card.pin_number,
    card.card_valid,
    card.activate_date,
    card.deactivate_date,
    card.expire_days,
    card.secondary_expiration_date,
    card.action_point_id,
    card.threat_level,
    card.auto_disable,
    card.grant_long_access_time,
    card.escort_visitor_capable,
    card.access_cost_override_capable,
    card.event_lock_override_capable,
    card.building_passback_exemption,
    card.parking_passback_exemption,
    card.card_holder_groups,
    card.activation_group,
    card.on_access_output,
    card.compass_command_group,
    personnel.apb_type_id,
    personnel.apb_zone_id,
    personnel.apb_violations,
    token.lost,
    token.downloaded,
    token.downloaded_by,
    token.download_required,
    card.low_battery
   FROM (("Card" card
     JOIN "Token" token ON ((card.token_id = token.id)))
     JOIN "Personnel" personnel ON ((token.personnel_id = personnel.id)))
  WHERE (token.deleted IS NULL);


ALTER TABLE "CardDownload" OWNER TO core;

--
-- Name: CardToken; Type: VIEW; Schema: core; Owner: core
--

CREATE VIEW "CardToken" AS
 SELECT card.token_id,
    card.card_number,
    card.site_code,
    card.card_format,
    card.card_type,
    card.pin_number,
    card.card_valid,
    card.activate_date,
    card.deactivate_date,
    card.secondary_expiration_date,
    card.expire_days,
    card.action_point_id,
    card.threat_level,
    card.auto_disable,
    card.grant_long_access_time,
    card.escort_visitor_capable,
    card.access_cost_override_capable,
    card.event_lock_override_capable,
    card.building_passback_exemption,
    card.parking_passback_exemption,
    card.card_holder_groups,
    card.activation_group,
    card.on_access_output,
    card.compass_command_group,
    token.user_level,
    token.personnel_id,
    token.badge_id,
    token.lost,
    token.last_read,
    token.last_reader,
    token.last_read_status,
    token.created,
    token.created_by,
    token.updated,
    token.updated_by,
    token.downloaded,
    token.downloaded_by,
    token.download_required,
    card.low_battery
   FROM ("Card" card
     JOIN "Token" token ON ((card.token_id = token.id)))
  WHERE (token.deleted IS NULL);


ALTER TABLE "CardToken" OWNER TO core;

--
-- Name: Parameter; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Parameter" (
    id bigint NOT NULL,
    name character varying(255) NOT NULL,
    value text
);


ALTER TABLE "Parameter" OWNER TO core;

--
-- Name: Parameter_id_seq; Type: SEQUENCE; Schema: core; Owner: core
--

CREATE SEQUENCE "Parameter_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "Parameter_id_seq" OWNER TO core;

--
-- Name: Parameter_id_seq; Type: SEQUENCE OWNED BY; Schema: core; Owner: core
--

ALTER SEQUENCE "Parameter_id_seq" OWNED BY "Parameter".id;


--
-- Name: PersonnelTokenCounts; Type: VIEW; Schema: core; Owner: core
--

CREATE VIEW "PersonnelTokenCounts" AS
 SELECT personnel.id AS personnel_id,
    token.type_id,
    count(token.id) AS count
   FROM ("Personnel" personnel
     LEFT JOIN "Token" token ON (((personnel.id = token.personnel_id) AND (token.deleted IS NULL))))
  WHERE (personnel.deleted IS NULL)
  GROUP BY personnel.id, token.type_id;


ALTER TABLE "PersonnelTokenCounts" OWNER TO core;

--
-- Name: PersonnelWithSingleCard; Type: VIEW; Schema: core; Owner: core
--

CREATE VIEW "PersonnelWithSingleCard" AS
 SELECT personnel.id AS personnel_id
   FROM ("Personnel" personnel
     LEFT JOIN "Token" token ON ((((personnel.id = token.personnel_id) AND (token.type_id = 1)) AND (token.deleted IS NULL))))
  WHERE (personnel.deleted IS NULL)
  GROUP BY personnel.id
 HAVING (count(token.id) = 1);


ALTER TABLE "PersonnelWithSingleCard" OWNER TO core;

--
-- Name: Reader; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Reader" (
    id integer NOT NULL,
    name character varying(255),
    is_zone boolean DEFAULT false NOT NULL,
    is_muster_zone boolean DEFAULT false NOT NULL
);


ALTER TABLE "Reader" OWNER TO core;

--
-- Name: ReadersToAccessEntries; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "ReadersToAccessEntries" (
    reader_id integer NOT NULL,
    access_entry_id integer NOT NULL
);


ALTER TABLE "ReadersToAccessEntries" OWNER TO core;

--
-- Name: RfidTag; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "RfidTag" (
    token_id uuid NOT NULL,
    tag_number numeric(39,0) NOT NULL
);


ALTER TABLE "RfidTag" OWNER TO core;

--
-- Name: ScheduledEvent; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "ScheduledEvent" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    start timestamp with time zone,
    stop timestamp with time zone,
    event_id integer,
    active boolean DEFAULT false NOT NULL
);


ALTER TABLE "ScheduledEvent" OWNER TO core;

--
-- Name: SystemInformation; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "SystemInformation" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    created timestamp with time zone DEFAULT now(),
    computer_id integer,
    computer_name character varying(50)
);


ALTER TABLE "SystemInformation" OWNER TO core;

--
-- Name: SystemInformationItem; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "SystemInformationItem" (
    sysinfo_id uuid NOT NULL,
    item_id integer NOT NULL,
    "group" character varying(255),
    name character varying(255),
    value text,
    kind character varying(255),
    key text,
    description text
);


ALTER TABLE "SystemInformationItem" OWNER TO core;

--
-- Name: TokenType; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "TokenType" (
    id smallint NOT NULL,
    name character varying(50) NOT NULL,
    table_name character varying(63)
);


ALTER TABLE "TokenType" OWNER TO core;

--
-- Name: TokenType_id_seq; Type: SEQUENCE; Schema: core; Owner: core
--

CREATE SEQUENCE "TokenType_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "TokenType_id_seq" OWNER TO core;

--
-- Name: TokenType_id_seq; Type: SEQUENCE OWNED BY; Schema: core; Owner: core
--

ALTER SEQUENCE "TokenType_id_seq" OWNED BY "TokenType".id;


--
-- Name: Vehicle; Type: TABLE; Schema: core; Owner: core; Tablespace: 
--

CREATE TABLE "Vehicle" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    personnel_id uuid,
    make character varying(50),
    model character varying(50),
    color character varying(50),
    accent_color character varying(50),
    state_or_prov character varying(50),
    tag character varying(50),
    sticker character varying(50),
    year smallint
);


ALTER TABLE "Vehicle" OWNER TO core;

SET search_path = extra, pg_catalog;

--
-- Name: AccessSet; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "AccessSet" (
    id uuid NOT NULL,
    notes_id uuid
);


ALTER TABLE "AccessSet" OWNER TO extra;

--
-- Name: Notes; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "Notes" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    text text
);


ALTER TABLE "Notes" OWNER TO extra;

--
-- Name: AllAccessSet; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "AllAccessSet" AS
 SELECT core.id,
    core.name,
    core.user_level,
    core.download_required,
    extra.notes_id,
    notes.text AS notes
   FROM ((core."AccessSet" core
     LEFT JOIN "AccessSet" extra ON ((core.id = extra.id)))
     LEFT JOIN "Notes" notes ON ((extra.notes_id = notes.id)));


ALTER TABLE "AllAccessSet" OWNER TO extra;

--
-- Name: Blob; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "Blob" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    type_id smallint,
    bytes bytea
);


ALTER TABLE "Blob" OWNER TO extra;

--
-- Name: Personnel; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "Personnel" (
    id uuid NOT NULL,
    name_middle character varying(50),
    name_prefix character varying(30),
    name_suffix character varying(30),
    company character varying(50),
    department character varying(50),
    job_title character varying(50),
    email character varying(255),
    phone_work character varying(30),
    phone_work_ext character varying(20),
    phone_mobile character varying(30),
    phone_home character varying(30),
    address character varying(150),
    city character varying(50),
    state_or_prov character varying(50),
    postal_code character varying(20),
    country character varying(50),
    notes_id uuid,
    photo_id uuid,
    signature_id uuid,
    fingerprint_id uuid,
    room character varying(50),
    assigned_to smallint,
    admission_date timestamp without time zone
);


ALTER TABLE "Personnel" OWNER TO extra;

--
-- Name: AllPersonnel; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "AllPersonnel" AS
 SELECT core.id,
    core.name_last,
    core.name_first,
    extra.name_middle,
    extra.name_prefix,
    extra.name_suffix,
    extra.company,
    extra.department,
    extra.job_title,
    extra.email,
    extra.phone_work,
    extra.phone_work_ext,
    extra.phone_mobile,
    extra.phone_home,
    extra.address,
    extra.city,
    extra.state_or_prov,
    extra.postal_code,
    extra.country,
    extra.notes_id,
    notes.text AS notes,
    extra.photo_id,
    photo.bytes AS photo,
    photo_type.mime_type AS photo_type,
    extra.signature_id,
    signature.bytes AS signature,
    signature_type.mime_type AS signature_type,
    extra.fingerprint_id,
    fingerprint.bytes AS fingerprint,
    fingerprint_type.mime_type AS fingerprint_type,
    core.user_level,
    core.days_to_log,
    core.apb_type_id,
    core.apb_zone_id,
    core.apb_violations,
    core.created,
    core.created_by,
    core.updated,
    core.updated_by,
    extra.room,
    extra.assigned_to,
    extra.admission_date
   FROM ((((((((core."AllPersonnel" core
     LEFT JOIN "Personnel" extra ON ((core.id = extra.id)))
     LEFT JOIN "Notes" notes ON ((extra.notes_id = notes.id)))
     LEFT JOIN "Blob" photo ON ((extra.photo_id = photo.id)))
     LEFT JOIN core."BlobType" photo_type ON ((photo.type_id = photo_type.id)))
     LEFT JOIN "Blob" signature ON ((extra.signature_id = signature.id)))
     LEFT JOIN core."BlobType" signature_type ON ((signature.type_id = signature_type.id)))
     LEFT JOIN "Blob" fingerprint ON ((extra.fingerprint_id = fingerprint.id)))
     LEFT JOIN core."BlobType" fingerprint_type ON ((fingerprint.type_id = fingerprint_type.id)));


ALTER TABLE "AllPersonnel" OWNER TO extra;

--
-- Name: Vehicle; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "Vehicle" (
    id uuid NOT NULL,
    notes_id uuid
);


ALTER TABLE "Vehicle" OWNER TO extra;

--
-- Name: AllVehicle; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "AllVehicle" AS
 SELECT core.id,
    core.personnel_id,
    core.make,
    core.model,
    core.color,
    core.accent_color,
    core.state_or_prov,
    core.tag,
    core.sticker,
    core.year,
    extra.notes_id,
    notes.text AS notes
   FROM ((core."Vehicle" core
     LEFT JOIN "Vehicle" extra ON ((core.id = extra.id)))
     LEFT JOIN "Notes" notes ON ((extra.notes_id = notes.id)));


ALTER TABLE "AllVehicle" OWNER TO extra;

--
-- Name: Card; Type: TABLE; Schema: extra; Owner: extra; Tablespace: 
--

CREATE TABLE "Card" (
    token_id uuid NOT NULL,
    card_emboss_num character varying(50),
    card_label character varying(50)
);


ALTER TABLE "Card" OWNER TO extra;

--
-- Name: CardToken; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "CardToken" AS
 SELECT core.token_id,
    core.card_number,
    core.site_code,
    core.card_format,
    core.card_type,
    extra.card_emboss_num,
    extra.card_label,
    core.pin_number,
    core.card_valid,
    core.activate_date,
    core.deactivate_date,
    core.secondary_expiration_date,
    core.expire_days,
    core.action_point_id,
    core.threat_level,
    core.auto_disable,
    core.grant_long_access_time,
    core.escort_visitor_capable,
    core.access_cost_override_capable,
    core.event_lock_override_capable,
    core.building_passback_exemption,
    core.parking_passback_exemption,
    core.card_holder_groups,
    core.activation_group,
    core.on_access_output,
    core.compass_command_group,
    core.user_level,
    core.personnel_id,
    core.badge_id,
    core.lost,
    core.last_read,
    core.last_reader,
    core.last_read_status,
    core.created,
    core.created_by,
    core.updated,
    core.updated_by,
    core.downloaded,
    core.downloaded_by,
    core.download_required,
    core.low_battery
   FROM (core."CardToken" core
     LEFT JOIN "Card" extra ON ((core.token_id = extra.token_id)));


ALTER TABLE "CardToken" OWNER TO extra;

--
-- Name: MultiCard; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "MultiCard" AS
 SELECT card.token_id,
    card.personnel_id,
    card.card_number,
    card.site_code,
    card.card_format,
    card.card_type,
    card.card_emboss_num,
    card.card_label,
    card.pin_number,
    card.card_valid,
    card.activate_date,
    card.deactivate_date,
    card.secondary_expiration_date,
    card.expire_days,
    card.action_point_id,
    card.threat_level,
    card.auto_disable,
    card.grant_long_access_time,
    card.escort_visitor_capable,
    card.access_cost_override_capable,
    card.event_lock_override_capable,
    card.building_passback_exemption,
    card.parking_passback_exemption,
    card.card_holder_groups,
    card.activation_group,
    card.on_access_output,
    card.compass_command_group,
    card.user_level AS card_user_level,
    card.badge_id,
    card.lost,
    card.last_read,
    card.last_reader,
    card.last_read_status,
    card.created AS card_created,
    card.created_by AS card_created_by,
    card.updated AS card_updated,
    card.updated_by AS card_updated_by,
    card.downloaded,
    card.downloaded_by,
    card.download_required,
    personnel.name_last,
    personnel.name_first,
    personnel.name_middle,
    personnel.name_prefix,
    personnel.name_suffix,
    personnel.company,
    personnel.department,
    personnel.job_title,
    personnel.email,
    personnel.phone_work,
    personnel.phone_work_ext,
    personnel.phone_mobile,
    personnel.phone_home,
    personnel.address,
    personnel.city,
    personnel.state_or_prov,
    personnel.postal_code,
    personnel.country,
    personnel.notes_id,
    personnel.notes,
    personnel.photo_id,
    personnel.photo,
    personnel.photo_type,
    personnel.signature_id,
    personnel.signature,
    personnel.signature_type,
    personnel.fingerprint_id,
    personnel.fingerprint,
    personnel.fingerprint_type,
    personnel.user_level AS personnel_user_level,
    personnel.days_to_log,
    personnel.apb_type_id,
    personnel.apb_zone_id,
    personnel.apb_violations,
    personnel.created AS personnel_created,
    personnel.created_by AS personnel_created_by,
    personnel.updated AS personnel_updated,
    personnel.updated_by AS personnel_updated_by,
    personnel.room,
    personnel.assigned_to,
    personnel.admission_date,
    card.low_battery
   FROM ("CardToken" card
     LEFT JOIN "AllPersonnel" personnel ON ((personnel.id = card.personnel_id)));


ALTER TABLE "MultiCard" OWNER TO extra;

--
-- Name: SingleCard; Type: VIEW; Schema: extra; Owner: extra
--

CREATE VIEW "SingleCard" AS
 SELECT card.token_id,
    card.personnel_id,
    card.card_number,
    card.site_code,
    card.card_format,
    card.card_type,
    card.card_emboss_num,
    card.card_label,
    card.pin_number,
    card.card_valid,
    card.activate_date,
    card.deactivate_date,
    card.secondary_expiration_date,
    card.expire_days,
    card.action_point_id,
    card.threat_level,
    card.auto_disable,
    card.grant_long_access_time,
    card.escort_visitor_capable,
    card.access_cost_override_capable,
    card.event_lock_override_capable,
    card.building_passback_exemption,
    card.parking_passback_exemption,
    card.card_holder_groups,
    card.activation_group,
    card.on_access_output,
    card.compass_command_group,
    card.user_level AS card_user_level,
    card.badge_id,
    card.lost,
    card.last_read,
    card.last_reader,
    card.last_read_status,
    card.created AS card_created,
    card.created_by AS card_created_by,
    card.updated AS card_updated,
    card.updated_by AS card_updated_by,
    card.downloaded,
    card.downloaded_by,
    card.download_required,
    personnel.name_last,
    personnel.name_first,
    personnel.name_middle,
    personnel.name_prefix,
    personnel.name_suffix,
    personnel.company,
    personnel.department,
    personnel.job_title,
    personnel.email,
    personnel.phone_work,
    personnel.phone_work_ext,
    personnel.phone_mobile,
    personnel.phone_home,
    personnel.address,
    personnel.city,
    personnel.state_or_prov,
    personnel.postal_code,
    personnel.country,
    personnel.notes_id,
    personnel.notes,
    personnel.photo_id,
    personnel.photo,
    personnel.photo_type,
    personnel.signature_id,
    personnel.signature,
    personnel.signature_type,
    personnel.fingerprint_id,
    personnel.fingerprint,
    personnel.fingerprint_type,
    personnel.user_level AS personnel_user_level,
    personnel.days_to_log,
    personnel.apb_type_id,
    personnel.apb_zone_id,
    personnel.apb_violations,
    personnel.created AS personnel_created,
    personnel.created_by AS personnel_created_by,
    personnel.updated AS personnel_updated,
    personnel.updated_by AS personnel_updated_by,
    personnel.room,
    personnel.assigned_to,
    personnel.admission_date,
    card.low_battery
   FROM ((core."PersonnelWithSingleCard" singles
     LEFT JOIN "CardToken" card ON ((card.personnel_id = singles.personnel_id)))
     LEFT JOIN "AllPersonnel" personnel ON ((personnel.id = singles.personnel_id)));


ALTER TABLE "SingleCard" OWNER TO extra;

SET search_path = history, pg_catalog;

--
-- Name: AccutechTagChange; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "AccutechTagChange" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    change_time timestamp with time zone DEFAULT now() NOT NULL,
    event smallint NOT NULL,
    card_number bigint NOT NULL,
    name_first character varying(50),
    name_last character varying(50),
    name_middle character varying(50),
    assigned_to smallint,
    updated_by character varying(255),
    room character varying(50)
);


ALTER TABLE "AccutechTagChange" OWNER TO core;

--
-- Name: Activity; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "Activity" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    "time" timestamp with time zone DEFAULT now() NOT NULL,
    event_type_id smallint,
    rtu_id integer,
    rtu_name character varying(100),
    point_id integer,
    point_name character varying(100),
    state smallint,
    status character varying(255),
    card_number bigint,
    site_code bigint,
    card_format smallint,
    card_holder_name character varying(100),
    computer character varying(100),
    "user" character varying(100),
    user_comments text,
    token_id uuid
);


ALTER TABLE "Activity" OWNER TO core;

--
-- Name: Activity_Statistics; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "Activity_Statistics" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    event_type_id smallint,
    rtu_id integer,
    rtu_name character varying(100),
    point_id integer,
    point_name character varying(100),
    state smallint,
    status character varying(255),
    card_number bigint,
    site_code bigint,
    card_format smallint,
    card_holder_name character varying(100),
    computer character varying(100),
    "user" character varying(100),
    user_comments text,
    token_id uuid,
    active_time timestamp with time zone,
    inactive_time timestamp with time zone,
    acked_time timestamp with time zone,
    cleared_time timestamp with time zone,
    last_active timestamp with time zone,
    total_active bigint,
    active_count bigint
);


ALTER TABLE "Activity_Statistics" OWNER TO core;

--
-- Name: ChangeType; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "ChangeType" (
    id smallint NOT NULL,
    name character varying(50) NOT NULL
);


ALTER TABLE "ChangeType" OWNER TO core;

--
-- Name: ChangeType_id_seq; Type: SEQUENCE; Schema: history; Owner: core
--

CREATE SEQUENCE "ChangeType_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "ChangeType_id_seq" OWNER TO core;

--
-- Name: ChangeType_id_seq; Type: SEQUENCE OWNED BY; Schema: history; Owner: core
--

ALTER SEQUENCE "ChangeType_id_seq" OWNED BY "ChangeType".id;


--
-- Name: EventType; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "EventType" (
    id smallint NOT NULL,
    name character varying(50) NOT NULL
);


ALTER TABLE "EventType" OWNER TO core;

--
-- Name: EventType_id_seq; Type: SEQUENCE; Schema: history; Owner: core
--

CREATE SEQUENCE "EventType_id_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE "EventType_id_seq" OWNER TO core;

--
-- Name: EventType_id_seq; Type: SEQUENCE OWNED BY; Schema: history; Owner: core
--

ALTER SEQUENCE "EventType_id_seq" OWNED BY "EventType".id;


--
-- Name: ProjectChange; Type: TABLE; Schema: history; Owner: core; Tablespace: 
--

CREATE TABLE "ProjectChange" (
    id uuid DEFAULT public.uuid_generate_v4() NOT NULL,
    "time" timestamp with time zone DEFAULT now() NOT NULL,
    change_type_id smallint,
    name character varying(100),
    computer character varying(100),
    "user" character varying(100),
    old_data bytea,
    new_data bytea
);


ALTER TABLE "ProjectChange" OWNER TO core;

SET search_path = core, pg_catalog;

--
-- Name: created; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AllPersonnel" ALTER COLUMN created SET DEFAULT now();


--
-- Name: id; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AlterTableInformation" ALTER COLUMN id SET DEFAULT nextval('"AlterTableInformation_id_seq"'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "BlobType" ALTER COLUMN id SET DEFAULT nextval('"BlobType_id_seq"'::regclass);


--
-- Name: low_battery; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "CardDownload" ALTER COLUMN low_battery SET DEFAULT false;


--
-- Name: low_battery; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "CardToken" ALTER COLUMN low_battery SET DEFAULT false;


--
-- Name: id; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "Parameter" ALTER COLUMN id SET DEFAULT nextval('"Parameter_id_seq"'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: core; Owner: core
--

ALTER TABLE ONLY "TokenType" ALTER COLUMN id SET DEFAULT nextval('"TokenType_id_seq"'::regclass);


SET search_path = extra, pg_catalog;

--
-- Name: card_type; Type: DEFAULT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "CardToken" ALTER COLUMN card_type SET DEFAULT 1;


--
-- Name: low_battery; Type: DEFAULT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "CardToken" ALTER COLUMN low_battery SET DEFAULT false;


--
-- Name: card_type; Type: DEFAULT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "MultiCard" ALTER COLUMN card_type SET DEFAULT 1;


--
-- Name: low_battery; Type: DEFAULT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "MultiCard" ALTER COLUMN low_battery SET DEFAULT false;


--
-- Name: card_type; Type: DEFAULT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "SingleCard" ALTER COLUMN card_type SET DEFAULT 1;


--
-- Name: low_battery; Type: DEFAULT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "SingleCard" ALTER COLUMN low_battery SET DEFAULT false;


SET search_path = history, pg_catalog;

--
-- Name: id; Type: DEFAULT; Schema: history; Owner: core
--

ALTER TABLE ONLY "ChangeType" ALTER COLUMN id SET DEFAULT nextval('"ChangeType_id_seq"'::regclass);


--
-- Name: id; Type: DEFAULT; Schema: history; Owner: core
--

ALTER TABLE ONLY "EventType" ALTER COLUMN id SET DEFAULT nextval('"EventType_id_seq"'::regclass);


SET search_path = core, pg_catalog;

--
-- Data for Name: AccessEntry; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "AccessEntry" (id, name) FROM stdin;
\.


--
-- Data for Name: AccessSet; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "AccessSet" (id, name, user_level, download_required) FROM stdin;
\.


--
-- Data for Name: AccessSetsToAccessEntries; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "AccessSetsToAccessEntries" (access_set_id, access_entry_id) FROM stdin;
\.


--
-- Data for Name: AccessSetsToTokens; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "AccessSetsToTokens" (access_set_id, token_id) FROM stdin;
\.


--
-- Data for Name: AlterTableInformation; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "AlterTableInformation" (id, tabletobealtered, ordertoalter, qryschema, qrytable, viewname, functionname, viewaliasname, returnfield1, returnfield2, returnfield3, wherefield, internalfunctiontableorviewname) FROM stdin;
1	Card	1	information_schema	views	CardToken	\N	extra	table_schema	table_name	view_definition	table_name	\N
2	Card	3	information_schema	views	MultiCard	\N	card	table_schema	table_name	view_definition	table_name	\N
3	Card	2	information_schema	views	SingleCard	\N	card	table_schema	table_name	view_definition	table_name	\N
4	Card	4	pg_catalog	pg_proc	\N	CardToken_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
5	Card	5	pg_catalog	pg_proc	\N	CardToken_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
6	Card	6	pg_catalog	pg_proc	\N	MultiCard_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
7	Card	7	pg_catalog	pg_proc	\N	MultiCard_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
8	Card	8	pg_catalog	pg_proc	\N	SingleCard_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
9	Card	9	pg_catalog	pg_proc	\N	SingleCard_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	Card
10	Personnel	1	information_schema	views	AllPersonnel	\N	extra	table_schema	table_name	view_definition	table_name	\N
11	Personnel	2	information_schema	views	MultiCard	\N	personnel	table_schema	table_name	view_definition	table_name	\N
12	Personnel	3	information_schema	views	SingleCard	\N	personnel	table_schema	table_name	view_definition	table_name	\N
13	Personnel	4	pg_catalog	pg_proc	\N	AllPersonnel_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	Personnel
14	Personnel	5	pg_catalog	pg_proc	\N	AllPersonnel_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	Personnel
15	Personnel	6	pg_catalog	pg_proc	\N	MultiCard_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	AllPersonnel
16	Personnel	7	pg_catalog	pg_proc	\N	MultiCard_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	AllPersonnel
17	Personnel	8	pg_catalog	pg_proc	\N	SingleCard_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	AllPersonnel
18	Personnel	9	pg_catalog	pg_proc	\N	SingleCard_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	AllPersonnel
19	Vehicle	1	information_schema	views	AllVehicle	\N	extra	table_schema	table_name	view_definition	table_name	\N
20	Vehicle	2	pg_catalog	pg_proc	\N	AllVehicle_DoInsert	\N	pg_get_functiondef(oid)	proname	\N	proname	Vehicle
21	Vehicle	3	pg_catalog	pg_proc	\N	AllVehicle_DoUpdate	\N	pg_get_functiondef(oid)	proname	\N	proname	Vehicle
\.


--
-- Name: AlterTableInformation_id_seq; Type: SEQUENCE SET; Schema: core; Owner: core
--

SELECT pg_catalog.setval('"AlterTableInformation_id_seq"', 21, true);


--
-- Data for Name: BlobType; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "BlobType" (id, name, abbrev, mime_type) FROM stdin;
0	Binary Data	BIN	application/octet-stream
1	Plain Text	TXT	text/plain
2	Comma-separated Values	CSV	text/csv
3	Rich Text Format	RTF	text/rtf
4	HyperText Markup Language	HTML	text/html
5	Cascading Style Sheets	CSS	text/css
6	JavaScript	JS	application/javascript
7	Portable Document Format	PDF	application/pdf
8	PostScript	PS	application/postscript
9	Extensible Markup Language	XML	application/xml
10	Bitmap Image	BMP	image/bmp
11	GIF Image	GIF	image/gif
12	JPEG Image	JPEG	image/jpeg
13	PNG Image	PNG	image/png
14	SVG Image	SVG	image/svg+xml
15	µ-Law (G.711) Audio	ULAW	audio/basic
16	AIFF Audio	AIFF	audio/aiff
17	MP3/MP2/MPEG Audio	MP3	audio/mpeg
18	MP4 Audio	MP4	audio/mp4
19	Ogg Vorbis Audio	OGG	audio/ogg
20	WAV/WAVE Audio	WAV	audio/vnd.wave
\.


--
-- Name: BlobType_id_seq; Type: SEQUENCE SET; Schema: core; Owner: core
--

SELECT pg_catalog.setval('"BlobType_id_seq"', 21, true);


--
-- Data for Name: Card; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Card" (token_id, card_number, site_code, card_format, card_type, pin_number, card_valid, activate_date, deactivate_date, secondary_expiration_date, expire_days, action_point_id, threat_level, auto_disable, grant_long_access_time, escort_visitor_capable, access_cost_override_capable, event_lock_override_capable, building_passback_exemption, parking_passback_exemption, card_holder_groups, activation_group, on_access_output, compass_command_group, deleted, low_battery) FROM stdin;
\.


--
-- Data for Name: Parameter; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Parameter" (id, name, value) FROM stdin;
2	product_version	4.0.29.22
1	db_version	4.0.17.16
\.


--
-- Name: Parameter_id_seq; Type: SEQUENCE SET; Schema: core; Owner: core
--

SELECT pg_catalog.setval('"Parameter_id_seq"', 2, true);


--
-- Data for Name: Personnel; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Personnel" (id, name_last, name_first, user_level, days_to_log, apb_type_id, apb_zone_id, apb_violations, created, created_by, updated, updated_by, deleted, deleted_by) FROM stdin;
\.


--
-- Data for Name: Reader; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Reader" (id, name, is_zone, is_muster_zone) FROM stdin;
\.


--
-- Data for Name: ReadersToAccessEntries; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "ReadersToAccessEntries" (reader_id, access_entry_id) FROM stdin;
\.


--
-- Data for Name: RfidTag; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "RfidTag" (token_id, tag_number) FROM stdin;
\.


--
-- Data for Name: ScheduledEvent; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "ScheduledEvent" (id, start, stop, event_id, active) FROM stdin;
\.


--
-- Data for Name: SystemInformation; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "SystemInformation" (id, created, computer_id, computer_name) FROM stdin;
8a4214af-6b50-4538-bf4f-6a1886c45d98	2018-03-04 21:09:35.583466-06	21041	OSSI-DNOVAK
6918d2bd-0be4-41bc-8a85-80844875385f	2018-03-05 08:21:41.615748-06	4	DLarrabee
\.


--
-- Data for Name: SystemInformationItem; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "SystemInformationItem" (sysinfo_id, item_id, "group", name, value, kind, key, description) FROM stdin;
6918d2bd-0be4-41bc-8a85-80844875385f	0	Computer System	Name	DLARRABEE	CIM:String	WMI:CIM_ManagedSystemElement.Name	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1	Computer System	DNSHostName	DLarrabee	CIM:String	WMI:Win32_ComputerSystem.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	2	Computer System	Domain	intelli-site.com	CIM:String	WMI:Win32_ComputerSystem.Domain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	3	Computer System	DomainRole	Member Workstation	string(CIM:UInt16)	WMI:Win32_ComputerSystem.DomainRole	\N
6918d2bd-0be4-41bc-8a85-80844875385f	4	Computer System	PartOfDomain	True	CIM:Boolean	WMI:Win32_ComputerSystem.PartOfDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	5	Computer System	Workgroup	\N	CIM:String	WMI:Win32_ComputerSystem.Workgroup	\N
6918d2bd-0be4-41bc-8a85-80844875385f	6	Computer System	PCSystemType	Mobile	string(CIM:UInt16)	WMI:Win32_ComputerSystem.PCSystemType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	7	Computer System	SystemType	x64-based PC	CIM:String	WMI:Win32_ComputerSystem.SystemType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	8	Computer System	Manufacturer	Hewlett-Packard	CIM:String	WMI:Win32_ComputerSystem.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	9	Computer System	Model	HP ProBook 4530s	CIM:String	WMI:Win32_ComputerSystem.Model	\N
6918d2bd-0be4-41bc-8a85-80844875385f	10	Computer System	NumberOfProcessors	1	CIM:UInt32	WMI:Win32_ComputerSystem.NumberOfProcessors	\N
6918d2bd-0be4-41bc-8a85-80844875385f	11	Computer System	NumberOfLogicalProcessors	4	CIM:UInt32	WMI:Win32_ComputerSystem.NumberOfLogicalProcessors	\N
6918d2bd-0be4-41bc-8a85-80844875385f	12	Computer System	TotalPhysicalMemory	8126 MB	toMegaBytes(CIM:UInt64)	WMI:Win32_ComputerSystem.TotalPhysicalMemory	\N
6918d2bd-0be4-41bc-8a85-80844875385f	13	Operating System	Computer System Name	DLARRABEE	CIM:String	WMI:CIM_OperatingSystem.CSName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	14	Operating System	Description	\N	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	15	Operating System	Caption	Microsoft Windows 7 Professional 	CIM:String	WMI:CIM_ManagedSystemElement.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	16	Operating System	OtherTypeDescription	\N	CIM:String	WMI:CIM_OperatingSystem.OtherTypeDescription	\N
6918d2bd-0be4-41bc-8a85-80844875385f	17	Operating System	OperatingSystemSKU	Unknown (48)	string(CIM:UInt32)	WMI:Win32_OperatingSystem.OperatingSystemSKU	\N
6918d2bd-0be4-41bc-8a85-80844875385f	18	Operating System	ProductType	Workstation	string(CIM:UInt32)	WMI:Win32_OperatingSystem.ProductType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	19	Operating System	OSArchitecture	64-bit	CIM:String	WMI:Win32_OperatingSystem.OSArchitecture	\N
6918d2bd-0be4-41bc-8a85-80844875385f	20	Operating System	OSLanguage	English – United States	string(CIM:UInt32)	WMI:Win32_OperatingSystem.OSLanguage	\N
6918d2bd-0be4-41bc-8a85-80844875385f	21	Operating System	CurrentTimeZone	-360	CIM:SInt16	WMI:CIM_OperatingSystem.CurrentTimeZone	\N
6918d2bd-0be4-41bc-8a85-80844875385f	22	Operating System	Version	6.1.7601	CIM:String	WMI:CIM_OperatingSystem.Version	\N
6918d2bd-0be4-41bc-8a85-80844875385f	23	Operating System	BuildNumber	7601	CIM:String	WMI:Win32_OperatingSystem.BuildNumber	\N
6918d2bd-0be4-41bc-8a85-80844875385f	24	Operating System	BuildType	Multiprocessor Free	CIM:String	WMI:Win32_OperatingSystem.BuildType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	25	Operating System	ServicePackMajorVersion	1	CIM:UInt16	WMI:Win32_OperatingSystem.ServicePackMajorVersion	\N
6918d2bd-0be4-41bc-8a85-80844875385f	26	Operating System	ServicePackMinorVersion	0	CIM:UInt16	WMI:Win32_OperatingSystem.ServicePackMinorVersion	\N
6918d2bd-0be4-41bc-8a85-80844875385f	27	Motherboard	Manufacturer	Hewlett-Packard	CIM:String	WMI:CIM_PhysicalElement.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	28	Motherboard	Model	\N	CIM:String	WMI:CIM_PhysicalElement.Model	\N
6918d2bd-0be4-41bc-8a85-80844875385f	29	Motherboard	Product	167C	CIM:String	WMI:Win32_BaseBoard.Product	\N
6918d2bd-0be4-41bc-8a85-80844875385f	30	Motherboard	Name	Base Board	CIM:String	WMI:CIM_ManagedSystemElement.Name	\N
6918d2bd-0be4-41bc-8a85-80844875385f	31	Motherboard	Description	Base Board	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	32	Motherboard	Version	KBC Version 22.1F	CIM:String	WMI:CIM_PhysicalElement.Version	\N
6918d2bd-0be4-41bc-8a85-80844875385f	33	System Firmware	Manufacturer	Hewlett-Packard	CIM:String	WMI:CIM_SoftwareElement.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	34	System Firmware	Description	Default System BIOS	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	35	System Firmware	ReleaseDate	20110718000000.000000+000	CIM:DateTime	WMI:Win32_BIOS.ReleaseDate	\N
6918d2bd-0be4-41bc-8a85-80844875385f	36	System Firmware	FirmwareType	BIOS	Enum:FirmwareType	Custom:GetFirmwareType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	37	System Firmware	BIOSVersion	HPQOEM - f	CIM:String	WMI:Win32_BIOS.BIOSVersion[0]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	38	System Firmware	SMBIOSBIOSVersion	68SRR Ver. F.0A	CIM:String	WMI:Win32_BIOS.SMBIOSBIOSVersion	\N
6918d2bd-0be4-41bc-8a85-80844875385f	39	System Firmware	SMBIOSMajorVersion	2	CIM:UInt16	WMI:Win32_BIOS.SMBIOSMajorVersion	\N
6918d2bd-0be4-41bc-8a85-80844875385f	40	System Firmware	SMBIOSMinorVersion	6	CIM:UInt16	WMI:Win32_BIOS.SMBIOSMinorVersion	\N
6918d2bd-0be4-41bc-8a85-80844875385f	41	System Firmware	BiosCharacteristics	[7] PCI is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[0]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	42	System Firmware	BiosCharacteristics	[8] PC Card (PCMCIA) is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[1]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	43	System Firmware	BiosCharacteristics	[11] BIOS is Upgradable (Flash)	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[2]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	44	System Firmware	BiosCharacteristics	[12] BIOS shadowing is allowed	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[3]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	45	System Firmware	BiosCharacteristics	[15] Boot from CD is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[4]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	46	System Firmware	BiosCharacteristics	[16] Selectable Boot is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[5]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	47	System Firmware	BiosCharacteristics	[19] EDD (Enhanced Disk Drive) Specification is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[6]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	48	System Firmware	BiosCharacteristics	[26] Int 5h, Print Screen Service is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[7]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	49	System Firmware	BiosCharacteristics	[27] Int 9h, 8042 Keyboard services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[8]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	50	System Firmware	BiosCharacteristics	[28] Int 14h, Serial Services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[9]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	51	System Firmware	BiosCharacteristics	[29] Int 17h, printer services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[10]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	52	System Firmware	BiosCharacteristics	[32] ACPI is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[11]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	53	System Firmware	BiosCharacteristics	[33] USB Legacy is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[12]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	54	System Firmware	BiosCharacteristics	[39] Smart Battery is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[13]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	55	System Firmware	BiosCharacteristics	[40] BIOS Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[14]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	56	System Firmware	BiosCharacteristics	[41] BIOS Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[15]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	57	System Firmware	BiosCharacteristics	[42] BIOS Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[16]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	58	System Firmware	BiosCharacteristics	[48] System Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[17]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	59	System Firmware	BiosCharacteristics	[49] System Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[18]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	60	System Firmware	BiosCharacteristics	[50] System Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[19]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	61	System Firmware	BiosCharacteristics	[51] System Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[20]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	62	System Firmware	BiosCharacteristics	[57] System Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[21]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	63	System Firmware	BiosCharacteristics	[59] System Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[22]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	64	System Firmware	BiosCharacteristics	[65] Unknown	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[23]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	65	System Firmware	BiosCharacteristics	[69] Unknown	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[24]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	66	System Firmware	BiosCharacteristics	[72] Unknown	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[25]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	67	System Firmware	BiosCharacteristics	[73] Unknown	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[26]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	68	System Firmware	BiosCharacteristics	[74] Unknown	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[27]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	69	System Firmware	BiosCharacteristics	[75] Unknown	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[28]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	70	System Firmware	BiosCharacteristics	[76] Unknown	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[29]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	71	Processor	Manufacturer	GenuineIntel	CIM:String	WMI:Win32_Processor.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	72	Processor	Name	Intel(R) Core(TM) i5-2410M CPU @ 2.30GHz	CIM:String	WMI:CIM_ManagedSystemElement.Name	\N
6918d2bd-0be4-41bc-8a85-80844875385f	73	Processor	Description	Intel64 Family 6 Model 42 Stepping 7	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	74	Processor	DeviceID	CPU0	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	75	Processor	Architecture	x64	string(CIM:UInt16)	WMI:Win32_Processor.Architecture	\N
6918d2bd-0be4-41bc-8a85-80844875385f	76	Processor	Family	Unknown (205)	string(CIM:UInt16)	WMI:CIM_Processor.Family	\N
6918d2bd-0be4-41bc-8a85-80844875385f	77	Processor	OtherFamilyDescription	\N	CIM:String	WMI:CIM_Processor.OtherFamilyDescription	\N
6918d2bd-0be4-41bc-8a85-80844875385f	78	Processor	Version	\N	CIM:String	WMI:Win32_Processor.Version	\N
6918d2bd-0be4-41bc-8a85-80844875385f	79	Processor	ProcessorId	BFEBFBFF000206A7	CIM:String	WMI:Win32_Processor.ProcessorId	\N
6918d2bd-0be4-41bc-8a85-80844875385f	80	Processor	NumberOfCores	2	CIM:UInt32	WMI:Win32_Processor.NumberOfCores	\N
6918d2bd-0be4-41bc-8a85-80844875385f	81	Processor	NumberOfLogicalProcessors	4	CIM:UInt32	WMI:Win32_Processor.NumberOfLogicalProcessors	\N
6918d2bd-0be4-41bc-8a85-80844875385f	82	Processor	AddressWidth	64	CIM:UInt16	WMI:CIM_Processor.AddressWidth	\N
6918d2bd-0be4-41bc-8a85-80844875385f	83	Processor	CurrentClockSpeed	2301	CIM:UInt32	WMI:CIM_Processor.CurrentClockSpeed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	84	Processor	MaxClockSpeed	2301	CIM:UInt32	WMI:CIM_Processor.MaxClockSpeed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	85	Memory [1/2]	Tag	Physical Memory 0	CIM:String	WMI:CIM_PhysicalElement.Tag	\N
6918d2bd-0be4-41bc-8a85-80844875385f	86	Memory [1/2]	Manufacturer	01BA	CIM:String	WMI:CIM_PhysicalElement.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	87	Memory [1/2]	Model	\N	CIM:String	WMI:CIM_PhysicalElement.Model	\N
6918d2bd-0be4-41bc-8a85-80844875385f	88	Memory [1/2]	PartNumber	64C0JKHNJ	CIM:String	WMI:CIM_PhysicalElement.PartNumber	\N
6918d2bd-0be4-41bc-8a85-80844875385f	89	Memory [1/2]	Description	Physical Memory	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	90	Memory [1/2]	Capacity	4096 MB	toMegaBytes(CIM:UInt64)	WMI:CIM_PhysicalMemory.Capacity	\N
6918d2bd-0be4-41bc-8a85-80844875385f	91	Memory [1/2]	Speed	1600	CIM:UInt32	WMI:CIM_PhysicalMemory.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	92	Memory [1/2]	DataWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.DataWidth	\N
6918d2bd-0be4-41bc-8a85-80844875385f	93	Memory [1/2]	TotalWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.TotalWidth	\N
6918d2bd-0be4-41bc-8a85-80844875385f	94	Memory [1/2]	BankLabel	BANK 0	CIM:String	WMI:CIM_PhysicalMemory.BankLabel	\N
6918d2bd-0be4-41bc-8a85-80844875385f	95	Memory [1/2]	TypeDetail	Synchronous	string(CIM:UInt16)	WMI:Win32_PhysicalMemory.TypeDetail	\N
6918d2bd-0be4-41bc-8a85-80844875385f	96	Memory [1/2]	MemoryType	Unknown	string(CIM:UInt16)	WMI:CIM_PhysicalMemory.MemoryType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	97	Memory [1/2]	FormFactor	SODIMM	string(CIM:UInt16)	WMI:CIM_Chip.FormFactor	\N
6918d2bd-0be4-41bc-8a85-80844875385f	98	Memory [1/2]	Status	\N	CIM:String	WMI:CIM_ManagedSystemElement.Status	\N
6918d2bd-0be4-41bc-8a85-80844875385f	99	Memory [1/2]	Version	\N	CIM:String	WMI:CIM_PhysicalElement.Version	\N
6918d2bd-0be4-41bc-8a85-80844875385f	100	Memory [2/2]	Tag	Physical Memory 1	CIM:String	WMI:CIM_PhysicalElement.Tag	\N
6918d2bd-0be4-41bc-8a85-80844875385f	101	Memory [2/2]	Manufacturer	01BA	CIM:String	WMI:CIM_PhysicalElement.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	102	Memory [2/2]	Model	\N	CIM:String	WMI:CIM_PhysicalElement.Model	\N
6918d2bd-0be4-41bc-8a85-80844875385f	103	Memory [2/2]	PartNumber	64C0JKHNJ	CIM:String	WMI:CIM_PhysicalElement.PartNumber	\N
6918d2bd-0be4-41bc-8a85-80844875385f	104	Memory [2/2]	Description	Physical Memory	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	105	Memory [2/2]	Capacity	4096 MB	toMegaBytes(CIM:UInt64)	WMI:CIM_PhysicalMemory.Capacity	\N
6918d2bd-0be4-41bc-8a85-80844875385f	106	Memory [2/2]	Speed	1600	CIM:UInt32	WMI:CIM_PhysicalMemory.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	107	Memory [2/2]	DataWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.DataWidth	\N
6918d2bd-0be4-41bc-8a85-80844875385f	108	Memory [2/2]	TotalWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.TotalWidth	\N
6918d2bd-0be4-41bc-8a85-80844875385f	109	Memory [2/2]	BankLabel	BANK 2	CIM:String	WMI:CIM_PhysicalMemory.BankLabel	\N
6918d2bd-0be4-41bc-8a85-80844875385f	110	Memory [2/2]	TypeDetail	Synchronous	string(CIM:UInt16)	WMI:Win32_PhysicalMemory.TypeDetail	\N
6918d2bd-0be4-41bc-8a85-80844875385f	111	Memory [2/2]	MemoryType	Unknown	string(CIM:UInt16)	WMI:CIM_PhysicalMemory.MemoryType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	11	Computer System	NumberOfLogicalProcessors	8	CIM:UInt32	WMI:Win32_ComputerSystem.NumberOfLogicalProcessors	\N
6918d2bd-0be4-41bc-8a85-80844875385f	112	Memory [2/2]	FormFactor	SODIMM	string(CIM:UInt16)	WMI:CIM_Chip.FormFactor	\N
6918d2bd-0be4-41bc-8a85-80844875385f	113	Memory [2/2]	Status	\N	CIM:String	WMI:CIM_ManagedSystemElement.Status	\N
6918d2bd-0be4-41bc-8a85-80844875385f	114	Memory [2/2]	Version	\N	CIM:String	WMI:CIM_PhysicalElement.Version	\N
6918d2bd-0be4-41bc-8a85-80844875385f	115	Network Adapter [1/18]	Description	WAN Miniport (SSTP)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	116	Network Adapter [1/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	117	Network Adapter [1/18]	ProductName	WAN Miniport (SSTP)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	118	Network Adapter [1/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	119	Network Adapter [1/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	120	Network Adapter [1/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	121	Network Adapter [1/18]	InterfaceIndex	2	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	122	Network Adapter [1/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	123	Network Adapter [1/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	124	Network Adapter [1/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	125	Network Adapter [1/18]	PNPDeviceID	ROOT\\MS_SSTPMINIPORT\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	126	Network Adapter [1/18]	DeviceID	0	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	127	Network Adapter [1/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	128	Network Adapter [2/18]	Description	WAN Miniport (IKEv2)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	129	Network Adapter [2/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	130	Network Adapter [2/18]	ProductName	WAN Miniport (IKEv2)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	131	Network Adapter [2/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	132	Network Adapter [2/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	133	Network Adapter [2/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	134	Network Adapter [2/18]	InterfaceIndex	16	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	135	Network Adapter [2/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	136	Network Adapter [2/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	137	Network Adapter [2/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	138	Network Adapter [2/18]	PNPDeviceID	ROOT\\MS_AGILEVPNMINIPORT\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	139	Network Adapter [2/18]	DeviceID	1	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	140	Network Adapter [2/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	141	Network Adapter [3/18]	Description	WAN Miniport (L2TP)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	142	Network Adapter [3/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	143	Network Adapter [3/18]	ProductName	WAN Miniport (L2TP)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	144	Network Adapter [3/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	145	Network Adapter [3/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	146	Network Adapter [3/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	147	Network Adapter [3/18]	InterfaceIndex	3	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	148	Network Adapter [3/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	149	Network Adapter [3/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	150	Network Adapter [3/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	151	Network Adapter [3/18]	PNPDeviceID	ROOT\\MS_L2TPMINIPORT\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	152	Network Adapter [3/18]	DeviceID	2	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	153	Network Adapter [3/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	154	Network Adapter [4/18]	Description	WAN Miniport (PPTP)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	155	Network Adapter [4/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	156	Network Adapter [4/18]	ProductName	WAN Miniport (PPTP)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	157	Network Adapter [4/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	158	Network Adapter [4/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	159	Network Adapter [4/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	160	Network Adapter [4/18]	InterfaceIndex	4	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	161	Network Adapter [4/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	162	Network Adapter [4/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	163	Network Adapter [4/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	164	Network Adapter [4/18]	PNPDeviceID	ROOT\\MS_PPTPMINIPORT\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	165	Network Adapter [4/18]	DeviceID	3	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	166	Network Adapter [4/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	167	Network Adapter [5/18]	Description	WAN Miniport (PPPOE)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	168	Network Adapter [5/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	169	Network Adapter [5/18]	ProductName	WAN Miniport (PPPOE)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	170	Network Adapter [5/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	171	Network Adapter [5/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	172	Network Adapter [5/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	173	Network Adapter [5/18]	InterfaceIndex	5	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	174	Network Adapter [5/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	175	Network Adapter [5/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	176	Network Adapter [5/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	177	Network Adapter [5/18]	PNPDeviceID	ROOT\\MS_PPPOEMINIPORT\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	178	Network Adapter [5/18]	DeviceID	4	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	179	Network Adapter [5/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	180	Network Adapter [6/18]	Description	WAN Miniport (IPv6)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	181	Network Adapter [6/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	182	Network Adapter [6/18]	ProductName	WAN Miniport (IPv6)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	183	Network Adapter [6/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	184	Network Adapter [6/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	185	Network Adapter [6/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	186	Network Adapter [6/18]	InterfaceIndex	6	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	187	Network Adapter [6/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	188	Network Adapter [6/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	189	Network Adapter [6/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	190	Network Adapter [6/18]	PNPDeviceID	ROOT\\MS_NDISWANIPV6\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	191	Network Adapter [6/18]	DeviceID	5	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	192	Network Adapter [6/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	193	Network Adapter [7/18]	Description	WAN Miniport (Network Monitor)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	194	Network Adapter [7/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	195	Network Adapter [7/18]	ProductName	WAN Miniport (Network Monitor)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	196	Network Adapter [7/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	197	Network Adapter [7/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	198	Network Adapter [7/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	199	Network Adapter [7/18]	InterfaceIndex	7	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	200	Network Adapter [7/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	201	Network Adapter [7/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	202	Network Adapter [7/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	203	Network Adapter [7/18]	PNPDeviceID	ROOT\\MS_NDISWANBH\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	204	Network Adapter [7/18]	DeviceID	6	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	205	Network Adapter [7/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	206	Network Adapter [8/18]	Description	Realtek PCIe GBE Family Controller	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	207	Network Adapter [8/18]	Manufacturer	Realtek	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	208	Network Adapter [8/18]	ProductName	Realtek PCIe GBE Family Controller	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	209	Network Adapter [8/18]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	210	Network Adapter [8/18]	MACAddress	10:1F:74:FC:FC:C0	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	211	Network Adapter [8/18]	GUID	{AE39AC40-EA12-4AA3-B826-96CB0088AC41}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	212	Network Adapter [8/18]	InterfaceIndex	10	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	213	Network Adapter [8/18]	NetConnectionStatus	2	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	214	Network Adapter [8/18]	Speed	100.00 Mbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	215	Network Adapter [8/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	216	Network Adapter [8/18]	PNPDeviceID	PCI\\VEN_10EC&DEV_8168&SUBSYS_167C103C&REV_06\\01000000684CE00000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	217	Network Adapter [8/18]	DeviceID	7	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	218	Network Adapter [8/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	219	Network Adapter [9/18]	Description	WAN Miniport (IP)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	220	Network Adapter [9/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	221	Network Adapter [9/18]	ProductName	WAN Miniport (IP)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	222	Network Adapter [9/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	223	Network Adapter [9/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	224	Network Adapter [9/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	225	Network Adapter [9/18]	InterfaceIndex	8	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	226	Network Adapter [9/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	227	Network Adapter [9/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	228	Network Adapter [9/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	229	Network Adapter [9/18]	PNPDeviceID	ROOT\\MS_NDISWANIP\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	230	Network Adapter [9/18]	DeviceID	8	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	231	Network Adapter [9/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	232	Network Adapter [10/18]	Description	Microsoft ISATAP Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	233	Network Adapter [10/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	234	Network Adapter [10/18]	ProductName	Microsoft ISATAP Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	235	Network Adapter [10/18]	AdapterType	Tunnel	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	236	Network Adapter [10/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	237	Network Adapter [10/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	238	Network Adapter [10/18]	InterfaceIndex	19	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	239	Network Adapter [10/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	240	Network Adapter [10/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	241	Network Adapter [10/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	242	Network Adapter [10/18]	PNPDeviceID	ROOT\\*ISATAP\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	243	Network Adapter [10/18]	DeviceID	9	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	244	Network Adapter [10/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	245	Network Adapter [11/18]	Description	RAS Async Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	246	Network Adapter [11/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	247	Network Adapter [11/18]	ProductName	RAS Async Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	248	Network Adapter [11/18]	AdapterType	Wide Area Network (WAN)	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	249	Network Adapter [11/18]	MACAddress	20:41:53:59:4E:FF	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	250	Network Adapter [11/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	251	Network Adapter [11/18]	InterfaceIndex	9	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	252	Network Adapter [11/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	253	Network Adapter [11/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	254	Network Adapter [11/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	255	Network Adapter [11/18]	PNPDeviceID	SW\\{EEAB7790-C514-11D1-B42B-00805FC1270E}\\ASYNCMAC	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	256	Network Adapter [11/18]	DeviceID	10	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	257	Network Adapter [11/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	258	Network Adapter [12/18]	Description	Bluetooth Device (Personal Area Network)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	259	Network Adapter [12/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	260	Network Adapter [12/18]	ProductName	Bluetooth Device (Personal Area Network)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	261	Network Adapter [12/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	262	Network Adapter [12/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	263	Network Adapter [12/18]	GUID	{852551B7-5097-4EE8-918A-BFAFD20B8BCD}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	264	Network Adapter [12/18]	InterfaceIndex	11	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	265	Network Adapter [12/18]	NetConnectionStatus	0	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	266	Network Adapter [12/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	267	Network Adapter [12/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	268	Network Adapter [12/18]	PNPDeviceID	BTH\\MS_BTHPAN\\7&5DBC8DB&0&2	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	269	Network Adapter [12/18]	DeviceID	11	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	270	Network Adapter [12/18]	ConfigManagerErrorCode	22	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	271	Network Adapter [13/18]	Description	Qualcomm Atheros AR9285 802.11b/g/n WiFi Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	272	Network Adapter [13/18]	Manufacturer	Qualcomm Atheros Communications Inc.	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	273	Network Adapter [13/18]	ProductName	Qualcomm Atheros AR9285 802.11b/g/n WiFi Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	274	Network Adapter [13/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	275	Network Adapter [13/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	276	Network Adapter [13/18]	GUID	{EF14CEA5-E1C2-40BB-A2D9-A65FF6B8142E}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	277	Network Adapter [13/18]	InterfaceIndex	13	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	278	Network Adapter [13/18]	NetConnectionStatus	0	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	279	Network Adapter [13/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	280	Network Adapter [13/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	281	Network Adapter [13/18]	PNPDeviceID	PCI\\VEN_168C&DEV_002B&SUBSYS_1461103C&REV_01\\001517FFFF24141200	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	282	Network Adapter [13/18]	DeviceID	13	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	283	Network Adapter [13/18]	ConfigManagerErrorCode	22	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	284	Network Adapter [14/18]	Description	Microsoft ISATAP Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	285	Network Adapter [14/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	286	Network Adapter [14/18]	ProductName	Microsoft ISATAP Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	287	Network Adapter [14/18]	AdapterType	Tunnel	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	288	Network Adapter [14/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	289	Network Adapter [14/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	290	Network Adapter [14/18]	InterfaceIndex	20	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	291	Network Adapter [14/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	292	Network Adapter [14/18]	Speed	100.00 Kbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	293	Network Adapter [14/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	294	Network Adapter [14/18]	PNPDeviceID	ROOT\\*ISATAP\\0001	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	295	Network Adapter [14/18]	DeviceID	14	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	296	Network Adapter [14/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	297	Network Adapter [15/18]	Description	Microsoft Teredo Tunneling Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	298	Network Adapter [15/18]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	299	Network Adapter [15/18]	ProductName	Microsoft Teredo Tunneling Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	300	Network Adapter [15/18]	AdapterType	Tunnel	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	301	Network Adapter [15/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	302	Network Adapter [15/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	303	Network Adapter [15/18]	InterfaceIndex	14	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	304	Network Adapter [15/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	305	Network Adapter [15/18]	Speed	100.00 Kbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	306	Network Adapter [15/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	307	Network Adapter [15/18]	PNPDeviceID	ROOT\\*TEREDO\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	308	Network Adapter [15/18]	DeviceID	16	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	309	Network Adapter [15/18]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	310	Network Adapter [16/18]	Description	Microsoft Virtual WiFi Miniport Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	311	Network Adapter [16/18]	Manufacturer	\N	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	312	Network Adapter [16/18]	ProductName	Microsoft Virtual WiFi Miniport Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	313	Network Adapter [16/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	314	Network Adapter [16/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	315	Network Adapter [16/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	316	Network Adapter [16/18]	InterfaceIndex	15	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	317	Network Adapter [16/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	318	Network Adapter [16/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	319	Network Adapter [16/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	320	Network Adapter [16/18]	PNPDeviceID	\N	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	321	Network Adapter [16/18]	DeviceID	17	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	322	Network Adapter [16/18]	ConfigManagerErrorCode	\N	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	323	Network Adapter [17/18]	Description	Cisco AnyConnect Secure Mobility Client Virtual Miniport Adapter for Windows x64	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	324	Network Adapter [17/18]	Manufacturer	Cisco Systems	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	325	Network Adapter [17/18]	ProductName	Cisco AnyConnect Secure Mobility Client Virtual Miniport Adapter for Windows x64	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	326	Network Adapter [17/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	327	Network Adapter [17/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	328	Network Adapter [17/18]	GUID	{FF0F4A5C-5AB8-4A90-B3CE-12F0BF30AA03}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	329	Network Adapter [17/18]	InterfaceIndex	18	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	330	Network Adapter [17/18]	NetConnectionStatus	0	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	331	Network Adapter [17/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	332	Network Adapter [17/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	333	Network Adapter [17/18]	PNPDeviceID	ROOT\\NET\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	334	Network Adapter [17/18]	DeviceID	18	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	335	Network Adapter [17/18]	ConfigManagerErrorCode	22	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	336	Network Adapter [18/18]	Description	BlackBerry Device	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	337	Network Adapter [18/18]	Manufacturer	\N	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	338	Network Adapter [18/18]	ProductName	BlackBerry Device	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	339	Network Adapter [18/18]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	340	Network Adapter [18/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	341	Network Adapter [18/18]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	342	Network Adapter [18/18]	InterfaceIndex	17	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	343	Network Adapter [18/18]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
6918d2bd-0be4-41bc-8a85-80844875385f	344	Network Adapter [18/18]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
6918d2bd-0be4-41bc-8a85-80844875385f	345	Network Adapter [18/18]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	346	Network Adapter [18/18]	PNPDeviceID	\N	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	347	Network Adapter [18/18]	DeviceID	22	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	348	Network Adapter [18/18]	ConfigManagerErrorCode	\N	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	349	Network Adapter Configuration [1/18]	Caption	[00000000] WAN Miniport (SSTP)	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	350	Network Adapter Configuration [1/18]	InterfaceIndex	2	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	351	Network Adapter Configuration [1/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	352	Network Adapter Configuration [1/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	353	Network Adapter Configuration [1/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	354	Network Adapter Configuration [1/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	355	Network Adapter Configuration [1/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
6918d2bd-0be4-41bc-8a85-80844875385f	356	Network Adapter Configuration [1/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	357	Network Adapter Configuration [1/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	358	Network Adapter Configuration [1/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	359	Network Adapter Configuration [1/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	360	Network Adapter Configuration [1/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	361	Network Adapter Configuration [1/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	362	Network Adapter Configuration [2/18]	Caption	[00000001] WAN Miniport (IKEv2)	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	363	Network Adapter Configuration [2/18]	InterfaceIndex	16	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	364	Network Adapter Configuration [2/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	365	Network Adapter Configuration [2/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	366	Network Adapter Configuration [2/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	367	Network Adapter Configuration [2/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	368	Network Adapter Configuration [2/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
6918d2bd-0be4-41bc-8a85-80844875385f	369	Network Adapter Configuration [2/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	370	Network Adapter Configuration [2/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	371	Network Adapter Configuration [2/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	372	Network Adapter Configuration [2/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	373	Network Adapter Configuration [2/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	374	Network Adapter Configuration [2/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	375	Network Adapter Configuration [3/18]	Caption	[00000002] WAN Miniport (L2TP)	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	376	Network Adapter Configuration [3/18]	InterfaceIndex	3	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	377	Network Adapter Configuration [3/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	378	Network Adapter Configuration [3/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	379	Network Adapter Configuration [3/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	380	Network Adapter Configuration [3/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	381	Network Adapter Configuration [3/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
6918d2bd-0be4-41bc-8a85-80844875385f	382	Network Adapter Configuration [3/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	383	Network Adapter Configuration [3/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	384	Network Adapter Configuration [3/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	385	Network Adapter Configuration [3/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	386	Network Adapter Configuration [3/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	387	Network Adapter Configuration [3/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	388	Network Adapter Configuration [4/18]	Caption	[00000003] WAN Miniport (PPTP)	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	389	Network Adapter Configuration [4/18]	InterfaceIndex	4	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	390	Network Adapter Configuration [4/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	391	Network Adapter Configuration [4/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	392	Network Adapter Configuration [4/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	393	Network Adapter Configuration [4/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	394	Network Adapter Configuration [4/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
6918d2bd-0be4-41bc-8a85-80844875385f	395	Network Adapter Configuration [4/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	396	Network Adapter Configuration [4/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	397	Network Adapter Configuration [4/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	398	Network Adapter Configuration [4/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	399	Network Adapter Configuration [4/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	400	Network Adapter Configuration [4/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	401	Network Adapter Configuration [5/18]	Caption	[00000004] WAN Miniport (PPPOE)	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	402	Network Adapter Configuration [5/18]	InterfaceIndex	5	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	403	Network Adapter Configuration [5/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	404	Network Adapter Configuration [5/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	405	Network Adapter Configuration [5/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	406	Network Adapter Configuration [5/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	407	Network Adapter Configuration [5/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
6918d2bd-0be4-41bc-8a85-80844875385f	408	Network Adapter Configuration [5/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	409	Network Adapter Configuration [5/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	410	Network Adapter Configuration [5/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	411	Network Adapter Configuration [5/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	412	Network Adapter Configuration [5/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	413	Network Adapter Configuration [5/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	414	Network Adapter Configuration [6/18]	Caption	[00000005] WAN Miniport (IPv6)	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	415	Network Adapter Configuration [6/18]	InterfaceIndex	6	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	416	Network Adapter Configuration [6/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	417	Network Adapter Configuration [6/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	418	Network Adapter Configuration [6/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	419	Network Adapter Configuration [6/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	420	Network Adapter Configuration [6/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
6918d2bd-0be4-41bc-8a85-80844875385f	421	Network Adapter Configuration [6/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	422	Network Adapter Configuration [6/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	423	Network Adapter Configuration [6/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	424	Network Adapter Configuration [6/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	425	Network Adapter Configuration [6/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	426	Network Adapter Configuration [6/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	427	Network Adapter Configuration [7/18]	Caption	[00000006] WAN Miniport (Network Monitor)	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	428	Network Adapter Configuration [7/18]	InterfaceIndex	7	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	429	Network Adapter Configuration [7/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	430	Network Adapter Configuration [7/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	431	Network Adapter Configuration [7/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	432	Network Adapter Configuration [7/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	433	Network Adapter Configuration [7/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
6918d2bd-0be4-41bc-8a85-80844875385f	434	Network Adapter Configuration [7/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	435	Network Adapter Configuration [7/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	436	Network Adapter Configuration [7/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	437	Network Adapter Configuration [7/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	438	Network Adapter Configuration [7/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	439	Network Adapter Configuration [7/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	440	Network Adapter Configuration [8/18]	Caption	[00000007] Realtek PCIe GBE Family Controller	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	441	Network Adapter Configuration [8/18]	InterfaceIndex	10	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	442	Network Adapter Configuration [8/18]	MACAddress	10:1F:74:FC:FC:C0	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	443	Network Adapter Configuration [8/18]	IPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	444	Network Adapter Configuration [8/18]	IPAddress	192.168.20.135	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[0]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	445	Network Adapter Configuration [8/18]	IPSubnet	255.255.255.0	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[0]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	446	Network Adapter Configuration [8/18]	DefaultIPGateway	192.168.20.254	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway[0]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	447	Network Adapter Configuration [8/18]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	448	Network Adapter Configuration [8/18]	DHCPServer	192.168.20.5	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	449	Network Adapter Configuration [8/18]	DNSHostName	DLarrabee	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	450	Network Adapter Configuration [8/18]	DNSDomain	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	451	Network Adapter Configuration [8/18]	DNSDomainSuffixSearchOrder	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder[0]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	452	Network Adapter Configuration [8/18]	DNSServerSearchOrder	192.168.20.5	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder[0]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	453	Network Adapter Configuration [8/18]	DNSServerSearchOrder	192.168.12.4	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder[1]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	454	Network Adapter Configuration [9/18]	Caption	[00000008] WAN Miniport (IP)	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	455	Network Adapter Configuration [9/18]	InterfaceIndex	8	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	456	Network Adapter Configuration [9/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	457	Network Adapter Configuration [9/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	458	Network Adapter Configuration [9/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	459	Network Adapter Configuration [9/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	460	Network Adapter Configuration [9/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
6918d2bd-0be4-41bc-8a85-80844875385f	461	Network Adapter Configuration [9/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	462	Network Adapter Configuration [9/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	463	Network Adapter Configuration [9/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	464	Network Adapter Configuration [9/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	465	Network Adapter Configuration [9/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	466	Network Adapter Configuration [9/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	467	Network Adapter Configuration [10/18]	Caption	[00000009] Microsoft ISATAP Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	468	Network Adapter Configuration [10/18]	InterfaceIndex	19	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	469	Network Adapter Configuration [10/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	470	Network Adapter Configuration [10/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	471	Network Adapter Configuration [10/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	472	Network Adapter Configuration [10/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	473	Network Adapter Configuration [10/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
6918d2bd-0be4-41bc-8a85-80844875385f	474	Network Adapter Configuration [10/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	475	Network Adapter Configuration [10/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	476	Network Adapter Configuration [10/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	477	Network Adapter Configuration [10/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	478	Network Adapter Configuration [10/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	479	Network Adapter Configuration [10/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	480	Network Adapter Configuration [11/18]	Caption	[00000010] RAS Async Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	481	Network Adapter Configuration [11/18]	InterfaceIndex	9	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	482	Network Adapter Configuration [11/18]	MACAddress	20:41:53:59:4E:FF	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	483	Network Adapter Configuration [11/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	484	Network Adapter Configuration [11/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	485	Network Adapter Configuration [11/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	486	Network Adapter Configuration [11/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
6918d2bd-0be4-41bc-8a85-80844875385f	487	Network Adapter Configuration [11/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	488	Network Adapter Configuration [11/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	489	Network Adapter Configuration [11/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	490	Network Adapter Configuration [11/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	491	Network Adapter Configuration [11/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	492	Network Adapter Configuration [11/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	493	Network Adapter Configuration [12/18]	Caption	[00000011] Bluetooth Device (Personal Area Network)	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	494	Network Adapter Configuration [12/18]	InterfaceIndex	11	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	495	Network Adapter Configuration [12/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	496	Network Adapter Configuration [12/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	497	Network Adapter Configuration [12/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	498	Network Adapter Configuration [12/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	499	Network Adapter Configuration [12/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
6918d2bd-0be4-41bc-8a85-80844875385f	500	Network Adapter Configuration [12/18]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	501	Network Adapter Configuration [12/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	502	Network Adapter Configuration [12/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	503	Network Adapter Configuration [12/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	504	Network Adapter Configuration [12/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	505	Network Adapter Configuration [12/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	506	Network Adapter Configuration [13/18]	Caption	[00000013] Qualcomm Atheros AR9285 802.11b/g/n WiFi Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	507	Network Adapter Configuration [13/18]	InterfaceIndex	13	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	508	Network Adapter Configuration [13/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	509	Network Adapter Configuration [13/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	510	Network Adapter Configuration [13/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	511	Network Adapter Configuration [13/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	512	Network Adapter Configuration [13/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
6918d2bd-0be4-41bc-8a85-80844875385f	513	Network Adapter Configuration [13/18]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	514	Network Adapter Configuration [13/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	515	Network Adapter Configuration [13/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	516	Network Adapter Configuration [13/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	517	Network Adapter Configuration [13/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	518	Network Adapter Configuration [13/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	519	Network Adapter Configuration [14/18]	Caption	[00000014] Microsoft ISATAP Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	520	Network Adapter Configuration [14/18]	InterfaceIndex	20	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	521	Network Adapter Configuration [14/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	12	Computer System	TotalPhysicalMemory	32659 MB	toMegaBytes(CIM:UInt64)	WMI:Win32_ComputerSystem.TotalPhysicalMemory	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	13	Operating System	Computer System Name	OSSI-DNOVAK	CIM:String	WMI:CIM_OperatingSystem.CSName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	14	Operating System	Description	OSSI-DNovak	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	15	Operating System	Caption	Microsoft Windows 10 Pro	CIM:String	WMI:CIM_ManagedSystemElement.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	16	Operating System	OtherTypeDescription	\N	CIM:String	WMI:CIM_OperatingSystem.OtherTypeDescription	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	17	Operating System	OperatingSystemSKU	Unknown (48)	string(CIM:UInt32)	WMI:Win32_OperatingSystem.OperatingSystemSKU	\N
6918d2bd-0be4-41bc-8a85-80844875385f	522	Network Adapter Configuration [14/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	523	Network Adapter Configuration [14/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	524	Network Adapter Configuration [14/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	525	Network Adapter Configuration [14/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
6918d2bd-0be4-41bc-8a85-80844875385f	526	Network Adapter Configuration [14/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	527	Network Adapter Configuration [14/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	528	Network Adapter Configuration [14/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	529	Network Adapter Configuration [14/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	530	Network Adapter Configuration [14/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	531	Network Adapter Configuration [14/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	532	Network Adapter Configuration [15/18]	Caption	[00000016] Microsoft Teredo Tunneling Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	533	Network Adapter Configuration [15/18]	InterfaceIndex	14	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	534	Network Adapter Configuration [15/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	535	Network Adapter Configuration [15/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	536	Network Adapter Configuration [15/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	537	Network Adapter Configuration [15/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	538	Network Adapter Configuration [15/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
6918d2bd-0be4-41bc-8a85-80844875385f	539	Network Adapter Configuration [15/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	540	Network Adapter Configuration [15/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	541	Network Adapter Configuration [15/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	542	Network Adapter Configuration [15/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	543	Network Adapter Configuration [15/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	544	Network Adapter Configuration [15/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	545	Network Adapter Configuration [16/18]	Caption	[00000017] Microsoft Virtual WiFi Miniport Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	546	Network Adapter Configuration [16/18]	InterfaceIndex	15	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	547	Network Adapter Configuration [16/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	548	Network Adapter Configuration [16/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	549	Network Adapter Configuration [16/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	550	Network Adapter Configuration [16/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	551	Network Adapter Configuration [16/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
6918d2bd-0be4-41bc-8a85-80844875385f	552	Network Adapter Configuration [16/18]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	553	Network Adapter Configuration [16/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	554	Network Adapter Configuration [16/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	555	Network Adapter Configuration [16/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	556	Network Adapter Configuration [16/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	557	Network Adapter Configuration [16/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	558	Network Adapter Configuration [17/18]	Caption	[00000018] Cisco AnyConnect Secure Mobility Client Virtual Miniport Adapter for Windows x64	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	559	Network Adapter Configuration [17/18]	InterfaceIndex	18	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	560	Network Adapter Configuration [17/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	561	Network Adapter Configuration [17/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	18	Operating System	ProductType	Workstation	string(CIM:UInt32)	WMI:Win32_OperatingSystem.ProductType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	19	Operating System	OSArchitecture	64-bit	CIM:String	WMI:Win32_OperatingSystem.OSArchitecture	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	20	Operating System	OSLanguage	English – United States	string(CIM:UInt32)	WMI:Win32_OperatingSystem.OSLanguage	\N
6918d2bd-0be4-41bc-8a85-80844875385f	562	Network Adapter Configuration [17/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	563	Network Adapter Configuration [17/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	564	Network Adapter Configuration [17/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	21	Operating System	CurrentTimeZone	-360	CIM:SInt16	WMI:CIM_OperatingSystem.CurrentTimeZone	\N
6918d2bd-0be4-41bc-8a85-80844875385f	565	Network Adapter Configuration [17/18]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	566	Network Adapter Configuration [17/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	567	Network Adapter Configuration [17/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	568	Network Adapter Configuration [17/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	569	Network Adapter Configuration [17/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	570	Network Adapter Configuration [17/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	571	Network Adapter Configuration [18/18]	Caption	[00000022] BlackBerry Device	CIM:String	WMI:CIM_Setting.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	572	Network Adapter Configuration [18/18]	InterfaceIndex	17	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	573	Network Adapter Configuration [18/18]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	574	Network Adapter Configuration [18/18]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	575	Network Adapter Configuration [18/18]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
6918d2bd-0be4-41bc-8a85-80844875385f	576	Network Adapter Configuration [18/18]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
6918d2bd-0be4-41bc-8a85-80844875385f	577	Network Adapter Configuration [18/18]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
6918d2bd-0be4-41bc-8a85-80844875385f	578	Network Adapter Configuration [18/18]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
6918d2bd-0be4-41bc-8a85-80844875385f	579	Network Adapter Configuration [18/18]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	580	Network Adapter Configuration [18/18]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	581	Network Adapter Configuration [18/18]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	582	Network Adapter Configuration [18/18]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	583	Network Adapter Configuration [18/18]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
6918d2bd-0be4-41bc-8a85-80844875385f	584	Video Adapter [1/2]	Description	AMD Radeon HD 7470M	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	585	Video Adapter [1/2]	AdapterRAM	1024 MB	toMegaBytes(CIM:UInt32)	WMI:Win32_VideoController.AdapterRAM	\N
6918d2bd-0be4-41bc-8a85-80844875385f	586	Video Adapter [1/2]	VideoMemoryType	2	CIM:UInt16	WMI:CIM_VideoController.VideoMemoryType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	587	Video Adapter [1/2]	VideoModeDescription	1920 x 1080 x 4294967296 colors	CIM:String	WMI:Win32_VideoController.VideoModeDescription	\N
6918d2bd-0be4-41bc-8a85-80844875385f	588	Video Adapter [1/2]	VideoProcessor	ATI display adapter (0x6760)	CIM:String	WMI:CIM_VideoController.VideoProcessor	\N
6918d2bd-0be4-41bc-8a85-80844875385f	589	Video Adapter [1/2]	CurrentBitsPerPixel	32	CIM:UInt32	WMI:CIM_VideoController.CurrentBitsPerPixel	\N
6918d2bd-0be4-41bc-8a85-80844875385f	590	Video Adapter [1/2]	CurrentHorizontalResolution	1920	CIM:UInt32	WMI:CIM_VideoController.CurrentHorizontalResolution	\N
6918d2bd-0be4-41bc-8a85-80844875385f	591	Video Adapter [1/2]	CurrentVerticalResolution	1080	CIM:UInt32	WMI:CIM_VideoController.CurrentVerticalResolution	\N
6918d2bd-0be4-41bc-8a85-80844875385f	592	Video Adapter [1/2]	CurrentRefreshRate	59	CIM:UInt32	WMI:CIM_VideoController.CurrentRefreshRate	\N
6918d2bd-0be4-41bc-8a85-80844875385f	593	Video Adapter [1/2]	InstalledDisplayDrivers	aticfx64.dll,aticfx64.dll,aticfx64.dll,aticfx32,aticfx32,aticfx32,atiumd64.dll,atidxx64.dll,atidxx64.dll,atiumdag,atidxx32,atidxx32,atiumdva,atiumd6a.cap,atitmm64.dll	CIM:String	WMI:Win32_VideoController.InstalledDisplayDrivers	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	22	Operating System	Version	10.0.16299	CIM:String	WMI:CIM_OperatingSystem.Version	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	23	Operating System	BuildNumber	16299	CIM:String	WMI:Win32_OperatingSystem.BuildNumber	\N
6918d2bd-0be4-41bc-8a85-80844875385f	594	Video Adapter [1/2]	DriverVersion	8.910.0.0	CIM:String	WMI:Win32_VideoController.DriverVersion	\N
6918d2bd-0be4-41bc-8a85-80844875385f	595	Video Adapter [1/2]	DriverDate	20111013000000.000000-000	CIM:DateTime	WMI:Win32_VideoController.DriverDate	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	24	Operating System	BuildType	Multiprocessor Free	CIM:String	WMI:Win32_OperatingSystem.BuildType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	596	Video Adapter [1/2]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	597	Video Adapter [1/2]	PNPDeviceID	PCI\\VEN_1002&DEV_6760&SUBSYS_167D103C&REV_00\\4&2679E7DC&0&0008	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	598	Video Adapter [1/2]	DeviceID	VideoController1	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	599	Video Adapter [1/2]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	600	Video Adapter [2/2]	Description	Intel(R) HD Graphics Family	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	601	Video Adapter [2/2]	AdapterRAM	3839 MB	toMegaBytes(CIM:UInt32)	WMI:Win32_VideoController.AdapterRAM	\N
6918d2bd-0be4-41bc-8a85-80844875385f	602	Video Adapter [2/2]	VideoMemoryType	2	CIM:UInt16	WMI:CIM_VideoController.VideoMemoryType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	603	Video Adapter [2/2]	VideoModeDescription	1920 x 1080 x 4294967296 colors	CIM:String	WMI:Win32_VideoController.VideoModeDescription	\N
6918d2bd-0be4-41bc-8a85-80844875385f	604	Video Adapter [2/2]	VideoProcessor	Intel(R) HD Graphics Family	CIM:String	WMI:CIM_VideoController.VideoProcessor	\N
6918d2bd-0be4-41bc-8a85-80844875385f	605	Video Adapter [2/2]	CurrentBitsPerPixel	32	CIM:UInt32	WMI:CIM_VideoController.CurrentBitsPerPixel	\N
6918d2bd-0be4-41bc-8a85-80844875385f	606	Video Adapter [2/2]	CurrentHorizontalResolution	1920	CIM:UInt32	WMI:CIM_VideoController.CurrentHorizontalResolution	\N
6918d2bd-0be4-41bc-8a85-80844875385f	607	Video Adapter [2/2]	CurrentVerticalResolution	1080	CIM:UInt32	WMI:CIM_VideoController.CurrentVerticalResolution	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	25	Operating System	ServicePackMajorVersion	0	CIM:UInt16	WMI:Win32_OperatingSystem.ServicePackMajorVersion	\N
6918d2bd-0be4-41bc-8a85-80844875385f	608	Video Adapter [2/2]	CurrentRefreshRate	60	CIM:UInt32	WMI:CIM_VideoController.CurrentRefreshRate	\N
6918d2bd-0be4-41bc-8a85-80844875385f	609	Video Adapter [2/2]	InstalledDisplayDrivers	igdumd64.dll,igd10umd64.dll,igd10umd64.dll,igdumdx32,igd10umd32,igd10umd32	CIM:String	WMI:Win32_VideoController.InstalledDisplayDrivers	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	26	Operating System	ServicePackMinorVersion	0	CIM:UInt16	WMI:Win32_OperatingSystem.ServicePackMinorVersion	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	27	Motherboard	Manufacturer	Dell Inc.	CIM:String	WMI:CIM_PhysicalElement.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	28	Motherboard	Model	\N	CIM:String	WMI:CIM_PhysicalElement.Model	\N
6918d2bd-0be4-41bc-8a85-80844875385f	610	Video Adapter [2/2]	DriverVersion	8.910.0.0	CIM:String	WMI:Win32_VideoController.DriverVersion	\N
6918d2bd-0be4-41bc-8a85-80844875385f	611	Video Adapter [2/2]	DriverDate	20111013000000.000000-000	CIM:DateTime	WMI:Win32_VideoController.DriverDate	\N
6918d2bd-0be4-41bc-8a85-80844875385f	612	Video Adapter [2/2]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	613	Video Adapter [2/2]	PNPDeviceID	PCI\\VEN_8086&DEV_0116&SUBSYS_167D103C&REV_09\\3&21436425&0&10	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	614	Video Adapter [2/2]	DeviceID	VideoController2	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	615	Video Adapter [2/2]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	616	Sound Device [1/3]	Description	Bluetooth Audio Device	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	617	Sound Device [1/3]	Manufacturer	Atheros Communications	CIM:String	WMI:Win32_SoundDevice.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	618	Sound Device [1/3]	ProductName	Bluetooth Audio Device	CIM:String	WMI:Win32_SoundDevice.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	619	Sound Device [1/3]	Availability	\N	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	620	Sound Device [1/3]	PNPDeviceID	BTHENUM\\{61118058-486C-4BB0-B4B8-ACE4DCADEC44}_LOCALMFG&0000\\8&255154EC&0&000000000000_00000000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	621	Sound Device [1/3]	DeviceID	BTHENUM\\{61118058-486C-4BB0-B4B8-ACE4DCADEC44}_LOCALMFG&0000\\8&255154EC&0&000000000000_00000000	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	622	Sound Device [1/3]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	623	Sound Device [2/3]	Description	IDT High Definition Audio CODEC	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	624	Sound Device [2/3]	Manufacturer	IDT	CIM:String	WMI:Win32_SoundDevice.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	625	Sound Device [2/3]	ProductName	IDT High Definition Audio CODEC	CIM:String	WMI:Win32_SoundDevice.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	626	Sound Device [2/3]	Availability	\N	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	627	Sound Device [2/3]	PNPDeviceID	HDAUDIO\\FUNC_01&VEN_111D&DEV_76D1&SUBSYS_103C167D&REV_1002\\4&5DEB806&0&0001	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	628	Sound Device [2/3]	DeviceID	HDAUDIO\\FUNC_01&VEN_111D&DEV_76D1&SUBSYS_103C167D&REV_1002\\4&5DEB806&0&0001	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	629	Sound Device [2/3]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	630	Sound Device [3/3]	Description	Intel(R) Display Audio	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	631	Sound Device [3/3]	Manufacturer	Intel(R) Corporation	CIM:String	WMI:Win32_SoundDevice.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	632	Sound Device [3/3]	ProductName	Intel(R) Display Audio	CIM:String	WMI:Win32_SoundDevice.ProductName	\N
6918d2bd-0be4-41bc-8a85-80844875385f	633	Sound Device [3/3]	Availability	\N	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
6918d2bd-0be4-41bc-8a85-80844875385f	634	Sound Device [3/3]	PNPDeviceID	HDAUDIO\\FUNC_01&VEN_8086&DEV_2805&SUBSYS_80860101&REV_1000\\4&5DEB806&0&0301	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	635	Sound Device [3/3]	DeviceID	HDAUDIO\\FUNC_01&VEN_8086&DEV_2805&SUBSYS_80860101&REV_1000\\4&5DEB806&0&0301	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	636	Sound Device [3/3]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	29	Motherboard	Product	0M1YNP	CIM:String	WMI:Win32_BaseBoard.Product	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	30	Motherboard	Name	Base Board	CIM:String	WMI:CIM_ManagedSystemElement.Name	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	31	Motherboard	Description	Base Board	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	32	Motherboard	Version	A00	CIM:String	WMI:CIM_PhysicalElement.Version	\N
6918d2bd-0be4-41bc-8a85-80844875385f	637	Disk Drive [1/2]	Description	Disk drive	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	33	System Firmware	Manufacturer	Dell Inc.	CIM:String	WMI:CIM_SoftwareElement.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	638	Disk Drive [1/2]	Manufacturer	(Standard disk drives)	CIM:String	WMI:Win32_DiskDrive.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	34	System Firmware	Description	1.13.6	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	35	System Firmware	ReleaseDate	20170621000000.000000+000	CIM:DateTime	WMI:Win32_BIOS.ReleaseDate	\N
6918d2bd-0be4-41bc-8a85-80844875385f	639	Disk Drive [1/2]	Model	SAMSUNG HM320HJ	CIM:String	WMI:Win32_DiskDrive.Model	\N
6918d2bd-0be4-41bc-8a85-80844875385f	640	Disk Drive [1/2]	FirmwareRevision	2AK1	CIM:String	WMI:Win32_DiskDrive.FirmwareRevision	\N
6918d2bd-0be4-41bc-8a85-80844875385f	641	Disk Drive [1/2]	InterfaceType	IDE	CIM:String	WMI:Win32_DiskDrive.InterfaceType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	642	Disk Drive [1/2]	MediaType	Fixed hard disk media	CIM:String	WMI:Win32_DiskDrive.MediaType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	643	Disk Drive [1/2]	Size	0.32 TB (0.29 TiB)	toStorageBytes(CIM:UInt64)	WMI:Win32_DiskDrive.Size	\N
6918d2bd-0be4-41bc-8a85-80844875385f	644	Disk Drive [1/2]	Partitions	4	CIM:UInt32	WMI:Win32_DiskDrive.Partitions	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	36	System Firmware	FirmwareType	Unknown	Enum:FirmwareType	Custom:GetFirmwareType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	37	System Firmware	BIOSVersion	DELL   - 1072009	CIM:String	WMI:Win32_BIOS.BIOSVersion[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	38	System Firmware	BIOSVersion	1.13.6	CIM:String	WMI:Win32_BIOS.BIOSVersion[1]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	39	System Firmware	BIOSVersion	American Megatrends - 5000B	CIM:String	WMI:Win32_BIOS.BIOSVersion[2]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	40	System Firmware	SMBIOSBIOSVersion	1.13.6	CIM:String	WMI:Win32_BIOS.SMBIOSBIOSVersion	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	41	System Firmware	SMBIOSMajorVersion	3	CIM:UInt16	WMI:Win32_BIOS.SMBIOSMajorVersion	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	42	System Firmware	SMBIOSMinorVersion	0	CIM:UInt16	WMI:Win32_BIOS.SMBIOSMinorVersion	\N
6918d2bd-0be4-41bc-8a85-80844875385f	645	Disk Drive [1/2]	PNPDeviceID	IDE\\DISKSAMSUNG_HM320HJ_________________________2AK10002\\4&3A93AF2C&0&0.0.0	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	646	Disk Drive [1/2]	DeviceID	\\\\.\\PHYSICALDRIVE0	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	647	Disk Drive [1/2]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	648	Disk Drive [2/2]	Description	Disk drive	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	649	Disk Drive [2/2]	Manufacturer	(Standard disk drives)	CIM:String	WMI:Win32_DiskDrive.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	650	Disk Drive [2/2]	Model	Apple iPod USB Device	CIM:String	WMI:Win32_DiskDrive.Model	\N
6918d2bd-0be4-41bc-8a85-80844875385f	651	Disk Drive [2/2]	FirmwareRevision	1.62	CIM:String	WMI:Win32_DiskDrive.FirmwareRevision	\N
6918d2bd-0be4-41bc-8a85-80844875385f	652	Disk Drive [2/2]	InterfaceType	USB	CIM:String	WMI:Win32_DiskDrive.InterfaceType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	653	Disk Drive [2/2]	MediaType	Removable Media	CIM:String	WMI:Win32_DiskDrive.MediaType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	654	Disk Drive [2/2]	Size	0.08 TB (0.07 TiB)	toStorageBytes(CIM:UInt64)	WMI:Win32_DiskDrive.Size	\N
6918d2bd-0be4-41bc-8a85-80844875385f	655	Disk Drive [2/2]	Partitions	1	CIM:UInt32	WMI:Win32_DiskDrive.Partitions	\N
6918d2bd-0be4-41bc-8a85-80844875385f	656	Disk Drive [2/2]	PNPDeviceID	USBSTOR\\DISK&VEN_APPLE&PROD_IPOD&REV_1.62\\000A270015158519&0	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	657	Disk Drive [2/2]	DeviceID	\\\\.\\PHYSICALDRIVE1	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	658	Disk Drive [2/2]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	659	CD-ROM Drive	Description	CD-ROM Drive	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
6918d2bd-0be4-41bc-8a85-80844875385f	660	CD-ROM Drive	Manufacturer	(Standard CD-ROM drives)	CIM:String	WMI:Win32_CDROMDrive.Manufacturer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	661	CD-ROM Drive	Caption	hp DVD A  DS8A5LH	CIM:String	WMI:CIM_ManagedSystemElement.Caption	\N
6918d2bd-0be4-41bc-8a85-80844875385f	662	CD-ROM Drive	Drive	F:	CIM:String	WMI:Win32_CDROMDrive.Drive	\N
6918d2bd-0be4-41bc-8a85-80844875385f	663	CD-ROM Drive	MediaType	DVD Writer	CIM:String	WMI:Win32_CDROMDrive.MediaType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	664	CD-ROM Drive	PNPDeviceID	IDE\\CDROMHP_DVD_A__DS8A5LH_______________________1H68____\\4&3A93AF2C&0&0.1.0	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	665	CD-ROM Drive	DeviceID	IDE\\CDROMHP_DVD_A__DS8A5LH_______________________1H68____\\4&3A93AF2C&0&0.1.0	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
6918d2bd-0be4-41bc-8a85-80844875385f	666	CD-ROM Drive	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
6918d2bd-0be4-41bc-8a85-80844875385f	667	Installed Programs	A360 Desktop	6.0.3.1100	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B209E611-5511-4AD6-B4B3-9D36F93DBCD4}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	668	Installed Programs	Access Control	5.21.73	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1F9F247F-CC99-4EBB-943A-974E662B8528}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	43	System Firmware	BiosCharacteristics	[7] PCI is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	44	System Firmware	BiosCharacteristics	[9] Plug and Play is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[1]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	45	System Firmware	BiosCharacteristics	[11] BIOS is Upgradable (Flash)	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[2]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	46	System Firmware	BiosCharacteristics	[12] BIOS shadowing is allowed	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[3]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	47	System Firmware	BiosCharacteristics	[15] Boot from CD is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[4]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	48	System Firmware	BiosCharacteristics	[16] Selectable Boot is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[5]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	49	System Firmware	BiosCharacteristics	[19] EDD (Enhanced Disk Drive) Specification is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[6]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	50	System Firmware	BiosCharacteristics	[23] Int 13h - 5.25 /1.2MB Floppy Services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[7]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	51	System Firmware	BiosCharacteristics	[24] Int 13h - 3.5 / 720 KB Floppy Services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[8]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	52	System Firmware	BiosCharacteristics	[25] Int 13h - 3.5 / 2.88 MB Floppy Services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[9]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	53	System Firmware	BiosCharacteristics	[26] Int 5h, Print Screen Service is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[10]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	54	System Firmware	BiosCharacteristics	[27] Int 9h, 8042 Keyboard services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[11]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	55	System Firmware	BiosCharacteristics	[28] Int 14h, Serial Services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[12]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	56	System Firmware	BiosCharacteristics	[29] Int 17h, printer services are supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[13]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	669	Installed Programs	ActiveCheck component for HP Active Support Library	3.0.0.3	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{254C37AA-6B72-4300-84F6-98A82419187E}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	670	Installed Programs	Adobe Acrobat Reader DC	18.011.20038	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{AC76BA86-7AD7-1033-7B44-AC0F074E4100}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	57	System Firmware	BiosCharacteristics	[32] ACPI is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[14]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	58	System Firmware	BiosCharacteristics	[33] USB Legacy is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[15]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	59	System Firmware	BiosCharacteristics	[39] Smart Battery is supported	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[16]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	60	System Firmware	BiosCharacteristics	[40] BIOS Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[17]	\N
6918d2bd-0be4-41bc-8a85-80844875385f	671	Installed Programs	Adobe Bridge 1.0	001.000.000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B74D4E10-1033-0000-0000-000000000001}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	672	Installed Programs	Adobe Common File Installer	1.00.0000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{8EDBA74D-0686-4C99-BFDD-F894678E5B39}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	673	Installed Programs	Adobe Creative Suite 2	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{0134A1A1-C283-4A47-91A1-92F19F960372}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	674	Installed Programs	Adobe Flash Player 24 NPAPI	24.0.0.186	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Adobe Flash Player NPAPI	\N
6918d2bd-0be4-41bc-8a85-80844875385f	675	Installed Programs	Adobe Flash Player 26 ActiveX	26.0.0.131	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Adobe Flash Player ActiveX	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	61	System Firmware	BiosCharacteristics	[41] BIOS Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[18]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	62	System Firmware	BiosCharacteristics	[42] BIOS Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[19]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	63	System Firmware	BiosCharacteristics	[43] BIOS Vendor Reserved	string(CIM:UInt16)	WMI:Win32_BIOS.BiosCharacteristics[20]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	64	Processor	Manufacturer	GenuineIntel	CIM:String	WMI:Win32_Processor.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	65	Processor	Name	Intel(R) Core(TM) i7-6920HQ CPU @ 2.90GHz	CIM:String	WMI:CIM_ManagedSystemElement.Name	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	66	Processor	Description	Intel64 Family 6 Model 94 Stepping 3	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	67	Processor	DeviceID	CPU0	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	68	Processor	Architecture	x64	string(CIM:UInt16)	WMI:Win32_Processor.Architecture	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	69	Processor	Family	Intel Core™ i7-2760QM	string(CIM:UInt16)	WMI:CIM_Processor.Family	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	70	Processor	OtherFamilyDescription	\N	CIM:String	WMI:CIM_Processor.OtherFamilyDescription	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	71	Processor	Version	\N	CIM:String	WMI:Win32_Processor.Version	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	72	Processor	ProcessorId	BFEBFBFF000506E3	CIM:String	WMI:Win32_Processor.ProcessorId	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	73	Processor	NumberOfCores	4	CIM:UInt32	WMI:Win32_Processor.NumberOfCores	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	74	Processor	NumberOfLogicalProcessors	8	CIM:UInt32	WMI:Win32_Processor.NumberOfLogicalProcessors	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	75	Processor	AddressWidth	64	CIM:UInt16	WMI:CIM_Processor.AddressWidth	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	76	Processor	CurrentClockSpeed	2901	CIM:UInt32	WMI:CIM_Processor.CurrentClockSpeed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	77	Processor	MaxClockSpeed	2901	CIM:UInt32	WMI:CIM_Processor.MaxClockSpeed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	78	Memory [1/4]	Tag	Physical Memory 0	CIM:String	WMI:CIM_PhysicalElement.Tag	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	79	Memory [1/4]	Manufacturer	SK Hynix	CIM:String	WMI:CIM_PhysicalElement.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	80	Memory [1/4]	Model	\N	CIM:String	WMI:CIM_PhysicalElement.Model	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	81	Memory [1/4]	PartNumber	HMA41GS6AFR8N-TF    	CIM:String	WMI:CIM_PhysicalElement.PartNumber	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	82	Memory [1/4]	Description	Physical Memory	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	83	Memory [1/4]	Capacity	8192 MB	toMegaBytes(CIM:UInt64)	WMI:CIM_PhysicalMemory.Capacity	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	84	Memory [1/4]	Speed	2133	CIM:UInt32	WMI:CIM_PhysicalMemory.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	85	Memory [1/4]	DataWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.DataWidth	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	86	Memory [1/4]	TotalWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.TotalWidth	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	87	Memory [1/4]	BankLabel	BANK 0	CIM:String	WMI:CIM_PhysicalMemory.BankLabel	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	88	Memory [1/4]	TypeDetail	Synchronous	string(CIM:UInt16)	WMI:Win32_PhysicalMemory.TypeDetail	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	89	Memory [1/4]	MemoryType	Unknown	string(CIM:UInt16)	WMI:CIM_PhysicalMemory.MemoryType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	90	Memory [1/4]	FormFactor	SODIMM	string(CIM:UInt16)	WMI:CIM_Chip.FormFactor	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	91	Memory [1/4]	Status	\N	CIM:String	WMI:CIM_ManagedSystemElement.Status	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	92	Memory [1/4]	Version	\N	CIM:String	WMI:CIM_PhysicalElement.Version	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	93	Memory [2/4]	Tag	Physical Memory 1	CIM:String	WMI:CIM_PhysicalElement.Tag	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	94	Memory [2/4]	Manufacturer	SK Hynix	CIM:String	WMI:CIM_PhysicalElement.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	95	Memory [2/4]	Model	\N	CIM:String	WMI:CIM_PhysicalElement.Model	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	96	Memory [2/4]	PartNumber	HMA41GS6AFR8N-TF    	CIM:String	WMI:CIM_PhysicalElement.PartNumber	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	97	Memory [2/4]	Description	Physical Memory	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	98	Memory [2/4]	Capacity	8192 MB	toMegaBytes(CIM:UInt64)	WMI:CIM_PhysicalMemory.Capacity	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	99	Memory [2/4]	Speed	2133	CIM:UInt32	WMI:CIM_PhysicalMemory.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	100	Memory [2/4]	DataWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.DataWidth	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	101	Memory [2/4]	TotalWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.TotalWidth	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	102	Memory [2/4]	BankLabel	BANK 1	CIM:String	WMI:CIM_PhysicalMemory.BankLabel	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	103	Memory [2/4]	TypeDetail	Synchronous	string(CIM:UInt16)	WMI:Win32_PhysicalMemory.TypeDetail	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	104	Memory [2/4]	MemoryType	Unknown	string(CIM:UInt16)	WMI:CIM_PhysicalMemory.MemoryType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	105	Memory [2/4]	FormFactor	SODIMM	string(CIM:UInt16)	WMI:CIM_Chip.FormFactor	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	106	Memory [2/4]	Status	\N	CIM:String	WMI:CIM_ManagedSystemElement.Status	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	107	Memory [2/4]	Version	\N	CIM:String	WMI:CIM_PhysicalElement.Version	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	108	Memory [3/4]	Tag	Physical Memory 2	CIM:String	WMI:CIM_PhysicalElement.Tag	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	109	Memory [3/4]	Manufacturer	SK Hynix	CIM:String	WMI:CIM_PhysicalElement.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	110	Memory [3/4]	Model	\N	CIM:String	WMI:CIM_PhysicalElement.Model	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	111	Memory [3/4]	PartNumber	HMA41GS6AFR8N-TF    	CIM:String	WMI:CIM_PhysicalElement.PartNumber	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	112	Memory [3/4]	Description	Physical Memory	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	113	Memory [3/4]	Capacity	8192 MB	toMegaBytes(CIM:UInt64)	WMI:CIM_PhysicalMemory.Capacity	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	114	Memory [3/4]	Speed	2133	CIM:UInt32	WMI:CIM_PhysicalMemory.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	115	Memory [3/4]	DataWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.DataWidth	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	116	Memory [3/4]	TotalWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.TotalWidth	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	117	Memory [3/4]	BankLabel	BANK 2	CIM:String	WMI:CIM_PhysicalMemory.BankLabel	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	118	Memory [3/4]	TypeDetail	Synchronous	string(CIM:UInt16)	WMI:Win32_PhysicalMemory.TypeDetail	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	119	Memory [3/4]	MemoryType	Unknown	string(CIM:UInt16)	WMI:CIM_PhysicalMemory.MemoryType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	120	Memory [3/4]	FormFactor	SODIMM	string(CIM:UInt16)	WMI:CIM_Chip.FormFactor	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	121	Memory [3/4]	Status	\N	CIM:String	WMI:CIM_ManagedSystemElement.Status	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	122	Memory [3/4]	Version	\N	CIM:String	WMI:CIM_PhysicalElement.Version	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	123	Memory [4/4]	Tag	Physical Memory 3	CIM:String	WMI:CIM_PhysicalElement.Tag	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	124	Memory [4/4]	Manufacturer	SK Hynix	CIM:String	WMI:CIM_PhysicalElement.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	125	Memory [4/4]	Model	\N	CIM:String	WMI:CIM_PhysicalElement.Model	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	126	Memory [4/4]	PartNumber	HMA41GS6AFR8N-TF    	CIM:String	WMI:CIM_PhysicalElement.PartNumber	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	127	Memory [4/4]	Description	Physical Memory	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	128	Memory [4/4]	Capacity	8192 MB	toMegaBytes(CIM:UInt64)	WMI:CIM_PhysicalMemory.Capacity	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	129	Memory [4/4]	Speed	2133	CIM:UInt32	WMI:CIM_PhysicalMemory.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	130	Memory [4/4]	DataWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.DataWidth	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	131	Memory [4/4]	TotalWidth	64	CIM:UInt16	WMI:CIM_PhysicalMemory.TotalWidth	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	132	Memory [4/4]	BankLabel	BANK 3	CIM:String	WMI:CIM_PhysicalMemory.BankLabel	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	133	Memory [4/4]	TypeDetail	Synchronous	string(CIM:UInt16)	WMI:Win32_PhysicalMemory.TypeDetail	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	134	Memory [4/4]	MemoryType	Unknown	string(CIM:UInt16)	WMI:CIM_PhysicalMemory.MemoryType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	135	Memory [4/4]	FormFactor	SODIMM	string(CIM:UInt16)	WMI:CIM_Chip.FormFactor	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	136	Memory [4/4]	Status	\N	CIM:String	WMI:CIM_ManagedSystemElement.Status	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	137	Memory [4/4]	Version	\N	CIM:String	WMI:CIM_PhysicalElement.Version	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	138	Network Adapter [1/19]	Description	Microsoft Kernel Debug Network Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	139	Network Adapter [1/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	140	Network Adapter [1/19]	ProductName	Microsoft Kernel Debug Network Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	141	Network Adapter [1/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	142	Network Adapter [1/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	143	Network Adapter [1/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	144	Network Adapter [1/19]	InterfaceIndex	20	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	145	Network Adapter [1/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	146	Network Adapter [1/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	147	Network Adapter [1/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	148	Network Adapter [1/19]	PNPDeviceID	ROOT\\KDNIC\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	149	Network Adapter [1/19]	DeviceID	0	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	150	Network Adapter [1/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	151	Network Adapter [2/19]	Description	Intel(R) Ethernet Connection (2) I219-LM	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	152	Network Adapter [2/19]	Manufacturer	Intel	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	153	Network Adapter [2/19]	ProductName	Intel(R) Ethernet Connection (2) I219-LM	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	154	Network Adapter [2/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	155	Network Adapter [2/19]	MACAddress	A4:4C:C8:57:01:94	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	156	Network Adapter [2/19]	GUID	{5776BA17-4C6A-4FF4-A1DF-B5EBEBDE19A5}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	157	Network Adapter [2/19]	InterfaceIndex	10	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	158	Network Adapter [2/19]	NetConnectionStatus	7	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	159	Network Adapter [2/19]	Speed	9,223,372.04 Tbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	160	Network Adapter [2/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	161	Network Adapter [2/19]	PNPDeviceID	PCI\\VEN_8086&DEV_15B7&SUBSYS_06D91028&REV_31\\3&11583659&0&FE	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	162	Network Adapter [2/19]	DeviceID	1	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	163	Network Adapter [2/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	164	Network Adapter [3/19]	Description	Qualcomm QCA61x4A 802.11ac Wireless Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	165	Network Adapter [3/19]	Manufacturer	Qualcomm Communications Inc.	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	166	Network Adapter [3/19]	ProductName	Qualcomm QCA61x4A 802.11ac Wireless Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	167	Network Adapter [3/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	168	Network Adapter [3/19]	MACAddress	9C:30:5B:0C:7D:3F	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	169	Network Adapter [3/19]	GUID	{437F570F-077F-4210-98F4-83687A25B49E}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	170	Network Adapter [3/19]	InterfaceIndex	8	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	171	Network Adapter [3/19]	NetConnectionStatus	2	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	172	Network Adapter [3/19]	Speed	144.40 Mbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	173	Network Adapter [3/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	174	Network Adapter [3/19]	PNPDeviceID	PCI\\VEN_168C&DEV_003E&SUBSYS_03101028&REV_32\\4&213D636C&0&00E0	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	175	Network Adapter [3/19]	DeviceID	2	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	176	Network Adapter [3/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	177	Network Adapter [4/19]	Description	Microsoft Wi-Fi Direct Virtual Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	178	Network Adapter [4/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	179	Network Adapter [4/19]	ProductName	Microsoft Wi-Fi Direct Virtual Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	180	Network Adapter [4/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	181	Network Adapter [4/19]	MACAddress	9E:30:5B:0C:7D:3F	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	182	Network Adapter [4/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	183	Network Adapter [4/19]	InterfaceIndex	15	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	184	Network Adapter [4/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	185	Network Adapter [4/19]	Speed	9,223,372.04 Tbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	186	Network Adapter [4/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	187	Network Adapter [4/19]	PNPDeviceID	{5D624F94-8850-40C3-A3FA-A4FD2080BAF3}\\VWIFIMP_WFD\\5&25B05188&1&12	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	188	Network Adapter [4/19]	DeviceID	3	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	189	Network Adapter [4/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	190	Network Adapter [5/19]	Description	Bluetooth Device (RFCOMM Protocol TDI)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	191	Network Adapter [5/19]	Manufacturer	\N	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	192	Network Adapter [5/19]	ProductName	Bluetooth Device (RFCOMM Protocol TDI)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	193	Network Adapter [5/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	194	Network Adapter [5/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	195	Network Adapter [5/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	196	Network Adapter [5/19]	InterfaceIndex	19	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	197	Network Adapter [5/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	198	Network Adapter [5/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	199	Network Adapter [5/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	200	Network Adapter [5/19]	PNPDeviceID	\N	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	201	Network Adapter [5/19]	DeviceID	4	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	202	Network Adapter [5/19]	ConfigManagerErrorCode	\N	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	203	Network Adapter [6/19]	Description	Bluetooth Device (Personal Area Network)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	204	Network Adapter [6/19]	Manufacturer	\N	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	205	Network Adapter [6/19]	ProductName	Bluetooth Device (Personal Area Network)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	206	Network Adapter [6/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	207	Network Adapter [6/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	208	Network Adapter [6/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	209	Network Adapter [6/19]	InterfaceIndex	2	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	210	Network Adapter [6/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	211	Network Adapter [6/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	212	Network Adapter [6/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	213	Network Adapter [6/19]	PNPDeviceID	\N	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	214	Network Adapter [6/19]	DeviceID	5	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	215	Network Adapter [6/19]	ConfigManagerErrorCode	\N	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	216	Network Adapter [7/19]	Description	WAN Miniport (SSTP)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	217	Network Adapter [7/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	218	Network Adapter [7/19]	ProductName	WAN Miniport (SSTP)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	219	Network Adapter [7/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	220	Network Adapter [7/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	221	Network Adapter [7/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	222	Network Adapter [7/19]	InterfaceIndex	3	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	223	Network Adapter [7/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	224	Network Adapter [7/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	225	Network Adapter [7/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	226	Network Adapter [7/19]	PNPDeviceID	SWD\\MSRRAS\\MS_SSTPMINIPORT	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	227	Network Adapter [7/19]	DeviceID	6	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	228	Network Adapter [7/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	229	Network Adapter [8/19]	Description	WAN Miniport (IKEv2)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	230	Network Adapter [8/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	231	Network Adapter [8/19]	ProductName	WAN Miniport (IKEv2)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	232	Network Adapter [8/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	233	Network Adapter [8/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	234	Network Adapter [8/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	235	Network Adapter [8/19]	InterfaceIndex	13	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	236	Network Adapter [8/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	237	Network Adapter [8/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	238	Network Adapter [8/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	239	Network Adapter [8/19]	PNPDeviceID	SWD\\MSRRAS\\MS_AGILEVPNMINIPORT	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	240	Network Adapter [8/19]	DeviceID	7	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	241	Network Adapter [8/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	242	Network Adapter [9/19]	Description	WAN Miniport (L2TP)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	243	Network Adapter [9/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	244	Network Adapter [9/19]	ProductName	WAN Miniport (L2TP)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	245	Network Adapter [9/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	246	Network Adapter [9/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	247	Network Adapter [9/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	248	Network Adapter [9/19]	InterfaceIndex	18	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	249	Network Adapter [9/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	250	Network Adapter [9/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	251	Network Adapter [9/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	252	Network Adapter [9/19]	PNPDeviceID	SWD\\MSRRAS\\MS_L2TPMINIPORT	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	253	Network Adapter [9/19]	DeviceID	8	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	254	Network Adapter [9/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	255	Network Adapter [10/19]	Description	WAN Miniport (PPTP)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	256	Network Adapter [10/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	257	Network Adapter [10/19]	ProductName	WAN Miniport (PPTP)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	258	Network Adapter [10/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	259	Network Adapter [10/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	260	Network Adapter [10/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	261	Network Adapter [10/19]	InterfaceIndex	7	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	262	Network Adapter [10/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	263	Network Adapter [10/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	264	Network Adapter [10/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	265	Network Adapter [10/19]	PNPDeviceID	SWD\\MSRRAS\\MS_PPTPMINIPORT	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	266	Network Adapter [10/19]	DeviceID	9	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	267	Network Adapter [10/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	268	Network Adapter [11/19]	Description	WAN Miniport (PPPOE)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	269	Network Adapter [11/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	270	Network Adapter [11/19]	ProductName	WAN Miniport (PPPOE)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	271	Network Adapter [11/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	272	Network Adapter [11/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	273	Network Adapter [11/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	274	Network Adapter [11/19]	InterfaceIndex	17	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	275	Network Adapter [11/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	276	Network Adapter [11/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	277	Network Adapter [11/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	278	Network Adapter [11/19]	PNPDeviceID	SWD\\MSRRAS\\MS_PPPOEMINIPORT	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	279	Network Adapter [11/19]	DeviceID	10	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	280	Network Adapter [11/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	281	Network Adapter [12/19]	Description	WAN Miniport (IP)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	282	Network Adapter [12/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	283	Network Adapter [12/19]	ProductName	WAN Miniport (IP)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	284	Network Adapter [12/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	285	Network Adapter [12/19]	MACAddress	DE:A7:20:52:41:53	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	286	Network Adapter [12/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	287	Network Adapter [12/19]	InterfaceIndex	12	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	288	Network Adapter [12/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	289	Network Adapter [12/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	290	Network Adapter [12/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	291	Network Adapter [12/19]	PNPDeviceID	SWD\\MSRRAS\\MS_NDISWANIP	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	292	Network Adapter [12/19]	DeviceID	11	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	293	Network Adapter [12/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	294	Network Adapter [13/19]	Description	WAN Miniport (IPv6)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	295	Network Adapter [13/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	296	Network Adapter [13/19]	ProductName	WAN Miniport (IPv6)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	297	Network Adapter [13/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	298	Network Adapter [13/19]	MACAddress	E0:C3:20:52:41:53	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	299	Network Adapter [13/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	300	Network Adapter [13/19]	InterfaceIndex	4	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	301	Network Adapter [13/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	302	Network Adapter [13/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	303	Network Adapter [13/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	304	Network Adapter [13/19]	PNPDeviceID	SWD\\MSRRAS\\MS_NDISWANIPV6	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	305	Network Adapter [13/19]	DeviceID	12	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	306	Network Adapter [13/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	307	Network Adapter [14/19]	Description	WAN Miniport (Network Monitor)	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	308	Network Adapter [14/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	309	Network Adapter [14/19]	ProductName	WAN Miniport (Network Monitor)	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	310	Network Adapter [14/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	311	Network Adapter [14/19]	MACAddress	E2:04:20:52:41:53	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	312	Network Adapter [14/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	313	Network Adapter [14/19]	InterfaceIndex	5	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	314	Network Adapter [14/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	315	Network Adapter [14/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	316	Network Adapter [14/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	317	Network Adapter [14/19]	PNPDeviceID	SWD\\MSRRAS\\MS_NDISWANBH	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	318	Network Adapter [14/19]	DeviceID	13	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	319	Network Adapter [14/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	320	Network Adapter [15/19]	Description	Microsoft Teredo Tunneling Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	321	Network Adapter [15/19]	Manufacturer	Microsoft	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	322	Network Adapter [15/19]	ProductName	Microsoft Teredo Tunneling Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	323	Network Adapter [15/19]	AdapterType	Tunnel	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	324	Network Adapter [15/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	325	Network Adapter [15/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	326	Network Adapter [15/19]	InterfaceIndex	6	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	327	Network Adapter [15/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	328	Network Adapter [15/19]	Speed	100.00 Kbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	329	Network Adapter [15/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	330	Network Adapter [15/19]	PNPDeviceID	SWD\\IP_TUNNEL_VBUS\\TEREDO_TUNNEL_DEVICE	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	331	Network Adapter [15/19]	DeviceID	14	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	332	Network Adapter [15/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	333	Network Adapter [16/19]	Description	Microsoft Wi-Fi Direct Virtual Adapter	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	334	Network Adapter [16/19]	Manufacturer	\N	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	335	Network Adapter [16/19]	ProductName	Microsoft Wi-Fi Direct Virtual Adapter	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	336	Network Adapter [16/19]	AdapterType	\N	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	337	Network Adapter [16/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	338	Network Adapter [16/19]	GUID	\N	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	339	Network Adapter [16/19]	InterfaceIndex	11	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	340	Network Adapter [16/19]	NetConnectionStatus	\N	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	341	Network Adapter [16/19]	Speed	\N	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	342	Network Adapter [16/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	343	Network Adapter [16/19]	PNPDeviceID	\N	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	344	Network Adapter [16/19]	DeviceID	15	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	345	Network Adapter [16/19]	ConfigManagerErrorCode	\N	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	346	Network Adapter [17/19]	Description	Cisco AnyConnect Secure Mobility Client Virtual Miniport Adapter for Windows x64	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	347	Network Adapter [17/19]	Manufacturer	Cisco Systems	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	348	Network Adapter [17/19]	ProductName	Cisco AnyConnect Secure Mobility Client Virtual Miniport Adapter for Windows x64	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	349	Network Adapter [17/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	350	Network Adapter [17/19]	MACAddress	00:05:9A:3C:7A:00	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	351	Network Adapter [17/19]	GUID	{D82D7D9C-2D02-4C25-9ED8-DFB5F5E7DD24}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	352	Network Adapter [17/19]	InterfaceIndex	16	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	353	Network Adapter [17/19]	NetConnectionStatus	2	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	354	Network Adapter [17/19]	Speed	143.68 Mbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	355	Network Adapter [17/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	356	Network Adapter [17/19]	PNPDeviceID	ROOT\\NET\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	357	Network Adapter [17/19]	DeviceID	16	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	358	Network Adapter [17/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	359	Network Adapter [18/19]	Description	VMware Virtual Ethernet Adapter for VMnet1	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	360	Network Adapter [18/19]	Manufacturer	VMware, Inc.	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	361	Network Adapter [18/19]	ProductName	VMware Virtual Ethernet Adapter for VMnet1	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	362	Network Adapter [18/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	363	Network Adapter [18/19]	MACAddress	00:50:56:C0:00:01	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	364	Network Adapter [18/19]	GUID	{575BA24A-1B69-4F70-8F0E-8C780CC13056}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	365	Network Adapter [18/19]	InterfaceIndex	9	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	366	Network Adapter [18/19]	NetConnectionStatus	2	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	367	Network Adapter [18/19]	Speed	100.00 Mbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	368	Network Adapter [18/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	369	Network Adapter [18/19]	PNPDeviceID	ROOT\\VMWARE\\0000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	370	Network Adapter [18/19]	DeviceID	17	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	371	Network Adapter [18/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	372	Network Adapter [19/19]	Description	VMware Virtual Ethernet Adapter for VMnet8	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	373	Network Adapter [19/19]	Manufacturer	VMware, Inc.	CIM:String	WMI:Win32_NetworkAdapter.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	374	Network Adapter [19/19]	ProductName	VMware Virtual Ethernet Adapter for VMnet8	CIM:String	WMI:Win32_NetworkAdapter.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	375	Network Adapter [19/19]	AdapterType	Ethernet 802.3	CIM:String	WMI:Win32_NetworkAdapter.AdapterType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	376	Network Adapter [19/19]	MACAddress	00:50:56:C0:00:08	CIM:String	WMI:Win32_NetworkAdapter.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	377	Network Adapter [19/19]	GUID	{BA7F8F6A-D5CC-4DE4-A999-52907CE27923}	CIM:String	WMI:Win32_NetworkAdapter.GUID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	378	Network Adapter [19/19]	InterfaceIndex	14	CIM:UInt32	WMI:Win32_NetworkAdapter.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	379	Network Adapter [19/19]	NetConnectionStatus	2	CIM:UInt16	WMI:Win32_NetworkAdapter.NetConnectionStatus	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	380	Network Adapter [19/19]	Speed	100.00 Mbps	toXferSpeed(CIM:UInt64)	WMI:CIM_NetworkAdapter.Speed	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	381	Network Adapter [19/19]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	382	Network Adapter [19/19]	PNPDeviceID	ROOT\\VMWARE\\0001	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	383	Network Adapter [19/19]	DeviceID	18	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	384	Network Adapter [19/19]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	385	Network Adapter Configuration [1/19]	Caption	[00000000] Microsoft Kernel Debug Network Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	386	Network Adapter Configuration [1/19]	InterfaceIndex	20	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	387	Network Adapter Configuration [1/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	388	Network Adapter Configuration [1/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	389	Network Adapter Configuration [1/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	390	Network Adapter Configuration [1/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	391	Network Adapter Configuration [1/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	392	Network Adapter Configuration [1/19]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	393	Network Adapter Configuration [1/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	394	Network Adapter Configuration [1/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	395	Network Adapter Configuration [1/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	396	Network Adapter Configuration [1/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	397	Network Adapter Configuration [1/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	398	Network Adapter Configuration [2/19]	Caption	[00000001] Intel(R) Ethernet Connection (2) I219-LM	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	399	Network Adapter Configuration [2/19]	InterfaceIndex	10	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	400	Network Adapter Configuration [2/19]	MACAddress	A4:4C:C8:57:01:94	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	401	Network Adapter Configuration [2/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	402	Network Adapter Configuration [2/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	403	Network Adapter Configuration [2/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	404	Network Adapter Configuration [2/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	405	Network Adapter Configuration [2/19]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	406	Network Adapter Configuration [2/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	407	Network Adapter Configuration [2/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	408	Network Adapter Configuration [2/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	409	Network Adapter Configuration [2/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	410	Network Adapter Configuration [2/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	411	Network Adapter Configuration [3/19]	Caption	[00000002] Qualcomm QCA61x4A 802.11ac Wireless Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	412	Network Adapter Configuration [3/19]	InterfaceIndex	8	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	413	Network Adapter Configuration [3/19]	MACAddress	9C:30:5B:0C:7D:3F	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	414	Network Adapter Configuration [3/19]	IPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	415	Network Adapter Configuration [3/19]	IPAddress	192.168.1.5	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	416	Network Adapter Configuration [3/19]	IPAddress	fe80::c520:d09a:3096:a75e	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[1]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	417	Network Adapter Configuration [3/19]	IPSubnet	255.255.255.0	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	418	Network Adapter Configuration [3/19]	IPSubnet	64	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[1]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	419	Network Adapter Configuration [3/19]	DefaultIPGateway	192.168.1.1	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	420	Network Adapter Configuration [3/19]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	421	Network Adapter Configuration [3/19]	DHCPServer	192.168.1.1	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	422	Network Adapter Configuration [3/19]	DNSHostName	OSSI-DNovak	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	423	Network Adapter Configuration [3/19]	DNSDomain	home	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	424	Network Adapter Configuration [3/19]	DNSDomainSuffixSearchOrder	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	425	Network Adapter Configuration [3/19]	DNSDomainSuffixSearchOrder	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder[1]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	426	Network Adapter Configuration [3/19]	DNSServerSearchOrder	192.168.1.1	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	427	Network Adapter Configuration [4/19]	Caption	[00000003] Microsoft Wi-Fi Direct Virtual Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	428	Network Adapter Configuration [4/19]	InterfaceIndex	15	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	429	Network Adapter Configuration [4/19]	MACAddress	9E:30:5B:0C:7D:3F	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	430	Network Adapter Configuration [4/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	431	Network Adapter Configuration [4/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	432	Network Adapter Configuration [4/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	433	Network Adapter Configuration [4/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	434	Network Adapter Configuration [4/19]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	435	Network Adapter Configuration [4/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	436	Network Adapter Configuration [4/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	437	Network Adapter Configuration [4/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	438	Network Adapter Configuration [4/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	439	Network Adapter Configuration [4/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	440	Network Adapter Configuration [5/19]	Caption	[00000004] Bluetooth Device (RFCOMM Protocol TDI)	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	441	Network Adapter Configuration [5/19]	InterfaceIndex	19	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
6918d2bd-0be4-41bc-8a85-80844875385f	676	Installed Programs	Adobe Help Center 1.0	001.000.000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E9787678-1033-0000-8E67-000000000001}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	442	Network Adapter Configuration [5/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	443	Network Adapter Configuration [5/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	444	Network Adapter Configuration [5/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	445	Network Adapter Configuration [5/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	446	Network Adapter Configuration [5/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	447	Network Adapter Configuration [5/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	448	Network Adapter Configuration [5/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	449	Network Adapter Configuration [5/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	450	Network Adapter Configuration [5/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	451	Network Adapter Configuration [5/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	452	Network Adapter Configuration [5/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	453	Network Adapter Configuration [6/19]	Caption	[00000005] Bluetooth Device (Personal Area Network)	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	454	Network Adapter Configuration [6/19]	InterfaceIndex	2	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	455	Network Adapter Configuration [6/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	456	Network Adapter Configuration [6/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	457	Network Adapter Configuration [6/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	458	Network Adapter Configuration [6/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	459	Network Adapter Configuration [6/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	460	Network Adapter Configuration [6/19]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	461	Network Adapter Configuration [6/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	462	Network Adapter Configuration [6/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	463	Network Adapter Configuration [6/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	464	Network Adapter Configuration [6/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	465	Network Adapter Configuration [6/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	466	Network Adapter Configuration [7/19]	Caption	[00000006] WAN Miniport (SSTP)	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	467	Network Adapter Configuration [7/19]	InterfaceIndex	3	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	468	Network Adapter Configuration [7/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	469	Network Adapter Configuration [7/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	470	Network Adapter Configuration [7/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	471	Network Adapter Configuration [7/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	472	Network Adapter Configuration [7/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	473	Network Adapter Configuration [7/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	474	Network Adapter Configuration [7/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	475	Network Adapter Configuration [7/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	476	Network Adapter Configuration [7/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	477	Network Adapter Configuration [7/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	478	Network Adapter Configuration [7/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	479	Network Adapter Configuration [8/19]	Caption	[00000007] WAN Miniport (IKEv2)	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	480	Network Adapter Configuration [8/19]	InterfaceIndex	13	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	481	Network Adapter Configuration [8/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	482	Network Adapter Configuration [8/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	483	Network Adapter Configuration [8/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	484	Network Adapter Configuration [8/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	485	Network Adapter Configuration [8/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	486	Network Adapter Configuration [8/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	487	Network Adapter Configuration [8/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	488	Network Adapter Configuration [8/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	489	Network Adapter Configuration [8/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	490	Network Adapter Configuration [8/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	491	Network Adapter Configuration [8/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	492	Network Adapter Configuration [9/19]	Caption	[00000008] WAN Miniport (L2TP)	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	493	Network Adapter Configuration [9/19]	InterfaceIndex	18	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	494	Network Adapter Configuration [9/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	495	Network Adapter Configuration [9/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	496	Network Adapter Configuration [9/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	497	Network Adapter Configuration [9/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	498	Network Adapter Configuration [9/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	499	Network Adapter Configuration [9/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	500	Network Adapter Configuration [9/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	501	Network Adapter Configuration [9/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	502	Network Adapter Configuration [9/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	503	Network Adapter Configuration [9/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	504	Network Adapter Configuration [9/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	505	Network Adapter Configuration [10/19]	Caption	[00000009] WAN Miniport (PPTP)	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	506	Network Adapter Configuration [10/19]	InterfaceIndex	7	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	507	Network Adapter Configuration [10/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	508	Network Adapter Configuration [10/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	509	Network Adapter Configuration [10/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	510	Network Adapter Configuration [10/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	511	Network Adapter Configuration [10/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	512	Network Adapter Configuration [10/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	513	Network Adapter Configuration [10/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	514	Network Adapter Configuration [10/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	515	Network Adapter Configuration [10/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	516	Network Adapter Configuration [10/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	517	Network Adapter Configuration [10/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	518	Network Adapter Configuration [11/19]	Caption	[00000010] WAN Miniport (PPPOE)	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	519	Network Adapter Configuration [11/19]	InterfaceIndex	17	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	520	Network Adapter Configuration [11/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	521	Network Adapter Configuration [11/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	522	Network Adapter Configuration [11/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	523	Network Adapter Configuration [11/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	524	Network Adapter Configuration [11/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	525	Network Adapter Configuration [11/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	526	Network Adapter Configuration [11/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	527	Network Adapter Configuration [11/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	528	Network Adapter Configuration [11/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	529	Network Adapter Configuration [11/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	530	Network Adapter Configuration [11/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	531	Network Adapter Configuration [12/19]	Caption	[00000011] WAN Miniport (IP)	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	532	Network Adapter Configuration [12/19]	InterfaceIndex	12	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	533	Network Adapter Configuration [12/19]	MACAddress	DE:A7:20:52:41:53	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	534	Network Adapter Configuration [12/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	535	Network Adapter Configuration [12/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	536	Network Adapter Configuration [12/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	537	Network Adapter Configuration [12/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	538	Network Adapter Configuration [12/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	539	Network Adapter Configuration [12/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	540	Network Adapter Configuration [12/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	541	Network Adapter Configuration [12/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	542	Network Adapter Configuration [12/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	543	Network Adapter Configuration [12/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	544	Network Adapter Configuration [13/19]	Caption	[00000012] WAN Miniport (IPv6)	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	545	Network Adapter Configuration [13/19]	InterfaceIndex	4	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	546	Network Adapter Configuration [13/19]	MACAddress	E0:C3:20:52:41:53	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	547	Network Adapter Configuration [13/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	548	Network Adapter Configuration [13/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	549	Network Adapter Configuration [13/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	550	Network Adapter Configuration [13/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	551	Network Adapter Configuration [13/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	552	Network Adapter Configuration [13/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	553	Network Adapter Configuration [13/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	554	Network Adapter Configuration [13/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	555	Network Adapter Configuration [13/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	556	Network Adapter Configuration [13/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	557	Network Adapter Configuration [14/19]	Caption	[00000013] WAN Miniport (Network Monitor)	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	558	Network Adapter Configuration [14/19]	InterfaceIndex	5	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	559	Network Adapter Configuration [14/19]	MACAddress	E2:04:20:52:41:53	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	560	Network Adapter Configuration [14/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	561	Network Adapter Configuration [14/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	562	Network Adapter Configuration [14/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	563	Network Adapter Configuration [14/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	564	Network Adapter Configuration [14/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	565	Network Adapter Configuration [14/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	566	Network Adapter Configuration [14/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	567	Network Adapter Configuration [14/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	568	Network Adapter Configuration [14/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	569	Network Adapter Configuration [14/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	570	Network Adapter Configuration [15/19]	Caption	[00000014] Microsoft Teredo Tunneling Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	571	Network Adapter Configuration [15/19]	InterfaceIndex	6	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	572	Network Adapter Configuration [15/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	573	Network Adapter Configuration [15/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	574	Network Adapter Configuration [15/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	575	Network Adapter Configuration [15/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	576	Network Adapter Configuration [15/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	577	Network Adapter Configuration [15/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	578	Network Adapter Configuration [15/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	579	Network Adapter Configuration [15/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	580	Network Adapter Configuration [15/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	581	Network Adapter Configuration [15/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	582	Network Adapter Configuration [15/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	583	Network Adapter Configuration [16/19]	Caption	[00000015] Microsoft Wi-Fi Direct Virtual Adapter	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	584	Network Adapter Configuration [16/19]	InterfaceIndex	11	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	585	Network Adapter Configuration [16/19]	MACAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	586	Network Adapter Configuration [16/19]	IPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	587	Network Adapter Configuration [16/19]	IPAddress	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	588	Network Adapter Configuration [16/19]	IPSubnet	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	589	Network Adapter Configuration [16/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	590	Network Adapter Configuration [16/19]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	591	Network Adapter Configuration [16/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	592	Network Adapter Configuration [16/19]	DNSHostName	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	593	Network Adapter Configuration [16/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	594	Network Adapter Configuration [16/19]	DNSDomainSuffixSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	595	Network Adapter Configuration [16/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	596	Network Adapter Configuration [17/19]	Caption	[00000016] Cisco AnyConnect Secure Mobility Client Virtual Miniport Adapter for Windows x64	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	597	Network Adapter Configuration [17/19]	InterfaceIndex	16	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	598	Network Adapter Configuration [17/19]	MACAddress	00:05:9A:3C:7A:00	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	599	Network Adapter Configuration [17/19]	IPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	600	Network Adapter Configuration [17/19]	IPAddress	192.168.21.124	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	601	Network Adapter Configuration [17/19]	IPAddress	fe80::ecc0:80e6:26a:112b	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[1]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	602	Network Adapter Configuration [17/19]	IPAddress	fe80::d050:8089:636e:2335	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[2]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	603	Network Adapter Configuration [17/19]	IPSubnet	255.255.255.0	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	604	Network Adapter Configuration [17/19]	IPSubnet	64	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[1]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	605	Network Adapter Configuration [17/19]	IPSubnet	64	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[2]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	606	Network Adapter Configuration [17/19]	DefaultIPGateway	::	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	607	Network Adapter Configuration [17/19]	DHCPEnabled	False	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	608	Network Adapter Configuration [17/19]	DHCPServer	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	609	Network Adapter Configuration [17/19]	DNSHostName	OSSI-DNovak	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	610	Network Adapter Configuration [17/19]	DNSDomain	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	611	Network Adapter Configuration [17/19]	DNSDomainSuffixSearchOrder	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	612	Network Adapter Configuration [17/19]	DNSDomainSuffixSearchOrder	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder[1]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	613	Network Adapter Configuration [17/19]	DNSServerSearchOrder	192.168.20.5	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	614	Network Adapter Configuration [18/19]	Caption	[00000017] VMware Virtual Ethernet Adapter for VMnet1	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	615	Network Adapter Configuration [18/19]	InterfaceIndex	9	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	616	Network Adapter Configuration [18/19]	MACAddress	00:50:56:C0:00:01	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	617	Network Adapter Configuration [18/19]	IPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	618	Network Adapter Configuration [18/19]	IPAddress	192.168.80.1	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	619	Network Adapter Configuration [18/19]	IPAddress	fe80::9480:d7fb:babf:e00a	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[1]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	620	Network Adapter Configuration [18/19]	IPSubnet	255.255.255.0	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	621	Network Adapter Configuration [18/19]	IPSubnet	64	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[1]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	622	Network Adapter Configuration [18/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	623	Network Adapter Configuration [18/19]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	624	Network Adapter Configuration [18/19]	DHCPServer	192.168.80.254	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	625	Network Adapter Configuration [18/19]	DNSHostName	OSSI-DNovak	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	626	Network Adapter Configuration [18/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
6918d2bd-0be4-41bc-8a85-80844875385f	677	Installed Programs	Adobe Photoshop CS2	9.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{236BB7C4-4419-42FD-0409-1E257A25E34D}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	678	Installed Programs	Adobe Refresh Manager	1.8.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{AC76BA86-0804-1033-1959-001824265200}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	679	Installed Programs	Adobe Stock Photos 1.0	001.000.000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{786C5747-1033-0000-B58E-000000000001}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	627	Network Adapter Configuration [18/19]	DNSDomainSuffixSearchOrder	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	628	Network Adapter Configuration [18/19]	DNSDomainSuffixSearchOrder	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder[1]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	629	Network Adapter Configuration [18/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	630	Network Adapter Configuration [19/19]	Caption	[00000018] VMware Virtual Ethernet Adapter for VMnet8	CIM:String	WMI:CIM_Setting.Caption	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	631	Network Adapter Configuration [19/19]	InterfaceIndex	14	CIM:UInt32	WMI:Win32_NetworkAdapterConfiguration.InterfaceIndex	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	632	Network Adapter Configuration [19/19]	MACAddress	00:50:56:C0:00:08	CIM:String	WMI:Win32_NetworkAdapterConfiguration.MACAddress	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	633	Network Adapter Configuration [19/19]	IPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.IPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	634	Network Adapter Configuration [19/19]	IPAddress	192.168.169.1	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	635	Network Adapter Configuration [19/19]	IPAddress	fe80::7491:e9ca:9a19:ba8	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPAddress[1]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	636	Network Adapter Configuration [19/19]	IPSubnet	255.255.255.0	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	637	Network Adapter Configuration [19/19]	IPSubnet	64	CIM:String	WMI:Win32_NetworkAdapterConfiguration.IPSubnet[1]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	638	Network Adapter Configuration [19/19]	DefaultIPGateway	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DefaultIPGateway	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	639	Network Adapter Configuration [19/19]	DHCPEnabled	True	CIM:Boolean	WMI:Win32_NetworkAdapterConfiguration.DHCPEnabled	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	640	Network Adapter Configuration [19/19]	DHCPServer	192.168.169.254	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DHCPServer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	641	Network Adapter Configuration [19/19]	DNSHostName	OSSI-DNovak	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	642	Network Adapter Configuration [19/19]	DNSDomain	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	643	Network Adapter Configuration [19/19]	DNSDomainSuffixSearchOrder	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder[0]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	644	Network Adapter Configuration [19/19]	DNSDomainSuffixSearchOrder	intelli-site.com	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSDomainSuffixSearchOrder[1]	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	645	Network Adapter Configuration [19/19]	DNSServerSearchOrder	\N	CIM:String	WMI:Win32_NetworkAdapterConfiguration.DNSServerSearchOrder	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	646	Video Adapter [1/2]	Description	Intel(R) HD Graphics 530	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	647	Video Adapter [1/2]	AdapterRAM	1024 MB	toMegaBytes(CIM:UInt32)	WMI:Win32_VideoController.AdapterRAM	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	648	Video Adapter [1/2]	VideoMemoryType	2	CIM:UInt16	WMI:CIM_VideoController.VideoMemoryType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	649	Video Adapter [1/2]	VideoModeDescription	1920 x 1080 x 4294967296 colors	CIM:String	WMI:Win32_VideoController.VideoModeDescription	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	650	Video Adapter [1/2]	VideoProcessor	Intel(R) HD Graphics Family	CIM:String	WMI:CIM_VideoController.VideoProcessor	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	651	Video Adapter [1/2]	CurrentBitsPerPixel	32	CIM:UInt32	WMI:CIM_VideoController.CurrentBitsPerPixel	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	652	Video Adapter [1/2]	CurrentHorizontalResolution	1920	CIM:UInt32	WMI:CIM_VideoController.CurrentHorizontalResolution	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	653	Video Adapter [1/2]	CurrentVerticalResolution	1080	CIM:UInt32	WMI:CIM_VideoController.CurrentVerticalResolution	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	654	Video Adapter [1/2]	CurrentRefreshRate	60	CIM:UInt32	WMI:CIM_VideoController.CurrentRefreshRate	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	655	Video Adapter [1/2]	InstalledDisplayDrivers	C:\\Windows\\System32\\DriverStore\\FileRepository\\ki125175.inf_amd64_4d74412f913cd0aa\\igdumdim64.dll,C:\\Windows\\System32\\DriverStore\\FileRepository\\ki125175.inf_amd64_4d74412f913cd0aa\\igd10iumd64.dll,C:\\Windows\\System32\\DriverStore\\FileRepository\\ki125175.inf_amd64_4d74412f913cd0aa\\igd10iumd64.dll,C:\\Windows\\System32\\DriverStore\\FileRepository\\ki125175.inf_amd64_4d74412f913cd0aa\\igd12umd64.dll	CIM:String	WMI:Win32_VideoController.InstalledDisplayDrivers	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	656	Video Adapter [1/2]	DriverVersion	22.20.16.4836	CIM:String	WMI:Win32_VideoController.DriverVersion	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	657	Video Adapter [1/2]	DriverDate	20171017000000.000000-000	CIM:DateTime	WMI:Win32_VideoController.DriverDate	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	658	Video Adapter [1/2]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	659	Video Adapter [1/2]	PNPDeviceID	PCI\\VEN_8086&DEV_191B&SUBSYS_06D91028&REV_06\\3&11583659&0&10	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	660	Video Adapter [1/2]	DeviceID	VideoController1	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	661	Video Adapter [1/2]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	662	Video Adapter [2/2]	Description	AMD FirePro W5170M	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	663	Video Adapter [2/2]	AdapterRAM	2048 MB	toMegaBytes(CIM:UInt32)	WMI:Win32_VideoController.AdapterRAM	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	664	Video Adapter [2/2]	VideoMemoryType	2	CIM:UInt16	WMI:CIM_VideoController.VideoMemoryType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	665	Video Adapter [2/2]	VideoModeDescription	1024 x 768 x 4294967296 colors	CIM:String	WMI:Win32_VideoController.VideoModeDescription	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	666	Video Adapter [2/2]	VideoProcessor	AMD FirePro SDI (0x6820)	CIM:String	WMI:CIM_VideoController.VideoProcessor	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	667	Video Adapter [2/2]	CurrentBitsPerPixel	32	CIM:UInt32	WMI:CIM_VideoController.CurrentBitsPerPixel	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	668	Video Adapter [2/2]	CurrentHorizontalResolution	1024	CIM:UInt32	WMI:CIM_VideoController.CurrentHorizontalResolution	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	669	Video Adapter [2/2]	CurrentVerticalResolution	768	CIM:UInt32	WMI:CIM_VideoController.CurrentVerticalResolution	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	670	Video Adapter [2/2]	CurrentRefreshRate	60	CIM:UInt32	WMI:CIM_VideoController.CurrentRefreshRate	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	671	Video Adapter [2/2]	InstalledDisplayDrivers	C:\\Windows\\System32\\DriverStore\\FileRepository\\c0308392.inf_amd64_bcaeacb8aa4bb9e8\\aticfx64.dll,C:\\Windows\\System32\\DriverStore\\FileRepository\\c0308392.inf_amd64_bcaeacb8aa4bb9e8\\aticfx64.dll,C:\\Windows\\System32\\DriverStore\\FileRepository\\c0308392.inf_amd64_bcaeacb8aa4bb9e8\\aticfx64.dll,C:\\Windows\\System32\\DriverStore\\FileRepository\\c0308392.inf_amd64_bcaeacb8aa4bb9e8\\amdxc64.dll	CIM:String	WMI:Win32_VideoController.InstalledDisplayDrivers	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	672	Video Adapter [2/2]	DriverVersion	21.19.154.768	CIM:String	WMI:Win32_VideoController.DriverVersion	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	673	Video Adapter [2/2]	DriverDate	20161026000000.000000-000	CIM:DateTime	WMI:Win32_VideoController.DriverDate	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	674	Video Adapter [2/2]	Availability	3	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	675	Video Adapter [2/2]	PNPDeviceID	PCI\\VEN_1002&DEV_6820&SUBSYS_06D91028&REV_83\\4&3062E079&0&0008	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	676	Video Adapter [2/2]	DeviceID	VideoController2	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	677	Video Adapter [2/2]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	678	Sound Device [1/2]	Description	Realtek Audio	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	679	Sound Device [1/2]	Manufacturer	Realtek	CIM:String	WMI:Win32_SoundDevice.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	680	Sound Device [1/2]	ProductName	Realtek Audio	CIM:String	WMI:Win32_SoundDevice.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	681	Sound Device [1/2]	Availability	\N	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	682	Sound Device [1/2]	PNPDeviceID	HDAUDIO\\FUNC_01&VEN_10EC&DEV_0293&SUBSYS_102806D9&REV_1000\\4&39F3B2C8&0&0001	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	683	Sound Device [1/2]	DeviceID	HDAUDIO\\FUNC_01&VEN_10EC&DEV_0293&SUBSYS_102806D9&REV_1000\\4&39F3B2C8&0&0001	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	684	Sound Device [1/2]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	685	Sound Device [2/2]	Description	Intel(R) Display Audio	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	686	Sound Device [2/2]	Manufacturer	Intel(R) Corporation	CIM:String	WMI:Win32_SoundDevice.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	687	Sound Device [2/2]	ProductName	Intel(R) Display Audio	CIM:String	WMI:Win32_SoundDevice.ProductName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	688	Sound Device [2/2]	Availability	\N	CIM:UInt16	WMI:CIM_LogicalDevice.Availability	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	689	Sound Device [2/2]	PNPDeviceID	HDAUDIO\\FUNC_01&VEN_8086&DEV_2809&SUBSYS_80860101&REV_1000\\4&39F3B2C8&0&0201	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	690	Sound Device [2/2]	DeviceID	HDAUDIO\\FUNC_01&VEN_8086&DEV_2809&SUBSYS_80860101&REV_1000\\4&39F3B2C8&0&0201	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	691	Sound Device [2/2]	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	692	Disk Drive	Description	Disk drive	CIM:String	WMI:CIM_ManagedSystemElement.Description	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	693	Disk Drive	Manufacturer	(Standard disk drives)	CIM:String	WMI:Win32_DiskDrive.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	694	Disk Drive	Model	THNSN5512GPU7 NVMe TOSHIBA 512GB	CIM:String	WMI:Win32_DiskDrive.Model	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	695	Disk Drive	FirmwareRevision	57DC4102	CIM:String	WMI:Win32_DiskDrive.FirmwareRevision	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	696	Disk Drive	InterfaceType	SCSI	CIM:String	WMI:Win32_DiskDrive.InterfaceType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	697	Disk Drive	MediaType	Fixed hard disk media	CIM:String	WMI:Win32_DiskDrive.MediaType	\N
6918d2bd-0be4-41bc-8a85-80844875385f	680	Installed Programs	Agatha Christie - Peril at End House	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT089362	\N
6918d2bd-0be4-41bc-8a85-80844875385f	681	Installed Programs	AMD APP SDK Runtime	2.5.793.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{503F672D-6C84-448A-8F8F-4BC35AC83441}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	682	Installed Programs	AMD Media Foundation Decoders	1.0.61013.1636	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3D2D0DB9-5199-4A77-B6D3-646693FAE63C}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	683	Installed Programs	Apple Application Support (32-bit)	6.3	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D4C80B0C-CF67-43A7-90C3-466853543B54}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	684	Installed Programs	Apple Application Support (64-bit)	6.3	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B2A2E8AF-BC48-4191-B2C4-3846A19835CA}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	698	Disk Drive	Size	0.51 TB (0.47 TiB)	toStorageBytes(CIM:UInt64)	WMI:Win32_DiskDrive.Size	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	699	Disk Drive	Partitions	3	CIM:UInt32	WMI:Win32_DiskDrive.Partitions	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	700	Disk Drive	PNPDeviceID	SCSI\\DISK&VEN_NVME&PROD_THNSN5512GPU7_NV\\4&38D6DE9&0&010000	CIM:String	WMI:CIM_LogicalDevice.PNPDeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	701	Disk Drive	DeviceID	\\\\.\\PHYSICALDRIVE0	CIM:String	WMI:CIM_LogicalDevice.DeviceID	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	702	Disk Drive	ConfigManagerErrorCode	0	CIM:UInt32	WMI:CIM_LogicalDevice.ConfigManagerErrorCode	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	703	Installed Programs	7-Zip 16.04 (x64)	16.04	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\7-Zip	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	704	Installed Programs	A360 Desktop	8.2.3.1800	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B65CD59E-A771-4354-AA4B-C3E01B496BCD}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	705	Installed Programs	Adobe Acrobat Reader DC	18.011.20038	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{AC76BA86-7AD7-1033-7B44-AC0F074E4100}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	706	Installed Programs	Adobe Bridge CC 2018	8.0.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\KBRG_8_0_1	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	707	Installed Programs	Adobe Creative Cloud	4.4.1.298	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Adobe Creative Cloud	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	708	Installed Programs	Adobe Illustrator CC 2018	22.0.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\ILST_22_0_1	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	709	Installed Programs	Adobe InDesign CC 2018	13.0.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\IDSN_13_0_1	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	710	Installed Programs	Adobe Photoshop CC 2018	19.0.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\PHSP_19_0_1	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	711	Installed Programs	Adobe Refresh Manager	1.8.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{AC76BA86-0804-1033-1959-001824265200}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	712	Installed Programs	AMD Install Manager	9.0.000.4	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\AMD Catalyst Install Manager	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	713	Installed Programs	AMD Install Manager	9.0.000.4	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{DF7CFEF3-5F05-AB56-E931-0FFACFC3DF35}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	714	Installed Programs	AMD Radeon Pro and AMD FirePro Settings	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6A2F70B5-9EA9-70EF-3BD6-4E53E7C87F68}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	715	Installed Programs	AMD Settings	2016.1026.404.5510	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{BA99E23E-C8CB-3391-98EA-677FF43162C3}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	716	Installed Programs	AMD Settings - Branding	1.00.0000	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{78ACE60E-0CB7-4935-BCD4-F33422105607}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	717	Installed Programs	Asmedia USB Host Controller Driver	1.16.49.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E4FB0B39-C991-4EE7-95DD-1A1A7857D33D}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	718	Installed Programs	AutoCAD LT 2018 - English	22.0.49.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{28B89EEF-1009-0000-0102-CF3F3A09B77D}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	719	Installed Programs	AutoCAD LT 2018 - English	22.0.49.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{28B89EEF-1009-0409-2102-CF3F3A09B77D}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	720	Installed Programs	AutoCAD LT 2018 Language Pack - English	22.0.49.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{28B89EEF-1009-0409-1102-CF3F3A09B77D}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	721	Installed Programs	Autodesk Advanced Material Library Image Library 2018	16.11.1.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{177AD7F6-9C77-4E50-BA53-B7259C5F282D}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	722	Installed Programs	Autodesk AutoCAD LT 2018 - English	22.0.49.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\AutoCAD LT 2018 - English	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	723	Installed Programs	Autodesk Desktop App	7.0.7.232	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Autodesk Desktop App	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	724	Installed Programs	Autodesk License Service (x64) - 5.1.4	5.1.4.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3609A8D9-FC0C-4C9B-9F58-0B1D1A4FE556}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	725	Installed Programs	Autodesk Material Library 2018	16.11.1.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7847611E-92E9-4917-B395-71C91D523104}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	726	Installed Programs	Autodesk Material Library Base Resolution Image Library 2018	16.11.1.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{FCDED119-A969-4E48-8A32-D21AD6B03253}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	727	Installed Programs	Catalyst Control Center Next Localization BR	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{8198911E-61B6-5269-900A-8835A1DB745C}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	728	Installed Programs	Catalyst Control Center Next Localization CHS	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3228102A-A1BC-B292-813A-3D8525C0EBBE}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	729	Installed Programs	Catalyst Control Center Next Localization CHT	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{FD9717CA-77A2-3C16-2799-2E821A90CF85}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	730	Installed Programs	Catalyst Control Center Next Localization CS	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A19DDC9C-DCC8-56E2-A118-E9B1BE3697A0}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	731	Installed Programs	Catalyst Control Center Next Localization DA	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{40C9B535-4197-FB0D-B167-3294734C9B39}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	732	Installed Programs	Catalyst Control Center Next Localization DE	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C840CAF7-42F8-C474-3354-804013E79D69}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	733	Installed Programs	Catalyst Control Center Next Localization EL	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C806EF06-DA5D-7E3E-1469-64D44A04A434}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	734	Installed Programs	Catalyst Control Center Next Localization ES	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D7A53E33-3755-D0BB-80A3-FB4E3169B489}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	735	Installed Programs	Catalyst Control Center Next Localization FI	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F40C52DB-FEA5-503F-DA04-58F784BC2837}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	736	Installed Programs	Catalyst Control Center Next Localization FR	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3E8846D9-CB92-6BC7-D010-64EBAB024121}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	737	Installed Programs	Catalyst Control Center Next Localization HU	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{679C5976-0CFD-EC79-E2D7-63DFCF7A4E42}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	685	Installed Programs	Apple Mobile Device Support	11.0.5.14	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{AA7D90D2-2387-4FA5-A3AF-96811BE49BFD}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	738	Installed Programs	Catalyst Control Center Next Localization IT	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{91B18C11-8470-81DF-07B1-919DB4D0D27E}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	739	Installed Programs	Catalyst Control Center Next Localization JA	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E7AE8A79-2357-0198-00DC-81B4A7466E4B}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	740	Installed Programs	Catalyst Control Center Next Localization KO	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CEEA750F-C747-1B3F-93E5-DD248E6E4AC0}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	741	Installed Programs	Catalyst Control Center Next Localization NL	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E8F66119-B17F-C43D-4908-AFCA24B66F08}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	742	Installed Programs	Catalyst Control Center Next Localization NO	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{70653054-8D22-1D7F-A059-15A549E320BD}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	743	Installed Programs	Catalyst Control Center Next Localization PL	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{FDE07145-B01B-4C13-12DF-EAFE5F1E7AA8}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	744	Installed Programs	Catalyst Control Center Next Localization RU	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{94B5DC1E-DCD0-A1CD-7F6D-4147F10EC337}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	745	Installed Programs	Catalyst Control Center Next Localization SV	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{711F94EC-F1A4-AE21-D715-F700C2203F0F}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	746	Installed Programs	Catalyst Control Center Next Localization TH	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{8FA6BE00-0F49-86E0-EF4E-0C8DC0D702E3}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	747	Installed Programs	Catalyst Control Center Next Localization TR	2016.1026.404.5510	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{0E137770-540F-B927-7DA7-D50A3027D497}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	748	Installed Programs	Cisco AnyConnect Secure Mobility Client	4.2.03013	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{69ABC61D-AE14-4833-A598-E2852A1AAA8A}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	749	Installed Programs	Cisco AnyConnect Secure Mobility Client	4.2.03013	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Cisco AnyConnect Secure Mobility Client	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	750	Installed Programs	Dell ControlVault Host Components Installer 64 bit	4.7.26.65	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{54874EC0-CEC5-4BD0-A442-9332BBA7AF89}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	751	Installed Programs	Dell Touchpad	10.2207.101.108	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{9F72EF8B-AEC9-4CA5-B483-143980AFD6FD}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	752	Installed Programs	Dell WLAN Radio Switch Driver	1.0.0.9	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A084898A-E69D-453F-ABE9-A7A075A4B261}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	753	Installed Programs	ESET Security	11.0.159.5	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3EB22EED-2263-4174-9F36-09BD15A7AEF8}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	754	Installed Programs	Google Chrome	64.0.3282.186	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Google Chrome	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	755	Installed Programs	Google Update Helper	1.3.33.7	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{60EC980A-BDA2-4CB6-A427-B07A5498B4CA}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	756	Installed Programs	GoTo Opener	1.0.473	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1F803452-798F-49FB-A5DD-9F527F7017E4}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	757	Installed Programs	Intel(R) Chipset Device Software	10.1.1.9	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{55398EAC-F58E-4F19-B553-BDF8B9EFD839}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	758	Installed Programs	Intel(R) Chipset Device Software	10.1.1.9	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{c7f54569-0018-439c-809a-48046a4d4ebc}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	759	Installed Programs	Intel(R) Dynamic Platform and Thermal Framework	8.2.10900.330	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{654EE65D-FAA4-4EA6-8C07-DC94E6A304D4}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	760	Installed Programs	Intel(R) Management Engine Components	11.0.0.1167	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1CEAC85D-2590-4760-800F-8DE5E91F3700}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	686	Installed Programs	Apple Software Update	2.5.0.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{19589375-5C58-4AFA-842F-8B34744CCEAD}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	687	Installed Programs	ArcSoft TotalMedia	2.0.39.12	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\ArcSoft TotalMedia	\N
6918d2bd-0be4-41bc-8a85-80844875385f	688	Installed Programs	ArcSoft TotalMedia	1.0.48.25	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4114A073-7385-4742-8A5E-A5788FAC838F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	689	Installed Programs	ArcSoft Webcam Sharing Manager	2.0.0.30	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{190A7D93-3823-439C-91B9-ADCE3EC2A6A2}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	690	Installed Programs	Atheros Driver Installation Program	9.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C3A32068-8AB1-4327-BB16-BED9C6219DC7}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	691	Installed Programs	AutoCAD LT 2016 - English	20.1.49.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5783F2D7-F009-0000-0102-0060B0CE6BBA}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	761	Installed Programs	Intel(R) Management Engine Components	11.0.0.1167	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{24962326-A318-4620-85A7-F91DD6DBF5C4}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	762	Installed Programs	Intel(R) Management Engine Components	1.0.0.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92979371-FDF4-45F8-8245-28560F71EC17}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	763	Installed Programs	Intel(R) Management Engine Components	1.0.0.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1F26F2D5-8DD0-4C68-A1E8-D7B423EC8B7C}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	764	Installed Programs	Intel(R) ME UninstallLegacy	1.0.1.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{DC051DD8-4EFB-4414-8721-4D45B448D1BE}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	765	Installed Programs	Intel(R) Network Connections 22.3.108.0	22.3.108.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1BF1F291-FDA4-404E-994E-AD711C689CFC}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	766	Installed Programs	Intel(R) Network Connections 22.3.108.0	22.3.108.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\PROSetDX	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	767	Installed Programs	Intel(R) Processor Graphics	22.20.16.4836	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F0E3AD40-2BBD-4360-9C76-B9AC9A5886EA}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	768	Installed Programs	Intel(R) Rapid Storage Technology	15.7.5.1025	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{409CB30E-E457-4008-9B1A-ED1B9EA21140}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	769	Installed Programs	Intel(R) Rapid Storage Technology	15.7.5.1025	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{69A3A70F-818A-47ED-8226-583A839DF7F9}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	770	Installed Programs	Intel® Security Assist	1.0.0.532	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4B230374-6475-4A73-BA6E-41015E9C5013}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	771	Installed Programs	Intel® Trusted Connect Service Client	1.42.17.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7D84E343-A23D-451C-B123-0195B2D903A6}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	772	Installed Programs	Intelli-Site	4.0.30.16	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A7FAAD35-A654-41A2-B2A8-14A8AF86FFF0}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	773	Installed Programs	Intelli-Site	4.0.30.16	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\InstallShield_{A7FAAD35-A654-41A2-B2A8-14A8AF86FFF0}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	774	Installed Programs	LinkPoint for Salesforce	5.00.0000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{DECDCD14-DEF6-49ED-9440-CC5E562FDC41}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	775	Installed Programs	Maxx Audio Installer (x64)	2.6.8627.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{307032B2-6AF2-46D7-B933-62438DEB2B9A}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	776	Installed Programs	Microsoft Office Home and Business 2016 - en-us	16.0.9029.2167	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\HomeBusinessRetail - en-us	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	777	Installed Programs	Microsoft Visual C++ 2005 Redistributable	8.0.56336	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7299052b-02a4-4627-81f2-1818da5d550d}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	778	Installed Programs	Microsoft Visual C++ 2005 Redistributable (x64)	8.0.56336	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{071c9b48-7c32-4621-a0ac-3f809523288f}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	779	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x64 9.0.30729.17	9.0.30729	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{8220EEFE-38CD-377E-8595-13398D740ACE}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	780	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x64 9.0.30729.4148	9.0.30729.4148	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4B6C7001-C7D6-3710-913E-5BC23FCE91E6}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	781	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x86 9.0.30729.17	9.0.30729	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{9A25302D-30C0-39D9-BD6F-21E6EC160475}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	782	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x86 9.0.30729.4148	9.0.30729.4148	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1F1C2DFC-2D24-3E06-BCB8-725134ADF989}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	783	Installed Programs	Microsoft Visual C++ 2010  x64 Redistributable - 10.0.40219	10.0.40219	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1D8E6291-B0D5-35EC-8441-6616F567A0F7}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	784	Installed Programs	Microsoft Visual C++ 2010  x86 Redistributable - 10.0.40219	10.0.40219	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F0C3E5D1-1ADE-321E-8167-68EF0DE699A5}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	785	Installed Programs	Microsoft Visual C++ 2012 Redistributable (x64) - 11.0.61030	11.0.61030.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{ca67548a-5ebe-413a-b50c-4b9ceb6d66c6}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	692	Installed Programs	AutoCAD LT 2016 - English	20.1.49.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5783F2D7-F009-0409-2102-0060B0CE6BBA}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	693	Installed Programs	AutoCAD LT 2016 Language Pack - English	20.1.49.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5783F2D7-F009-0409-1102-0060B0CE6BBA}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	911	Installed Programs	OSSI	1.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{45024190-9404-44EA-BD4A-A06AA29D52E8}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	786	Installed Programs	Microsoft Visual C++ 2012 Redistributable (x86) - 11.0.60610	11.0.60610.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{95716cce-fc71-413f-8ad5-56c2892d4b3a}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	787	Installed Programs	Microsoft Visual C++ 2012 Redistributable (x86) - 11.0.61030	11.0.61030.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{33d1fd90-4274-48a1-9bc1-97e33d9c2d6f}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	788	Installed Programs	Microsoft Visual C++ 2012 x64 Additional Runtime - 11.0.61030	11.0.61030	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{37B8F9C7-03FB-3253-8781-2517C99D7C00}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	789	Installed Programs	Microsoft Visual C++ 2012 x64 Minimum Runtime - 11.0.61030	11.0.61030	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CF2BEA3C-26EA-32F8-AA9B-331F7E34BA97}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	790	Installed Programs	Microsoft Visual C++ 2012 x86 Additional Runtime - 11.0.61030	11.0.61030	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B175520C-86A2-35A7-8619-86DC379688B9}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	791	Installed Programs	Microsoft Visual C++ 2012 x86 Minimum Runtime - 11.0.61030	11.0.61030	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{BD95A8CD-1D9F-35AD-981A-3E7925026EBB}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	792	Installed Programs	Microsoft Visual C++ 2013 Redistributable (x64) - 12.0.30501	12.0.30501.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{050d4fc8-5d48-4b8f-8972-47c82c46020f}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	694	Installed Programs	Autodesk Advanced Material Library Image Library 2016	6.3.0.15	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{94AD53E7-493B-4291-8714-7A3B761D2783}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	695	Installed Programs	Autodesk AutoCAD LT 2016 - English	20.1.49.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\AutoCAD LT 2016 - English	\N
6918d2bd-0be4-41bc-8a85-80844875385f	696	Installed Programs	Autodesk Content Service	3.2.0.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A37CDB58-AAE8-0000-8C13-E0F7BACB0D5F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	697	Installed Programs	Autodesk Content Service	3.2.0.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Autodesk Content Service	\N
6918d2bd-0be4-41bc-8a85-80844875385f	698	Installed Programs	Autodesk Content Service Language Pack	3.2.0.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A37CDB58-AAE8-0001-8C13-E0F7BACB0D5F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	699	Installed Programs	Autodesk Desktop App	6.0.108.150	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Autodesk Desktop App	\N
6918d2bd-0be4-41bc-8a85-80844875385f	700	Installed Programs	Autodesk Download Manager	4.0.14.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{EC92633C-8F08-470A-BCDF-3FE5FD778C8D}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	701	Installed Programs	Autodesk DWG TrueView 2016 - English	20.1.107.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\DWG TrueView 2016 - English	\N
6918d2bd-0be4-41bc-8a85-80844875385f	702	Installed Programs	Autodesk Material Library 2016	6.3.0.15	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{29A7D6EC-63C2-42FD-8143-5812ABD2923F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	703	Installed Programs	Autodesk Material Library Base Resolution Image Library 2016	6.3.0.15	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6B4CFC6E-ECB0-47FE-95D3-65C680ED0687}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	704	Installed Programs	Avery Design & Print	3.0.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Avery Design & Print 3.0.2	\N
6918d2bd-0be4-41bc-8a85-80844875385f	705	Installed Programs	AXIS Media Control 6.00 Redist	6.00	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\AXIS Media Control SDK_is1	\N
6918d2bd-0be4-41bc-8a85-80844875385f	706	Installed Programs	Bejeweled 2 Deluxe	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087428	\N
6918d2bd-0be4-41bc-8a85-80844875385f	707	Installed Programs	Blasterball 3	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT089308	\N
6918d2bd-0be4-41bc-8a85-80844875385f	708	Installed Programs	Bluetooth Win7 Suite (64)	7.02.000.55	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{230D1595-57DA-4933-8C4E-375797EBB7E1}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	709	Installed Programs	Bonjour	3.1.0.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{56DDDFB8-7F79-4480-89D5-25E1F52AB28F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	710	Installed Programs	Bounce Symphony	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087330	\N
6918d2bd-0be4-41bc-8a85-80844875385f	711	Installed Programs	Brother HL-5250DN	1.00	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{894F571B-3B34-4659-8E57-0B1B2F2F44BB}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	712	Installed Programs	Brother MFL-Pro Suite MFC-7860DW	1.1.3.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3ACCCFB3-7B17-4E9F-ACB0-46868FCD4487}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	713	Installed Programs	Build-a-Lot - The Elizabethan Era	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT089303	\N
6918d2bd-0be4-41bc-8a85-80844875385f	714	Installed Programs	Cake Mania	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT089359	\N
6918d2bd-0be4-41bc-8a85-80844875385f	715	Installed Programs	Catalyst Control Center	2011.1013.1702.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3A53DC94-79F4-2141-772A-569A7FCD38A9}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	716	Installed Programs	Catalyst Control Center - Branding	1.00.0000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C33240AB-1F4B-4DE2-B1C7-54E0A182BB5D}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	717	Installed Programs	Catalyst Control Center Graphics Previews Common	2011.1013.1702.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{2396EE07-88BE-67F0-229D-E46088C86AC1}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	718	Installed Programs	Catalyst Control Center InstallProxy	2011.1013.1702.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{99BBECCE-5865-B26C-912A-0B339081F799}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	719	Installed Programs	Catalyst Control Center Localization All	2011.1013.1702.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B975C052-531D-97C0-AB47-EB6BA7620887}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	720	Installed Programs	Catalyst Control Center Profiles Mobile	2011.1013.1702.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{501B8F04-368E-A540-2E46-19A44FDF7109}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	721	Installed Programs	CC Get MAC Address 2.3	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\CC Get MAC Address_is1	\N
6918d2bd-0be4-41bc-8a85-80844875385f	722	Installed Programs	CCC Help Chinese Standard	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{692C218E-34B2-1D36-670D-9AB3A8D107BC}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	723	Installed Programs	CCC Help Chinese Traditional	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{110A6D3A-A966-992B-173F-6D4A6A93A7F3}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	724	Installed Programs	CCC Help Czech	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7C62B5F1-938A-50F9-78AF-4143E9604507}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	725	Installed Programs	CCC Help Danish	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5DF24781-FA89-2E36-3FDE-D3974BCB5675}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	726	Installed Programs	CCC Help Dutch	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{EAD66E57-B386-DB10-29F9-A5A75BC60952}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	727	Installed Programs	CCC Help English	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{670B9685-76B4-0E94-99F8-92FCBFAF3547}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	728	Installed Programs	CCC Help Finnish	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{48B40F85-4F69-456F-82EB-E3DCCA15E9F0}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	729	Installed Programs	CCC Help French	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C7DF9961-9EB4-B130-D201-BE71591673F9}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	730	Installed Programs	CCC Help German	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B78F6C6D-3EFB-B64D-FE49-C6318FDD116E}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	731	Installed Programs	CCC Help Greek	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B1525FFC-6691-BCC7-CBFF-CDCF47BC606C}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	732	Installed Programs	CCC Help Hungarian	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{96F82870-A977-2AE6-BAF0-04B143412099}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	733	Installed Programs	CCC Help Italian	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{FD53BD91-BAA5-2F85-315D-CD3816A280A6}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	734	Installed Programs	CCC Help Japanese	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3327995E-0937-0BB1-F258-711F165E096F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	735	Installed Programs	CCC Help Korean	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{638FCD4E-0EA4-4EC2-6C06-FC1A06BAB336}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	736	Installed Programs	CCC Help Norwegian	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{19D899D7-CF47-8DEC-4976-F8CB8DAD6C61}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	737	Installed Programs	CCC Help Polish	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E7EA2C61-4E65-AD62-B151-D517F37AFB80}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	738	Installed Programs	CCC Help Portuguese	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{08D02198-001C-FB17-9280-756444349E29}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	739	Installed Programs	CCC Help Russian	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B2506DF2-78E6-8C09-A40D-EA92DB0FA5F0}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	740	Installed Programs	CCC Help Spanish	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{610C146B-F818-BD30-C0F1-7D6E46EEC025}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	741	Installed Programs	CCC Help Swedish	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6A822F2F-8C69-4095-8B18-32326C49B0ED}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	742	Installed Programs	CCC Help Thai	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E328DF8F-CD40-DE5A-E9D0-4367EBA5BD25}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	743	Installed Programs	CCC Help Turkish	2011.1013.1701.28713	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B6B16F49-0533-8772-7C20-09C241847185}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	744	Installed Programs	ccc-utility64	2011.1013.1702.28713	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{2C233758-BD55-8F3F-4BBE-0A11B833CB96}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	745	Installed Programs	Chuzzle Deluxe	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087453	\N
6918d2bd-0be4-41bc-8a85-80844875385f	746	Installed Programs	Cisco AnyConnect Secure Mobility Client	4.2.03013	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Cisco AnyConnect Secure Mobility Client	\N
6918d2bd-0be4-41bc-8a85-80844875385f	747	Installed Programs	Cisco AnyConnect Secure Mobility Client	4.2.03013	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{69ABC61D-AE14-4833-A598-E2852A1AAA8A}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	748	Installed Programs	Cisco Connect	1.4.11299.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Cisco Connect	\N
6918d2bd-0be4-41bc-8a85-80844875385f	749	Installed Programs	Cisco EAP-FAST Module	2.2.14	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{64BF0187-F3D2-498B-99EA-163AF9AE6EC9}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	750	Installed Programs	Cisco LEAP Module	1.0.19	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{51C7AD07-C3F6-4635-8E8A-231306D810FE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	751	Installed Programs	Cisco PEAP Module	1.1.6	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{ED5776D5-59B4-46B7-AF81-5F2D94D7C640}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	752	Installed Programs	Cisco WebEx Meetings	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\ActiveTouchMeetingClient	\N
6918d2bd-0be4-41bc-8a85-80844875385f	753	Installed Programs	Citrix Online Launcher	1.0.335	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{DB014C85-A264-4BCA-A66F-6DD1FCF8EC36}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	754	Installed Programs	CodeMeter Runtime Kit v6.40	6.40.2396.500	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F6DA1584-1044-466A-BB16-828F30CA8C85}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	755	Installed Programs	ComponentSoftware Revision Control System (CS-RCS)	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\CS-RCS	\N
6918d2bd-0be4-41bc-8a85-80844875385f	756	Installed Programs	Cross Match Technologies L SCAN Essentials (x64) Runtime 6.6.5.0	6.6.5.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{EDE7514E-C390-4CCC-83C0-61EACE19A136}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	757	Installed Programs	Crystal Reports Viewer 2011 SP2	14.0.2.364	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D1ED9B6B-2804-4708-9F8E-D494A3D54288}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	758	Installed Programs	crystalreports.designers.java.documentation.viewer-4.0-en-32	14.0.2.364	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{822F8085-B67C-4C80-B8B4-E024B177516B}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	759	Installed Programs	crystalreports.designers.java.javaviewer-4.0-core-32	14.0.2.364	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{61220D25-5D7E-4C95-935D-249501E71B19}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	760	Installed Programs	crystalreports.designers.java.javaviewer-4.0-en-32	14.0.1.287	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7E9A9833-DD3E-4AED-B49E-26CBDDF58864}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	761	Installed Programs	crystalreports.designers.java.launcher-4.0-core-32	14.0.0.760	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E620C02B-9597-4391-9493-6316F8FD68A2}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	762	Installed Programs	CutePDF Writer 2.7	\N	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\CutePDF Writer Installation	\N
6918d2bd-0be4-41bc-8a85-80844875385f	763	Installed Programs	D3DX10	15.4.2368.0902	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E09C4DB7-630C-4F06-A631-8EA7239923AF}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	764	Installed Programs	Definition Update for Microsoft Office 2010 (KB3115321) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{0ED568CA-DDB4-4F60-81A8-FA0595BC6B97}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	765	Installed Programs	Diner Dash 2 Restaurant Rescue	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087536	\N
6918d2bd-0be4-41bc-8a85-80844875385f	766	Installed Programs	Dropbox	44.4.58	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Dropbox	\N
6918d2bd-0be4-41bc-8a85-80844875385f	767	Installed Programs	Dropbox Update Helper	1.3.65.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{099218A5-A723-43DC-8DB5-6173656A1E94}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	768	Installed Programs	DW Spectrum Bundle	3.1.0.16975	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7e4985c5-ff3c-4315-8b58-737f0311c603}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	769	Installed Programs	DW Spectrum Client	3.1.0.16975	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{47D0F46F-EDC9-4009-8B4B-3313F68D219B}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	770	Installed Programs	DW Spectrum Server	3.1.0.16975	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{EDD7BA73-74FD-403E-A98E-679E9660433B}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	771	Installed Programs	DWG TrueView 2016 - English	20.1.107.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5783F2D7-F028-0409-0100-0060B0CE6BBA}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	772	Installed Programs	DWGSee Pro 2018	4.72	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A1E00A4C-1463-4F7D-B62C-431ADC45EB15}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	773	Installed Programs	Echelon iLON 10	2.00.28	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1D11C43D-4A24-49E2-8584-BE035A008024}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	774	Installed Programs	Echelon OpenLDV 4.0	4.00.102	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{266C3F8F-F098-4731-B82F-E2D60868ADE0}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	775	Installed Programs	Energy Star Digital Logo	1.0.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{BD1A34C9-4764-4F79-AE1F-112F8C89D3D4}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	776	Installed Programs	Farm Frenzy	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT089328	\N
6918d2bd-0be4-41bc-8a85-80844875385f	777	Installed Programs	FATE	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087361	\N
6918d2bd-0be4-41bc-8a85-80844875385f	778	Installed Programs	Galería fotográfica de Windows Live	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E85A4EFC-82F2-4CEE-8A8E-62FDAD353A66}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	779	Installed Programs	Galeria fotogràfica del Windows Live	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4736B0ED-F6A1-48EC-A1B7-C053027648F1}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	780	Installed Programs	Galerie de photos Windows Live	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{488F0347-C4A7-4374-91A7-30818BEDA710}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	781	Installed Programs	GIMP 2.8.22	2.8.22	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\GIMP-2_is1	\N
6918d2bd-0be4-41bc-8a85-80844875385f	782	Installed Programs	Google Update Helper	1.3.33.5	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{60EC980A-BDA2-4CB6-A427-B07A5498B4CA}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	783	Installed Programs	Google Update Helper	1.3.25.11	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A92DAB39-4E2C-4304-9AB6-BC44E68B55E2}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	784	Installed Programs	GoTo Opener	1.0.459	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C0A5FA19-686C-490A-91CF-513FE6832187}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	785	Installed Programs	GoToAssist Customer 4.3.0.1575	4.3.0.1575	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\GoToAssist Express Customer	\N
6918d2bd-0be4-41bc-8a85-80844875385f	786	Installed Programs	Heatsoft ADCS	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Heatsoft ADCS	\N
6918d2bd-0be4-41bc-8a85-80844875385f	787	Installed Programs	Hotfix for Microsoft Visual Studio 2007 Tools for Applications - ENU (KB946040)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4ECF4BDC-8387-329A-ABE9-CF5798F84BB2}.KB946040	\N
6918d2bd-0be4-41bc-8a85-80844875385f	788	Installed Programs	Hotfix for Microsoft Visual Studio 2007 Tools for Applications - ENU (KB946308)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4ECF4BDC-8387-329A-ABE9-CF5798F84BB2}.KB946308	\N
6918d2bd-0be4-41bc-8a85-80844875385f	789	Installed Programs	Hotfix for Microsoft Visual Studio 2007 Tools for Applications - ENU (KB946344)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4ECF4BDC-8387-329A-ABE9-CF5798F84BB2}.KB946344	\N
6918d2bd-0be4-41bc-8a85-80844875385f	790	Installed Programs	Hotfix for Microsoft Visual Studio 2007 Tools for Applications - ENU (KB947540)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4ECF4BDC-8387-329A-ABE9-CF5798F84BB2}.KB947540	\N
6918d2bd-0be4-41bc-8a85-80844875385f	791	Installed Programs	Hotfix for Microsoft Visual Studio 2007 Tools for Applications - ENU (KB947789)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4ECF4BDC-8387-329A-ABE9-CF5798F84BB2}.KB947789	\N
6918d2bd-0be4-41bc-8a85-80844875385f	792	Installed Programs	HP 3D DriveGuard	4.1.4.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{83DA38AB-1014-41C2-A3CD-E2B93832A71A}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	793	Installed Programs	HP Auto	1.0.12494.3472	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CC4D56B7-6F18-470B-8734-ABCD75BCF4F1}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	794	Installed Programs	HP Customer Experience Enhancements	6.0.1.7	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{07FA4960-B038-49EB-891B-9F95930AA544}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	795	Installed Programs	HP DayStarter	2.0.0.12	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{483D5A49-A26B-4CB8-AA2D-0D1811322061}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	796	Installed Programs	HP Documentation	1.2.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6A9C9BE1-14A3-42ED-A388-42E30A1412E9}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	797	Installed Programs	HP ESU for Microsoft Windows 7	1.1.11.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CFC1988A-F492-4BC5-B6F7-683A95718AE9}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	798	Installed Programs	HP Game Console	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\My HP Game Console	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	793	Installed Programs	Microsoft Visual C++ 2013 Redistributable (x86) - 12.0.30501	12.0.30501.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{f65db027-aff3-4070-886a-0d87064aabb1}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	794	Installed Programs	Microsoft Visual C++ 2013 x64 Additional Runtime - 12.0.21005	12.0.21005	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{929FBD26-9020-399B-9A7A-751D61F0B942}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	795	Installed Programs	Microsoft Visual C++ 2013 x64 Minimum Runtime - 12.0.21005	12.0.21005	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A749D8E6-B613-3BE3-8F5F-045C84EBA29B}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	796	Installed Programs	Microsoft Visual C++ 2013 x86 Additional Runtime - 12.0.21005	12.0.21005	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F8CFEB22-A2E7-3971-9EDA-4B11EDEFC185}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	797	Installed Programs	Microsoft Visual C++ 2013 x86 Minimum Runtime - 12.0.21005	12.0.21005	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{13A4EE12-23EA-3371-91EE-EFB36DDFFF3E}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	798	Installed Programs	Microsoft Visual C++ 2017 Redistributable (x64) - 14.12.25810	14.12.25810.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{e2ee15e2-a480-4bc5-bfb7-e9803d1d9823}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	799	Installed Programs	Microsoft Visual C++ 2017 Redistributable (x86) - 14.12.25810	14.12.25810.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{56e11d69-7cc9-40a5-a4f9-8f6190c4d84d}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	800	Installed Programs	Microsoft Visual C++ 2017 x64 Additional Runtime - 14.12.25810	14.12.25810	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{2CD849A7-86A1-34A6-B8F9-D72F5B21A9AE}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	801	Installed Programs	Microsoft Visual C++ 2017 x64 Minimum Runtime - 14.12.25810	14.12.25810	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C99E2ADC-0347-336E-A603-F1992B09D582}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	802	Installed Programs	Microsoft Visual C++ 2017 x86 Additional Runtime - 14.12.25810	14.12.25810	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7FED75A1-600C-394B-8376-712E2A8861F2}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	803	Installed Programs	Microsoft Visual C++ 2017 x86 Minimum Runtime - 14.12.25810	14.12.25810	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{828952EB-5572-3666-8CA9-000B6CE79350}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	804	Installed Programs	Mozilla Firefox 57.0.4 (x64 en-US)	57.0.4	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Mozilla Firefox 57.0.4 (x64 en-US)	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	805	Installed Programs	Mozilla Maintenance Service	57.0.4	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\MozillaMaintenanceService	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	806	Installed Programs	Office 16 Click-to-Run Extensibility Component	16.0.9029.2167	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90160000-008C-0000-0000-0000000FF1CE}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	807	Installed Programs	Office 16 Click-to-Run Extensibility Component 64-bit Registration	16.0.9029.2167	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90160000-00DD-0000-1000-0000000FF1CE}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	808	Installed Programs	Office 16 Click-to-Run Licensing Component	16.0.9029.2167	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90160000-008F-0000-1000-0000000FF1CE}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	809	Installed Programs	Office 16 Click-to-Run Localization Component	16.0.9029.2167	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90160000-008C-0409-0000-0000000FF1CE}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	810	Installed Programs	PX Profile Update	1.00.1.	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E4D56AEC-96DF-C9BA-62AC-691A9AF21AE1}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	811	Installed Programs	Qualcomm Atheros Bluetooth Installer (64)	10.0.0.303	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{628988B4-3FA5-4EA6-BAA3-DA640F6718BD}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	812	Installed Programs	Qualcomm Unified Wireless Suite	11.0.0.10426	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6CFE6F33-3D69-4B9C-AA20-FF1F8CB064D5}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	813	Installed Programs	Realtek Audio COM Components	1.0.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{2355B503-9B11-4449-861D-1C1748B26320}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	814	Installed Programs	Realtek Card Reader	10.0.10586.21289	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5BC2B5AB-80DE-4E83-B8CF-426902051D0A}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	815	Installed Programs	Realtek High Definition Audio Driver	6.0.1.6111	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F132AF7F-7BCA-4EDE-8A7C-958108FE7DBC}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	816	Installed Programs	ST Microelectronics 3 Axis Digital Accelerometer Solution	4.10.0071	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{9C24F411-9CA7-4A8A-91F3-F08A4A38EB31}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	817	Installed Programs	Thunderbolt™ Software	16.3.61.275	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{87A31923-8F18-4943-8093-17DBEE0101B7}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	818	Installed Programs	VMware Workstation	12.1.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F4C0A853-FA3B-4404-954B-799299EB5A98}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	799	Installed Programs	HP Games	1.0.1.5	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WildTangent hp Master Uninstall	\N
6918d2bd-0be4-41bc-8a85-80844875385f	800	Installed Programs	HP HD Webcam [Fixed]	3.3.4.07	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Sunplus SPUVCb	\N
6918d2bd-0be4-41bc-8a85-80844875385f	801	Installed Programs	HP HotKey Support	4.0.10.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7D1C63D1-6520-49DA-B738-958133526E80}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	802	Installed Programs	HP Power Assistant	2.0.2.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3D8EDF72-13CC-4E51-AAB6-32A20524D2E0}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	803	Installed Programs	HP QuickWeb	3.0.0.9057	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{20976B1F-E910-404D-9261-C16EE7E12DC8}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	804	Installed Programs	HP Setup	8.5.4526.3645	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{03046EBB-CB7C-4B98-BEFB-690EB955DA22}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	805	Installed Programs	HP SoftPaq Download Manager	3.2.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{344A1AA2-AC8E-4741-BDB0-65B68FDA883C}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	806	Installed Programs	HP Software Framework	4.0.112.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B7F60A16-7A7B-41FB-9AE3-DE9E324FBA06}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	807	Installed Programs	HP Software Setup	8.2.1.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{531000B3-DBEE-4115-BBF3-DA48B67C053F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	808	Installed Programs	HP Support Assistant	5.2.3.4	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E02FBF01-0DE3-4BCB-89E8-D300FEFC3289}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	809	Installed Programs	HP System Default Settings	2.1.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{54C65FE7-83BD-4A5B-A9B4-41F793C5F241}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	810	Installed Programs	HP Wallpaper	2.00	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{11C9A461-DD9D-4C71-85A4-6DCE7F99CC44}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	811	Installed Programs	HPAsset component for HP Active Support Library	3.0.0.3	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{669D4A35-146B-4314-89F1-1AC3D7B88367}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	812	Installed Programs	IDT Audio	1.0.6325.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{E3A5A8AB-58F6-45FF-AFCB-C9AE18C05001}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	813	Installed Programs	Insaniquarium Deluxe	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087480	\N
6918d2bd-0be4-41bc-8a85-80844875385f	814	Installed Programs	Intel(R) Display Audio Driver	6.14.00.3074	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F0E3AD40-2BBD-4360-9C76-B9AC9A5886EA}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	815	Installed Programs	Intel(R) Identity Protection Technology 1.0.71.0	1.0.71.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{2C43790E-8470-1027-82D3-DF319F3C410F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	816	Installed Programs	Intel(R) Management Engine Components	7.0.0.1144	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{65153EA5-8B6E-43B6-857B-C6E4FC25798A}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	819	Installed Programs	Vulkan Run Time Libraries 1.0.26.0	1.0.26.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\VulkanRT1.0.26.0	\N
6918d2bd-0be4-41bc-8a85-80844875385f	817	Installed Programs	Intel(R) Rapid Storage Technology	10.1.2.1004	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3E29EE6C-963A-4aae-86C1-DC237C4A49FC}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	820	Installed Programs	Vulkan Run Time Libraries 1.0.54.1	1.0.54.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\VulkanRT1.0.54.1	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	0	Computer System	Name	OSSI-DNOVAK	CIM:String	WMI:CIM_ManagedSystemElement.Name	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	1	Computer System	DNSHostName	OSSI-DNovak	CIM:String	WMI:Win32_ComputerSystem.DNSHostName	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	2	Computer System	Domain	intelli-site.com	CIM:String	WMI:Win32_ComputerSystem.Domain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	3	Computer System	DomainRole	Member Workstation	string(CIM:UInt16)	WMI:Win32_ComputerSystem.DomainRole	\N
6918d2bd-0be4-41bc-8a85-80844875385f	818	Installed Programs	Intelli-Site	4.0.30.16	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\InstallShield_{A7FAAD35-A654-41A2-B2A8-14A8AF86FFF0}	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	4	Computer System	PartOfDomain	True	CIM:Boolean	WMI:Win32_ComputerSystem.PartOfDomain	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	5	Computer System	Workgroup	\N	CIM:String	WMI:Win32_ComputerSystem.Workgroup	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	6	Computer System	PCSystemType	Mobile	string(CIM:UInt16)	WMI:Win32_ComputerSystem.PCSystemType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	7	Computer System	SystemType	x64-based PC	CIM:String	WMI:Win32_ComputerSystem.SystemType	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	8	Computer System	Manufacturer	Dell Inc.	CIM:String	WMI:Win32_ComputerSystem.Manufacturer	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	9	Computer System	Model	Precision 7510	CIM:String	WMI:Win32_ComputerSystem.Model	\N
8a4214af-6b50-4538-bf4f-6a1886c45d98	10	Computer System	NumberOfProcessors	1	CIM:UInt32	WMI:Win32_ComputerSystem.NumberOfProcessors	\N
6918d2bd-0be4-41bc-8a85-80844875385f	819	Installed Programs	Intelli-Site	4.0.30.16	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A7FAAD35-A654-41A2-B2A8-14A8AF86FFF0}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	820	Installed Programs	Intelli-Site	3.9.71	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{0DB69541-0103-11D5-9396-00E0B8161E5B}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	821	Installed Programs	iTunes	12.7.3.46	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1D7D1271-5258-4F5A-B8C1-7176BF398782}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	822	Installed Programs	Java 8 Update 131	8.0.1310.11	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{26A24AE4-039D-4CA4-87B4-2F32180131F0}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	823	Installed Programs	Java Auto Updater	2.8.131.11	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4A03706F-666A-4037-7777-5F2748764D10}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	824	Installed Programs	JavaFX 2.1.1	2.1.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1111706F-666A-4037-7777-211328764D10}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	825	Installed Programs	Jewel Quest II	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087485	\N
6918d2bd-0be4-41bc-8a85-80844875385f	826	Installed Programs	Jewel Quest Solitaire	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087490	\N
6918d2bd-0be4-41bc-8a85-80844875385f	827	Installed Programs	JMicron Flash Media Controller Driver	1.0.57.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{26604C7E-A313-4D12-867F-7C6E7820BE4C}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	828	Installed Programs	John Deere Drive Green	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087380	\N
6918d2bd-0be4-41bc-8a85-80844875385f	829	Installed Programs	Malwarebytes version 3.2.2.2029	3.2.2.2029	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{35065F43-4BB2-439A-BFF7-0F1014F2E0CD}_is1	\N
6918d2bd-0be4-41bc-8a85-80844875385f	830	Installed Programs	Microsoft .NET Framework 1.1	1.1.4322	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CB2F7EDD-9D1F-43C1-90FC-4F52EAE172A1}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	831	Installed Programs	Microsoft .NET Framework 1.1	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Microsoft .NET Framework 1.1  (1033)	\N
6918d2bd-0be4-41bc-8a85-80844875385f	832	Installed Programs	Microsoft .NET Framework 4.5.2	4.5.51209	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{26784146-6E05-3FF9-9335-786C7C0FB5BE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	833	Installed Programs	Microsoft .NET Framework 4.5.2	4.5.51209	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132} - 1033	\N
6918d2bd-0be4-41bc-8a85-80844875385f	834	Installed Programs	Microsoft Application Error Reporting	12.0.6012.5000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{95120000-00B9-0409-0000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	835	Installed Programs	Microsoft Application Error Reporting	12.0.6015.5000	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{95120000-00B9-0409-1000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	836	Installed Programs	Microsoft Office Access MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0015-0409-0000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	837	Installed Programs	Microsoft Office Access Setup Metadata MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0117-0409-0000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	838	Installed Programs	Microsoft Office Excel MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0016-0409-0000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	839	Installed Programs	Microsoft Office Home and Business 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Office14.SingleImage	\N
6918d2bd-0be4-41bc-8a85-80844875385f	840	Installed Programs	Microsoft Office Office 64-bit Components 2010	14.0.7015.1000	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	841	Installed Programs	Microsoft Office OneNote MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-00A1-0409-0000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	842	Installed Programs	Microsoft Office Outlook MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001A-0409-0000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	843	Installed Programs	Microsoft Office PowerPoint MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0018-0409-0000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	844	Installed Programs	Microsoft Office Proof (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-0409-0000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	845	Installed Programs	Microsoft Office Proof (French) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-040C-0000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	846	Installed Programs	Microsoft Office Proof (Spanish) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-0C0A-0000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	847	Installed Programs	Microsoft Office Proofing (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002C-0409-0000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	848	Installed Programs	Microsoft Office Publisher MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0019-0409-0000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	849	Installed Programs	Microsoft Office Shared 64-bit MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0409-1000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	909	Installed Programs	MSXML 4.0 SP2 (KB973688)	4.20.9876.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F662A8E6-F4DC-41A2-901E-8C11F044BDEC}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	850	Installed Programs	Microsoft Office Shared 64-bit Setup Metadata MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0116-0409-1000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	851	Installed Programs	Microsoft Office Shared MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-006E-0409-0000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	852	Installed Programs	Microsoft Office Shared Setup Metadata MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0115-0409-0000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	853	Installed Programs	Microsoft Office Single Image 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	854	Installed Programs	Microsoft Office Word MUI (English) 2010	14.0.7015.1000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001B-0409-0000-0000000FF1CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	855	Installed Programs	Microsoft Report Viewer Redistributable 2008 (KB971119)	9.0.30731	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CED243AB-C7BA-3D42-9609-14EF5A6FC601}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	856	Installed Programs	Microsoft Report Viewer Redistributable 2008 SP1	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Microsoft Report Viewer Redistributable 2008 (KB971119)	\N
6918d2bd-0be4-41bc-8a85-80844875385f	857	Installed Programs	Microsoft Security Client	4.7.0205.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{996D32B6-F629-4764-894B-CB24D9C19051}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	858	Installed Programs	Microsoft Security Essentials	4.7.205.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Microsoft Security Client	\N
6918d2bd-0be4-41bc-8a85-80844875385f	859	Installed Programs	Microsoft Silverlight	5.1.50907.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{89F4137D-6C26-4A84-BDB8-2E5A4BB71E00}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	860	Installed Programs	Microsoft SQL Server 2005 Backward compatibility	8.05.2309	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{8909B8A7-CEAB-4772-BF29-1892C4E6603B}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	861	Installed Programs	Microsoft SQL Server 2008 R2	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Microsoft SQL Server 10	\N
6918d2bd-0be4-41bc-8a85-80844875385f	862	Installed Programs	Microsoft SQL Server 2008 R2	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Microsoft SQL Server 2008 R2	\N
6918d2bd-0be4-41bc-8a85-80844875385f	863	Installed Programs	Microsoft SQL Server 2008 R2 Native Client	10.51.2500.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{471AAD2C-9078-4DAC-BD43-FA10FB7C3FCE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	864	Installed Programs	Microsoft SQL Server 2008 R2 Policies	10.50.1600.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D21BC5B2-CBAC-48FA-A701-B5A63C1CA7B8}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	865	Installed Programs	Microsoft SQL Server 2008 R2 RsFx Driver	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{93968FB2-C67A-4A9B-80C2-5D4D9393058E}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	866	Installed Programs	Microsoft SQL Server 2008 R2 Setup (English)	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{48B08845-0CB0-45EC-893C-15319ADDA312}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	867	Installed Programs	Microsoft SQL Server 2008 Setup Support Files	10.1.2731.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D441BD04-E548-4F8E-97A4-1B66135BAAA8}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	868	Installed Programs	Microsoft SQL Server Browser	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{BF9BF038-FE03-429D-9B26-2FA0FD756052}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	869	Installed Programs	Microsoft SQL Server Compact 3.5 SP2 ENU	3.5.8080.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3A9FC03D-C685-4831-94CF-4EDFD3749497}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	870	Installed Programs	Microsoft SQL Server Compact 3.5 SP2 Query Tools ENU	3.5.8080.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{DDFD8348-058C-4F4B-85E5-6D740D4AB3FE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	871	Installed Programs	Microsoft SQL Server VSS Writer	10.51.2500.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{288D79EE-A2D1-42AF-9597-B0ADCC23A8ED}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	872	Installed Programs	Microsoft Text-to-Speech Engine 4.0 (English)	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\MSTTS	\N
6918d2bd-0be4-41bc-8a85-80844875385f	873	Installed Programs	Microsoft VC9 runtime libraries	2.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{553C904F-57A2-4113-888E-BA0C3D1C69C0}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	874	Installed Programs	Microsoft Visual C++ 2005 Redistributable	8.0.61001	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{710f4c1c-cc18-4c49-8cbf-51240c89a1a2}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	875	Installed Programs	Microsoft Visual C++ 2005 Redistributable (x64)	8.0.59192	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6ce5bae9-d3ca-4b99-891a-1dc6c118a5fc}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	876	Installed Programs	Microsoft Visual C++ 2005 Redistributable (x64)	8.0.61000	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{ad8a2fa1-06e7-4b0d-927d-6e54b3d31028}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	877	Installed Programs	Microsoft Visual C++ 2005 Redistributable (x64)	8.0.56336	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{071c9b48-7c32-4621-a0ac-3f809523288f}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	878	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x64 9.0.30729.17	9.0.30729	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{8220EEFE-38CD-377E-8595-13398D740ACE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	879	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x64 9.0.30729.4148	9.0.30729.4148	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4B6C7001-C7D6-3710-913E-5BC23FCE91E6}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	910	Installed Programs	Notepad++ (32-bit x86)	7.2.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Notepad++	\N
6918d2bd-0be4-41bc-8a85-80844875385f	880	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x64 9.0.30729.6161	9.0.30729.6161	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5FCE6D76-F5DC-37AB-B2B8-22AB8CEDB1D4}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	881	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x86 9.0.30729.17	9.0.30729	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{9A25302D-30C0-39D9-BD6F-21E6EC160475}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	882	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x86 9.0.30729.4148	9.0.30729.4148	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1F1C2DFC-2D24-3E06-BCB8-725134ADF989}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	883	Installed Programs	Microsoft Visual C++ 2008 Redistributable - x86 9.0.30729.6161	9.0.30729.6161	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{9BE518E6-ECC6-35A9-88E4-87755C07200F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	884	Installed Programs	Microsoft Visual C++ 2010  x64 Redistributable - 10.0.40219	10.0.40219	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1D8E6291-B0D5-35EC-8441-6616F567A0F7}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	885	Installed Programs	Microsoft Visual C++ 2010  x86 Redistributable - 10.0.40219	10.0.40219	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F0C3E5D1-1ADE-321E-8167-68EF0DE699A5}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	886	Installed Programs	Microsoft Visual C++ 2012 Redistributable (x64) - 11.0.61030	11.0.61030.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{ca67548a-5ebe-413a-b50c-4b9ceb6d66c6}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	887	Installed Programs	Microsoft Visual C++ 2012 Redistributable (x86) - 11.0.60610	11.0.60610.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{95716cce-fc71-413f-8ad5-56c2892d4b3a}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	888	Installed Programs	Microsoft Visual C++ 2012 Redistributable (x86) - 11.0.61030	11.0.61030.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{33d1fd90-4274-48a1-9bc1-97e33d9c2d6f}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	889	Installed Programs	Microsoft Visual C++ 2012 x64 Additional Runtime - 11.0.61030	11.0.61030	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{37B8F9C7-03FB-3253-8781-2517C99D7C00}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	890	Installed Programs	Microsoft Visual C++ 2012 x64 Minimum Runtime - 11.0.61030	11.0.61030	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CF2BEA3C-26EA-32F8-AA9B-331F7E34BA97}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	891	Installed Programs	Microsoft Visual C++ 2012 x86 Additional Runtime - 11.0.61030	11.0.61030	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B175520C-86A2-35A7-8619-86DC379688B9}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	892	Installed Programs	Microsoft Visual C++ 2012 x86 Minimum Runtime - 11.0.61030	11.0.61030	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{BD95A8CD-1D9F-35AD-981A-3E7925026EBB}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	893	Installed Programs	Microsoft Visual C++ 2013 Redistributable (x64) - 12.0.21005	12.0.21005.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7f51bdb9-ee21-49ee-94d6-90afc321780e}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	894	Installed Programs	Microsoft Visual C++ 2013 Redistributable (x86) - 12.0.21005	12.0.21005.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{ce085a78-074e-4823-8dc1-8a721b94b76d}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	895	Installed Programs	Microsoft Visual C++ 2013 x64 Additional Runtime - 12.0.21005	12.0.21005	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{929FBD26-9020-399B-9A7A-751D61F0B942}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	896	Installed Programs	Microsoft Visual C++ 2013 x64 Minimum Runtime - 12.0.21005	12.0.21005	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A749D8E6-B613-3BE3-8F5F-045C84EBA29B}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	897	Installed Programs	Microsoft Visual C++ 2013 x86 Additional Runtime - 12.0.21005	12.0.21005	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F8CFEB22-A2E7-3971-9EDA-4B11EDEFC185}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	898	Installed Programs	Microsoft Visual C++ 2013 x86 Minimum Runtime - 12.0.21005	12.0.21005	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{13A4EE12-23EA-3371-91EE-EFB36DDFFF3E}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	899	Installed Programs	Microsoft Visual Studio 2010 Tools for Office Runtime (x64)	10.0.50908	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{9495AEB4-AB97-39DE-8C42-806EEF75ECA7}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	900	Installed Programs	Microsoft Visual Studio 2010 Tools for Office Runtime (x64)	10.0.50903	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Microsoft Visual Studio 2010 Tools for Office Runtime (x64)	\N
6918d2bd-0be4-41bc-8a85-80844875385f	901	Installed Programs	Microsoft Visual Studio Tools for Applications 2.0 - ENU	9.0.35191	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4ECF4BDC-8387-329A-ABE9-CF5798F84BB2}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	902	Installed Programs	Microsoft_VC90_CRT_x86	1.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{DF2035BE-5820-4965-BD97-7FAF8D4A7879}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	903	Installed Programs	Mozilla Firefox 57.0 (x64 en-US)	57.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Mozilla Firefox 57.0 (x64 en-US)	\N
6918d2bd-0be4-41bc-8a85-80844875385f	904	Installed Programs	Mozilla Firefox 58.0.1 (x64 en-US)	58.0.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\Mozilla Firefox 58.0.1 (x64 en-US)	\N
6918d2bd-0be4-41bc-8a85-80844875385f	905	Installed Programs	Mozilla Maintenance Service	57.0.2	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\MozillaMaintenanceService	\N
6918d2bd-0be4-41bc-8a85-80844875385f	906	Installed Programs	MPLAB X IDE v3.26	v3.26	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\MPLAB X IDE v3.26 v3.26	\N
6918d2bd-0be4-41bc-8a85-80844875385f	907	Installed Programs	MSVCRT	15.4.2862.0708	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{8DD46C6A-0056-4FEC-B70A-28BB16A1F11F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	908	Installed Programs	MSXML 4.0 SP2 (KB954430)	4.20.9870.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{86493ADD-824D-4B8E-BD72-8C5DCDC52A71}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	912	Installed Programs	Pelco SDK (ver 2.0.0)	2.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5E09A0E6-63F0-46F9-B995-0FA3B98595A4}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	913	Installed Programs	PelcoEnduraRedist	1.00.0000	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4144D69C-E9EF-46B2-A9AC-72CBBAFCCA54}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	914	Installed Programs	Penguins!	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087394	\N
6918d2bd-0be4-41bc-8a85-80844875385f	915	Installed Programs	Plants vs. Zombies	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087501	\N
6918d2bd-0be4-41bc-8a85-80844875385f	916	Installed Programs	Polar Bowler	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087396	\N
6918d2bd-0be4-41bc-8a85-80844875385f	917	Installed Programs	PostgreSQL 9.4	9.4	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\PostgreSQL 9.4	\N
6918d2bd-0be4-41bc-8a85-80844875385f	918	Installed Programs	Print Artist Platinum 25	25.0.0.6	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{54E76A97-D5FB-4EF4-857B-838E47705B98}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	919	Installed Programs	product.crystalreportsviewer.arp-4.0-core-32	14.0.2.364	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{337AF528-96DA-4946-94BD-92F40A712484}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	920	Installed Programs	product.crystalreportsviewer.installiverse.reg-4.0-core-nu	14.0.0.760	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5176A2AA-DEA7-435F-94AA-AC80C3E0ADFB}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	921	Installed Programs	product.crystalreportsviewer.langpackproperty-4.0-en-nu	14.0.1.287	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7CF3BDB0-E3EB-48B2-AA59-B48CEAC696D7}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	922	Installed Programs	PuTTY version 0.66 x64	0.66 x64	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6B04E35A-94EB-4F24-8A55-4276390C0EE3}_is1	\N
6918d2bd-0be4-41bc-8a85-80844875385f	923	Installed Programs	PX Profile Update	1.00.1.	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{80C45B94-2BA0-8E23-95A7-8A9FCD836EFD}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	924	Installed Programs	PX Profile Update	1.00.1.	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{DB94388C-62E9-570D-2BD6-90864F7E1282}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	925	Installed Programs	R3.9.58 Workstation Hikvision IP Camera Patch	3.9.58.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\R3.9.58 Workstation Hikvision IP Camera Patch	\N
6918d2bd-0be4-41bc-8a85-80844875385f	926	Installed Programs	Realtek Ethernet Controller All-In-One Windows Driver	1.12.0016	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F7E7F0CB-AA41-4D5A-B6F2-8E6738EB063F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	927	Installed Programs	Revo Uninstaller 2.0.4	2.0.4	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A28DBDA2-3CC7-4ADC-8BFE-66D7743C6C97}_is1	\N
6918d2bd-0be4-41bc-8a85-80844875385f	928	Installed Programs	SADPTool	3.0.0.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7D9B79C2-B1B2-433B-844F-F4299B86F26E}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	929	Installed Programs	Samsung USB Driver for Mobile Phones	1.5.63.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D0795B21-0CDA-4a92-AB9E-6E92D8111E44}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	930	Installed Programs	SDK	2.24.025	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{0DEA342C-15CB-4F52-97B6-06A9C4B9C06F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	931	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB2972107)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB2972107	\N
6918d2bd-0be4-41bc-8a85-80844875385f	932	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB2972216)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB2972216	\N
6918d2bd-0be4-41bc-8a85-80844875385f	933	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB2978128)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB2978128	\N
6918d2bd-0be4-41bc-8a85-80844875385f	934	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB2979578v2)	2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB2979578v2	\N
6918d2bd-0be4-41bc-8a85-80844875385f	935	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3023224)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3023224	\N
6918d2bd-0be4-41bc-8a85-80844875385f	936	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3035490)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3035490	\N
6918d2bd-0be4-41bc-8a85-80844875385f	937	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3037581)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3037581	\N
6918d2bd-0be4-41bc-8a85-80844875385f	938	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3074230)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3074230	\N
6918d2bd-0be4-41bc-8a85-80844875385f	939	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3074550)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3074550	\N
6918d2bd-0be4-41bc-8a85-80844875385f	940	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3097996)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3097996	\N
6918d2bd-0be4-41bc-8a85-80844875385f	941	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3098781)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3098781	\N
6918d2bd-0be4-41bc-8a85-80844875385f	942	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3122656)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3122656	\N
6918d2bd-0be4-41bc-8a85-80844875385f	943	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3127229)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3127229	\N
6918d2bd-0be4-41bc-8a85-80844875385f	944	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3135996)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3135996	\N
6918d2bd-0be4-41bc-8a85-80844875385f	945	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3142033)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3142033	\N
6918d2bd-0be4-41bc-8a85-80844875385f	946	Installed Programs	Security Update for Microsoft .NET Framework 4.5.2 (KB3163251)	1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92FB6C44-E685-45AD-9B20-CADF4CABA132}.KB3163251	\N
6918d2bd-0be4-41bc-8a85-80844875385f	947	Installed Programs	Security Update for Microsoft Access 2010 (KB3101544) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{DAE3147C-5212-428A-982D-4D8B298548C4}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	948	Installed Programs	Security Update for Microsoft Excel 2010 (KB3115322) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{14949093-4B12-40A0-A45F-8F7A3B78E62F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	949	Installed Programs	Security Update for Microsoft InfoPath 2010 (KB3114414) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{B3F75577-16EF-48AA-9259-2AF290C973FD}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	950	Installed Programs	Security Update for Microsoft Office 2010 (KB2553313) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{473DA037-A808-4DF4-9F37-548928C3CDA1}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	951	Installed Programs	Security Update for Microsoft Office 2010 (KB2553313) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{473DA037-A808-4DF4-9F37-548928C3CDA1}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	952	Installed Programs	Security Update for Microsoft Office 2010 (KB2850016) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{7AC3F78E-ECA0-45F4-A9CC-3E885DA23662}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	953	Installed Programs	Security Update for Microsoft Office 2010 (KB2880971) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{5EE42B42-1159-435C-898A-2A3298453B20}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	954	Installed Programs	Security Update for Microsoft Office 2010 (KB2881029) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{433890E5-7858-4D14-8FD3-CCD28015472F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	955	Installed Programs	Security Update for Microsoft Office 2010 (KB2881071) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{0BC570F0-7352-4A3A-B2A2-CA56ADA7375F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	956	Installed Programs	Security Update for Microsoft Office 2010 (KB2956063) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{0567725C-77BA-47C1-BE23-FFC218C8F953}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	957	Installed Programs	Security Update for Microsoft Office 2010 (KB2956076) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-006E-0409-0000-0000000FF1CE}_Office14.SingleImage_{A12F43A5-CF0B-44E3-942F-2441CD442F0D}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	958	Installed Programs	Security Update for Microsoft Office 2010 (KB3054984) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{7D8AB432-0662-4DC9-8C37-5BA7541153C9}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	959	Installed Programs	Security Update for Microsoft Office 2010 (KB3085528) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{9429D223-4B64-4038-B63D-3F239216F6E5}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	960	Installed Programs	Security Update for Microsoft Office 2010 (KB3085560) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-006E-0409-0000-0000000FF1CE}_Office14.SingleImage_{DA24C5B4-EB67-4143-8CBE-18C3B4F13694}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	961	Installed Programs	Security Update for Microsoft Office 2010 (KB3101520) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{B6BB5C05-372B-48FE-8348-D3ED54EF172B}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	962	Installed Programs	Security Update for Microsoft OneNote 2010 (KB3054978) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-00A1-0409-0000-0000000FF1CE}_Office14.SingleImage_{82148027-13B5-4920-97F3-6A44A29B83D0}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	963	Installed Programs	Security Update for Microsoft Outlook 2010 (KB3115246) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{CD2932ED-8DA5-4B7F-B220-7CEE3549D12A}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	964	Installed Programs	Security Update for Microsoft PowerPoint 2010 (KB2920812) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0018-0409-0000-0000000FF1CE}_Office14.SingleImage_{DF548669-AAED-467B-A074-AE2B72A4A871}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	965	Installed Programs	Security Update for Microsoft PowerPoint 2010 (KB3115118) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{715F30CA-6F8C-4115-8928-CD24DA9025BF}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	966	Installed Programs	Security Update for Microsoft Publisher 2010 (KB2817478) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{7DD2401D-E882-499C-9009-5F2A6B610C7A}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	967	Installed Programs	Security Update for Microsoft Visio 2010 (KB3114872) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{14044761-B4DB-4690-BA5C-E79CC538C58E}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	968	Installed Programs	Security Update for Microsoft Visio Viewer 2010 (KB2999465) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{D54D39CD-37D6-42EF-AD2E-2222515782F1}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	969	Installed Programs	Security Update for Microsoft Word 2010 (KB2965313) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001A-0409-0000-0000000FF1CE}_Office14.SingleImage_{102FADF9-3B36-4EAB-A272-BF6E539223F8}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	970	Installed Programs	Security Update for Microsoft Word 2010 (KB2965313) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001B-0409-0000-0000000FF1CE}_Office14.SingleImage_{102FADF9-3B36-4EAB-A272-BF6E539223F8}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	971	Installed Programs	Security Update for Microsoft Word 2010 (KB3115317) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{0AAE878F-DA45-4DD8-A32D-E85AB53889CB}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	972	Installed Programs	Sentinel HASP Run-time	5.0.1.14210	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{2A414CBE-CDF3-48C6-A91B-D3D4522F8EB5}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	973	Installed Programs	Sentinel System Driver Installer 7.5.2	7.5.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{504B7439-03BB-4C23-B17E-A1EC2D1D47B1}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	974	Installed Programs	Service Pack 1 for SQL Server 2008 R2 (KB2528583)	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\KB2528583	\N
6918d2bd-0be4-41bc-8a85-80844875385f	975	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0016-0409-0000-0000000FF1CE}_Office14.SingleImage_{D6A2CD7F-C90C-4B90-BBA7-2BADE2E08610}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	976	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0019-0409-0000-0000000FF1CE}_Office14.SingleImage_{D6A2CD7F-C90C-4B90-BBA7-2BADE2E08610}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	977	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-00A1-0409-0000-0000000FF1CE}_Office14.SingleImage_{D6A2CD7F-C90C-4B90-BBA7-2BADE2E08610}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	978	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0116-0409-1000-0000000FF1CE}_Office14.SingleImage_{03AE1408-7BF1-4AC6-A327-E32E7799BCE4}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	979	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0015-0409-0000-0000000FF1CE}_Office14.SingleImage_{D6A2CD7F-C90C-4B90-BBA7-2BADE2E08610}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	980	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-006E-0409-0000-0000000FF1CE}_Office14.SingleImage_{8DD50F3B-E0BD-4E39-AF1F-2F316B4FC528}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	981	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001A-0409-0000-0000000FF1CE}_Office14.SingleImage_{D6A2CD7F-C90C-4B90-BBA7-2BADE2E08610}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	982	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{DE28B448-32E8-4E8F-84F0-A52B21A49B5B}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	983	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0115-0409-0000-0000000FF1CE}_Office14.SingleImage_{8DD50F3B-E0BD-4E39-AF1F-2F316B4FC528}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	984	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0018-0409-0000-0000000FF1CE}_Office14.SingleImage_{D6A2CD7F-C90C-4B90-BBA7-2BADE2E08610}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	985	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0117-0409-0000-0000000FF1CE}_Office14.SingleImage_{D6A2CD7F-C90C-4B90-BBA7-2BADE2E08610}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	986	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-0409-0000-0000000FF1CE}_Office14.SingleImage_{09A9DF49-DA06-4093-A2FD-F339211E39EA}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	987	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{E4D76E88-C65F-4003-9C71-EC4306679D17}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	988	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002C-0409-0000-0000000FF1CE}_Office14.SingleImage_{945F1D43-451D-4383-9BBE-241F37950B15}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	989	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-0C0A-0000-0000000FF1CE}_Office14.SingleImage_{8C5A05B6-FF56-480F-A0E6-9F4BCA4B4CAC}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	990	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-040C-0000-0000000FF1CE}_Office14.SingleImage_{ECC1D579-DC17-4B90-929C-B4A0BB35F7B3}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1067	Installed Programs	VIP Access SDK x64(1.0.0.50)	1.0.0.50	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\VIP Access SDK	\N
6918d2bd-0be4-41bc-8a85-80844875385f	991	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001B-0409-0000-0000000FF1CE}_Office14.SingleImage_{D6A2CD7F-C90C-4B90-BBA7-2BADE2E08610}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	992	Installed Programs	Service Pack 2 for Microsoft Office 2010 (KB2687455) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0409-1000-0000000FF1CE}_Office14.SingleImage_{03AE1408-7BF1-4AC6-A327-E32E7799BCE4}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	993	Installed Programs	SimonsVoss Locking System Management Basic 3.1 (English UK)	3.1.20412	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7D2ABFC5-8710-42C0-9288-1C43BAE22D79}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	994	Installed Programs	SimonsVoss LSM Mobile (English UK)	3.1.20412	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6DD70464-1843-4F24-BD7E-E4F412F7C57E}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	995	Installed Programs	Slingo Deluxe	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087510	\N
6918d2bd-0be4-41bc-8a85-80844875385f	996	Installed Programs	Spybot - Search & Destroy	1.6.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B4092C6D-E886-4CB2-BA68-FE5A88D31DE6}_is1	\N
6918d2bd-0be4-41bc-8a85-80844875385f	997	Installed Programs	SQL Server 2008 R2 SP1 Common Files	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{FC835376-FF3B-4CAA-83E0-2148B3FB7C98}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	998	Installed Programs	SQL Server 2008 R2 SP1 Common Files	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CACEA8C8-3D38-4F51-953D-1E6FC3346FEF}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	999	Installed Programs	SQL Server 2008 R2 SP1 Database Engine Services	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{58721EC3-8D4E-4B79-BC51-1054E2DDCD10}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1000	Installed Programs	SQL Server 2008 R2 SP1 Database Engine Services	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B5153233-9AEE-4CD4-9D2C-4FAAC870DBE2}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1001	Installed Programs	SQL Server 2008 R2 SP1 Database Engine Shared	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4C9D82EB-9001-4E59-8F64-0BEEE5F4A30A}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1002	Installed Programs	SQL Server 2008 R2 SP1 Database Engine Shared	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F021CC0C-21C3-4038-AA4A-6E3CBC669CE8}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1003	Installed Programs	SQL Server 2008 R2 SP1 Management Studio	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{121475F5-2598-4574-8801-8F6B3D6A99BB}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1004	Installed Programs	SQL Server 2008 R2 SP1 Management Studio	10.51.2500.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{020617D7-2F72-4D02-BF59-A5CBC1761177}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1005	Installed Programs	Sql Server Customer Experience Improvement Program	10.50.1600.1	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{93998800-1608-403F-9A51-420A77D23C25}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1006	Installed Programs	Suite Specific	2.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C49DAA9C-5BA8-459A-8244-E57B69DF0F04}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1007	Installed Programs	Synaptics Pointing Device Driver	15.2.11.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\SynTPDeinstKey	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1008	Installed Programs	tp.azalea.fonts-5.5-core-nu	14.0.0.760	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{EC895F19-3571-4429-83F0-441674E04989}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1009	Installed Programs	U3Launcher	1.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D8E363A7-88B7-446D-B2C0-E26CE4DC8E54}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1010	Installed Programs	ULinx USB Driver	1.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{01F41214-12C3-4118-AF55-5A4605CAEB6A}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1011	Installed Programs	Update for Microsoft Excel 2010 (KB2956084) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001B-0409-0000-0000000FF1CE}_Office14.SingleImage_{A7C2902F-C60B-428F-BDD7-ECE4DC0A2CA1}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1012	Installed Programs	Update for Microsoft Excel 2010 (KB2956084) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0016-0409-0000-0000000FF1CE}_Office14.SingleImage_{A7C2902F-C60B-428F-BDD7-ECE4DC0A2CA1}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1013	Installed Programs	Update for Microsoft Excel 2010 (KB2956084) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0018-0409-0000-0000000FF1CE}_Office14.SingleImage_{A7C2902F-C60B-428F-BDD7-ECE4DC0A2CA1}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1014	Installed Programs	Update for Microsoft Filter Pack 2.0 (KB2999508) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{9DCB10B2-8E20-4678-B85B-DDB48895B885}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1015	Installed Programs	Update for Microsoft Filter Pack 2.0 (KB2999508) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{9DCB10B2-8E20-4678-B85B-DDB48895B885}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1016	Installed Programs	Update for Microsoft InfoPath 2010 (KB2817369) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{4EEA3D3E-989C-4DF4-AB0A-3042C0C12AA3}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1017	Installed Programs	Update for Microsoft Office 2010 (KB2553140) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{8BEEA2FC-D416-428A-B52A-A3ED45921151}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1018	Installed Programs	Update for Microsoft Office 2010 (KB2553140) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-006E-0409-0000-0000000FF1CE}_Office14.SingleImage_{8BEEA2FC-D416-428A-B52A-A3ED45921151}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1019	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1020	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-040C-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1021	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-0C0A-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1022	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0018-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1023	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1024	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0015-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1025	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0019-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1026	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0016-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1027	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-006E-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1028	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-00A1-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1029	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0409-1000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1030	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002C-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1031	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0115-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1032	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001A-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1033	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001B-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1034	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0117-0409-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1035	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-0116-0409-1000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1036	Installed Programs	Update for Microsoft Office 2010 (KB2553347) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{7CA28304-D86F-4ACA-97FA-D126E0D02416}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1037	Installed Programs	Update for Microsoft Office 2010 (KB2553388) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{AEB4E79E-26B6-42F3-9980-096443C534BE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1038	Installed Programs	Update for Microsoft Office 2010 (KB2589298) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{DADF7E25-FFA4-4D02-BE84-1DAE62C18516}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1039	Installed Programs	Update for Microsoft Office 2010 (KB2589318) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{091CB6F9-4347-4084-A572-7C320DA7D686}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1040	Installed Programs	Update for Microsoft Office 2010 (KB2589352) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{F4284D93-7AE8-4309-8CF3-9AD394F35F3A}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1041	Installed Programs	Update for Microsoft Office 2010 (KB2589352) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{F4284D93-7AE8-4309-8CF3-9AD394F35F3A}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1042	Installed Programs	Update for Microsoft Office 2010 (KB2589375) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{287A1E92-9E41-4BC1-8920-B3D0E9220800}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1043	Installed Programs	Update for Microsoft Office 2010 (KB2589386) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{A4F91D60-654C-4892-BFD3-0D41ADA649B6}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1044	Installed Programs	Update for Microsoft Office 2010 (KB2597087) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{9D69691D-823D-4C3E-9B12-563A3F520366}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1045	Installed Programs	Update for Microsoft Office 2010 (KB2687275) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{0B7744D2-1FDD-4843-9987-7CE11B79F370}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1046	Installed Programs	Update for Microsoft Office 2010 (KB2791057) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{43EBBFDD-8FB7-4FCC-9780-EB40277987A2}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1047	Installed Programs	Update for Microsoft Office 2010 (KB2794737) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{5AA578BB-759C-40FD-9661-A737C0884541}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1048	Installed Programs	Update for Microsoft Office 2010 (KB2881030) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{D6C976E4-E88C-4048-9A6B-39400D2933C7}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1049	Installed Programs	Update for Microsoft Office 2010 (KB2883019) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{D1C4AD0B-CC79-41D2-8D6A-571E7B30658C}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1050	Installed Programs	Update for Microsoft Office 2010 (KB3054873) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{9C9636BD-37A7-43F7-BB00-5C7606B42D27}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1051	Installed Programs	Update for Microsoft Office 2010 (KB3054886) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{A786FC51-D7D5-4499-A230-D1EBEA64932C}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1052	Installed Programs	Update for Microsoft Office 2010 (KB3054886) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{A786FC51-D7D5-4499-A230-D1EBEA64932C}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1053	Installed Programs	Update for Microsoft Office 2010 (KB3055047) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{B29C45D3-4B2D-4FC2-B072-81E3528E4EE1}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1054	Installed Programs	Update for Microsoft Office 2010 (KB3085605) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-0409-0000-0000000FF1CE}_Office14.SingleImage_{548F42CA-61CC-4A49-9963-50124AC7B81D}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1055	Installed Programs	Update for Microsoft Office 2010 (KB3085605) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-0C0A-0000-0000000FF1CE}_Office14.SingleImage_{A7AA9E77-A9F4-4596-8AFD-4910FF258C3D}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1056	Installed Programs	Update for Microsoft Office 2010 (KB3085605) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001F-040C-0000-0000000FF1CE}_Office14.SingleImage_{C1954E2B-1672-4E5C-B564-F8CB2D08345B}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1057	Installed Programs	Update for Microsoft Office 2010 (KB3114555) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{F2644070-2DCF-4ABF-812B-DDCFD4652E3A}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1058	Installed Programs	Update for Microsoft Office 2010 (KB3114750) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{F4F9D4DD-8D81-4424-BCCD-333DE4305105}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1059	Installed Programs	Update for Microsoft Office 2010 (KB3114989) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{37377C07-9556-4A60-B42D-85EC9B955C71}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1060	Installed Programs	Update for Microsoft OneNote 2010 (KB3114410) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{007AAA88-1D1E-400B-B8FE-2C8DF2ABC700}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1061	Installed Programs	Update for Microsoft OneNote 2010 (KB3114410) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{007AAA88-1D1E-400B-B8FE-2C8DF2ABC700}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1062	Installed Programs	Update for Microsoft Outlook 2010 (KB2760779) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{B8BF0BCB-30FA-4BCA-BB01-2243B6295CC8}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1063	Installed Programs	Update for Microsoft Outlook 2010 (KB3114756) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-001A-0409-0000-0000000FF1CE}_Office14.SingleImage_{F81ABFD2-D304-4C54-A52B-A9640C4885CE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1064	Installed Programs	Update for Microsoft Outlook Social Connector 2010 (KB2553308) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-003D-0000-0000-0000000FF1CE}_Office14.SingleImage_{E7C8C158-9575-4120-AF5E-5CCEF2DD6761}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1065	Installed Programs	Update for Microsoft SharePoint Workspace 2010 (KB2760601) 32-Bit Edition	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{90140000-002A-0000-1000-0000000FF1CE}_Office14.SingleImage_{F9F5A080-AF38-4966-9A6B-C43DCA465035}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1066	Installed Programs	USSC Web Components	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4AD000A7-A6AD-46B1-95DC-11912B026D37}_is1	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1068	Installed Programs	Virtual Villagers - The Secret City	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087513	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1069	Installed Programs	Web Components	\N	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{03B13AF8-9625-478A-AF0E-205337B9415A}_is1	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1070	Installed Programs	WebM Media Foundation Components	1.0.1.2	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\webmmf	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1071	Installed Programs	Wedding Dash	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087519	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1072	Installed Programs	Windows Driver Package - Segger (jlink) USB  (07/28/2014 2.6.8.1)	07/28/2014 2.6.8.1	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\468237BA12C6D9DD0125166A16609C632EE9CF1C	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1073	Installed Programs	Windows Driver Package - SEGGER (JLinkCDC_x64) Ports  (08/28/2014 6.0.2601.5)	08/28/2014 6.0.2601.5	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\ED80E3D3A350D18BFD3D3D8DAED8E2B19105763A	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1074	Installed Programs	Windows Live	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{34319F1F-7CF2-4CC9-B357-1AE7D2FF3AC5}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1075	Installed Programs	Windows Live Argazki Galeria	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{86F444A5-C9B9-41DC-AF28-B5E46F5497C7}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1076	Installed Programs	Windows Live Communications Platform	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D45240D3-B6B3-4FF9-B243-54ECE3E10066}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1077	Installed Programs	Windows Live Essentials	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{43B43577-2514-4CE0-B14A-7E85C17C0453}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1078	Installed Programs	Windows Live Essentials	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WinLiveSuite	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1079	Installed Programs	Windows Live Essentials	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{06B05153-97E4-427E-B1A8-E098F6C5E52F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1080	Installed Programs	Windows Live Essentials	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7D1C7B9F-2744-4388-B128-5C75B8BCCC84}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1081	Installed Programs	Windows Live Essentials	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{7D99B933-E29C-4599-92F0-DAED2AF041E3}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1082	Installed Programs	Windows Live Essentials	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{FE044230-9CA5-43F7-9B58-5AC5A28A1F33}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1083	Installed Programs	Windows Live Galeria de Fotos	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F7A46527-DF1F-4B0F-9637-98547E189442}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1084	Installed Programs	Windows Live ID Sign-in Assistant	7.250.4225.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{1B8ABA62-74F0-47ED-B18C-A43128E591B8}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1085	Installed Programs	Windows Live Installer	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{0B0F231F-CE6A-483D-AA23-77B364F75917}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1086	Installed Programs	Windows Live Language Selector	15.4.3502.0922	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5EB6F3CB-46F4-451F-A028-7F6D8D35D7D0}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1087	Installed Programs	Windows Live Movie Maker	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A199DB88-E22D-4CE7-90AC-B8BE396D7BF4}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1088	Installed Programs	Windows Live Movie Maker	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92EA4134-10D1-418A-91E1-5A0453131A38}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1089	Installed Programs	Windows Live Movie Maker	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{71527C7C-5289-4CB2-88C9-23344C0FF6C1}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1090	Installed Programs	Windows Live Movie Maker	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6DEC8BD5-7574-47FA-B080-492BBBE2FEA3}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1091	Installed Programs	Windows Live Movie Maker	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5D273F60-0525-48BA-A5FB-D0CAA4A952AE}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1092	Installed Programs	Windows Live Movie Maker	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{19BA08F7-C728-469C-8A35-BFBD3633BE08}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1093	Installed Programs	Windows Live Movie Maker	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{226F0D93-76DE-4F1C-B14D-DE10443ADB60}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1094	Installed Programs	Windows Live Photo Common	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{120C160F-F53D-4A15-A873-E79BF5B98B48}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1095	Installed Programs	Windows Live Photo Common	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{D436F577-1695-4D2F-8B44-AC76C99E0002}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1096	Installed Programs	Windows Live Photo Common	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{B33B61FE-701F-425F-98AB-2B85725CBF68}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1097	Installed Programs	Windows Live Photo Common	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{C893D8C0-1BA0-4517-B11C-E89B65E72F70}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1098	Installed Programs	Windows Live Photo Common	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A41A708E-3BE6-4561-855D-44027C1CF0F8}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1099	Installed Programs	Windows Live Photo Common	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{A9BDCA6B-3653-467B-AC83-94367DA3BFE3}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1100	Installed Programs	Windows Live Photo Common	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{F0F5D89A-197C-495B-827E-3E98B811CD2E}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1101	Installed Programs	Windows Live Photo Gallery	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{3336F667-9049-4D46-98B6-4C743EEBC5B1}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1102	Installed Programs	Windows Live Photo Gallery	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{34F4D9A4-42C2-4348-BEF4-E553C84549E7}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1103	Installed Programs	Windows Live PIMT Platform	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{4CBABDFD-49F8-47FD-BE7D-ECDE7270525A}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1104	Installed Programs	Windows Live SOXE	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{682B3E4F-696A-42DE-A41C-4C07EA1678B4}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1105	Installed Programs	Windows Live SOXE Definitions	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{200FEC62-3C34-4D60-9CE8-EC372E01C08F}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1106	Installed Programs	Windows Live UX Platform	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{CE95A79E-E4FC-4FFF-8A75-29F04B942FF2}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1107	Installed Programs	Windows Live UX Platform Language Pack	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{ED86C4AB-D1E5-42CF-BFA3-56BAAE617D4E}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1108	Installed Programs	Windows Live UX Platform Language Pack	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{5CADEAC5-0A9C-4680-B850-6A9085ADD23B}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1109	Installed Programs	Windows Live UX Platform Language Pack	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{6A05FEDF-662E-46BF-8A25-010E3F1C9C69}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1110	Installed Programs	Windows Live UX Platform Language Pack	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{9A66D83C-269C-4812-932A-7CF41F0B1ABF}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1111	Installed Programs	Windows Live UX Platform Language Pack	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{96303101-1FF8-4887-9E89-993024271145}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1112	Installed Programs	Windows Live UX Platform Language Pack	15.4.3502.0922	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{09F56A49-A7B1-4AAB-95B9-D13094254AD1}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1113	Installed Programs	Windows Mobile Device Center Driver Update	6.1.6965.0	RegistryValue:String	Registry64:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{92DBCA36-9B41-4DD1-941A-AED149DD37F0}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1114	Installed Programs	Xobni Core	1.0.0	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{8DC069E7-893C-41E1-9442-DE89FEC33371}	\N
6918d2bd-0be4-41bc-8a85-80844875385f	1115	Installed Programs	Zuma Deluxe	2.2.0.95	RegistryValue:String	Registry32:HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\WT087533	\N
\.


--
-- Data for Name: Token; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Token" (id, type_id, user_level, personnel_id, badge_id, lost, last_read, last_reader, last_read_status, created, created_by, updated, updated_by, deleted, deleted_by, downloaded, downloaded_by, download_required) FROM stdin;
\.


--
-- Data for Name: TokenType; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "TokenType" (id, name, table_name) FROM stdin;
1	Access Card	Card
2	RFID Tag	RfidTag
\.


--
-- Name: TokenType_id_seq; Type: SEQUENCE SET; Schema: core; Owner: core
--

SELECT pg_catalog.setval('"TokenType_id_seq"', 3, true);


--
-- Data for Name: Vehicle; Type: TABLE DATA; Schema: core; Owner: core
--

COPY "Vehicle" (id, personnel_id, make, model, color, accent_color, state_or_prov, tag, sticker, year) FROM stdin;
\.


SET search_path = extra, pg_catalog;

--
-- Data for Name: AccessSet; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "AccessSet" (id, notes_id) FROM stdin;
\.


--
-- Data for Name: Blob; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "Blob" (id, type_id, bytes) FROM stdin;
\.


--
-- Data for Name: Card; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "Card" (token_id, card_emboss_num, card_label) FROM stdin;
\.


--
-- Data for Name: Notes; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "Notes" (id, text) FROM stdin;
\.


--
-- Data for Name: Personnel; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "Personnel" (id, name_middle, name_prefix, name_suffix, company, department, job_title, email, phone_work, phone_work_ext, phone_mobile, phone_home, address, city, state_or_prov, postal_code, country, notes_id, photo_id, signature_id, fingerprint_id, room, assigned_to, admission_date) FROM stdin;
\.


--
-- Data for Name: Vehicle; Type: TABLE DATA; Schema: extra; Owner: extra
--

COPY "Vehicle" (id, notes_id) FROM stdin;
\.


SET search_path = history, pg_catalog;

--
-- Data for Name: AccutechTagChange; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "AccutechTagChange" (id, change_time, event, card_number, name_first, name_last, name_middle, assigned_to, updated_by, room) FROM stdin;
\.


--
-- Data for Name: Activity; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "Activity" (id, "time", event_type_id, rtu_id, rtu_name, point_id, point_name, state, status, card_number, site_code, card_format, card_holder_name, computer, "user", user_comments, token_id) FROM stdin;
91774b41-9575-4e80-85cb-0c4fbe933537	2018-02-28 10:53:41.572169-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
dbbc1123-a03b-4605-8e02-9a3468482853	2018-02-28 10:56:35.091519-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
4795c839-2a60-4567-9f2b-1ee0f7c930e4	2018-02-28 11:04:14.172422-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5cc3f956-2b86-465e-9988-8bc1f7311304	2018-02-28 11:04:28.489854-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b0583961-77d9-4d92-8de4-1d940cec296f	2018-02-28 11:43:20.497031-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
0189788c-1967-4602-a89c-b71196ab10df	2018-02-28 11:43:25.358517-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ce6497b1-3bd9-4ab8-bd31-459f7ba4618d	2018-02-28 11:48:24.775456-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
31baeecb-989c-4aec-98bc-ea08acfcb439	2018-02-28 13:02:12.366171-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a25d7464-60a0-4495-9b1c-c0624a155644	2018-02-28 13:46:23.396247-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a3ce7f12-979c-49bd-aae9-580a7c91a260	2018-02-28 13:46:36.281536-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b7bc83e2-2cc3-461e-9bd6-0c7512d9621c	2018-02-28 13:47:36.469554-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
03e74316-29c8-4060-ac68-c38dca85c197	2018-02-28 13:47:41.168024-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
4dac001b-a0e6-4525-a07b-02c823fc3655	2018-02-28 15:51:00.425937-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
0eb0eaf3-dc73-4d42-93cb-0422ac585cca	2018-02-28 16:42:42.164079-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
63d1d3b8-4a71-467a-bf66-793401c54abc	2018-02-28 20:21:00.890821-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
7e8bc598-9cd2-4ec1-8917-607081c41419	2018-03-01 07:46:28.881265-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d0ec791e-c42f-4c92-8759-b74042b12826	2018-03-01 07:46:51.806558-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
0e7c821f-764a-4e18-b454-c448082a8e15	2018-03-01 07:50:45.215896-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6e0420dc-c533-47b0-9847-6e5798e3f76d	2018-03-01 08:04:16.258992-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
b3047e22-bd0a-4f7e-b2d5-5b543e8170de	2018-03-01 08:29:54.716823-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
45bcf7bd-26ba-47ff-9714-37b381cdfa86	2018-03-01 08:29:56.055957-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c750a80f-8e48-4f54-9905-3a29c0c71d0a	2018-03-01 08:29:57.056057-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a9707c0f-90d3-4d2a-8f35-34f6f1633617	2018-03-01 08:29:58.148166-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6c279c51-a181-42a5-bc2b-0329ce55eb71	2018-03-01 08:29:58.319183-06	5	21155	[21155] Area D Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e9c831eb-de3d-43c6-973b-f3c7d0e4a73c	2018-03-01 08:29:59.321283-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
803f6a51-8b8c-4cde-a378-6903f2d5bfa5	2018-03-01 08:30:00.678419-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c39e5322-5752-4af0-86b5-dd30841dd3a1	2018-03-01 08:30:01.538505-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
dda840ca-9fb3-4598-ab7c-23e8f1a384bc	2018-03-01 08:50:02.653361-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
6d6c3aa3-abcd-45c7-a513-2244874a27e3	2018-03-01 08:50:04.414361-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
b7dced6c-5727-4a96-89a1-0929848598b3	2018-03-01 08:50:04.590361-06	5	21155	[21155] Area D Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
b74e746e-af77-4489-b822-8c2b6b05ff01	2018-03-01 08:50:04.799361-06	5	21155	[21155] Area D Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
7928fa2f-ce23-412f-a691-69db3efa618c	2018-03-01 08:50:05.598361-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
f4bc4a96-7694-47eb-bc56-117e2828bdb7	2018-03-01 08:50:07.014361-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
8df5adde-b700-4c68-95f8-b3eaa1c8e658	2018-03-01 09:08:34.422836-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
c243ad60-9d3f-432b-ad79-fd85dedc8d3e	2018-03-01 09:08:36.143008-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
ff262176-ff32-4e25-a1f7-350bbc7a2b2c	2018-03-01 09:08:37.279122-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
2dc36d84-ebad-4128-8a38-aa5d14fdd6a4	2018-03-01 09:08:38.679262-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
2df9ee9d-1bd8-472c-ae7b-3daea6e9daa9	2018-03-01 09:08:40.048399-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
edee3edf-c468-45a8-8dbe-07dfd46bd159	2018-03-01 09:15:52.224612-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
fda47c60-c058-4454-bb8f-6825e757beec	2018-03-01 10:44:21.43648-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
07efec80-5544-4bff-a4ee-b7ee1b78938b	2018-03-01 10:44:34.995836-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a71cb1c0-fc46-4a51-9b0e-6c5ac09f5b10	2018-03-01 11:15:48.359153-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
700ca737-668d-4457-b009-ef5e56069d5d	2018-03-01 11:17:16.716988-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d8b451b1-ce0f-44e2-83b0-e08e35c1b000	2018-03-01 11:17:43.315648-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
47d55880-4a46-4c11-9719-167bbf9b5a33	2018-03-01 11:17:45.103827-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
548991ec-4b20-446e-949b-7855bde189af	2018-03-01 11:17:46.024919-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
73f66831-cbe8-4189-95cd-bb4dd5be0e58	2018-03-01 11:17:46.555972-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
dbb23cac-bdb0-4a23-a503-fdfd59b0cea8	2018-03-01 11:21:34.003714-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
259946a1-80f0-4ae1-9b03-36853a2a7596	2018-03-01 11:21:34.205735-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9a37990c-8514-4d20-8b6b-e0d28bd4a403	2018-03-01 11:21:34.427757-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
0d85f681-9a90-46ae-a417-3578ab09e08b	2018-03-01 11:21:35.877902-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
00d66b99-b497-4311-a65e-0dffbb937f3f	2018-03-01 11:21:35.880902-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
193d8256-6cc1-4753-a746-f9a2ee0a53ef	2018-03-01 11:21:36.970011-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
319e116a-e414-4597-b7c1-2f99ed81236c	2018-03-01 11:21:37.551069-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a41e8db3-1a6b-4b4e-af88-73e3adce8ae7	2018-03-01 11:21:39.313245-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1eab4796-5bdf-41eb-95ee-786f837af35a	2018-03-01 11:21:40.983412-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
4343f975-db55-45fc-bc23-22b5cb6da237	2018-03-01 11:21:40.991413-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
cc9546b6-c1a3-4aaa-beba-1b8142b59660	2018-03-01 11:21:44.150729-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b7b9017f-0c22-4a3d-9c9e-0f41e3caf810	2018-03-01 11:21:44.75779-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
da7adf38-b174-4c4e-8a12-4627094d844f	2018-03-01 11:21:44.782792-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
478cb1d0-d1b6-4bef-8c99-ca0e71452d39	2018-03-01 11:21:45.148829-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c711b27f-1079-4344-a5ad-112aeb75e3de	2018-03-01 11:21:45.734887-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
bfcfb2fd-d3a3-47de-af5a-ec72f56840ac	2018-03-01 11:21:45.737888-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e365210f-c484-4b8e-990f-e6491c5ebf6e	2018-03-01 11:21:49.687283-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ab7f6de2-f741-4c5e-bb51-f440cc998fd6	2018-03-01 11:21:50.227337-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
76549fbf-afc9-4fd7-abc1-6b513a9d73ae	2018-03-01 11:21:53.303644-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
da56e75f-f2cb-4925-971a-d268beed2a03	2018-03-01 11:21:55.138828-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ae51cd81-e4ec-4ddd-9a69-56409e6de8fd	2018-03-01 11:21:55.148829-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2280398a-87c1-4a98-9130-a0b207925f64	2018-03-01 11:21:55.488863-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ba0c7e65-2abe-4fb8-9f65-564fdee7e285	2018-03-01 11:21:56.56697-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e484205c-05b5-422d-b151-c55e7b179dcf	2018-03-01 11:21:56.570971-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e8d4aab9-5f21-4fd1-a7a0-3db0cd9cd5af	2018-03-01 11:21:59.040218-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a2ef46ef-ec0f-4d33-9a5e-c40914ed65a1	2018-03-01 11:21:59.584272-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6e32785c-3856-454a-a5ac-848356e5454e	2018-03-01 11:21:59.590273-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
04103d74-82fa-4a4a-a907-d51c6e01c0e8	2018-03-01 11:34:25.928899-06	5	21154	[21154] Area C Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
38542445-5e9e-4499-91f2-f6a5d9876346	2018-03-01 11:34:26.016908-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
05e5b446-1bb7-4f0d-a53a-02236817a9a1	2018-03-01 11:34:26.749981-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
41734161-dce4-404f-8010-6070e7da02e3	2018-03-01 11:34:27.428049-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
123519b1-c346-49e9-a94b-cdbdfe8f0b6d	2018-03-01 11:34:27.497056-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
ee4c6045-8e6d-4c1c-a7e6-867660ea04c1	2018-03-01 11:34:28.251131-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
8ba6bc44-5643-47bf-b415-0b72faa0a6c5	2018-03-01 11:34:28.83719-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
8b7a5c98-d4cd-45d3-96e5-46ec6418083a	2018-03-01 11:34:29.417248-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
c07918fe-9dc1-4893-b2bc-37988ceadb2f	2018-03-01 11:34:29.730279-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
b2f7e269-98fd-495e-874d-07bf5389aa91	2018-03-01 11:34:30.34034-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
b90ecb52-1775-45c4-a82b-76e38134e71c	2018-03-01 11:34:30.825389-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
d3adbe54-9e1c-474b-8603-9156f47bf6de	2018-03-01 11:34:31.186425-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
a3eb0b75-5b27-4eca-91b8-ba4ca5081366	2018-03-01 11:34:32.907597-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
76f0c7a5-8b79-4791-84dd-ed7251b37be4	2018-03-01 11:34:34.305737-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
c5693a15-4cbf-4dfa-844b-f96a668117f6	2018-03-01 11:34:34.889795-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
2c5c2a56-6a7c-4bf2-bba2-fb8bf887e90f	2018-03-01 11:35:12.111517-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
6227793e-6f3a-40bf-b801-1872179ff95d	2018-03-01 11:35:41.219427-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
8189430f-fe62-44eb-b89a-4c7338c4d9d7	2018-03-01 11:36:11.704476-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
2c262ef4-e4f7-4cf4-b9b5-595a6fe5a3db	2018-03-01 11:36:12.296535-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
6ed6ff0c-bd81-436c-b5cf-c1619aa4e1b6	2018-03-01 11:36:12.827588-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
072c7d95-d148-4575-8eb7-e7eef9b88ff3	2018-03-01 11:36:25.469852-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
4158068c-2962-4c9a-bd1b-3ff8c0cadcf0	2018-03-01 11:36:25.725878-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
8b7f7df0-6b8f-402c-b343-0da278092da3	2018-03-01 11:36:26.438949-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
4b8b0466-aab1-4a30-a60c-e9a98fc8a370	2018-03-01 11:36:27.034008-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
c6ff9833-2b14-42f0-b8f2-bb16f9835b40	2018-03-01 11:36:28.605166-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
278c47c7-e7d4-45dd-9b6c-2be22ca83eda	2018-03-01 11:36:29.224227-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
c2033ee8-2b49-4f11-9983-629f0f2cc67a	2018-03-01 11:36:29.824287-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
56aab1fb-b0cb-4696-a6be-763fa6bd0ccc	2018-03-01 11:37:18.765181-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
c0a56e15-641d-4b6f-afe7-e35181b74294	2018-03-01 11:37:32.65457-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
ba433ea5-f0af-456d-8b95-299246828b30	2018-03-01 11:37:32.775582-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
d9eb2cbc-056b-453b-9d22-28767090fafa	2018-03-01 11:43:25.541855-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1f989f51-ddd9-4a44-9df8-abb6549c12fd	2018-03-01 11:43:25.743875-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
58472177-4b90-461e-b8fa-ba3e2dea55da	2018-03-01 11:53:42.247519-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
3891162c-0d23-47a3-b93c-703be5a38d6d	2018-03-01 11:53:42.565551-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f6215195-b691-40fb-b5ef-48e8c9a71e7a	2018-03-01 11:53:42.766571-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
efb089e3-7597-4527-be30-ee19f480ddd1	2018-03-01 11:53:43.410636-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e672fdca-c04a-4243-8daf-309b32dc75d4	2018-03-01 11:53:43.929688-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5205fe8f-8224-4936-a204-16e694b670fe	2018-03-01 11:53:43.934688-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
82c93e80-68d6-4a12-8907-cb61ae2585c8	2018-03-01 11:53:44.394734-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
325bdff1-922c-4bda-90d7-b995428feca7	2018-03-01 11:53:44.974792-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9d24a612-8501-4678-8df7-9f9f7bc0685c	2018-03-01 11:53:44.978793-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2ddddb95-b79a-40eb-90ba-769e5a698112	2018-03-01 11:54:02.508545-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
92be8c50-f777-48dd-a48d-b20b9d5ecf18	2018-03-01 12:01:10.224313-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b7fe93bd-4963-425a-94b0-60eb6c800f6b	2018-03-01 12:01:24.748765-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
35d995c9-df39-4353-8dc5-b0f2c5e651da	2018-03-01 12:01:34.709761-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a0e4e936-0d72-45ca-b9ed-d5fe577e39ff	2018-03-01 12:02:21.456435-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
373adb14-4bd7-44a0-bb71-e2ca350f2641	2018-03-01 12:02:37.781067-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
4b6ed205-ba7b-40b2-904a-1d59bd571ecc	2018-03-01 12:02:48.729162-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6335629f-6227-4617-b303-c423356d9282	2018-03-01 12:04:02.01549-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
be418b8a-adbb-4448-abe6-6861eda5f990	2018-03-01 12:04:15.162805-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
706370cc-a593-4626-858e-83ed58469091	2018-03-01 12:04:22.390527-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
55507cfb-338b-4127-9cca-7fc98115c2f3	2018-03-01 12:05:10.602348-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
da6b0f43-3a5c-4e59-b96c-6a2e8b2bbf21	2018-03-01 12:05:29.537241-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1a8219f7-777a-46c2-bd7d-6d6d255b2f93	2018-03-01 12:05:36.289917-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c443d5fd-5b21-487f-832a-1bb7e42f5332	2018-03-01 12:07:24.916778-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
445fd258-6ec7-48cc-b5c4-b1afa15c8d11	2018-03-01 12:07:25.916878-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
bb146cfd-3a44-4a4a-ad7e-06187381f511	2018-03-01 12:17:41.337414-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
03a996f1-e48d-4db7-a0db-95262942e562	2018-03-01 12:25:57.091985-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
45043521-2763-43fe-9480-a216ec123dc2	2018-03-01 12:27:04.225697-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
dd94ea35-3b56-4377-8912-3b1362134fc5	2018-03-01 12:27:23.921667-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
76267391-1fcc-4e54-9ea6-ca1ff9cd7611	2018-03-01 12:37:08.260095-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ff0ee322-3c62-4bd2-87f7-3696319ab06c	2018-03-01 12:37:08.285097-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
0e2c54ba-3f27-4b06-ae13-85cee7635ca5	2018-03-01 12:37:09.01017-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b857cbff-edb3-44c3-a031-ffcd95b1684f	2018-03-01 12:37:10.065275-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
730888c3-6b81-4008-af1f-60f5fdd08dcc	2018-03-05 08:22:46.079194-06	5	22441	[22441] Door 405A	0	MouseDown	0	Pulse [2306] R1C4-16R\\LOCK DR-405A Relay	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
c0536077-1475-4314-ac28-e05bf9f1cf0a	2018-03-01 12:37:10.068275-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
cf615e0b-de0a-43fb-a652-e6c2b7f01e41	2018-03-01 12:37:11.260395-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e364e71b-bc44-4275-adec-628a784e1920	2018-03-01 12:37:11.780447-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
721946b1-9bc5-49b2-b53d-9c87a5371ba9	2018-03-01 12:37:11.789448-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
688744f1-088f-403d-9bd7-5b93ff60a3cd	2018-03-01 12:37:12.073476-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c915e8d9-9307-48fd-8e44-68a3b5022e67	2018-03-01 12:37:12.820551-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e5d5c7dc-bfe6-471f-a689-d717944d77e3	2018-03-01 12:37:14.226691-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
851fc292-6ecf-4a6d-8faa-aba5924fe063	2018-03-01 12:37:15.594828-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
219e3b5e-9bc5-4fa1-90d3-41ab1f38640d	2018-03-01 12:37:15.603829-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
44535f47-eb0a-4b1c-bc46-890733834f70	2018-03-01 12:39:39.866254-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8778afdd-a029-4017-9600-54c230a224ee	2018-03-01 13:05:40.209272-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
9b61eaf8-9ee4-4a9c-8b24-307b14462de7	2018-03-01 13:05:40.293281-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
31ba336f-2d7d-49b0-9179-193e41348de3	2018-03-01 13:05:42.047456-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
ae934abd-b9b4-497f-a948-a53cc8ba2fab	2018-03-01 13:05:43.355587-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
376f9b83-6728-40e8-8812-386df2c174fc	2018-03-01 13:05:43.827634-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
f1a56dc6-024e-4987-a903-0d3181e0d86c	2018-03-01 13:05:45.816833-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
a0e47d3b-e735-49ff-beed-bf37d9f0f715	2018-03-01 13:05:46.473899-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
833edd0d-905e-4930-aac0-fc16676063eb	2018-03-01 13:05:48.727124-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
be95fd46-2662-44ad-a5a7-d1a5899cf005	2018-03-01 13:05:50.533305-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
2172a876-c850-448f-a84f-d20fe573cfb8	2018-03-01 13:05:51.014353-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
41da0f9d-5282-400e-a206-772b4fd6c87f	2018-03-01 13:06:05.88384-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
89daebee-5581-444c-a9f2-db9b254249a6	2018-03-01 13:29:37.395977-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
46e6b4c9-e48c-488a-a6aa-f1db0f9a04a7	2018-03-01 14:38:03.852581-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
153fc8cb-9504-47c0-9ba3-8a92adb91552	2018-03-01 15:14:48.300004-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[21062] a	\N	\N	00000000-0000-0000-0000-000000000000
e618c647-4b88-4b0a-a26e-32b48e4c063a	2018-03-01 15:14:54.814655-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
95d25486-9ae4-45fb-8f3e-7c897b5d75c5	2018-03-01 15:16:47.399913-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
e9d63809-e175-4878-9059-e6d4865b1ee3	2018-03-01 15:16:47.484921-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
857449f2-b874-4e05-825c-b506cec85f4a	2018-03-01 15:16:49.930166-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
927eb8e6-2457-4e4d-81d7-65defef86b92	2018-03-01 15:16:51.518325-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
172132b4-aeff-452b-b180-e286cb905607	2018-03-01 15:16:51.998373-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
722a5373-695a-4011-b803-87f03f69b8de	2018-03-01 15:16:52.955468-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
9b049f39-e1dc-49d3-9c23-723a27620f72	2018-03-01 15:16:53.878561-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
88149f18-6cf7-48a8-a6d5-2adb40bdca67	2018-03-01 15:16:54.359609-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
3fc2f68b-37e8-4869-9741-67ff47119933	2018-03-01 15:16:54.435616-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
20f650ad-114c-4b7c-8985-216ff69df15b	2018-03-01 15:16:55.083681-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
52ba61f1-c8ea-4d9c-88d9-438c58c72dae	2018-03-01 15:16:55.565729-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
3fde5c6b-39ff-4495-b28e-7e5475469629	2018-03-01 15:17:02.148388-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
da3a66ea-7a30-4a23-bb4f-e2c363ed4e43	2018-03-01 15:53:04.28458-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
574bef2b-9485-4498-adcb-064a1846eb1b	2018-03-01 15:53:07.78593-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
ec6486d1-e9c6-4514-8638-6e4301cf2149	2018-03-01 15:53:09.739125-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
01c3a16e-6d46-449d-835d-956d8d8f5227	2018-03-01 15:53:27.09486-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
98fafbec-6411-4539-860e-69e46da17d62	2018-03-01 16:32:00.900218-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
1a4cfa7f-19c1-43b1-94dd-bbea94db48ff	2018-03-01 16:32:04.388567-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
21e63e16-cc46-4a43-8dc4-c1cc7068dbd7	2018-03-01 16:44:36.447765-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
2934697d-3696-4324-817f-66a358593c2d	2018-03-01 16:44:36.921812-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
8e8738fb-2550-4e7d-ba8e-95e716060f0c	2018-03-01 16:44:37.233844-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
8b096bc5-ece7-48c6-bd48-635aa7587b78	2018-03-01 17:16:42.684369-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b01e4def-90e7-4bff-9bfc-4fac0cf47219	2018-03-01 17:17:48.312932-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2333481f-214b-4431-bf23-1b38323fa121	2018-03-01 17:55:22.274898-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d768abe4-5b35-4022-9f3a-abbde1b9d9f3	2018-03-01 19:18:20.792168-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
03e30b70-03b2-4d5a-85cd-6aee6bd22992	2018-03-01 19:19:01.652254-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
75ed942a-9335-4bd0-ac09-802faaba44b3	2018-03-01 19:20:10.685156-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
4c320808-278d-40ef-a8d3-7abf5c004ca9	2018-03-01 19:20:29.090997-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6b8f4269-9a42-474b-98e5-87fd46e202e2	2018-03-01 19:20:30.02609-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
dce74ed8-f11b-49ef-936e-6f6d910164c5	2018-03-01 21:43:24.27543-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
880e9087-cea7-45ef-83d4-e80a030e01db	2018-03-01 21:43:26.132615-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
df9f78e2-f8d3-4669-a4a6-6188501659bc	2018-03-01 21:43:27.253727-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d76024ca-eeee-44d2-816e-c34ce629fbc6	2018-03-01 21:44:01.289131-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
02536ff4-117b-4dcc-8781-5acd86344dff	2018-03-01 21:44:01.651167-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
045335ed-9899-46d5-b8be-27f1b868c302	2018-03-01 21:44:01.873189-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1576ccbf-85e0-4a67-a3d5-339e13f07271	2018-03-01 21:44:04.461448-06	5	21227	[21227] Door 114B	0	MouseDown	0	Pulse [15795] R7C1-16R\\Lock DR-114B Relay	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e5eefe18-12aa-4259-b212-491153a0daf2	2018-03-01 21:44:29.698971-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6f57e23f-3ea6-421c-911e-f1a3f7db8012	2018-03-01 21:44:31.773179-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
36c9b280-50a5-491a-bd7d-b42bcc523137	2018-03-01 21:44:32.009202-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e917624b-4a13-4b18-8bee-87afbaf9529d	2018-03-01 21:44:33.59136-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
0abc452f-2aec-45e0-9eeb-1edc756b53e3	2018-03-01 21:44:35.016503-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
84cf713e-3304-4918-8129-6a88c051a22a	2018-03-01 21:44:36.315633-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
63c040c0-74ed-4b27-ae3e-5599801c40e9	2018-03-01 21:44:36.968698-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[21062] a	\N	\N	00000000-0000-0000-0000-000000000000
315ec703-f8d8-4d71-a532-30783eb73103	2018-03-02 03:49:18.128656-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
c62f20da-c042-420d-878a-307d8f8e5549	2018-03-01 21:44:36.995701-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6a728f99-7f98-41d6-9d88-15509e256722	2018-03-01 21:44:39.578959-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
04af0187-654a-485e-995c-aa756aad21a1	2018-03-01 21:44:40.243026-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
85150402-e2e6-4234-8f36-ffb37fde338a	2018-03-01 21:44:56.961697-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
63ec0afd-c637-4729-bf3b-5db41cac9497	2018-03-01 21:45:02.515253-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6648622a-26dd-4727-97ec-aacb8ea7683c	2018-03-01 21:45:03.271328-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e4fa0f51-b3bc-4573-b3b2-d2215f29bb23	2018-03-01 21:45:06.879689-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
29208fc8-4e67-4e6a-94a1-029c481552eb	2018-03-01 21:45:07.930794-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ceffeebc-2ac8-496e-9812-62cf7eeeb57c	2018-03-01 21:45:10.269028-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9a641aa3-293d-4d20-8fa7-9159321082a2	2018-03-01 21:45:14.081409-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a7a7e965-eea1-4ef8-b69b-22d36003ea12	2018-03-01 21:45:16.849686-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
4c7e9b95-3804-450f-9ced-d7eb642f8afb	2018-03-01 21:45:18.539855-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
848df180-8b0d-46ab-9fee-5c3e61c89b0b	2018-03-01 21:45:20.584059-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
02b84079-6737-4074-9d81-54af72540b22	2018-03-01 21:45:22.062207-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
866e153c-b84a-44b6-8cd2-b4b9c4235692	2018-03-01 21:45:23.021303-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
30ac7729-ce2a-42ce-b739-e927c88f64b2	2018-03-01 21:45:23.811382-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a22a301f-2e44-48e2-bd68-9ee0273c62c4	2018-03-01 21:45:24.804481-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
41bb16e0-406f-48d8-9b86-d5c81e13699a	2018-03-01 21:45:25.171518-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
708a1614-a866-4761-8261-0a60caf02d9e	2018-03-01 21:45:25.872588-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
528b3e28-6fdb-4c95-ada6-ba33f48a67ff	2018-03-01 21:45:38.684869-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
65b19ef4-d6d1-4543-8eb7-180dc0c46c91	2018-03-01 21:46:06.475648-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e87de6a7-8dae-48c0-8ecb-1b7e02e84906	2018-03-01 22:08:43.672354-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
d0c419e8-a638-46b4-89de-8edaa71d46c5	2018-03-01 22:09:08.809868-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
955c94b3-4a34-48b0-97a5-a2460fb20d14	2018-03-01 22:24:19.876965-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
e13d1291-9dd9-4c36-bb5a-986edbc94d8e	2018-03-01 22:24:38.299807-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
92b80df0-1470-47a3-acca-389a7d3b4fdc	2018-03-01 22:42:43.667333-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
99c92cd3-94dd-4182-8e84-7b0514f665b2	2018-03-02 03:48:37.084552-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
2ba11c65-de72-4c57-8293-fc6655688378	2018-03-02 03:49:12.86813-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
e450d046-396e-4a25-b0df-c527052e48d5	2018-03-02 03:49:15.577401-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
03470d03-68da-41e2-b677-5ec3a0f6da8b	2018-03-02 03:49:16.076451-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
790b6aa0-9253-49e3-aa94-7c0e77845cf5	2018-03-02 03:49:16.881532-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
de53fe2e-de25-4183-aae9-a5cef3736b26	2018-03-02 03:49:17.619606-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
68f3c529-4930-4d46-b736-2d22e640268d	2018-03-02 03:49:18.124656-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
a25739e4-94b7-470e-9f8e-93ee0626ace4	2018-03-02 03:49:19.831827-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
21c48b5a-e240-40b8-bfa4-fbe9fd58bf49	2018-03-02 03:49:20.336877-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
7879e409-b59b-4a87-90ef-4e17361affd2	2018-03-02 03:49:23.354179-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
fd75403f-30cc-4141-a5c6-11e1b76f0a97	2018-03-02 03:49:24.824326-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
a1f5b3bd-afda-449f-83d8-19834c8995bc	2018-03-02 03:49:31.515995-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
9e950657-b089-4ba4-bd66-cbfed1258702	2018-03-02 03:49:32.001044-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
9dded022-f9d1-44c7-afea-fd723386a69f	2018-03-02 03:49:41.887032-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
d5770698-5257-4682-82a0-e2e2ab6d4030	2018-03-02 03:55:46.874527-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
191ad0fd-08ac-4a2e-a6df-5d2008235c30	2018-03-02 05:51:03.863157-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d35c6442-0290-4634-847f-82f7d4f6ac97	2018-03-02 05:54:54.288197-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a8648f1e-b56e-4cd7-a11a-552bb76599a8	2018-03-02 05:54:54.488217-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
30f8c1d8-340e-469d-90da-bb02e47b1bbd	2018-03-02 05:54:55.954364-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5dbcbfe8-4515-4017-b50a-bd8fe8600f28	2018-03-02 05:54:56.801448-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e08382d3-3fcf-41d8-9388-a4b6b8cf06b0	2018-03-02 05:54:56.804449-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f68af08c-0723-4b05-ba91-1462ff257758	2018-03-02 05:55:32.287997-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
2dc3ab8c-8901-4e95-b915-42365f0834ff	2018-03-02 05:55:54.958263-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1a8bac2a-69df-4dcb-bd8e-2fd81a4e0b18	2018-03-02 06:10:45.000259-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
bc2a0b0c-f3c6-4700-9cf2-27cf6d308fa9	2018-03-02 06:10:59.703729-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
862c3260-47e6-4dc5-94c5-4343bb4a3e25	2018-03-02 06:11:30.586817-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
5020e8bb-c748-4c11-8734-b5cd24ab9e9c	2018-03-02 06:11:36.61342-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f1cb4fca-b801-464a-961a-784f1d219af9	2018-03-02 06:25:18.713621-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
8cb1a7f9-793b-43c4-a268-b580e566e976	2018-03-02 06:25:35.932343-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
ddf6a354-414c-464f-892f-12a1c0859ecb	2018-03-02 06:52:38.423576-06	5	21686	[21686] A 1 MULTI-USE DINING 122 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21506] Counters\\A Cameras\\A 1 MULTI-USE DINING 122 	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
848f738a-2ef2-4e21-90e4-804473fb891f	2018-03-02 06:52:40.383772-06	5	21688	[21688] A 3 MULTI-USE DINING 123	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21508] Counters\\A Cameras\\A 3 MULTI-USE DINING 123	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
8d14f17e-5ff0-4d49-a45c-f9920799d697	2018-03-02 06:52:42.388972-06	5	21686	[21686] A 1 MULTI-USE DINING 122 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21506] Counters\\A Cameras\\A 1 MULTI-USE DINING 122 	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
c7a2c908-44e1-49fe-a6b4-6d8c3f8ad96f	2018-03-02 06:52:44.76821-06	5	21687	[21687] A 2 MULTI-USE DINING 122	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21507] Counters\\A Cameras\\A 2 MULTI-USE DINING 122	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
27fdc051-594b-43ef-8bd7-9da91ebb9255	2018-03-02 06:52:45.624296-06	5	21688	[21688] A 3 MULTI-USE DINING 123	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21508] Counters\\A Cameras\\A 3 MULTI-USE DINING 123	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
bdc06b23-0936-400b-b9a2-b89515c68c36	2018-03-02 06:52:46.395373-06	5	21689	[21689] A 4 MULTI-USE DINING 123	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21509] Counters\\A Cameras\\A 4 MULTI-USE DINING 123	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
2f5e3c1f-649c-405b-b997-d3d1944ffada	2018-03-02 06:52:47.225456-06	5	21690	[21690] A 5 LIVING ROOM 113	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21510] Counters\\A Cameras\\A 5 LIVING ROOM 113	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
da268b8f-61d6-4cf8-b327-d0c734f5f442	2018-03-02 06:52:47.905524-06	5	21696	[21696] A 11 LIVING ROOM 133	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21516] Counters\\A Cameras\\A 11 LIVING ROOM 133	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
a0cb5698-fa92-4a14-b460-b51464a5938a	2018-03-02 06:52:48.738607-06	5	21695	[21695] A 10 LIVING ROOM 133	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21515] Counters\\A Cameras\\A 10 LIVING ROOM 133	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
76e4c442-3940-4cba-ba4a-54cf057c69c1	2018-03-02 06:52:49.328666-06	5	21694	[21694] A 9 COURTYARD 114	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21514] Counters\\A Cameras\\A 9 COURTYARD 114	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
7751f3cf-e846-43c0-a65f-66a6bbd3c092	2018-03-02 06:52:50.397773-06	5	21693	[21693] A 8 LIVING ROOM 113	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21513] Counters\\A Cameras\\A 8 LIVING ROOM 113	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
ebbc73fa-057d-4ca6-921e-b3fa96ee11cd	2018-03-02 06:52:50.884822-06	5	21692	[21692] A 7 LIVING ROOM 113 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21512] Counters\\A Cameras\\A 7 LIVING ROOM 113 	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
4d9dd1a9-4993-4c0d-9e7e-edcd83629b4b	2018-03-04 09:20:36.735901-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5ab469ad-2f9d-49e1-80d7-e957afe910c4	2018-03-02 06:54:06.918425-06	5	21691	[21691] A 6 LIVING ROOM 113 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21511] Counters\\A Cameras\\A 6 LIVING ROOM 113 	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
eebe7d51-dac8-41de-ba98-9f17e6b8bdba	2018-03-02 06:54:07.881521-06	5	21697	[21697] A 12 LIVING ROOM 133 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21517] Counters\\A Cameras\\A 12 LIVING ROOM 133 	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
1dd14653-0dc2-44a8-9769-8194776cb818	2018-03-02 06:54:08.46958-06	5	21709	[21709] A24 ADA SLEEPING 119	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21529] Counters\\A Cameras\\A24 ADA SLEEPING 119	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
f2e09c3f-5fc4-4ebb-9d90-c05f7926ce27	2018-03-02 06:54:09.184651-06	5	21722	[21722] None	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21535] Counters\\A Cameras\\None	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
3e4b3069-506c-4d82-9b0a-165309ba4842	2018-03-02 06:54:11.461879-06	5	21686	[21686] A 1 MULTI-USE DINING 122 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21506] Counters\\A Cameras\\A 1 MULTI-USE DINING 122 	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
c4912d84-435b-4bf1-a951-31e8280a56bf	2018-03-02 06:54:12.156948-06	5	21687	[21687] A 2 MULTI-USE DINING 122	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21507] Counters\\A Cameras\\A 2 MULTI-USE DINING 122	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
0366546f-fc12-4899-b2e8-790533b1e083	2018-03-02 06:54:12.710004-06	5	21688	[21688] A 3 MULTI-USE DINING 123	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21508] Counters\\A Cameras\\A 3 MULTI-USE DINING 123	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
ce3bb86c-020f-4a84-8932-ea7330871463	2018-03-02 06:54:13.845117-06	5	21689	[21689] A 4 MULTI-USE DINING 123	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21509] Counters\\A Cameras\\A 4 MULTI-USE DINING 123	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
03b9f056-c1e9-4ad7-91c5-fef949bd91a0	2018-03-02 06:54:14.323165-06	5	21690	[21690] A 5 LIVING ROOM 113	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21510] Counters\\A Cameras\\A 5 LIVING ROOM 113	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
78516041-2a64-4d5b-9320-00f891056075	2018-03-02 06:54:58.462578-06	5	21699	[21699] A 14 COURTYARD 134 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21519] Counters\\A Cameras\\A 14 COURTYARD 134 	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
907718e1-42f8-4e06-9d73-1cd418704fa0	2018-03-02 06:59:04.40017-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
67bab4f6-52c4-486c-86e8-e032b24254b7	2018-03-02 06:59:04.438174-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
6c235107-c306-4bc9-a8e0-5af1e33cf2bc	2018-03-02 06:59:04.976227-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
30c32189-6d87-4d35-90fe-1f33fb2883b6	2018-03-02 06:59:06.470377-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
ffd0918b-227d-4539-a1f9-fb6bf381d49e	2018-03-02 06:59:06.993429-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
a5426925-8050-4134-9d60-11c70ff69bd5	2018-03-02 06:59:06.997429-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
01e1da76-3750-4e36-8994-bcc59ab8e24f	2018-03-02 06:59:08.564586-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
c8d49c96-4b0c-4560-a599-9b060ac37097	2018-03-02 06:59:10.526782-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
eed4c933-bba4-4a62-ab11-0062d410a680	2018-03-02 06:59:12.461976-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
4d0505b6-b7a4-4d2a-afdc-21e730e05f20	2018-03-02 06:59:12.975027-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
fe28c251-79fb-482a-9c81-3f47cd3272d6	2018-03-02 06:59:12.979028-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
be2b6224-8910-4dec-95e6-ebc22f1fbc9f	2018-03-02 06:59:13.90112-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
a8838dc1-6bcd-408b-b5ce-cdf9b256a0a2	2018-03-02 06:59:14.424172-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
75a3f04d-38bc-4349-b00c-2a3ef1beec96	2018-03-02 06:59:22.475977-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
19b7b2a5-6adc-41ec-b806-d5bf8f14df79	2018-03-02 06:59:27.891519-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
5251dea4-8b35-422a-84b5-e3dbd29ceaac	2018-03-02 07:03:25.179245-06	5	21155	[21155] Area D Target	1	MouseDown	0	\N	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b3e8d038-e80e-40a7-86ce-6bf2d88e6664	2018-03-02 07:03:31.039831-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9a4ad930-c3df-4866-ba80-996942248663	2018-03-02 07:03:31.044832-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
0af04902-78fd-46a4-875f-a9ee4a985657	2018-03-02 07:03:47.725499-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9bcc61f4-d5b6-4371-a487-670d8010fda3	2018-03-02 07:03:48.648592-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9170f2c7-ded2-4b62-a534-1a55e38c4b1b	2018-03-02 07:03:48.651592-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
89289601-5ebc-4ab4-abe7-a78e46d22a61	2018-03-02 07:03:50.910818-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e2446da8-2245-4d30-abdd-9a9dc7d9519f	2018-03-02 07:04:25.952322-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
0130ea28-2910-4710-ae47-990f05d3f42f	2018-03-02 07:04:26.151342-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
619c3606-1d3b-4a0e-bed3-48c30b206460	2018-03-02 07:04:26.577384-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
38ec8bf2-9426-47d2-bda2-0fc77232218d	2018-03-02 07:04:29.150642-06	5	21691	[21691] A 6 LIVING ROOM 113 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21511] Counters\\A Cameras\\A 6 LIVING ROOM 113 	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
148aade8-cd35-4823-b761-816dada9cbcd	2018-03-02 07:04:30.810808-06	5	21697	[21697] A 12 LIVING ROOM 133 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21517] Counters\\A Cameras\\A 12 LIVING ROOM 133 	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8dba3a7e-388f-4aed-a6b7-24270fe9a616	2018-03-02 07:04:32.103937-06	5	21703	[21703] A 18 CORRIDOR 154	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21523] Counters\\A Cameras\\A 18 CORRIDOR 154	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
27b3104c-b36e-41f5-8d26-7ffcb91f2702	2018-03-02 07:11:00.294752-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
20383300-e066-4e91-a776-37c09bfe320a	2018-03-02 07:11:34.006123-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
49ec3889-b40d-4018-bae7-564f4b0066c9	2018-03-02 07:11:34.049127-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
b10f38a4-8a90-44bb-a1b5-3c879be7b8f6	2018-03-02 07:11:34.57918-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
9455b912-e4f8-4c5f-9a17-92956eb530b1	2018-03-02 07:11:36.163339-06	5	21154	[21154] Area C Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
efbe25fa-5a1f-4389-8d98-32ef937a8e60	2018-03-02 07:11:36.691391-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
96540872-4456-4154-9f6a-f5d8e4407ff1	2018-03-02 07:11:36.695392-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
2f0e51ba-1dd1-48da-a33d-fc2066cee584	2018-03-02 07:11:37.083431-06	5	21155	[21155] Area D Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
d7377d53-421d-4f19-9512-1e455c9d773c	2018-03-02 07:11:39.741696-06	5	21156	[21156] Area E Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
622de38d-c48b-4562-a9b5-16e61ee7f118	2018-03-02 07:11:41.334856-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
61c05992-6c05-4a1d-846d-c8c4c01be173	2018-03-02 07:11:41.888911-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
4e382aa7-db2a-4f73-ac62-6bb213e8a9c6	2018-03-02 07:11:41.909913-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
e69b6630-1593-43fa-9b63-4d3a3bb9152a	2018-03-02 07:11:42.751997-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
ecbd7a5a-028f-483f-8462-8b960bbe1205	2018-03-02 07:11:43.27705-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
3d00f535-acac-4fa9-b4f3-b0390bef3e31	2018-03-02 07:11:55.466269-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
29bce31e-254f-4e54-b180-0ffebb678934	2018-03-02 07:12:47.946516-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
0dd91c64-82e1-4601-8abb-c313925a3dcd	2018-03-02 07:12:48.48557-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
53110a31-2908-45e8-b9c8-f0263d17cd16	2018-03-02 07:12:59.471669-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
7fcc8b7c-ecf5-4d62-b0cf-f2bca811ecb8	2018-03-02 07:13:03.123034-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
62a6b6c4-2093-4b29-bcba-acee439212c0	2018-03-02 07:13:03.129034-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
c69fd950-6353-4868-88c7-fe3d3c2c0e34	2018-03-02 07:13:05.624284-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
1e870b2a-543a-45e5-a2e8-e947b4827869	2018-03-02 07:13:06.08733-06	5	21154	[21154] Area C Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
a81b5719-06f5-4f00-bee5-39ea4e9b7a88	2018-03-02 07:13:06.597381-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
5915a9b3-6d98-4fc6-afde-8043d4de024e	2018-03-02 07:13:18.738595-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
0da0f44c-af7c-4ac5-a0e9-f12840cc489d	2018-03-02 07:13:20.170738-06	5	21155	[21155] Area D Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
4da7a859-eaeb-4876-a5dc-298b823fa479	2018-03-02 07:15:34.434163-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
14d68de7-8418-467c-99da-f0332c14b4be	2018-03-02 07:15:34.967217-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
98bce84e-5948-4f3a-b907-80626193491c	2018-03-02 07:15:35.8063-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
cad0fee6-3a7c-4741-90f1-24b124b2c667	2018-03-02 07:19:32.770995-06	5	21686	[21686] A 1 MULTI-USE DINING 122 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21506] Counters\\A Cameras\\A 1 MULTI-USE DINING 122 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
83dc17aa-91d5-436f-a8fb-edf6732db52a	2018-03-02 07:19:33.290046-06	5	21687	[21687] A 2 MULTI-USE DINING 122	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21507] Counters\\A Cameras\\A 2 MULTI-USE DINING 122	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
eb32241e-92f9-41e8-8c99-f0c015b0319c	2018-03-02 07:19:33.835101-06	5	21688	[21688] A 3 MULTI-USE DINING 123	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21508] Counters\\A Cameras\\A 3 MULTI-USE DINING 123	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
f86283b1-7576-438c-802b-da57e01a4b6a	2018-03-02 07:19:34.831201-06	5	21689	[21689] A 4 MULTI-USE DINING 123	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21509] Counters\\A Cameras\\A 4 MULTI-USE DINING 123	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
94e47659-0a56-42bc-811f-4c536ad78594	2018-03-02 07:19:35.485266-06	5	21690	[21690] A 5 LIVING ROOM 113	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21510] Counters\\A Cameras\\A 5 LIVING ROOM 113	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
3438f429-3540-427e-b1f4-0b445e180b12	2018-03-02 07:19:36.057323-06	5	21696	[21696] A 11 LIVING ROOM 133	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21516] Counters\\A Cameras\\A 11 LIVING ROOM 133	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
2b63c314-c5be-425b-a181-a2ab790358bc	2018-03-02 07:19:36.568374-06	5	21695	[21695] A 10 LIVING ROOM 133	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21515] Counters\\A Cameras\\A 10 LIVING ROOM 133	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
fe4daaa9-10a1-4089-968c-9c3ddc526fa3	2018-03-02 07:19:37.466464-06	5	21694	[21694] A 9 COURTYARD 114	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21514] Counters\\A Cameras\\A 9 COURTYARD 114	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
3f5319ca-85e9-414d-9763-b9e3adb0f241	2018-03-02 07:19:38.356553-06	5	21693	[21693] A 8 LIVING ROOM 113	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21513] Counters\\A Cameras\\A 8 LIVING ROOM 113	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
b0f594d1-9385-4fc7-92c5-fe5f2d9cabb4	2018-03-02 07:19:38.945612-06	5	21692	[21692] A 7 LIVING ROOM 113 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21512] Counters\\A Cameras\\A 7 LIVING ROOM 113 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
a6437a97-ae48-40f7-9473-94703c920628	2018-03-02 07:19:39.445662-06	5	21698	[21698] A 13 LIVING ROOM 133 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21518] Counters\\A Cameras\\A 13 LIVING ROOM 133 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
d5c1b564-6dfd-46c2-969b-78514df53883	2018-03-02 07:19:39.882706-06	5	21699	[21699] A 14 COURTYARD 134 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21519] Counters\\A Cameras\\A 14 COURTYARD 134 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
0530edd6-b41c-4479-b14c-fd4d605d473c	2018-03-02 07:19:40.276745-06	5	21700	[21700] A 15 COURTYARD 156	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21520] Counters\\A Cameras\\A 15 COURTYARD 156	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
86f9bf66-4293-4076-ba2d-4e8c890148d5	2018-03-02 07:19:40.8258-06	5	21701	[21701] A 16 COURTYARD 156	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21521] Counters\\A Cameras\\A 16 COURTYARD 156	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
1cda6911-0fc4-4589-ab5c-2e2c9066afee	2018-03-02 07:36:33.856093-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
75fc8ae5-0386-475d-a82a-b5447f233031	2018-03-02 07:36:34.090116-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2783875a-2929-4517-b6be-5a0f56c69afa	2018-03-02 07:36:34.820189-06	5	21154	[21154] Area C Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
42df045a-61cf-4806-a0b4-e19bb92bce99	2018-03-02 07:36:35.015209-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8c99f9ef-1093-433c-beb6-224089426981	2018-03-02 07:36:35.018209-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
421b44af-f4e1-4ae1-9d93-54f60349e255	2018-03-02 07:37:36.817388-06	5	21691	[21691] A 6 LIVING ROOM 113 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21511] Counters\\A Cameras\\A 6 LIVING ROOM 113 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
8f84911e-cee3-4e59-804d-27df039e9c66	2018-03-02 07:52:09.892687-06	5	21154	[21154] Area C Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
ad92421e-00f3-4cd1-8cdb-9f28aca019ab	2018-03-02 07:52:10.171715-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
ec3dbc3a-879d-4131-9ec5-c2930dcb22a4	2018-03-02 07:52:11.335831-06	5	21686	[21686] A 1 MULTI-USE DINING 122 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21506] Counters\\A Cameras\\A 1 MULTI-USE DINING 122 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
93a1f289-7f7b-41c2-aa69-c7b58ba42414	2018-03-02 07:52:12.804978-06	5	21687	[21687] A 2 MULTI-USE DINING 122	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21507] Counters\\A Cameras\\A 2 MULTI-USE DINING 122	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
6581f291-2b80-406e-8f24-56dc1e789573	2018-03-02 07:52:13.334031-06	5	21688	[21688] A 3 MULTI-USE DINING 123	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21508] Counters\\A Cameras\\A 3 MULTI-USE DINING 123	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
295777af-b637-43ab-b155-6a622e213bfe	2018-03-02 07:52:14.739172-06	5	21154	[21154] Area C Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
22c8cfff-36f0-4921-8ea0-3c8a15eb6251	2018-03-02 07:52:14.833181-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
811ca90f-99be-4054-bf70-506c858d4423	2018-03-02 07:52:15.195217-06	5	21155	[21155] Area D Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
18bc3a95-4bff-42bc-a20a-17e5c6633c93	2018-03-02 07:52:19.309629-06	5	21853	[21853] D 1 CORRIDOR 437 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21595] Counters\\D Cameras\\D 1 CORRIDOR 437 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
66e4aeca-4f49-47a7-9635-3aef10469151	2018-03-02 07:52:20.234721-06	5	21855	[21855] D 2 CORRIDOR 437 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21596] Counters\\D Cameras\\D 2 CORRIDOR 437 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
b37d47e4-4c9d-4ec7-9d17-f461ce6fa3b1	2018-03-02 07:52:21.012799-06	5	21856	[21856] D 3 CORRIDOR 437	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21597] Counters\\D Cameras\\D 3 CORRIDOR 437	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
82345aba-1d30-4cb3-8083-0650abb5a29c	2018-03-04 09:21:01.63039-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
3707d932-3cce-4180-a214-55d01a8cda8e	2018-03-02 07:52:21.838882-06	5	21857	[21857] D 4 CORRIDOR 437 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21598] Counters\\D Cameras\\D 4 CORRIDOR 437 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
87ad0833-ceee-4ae0-b81f-40729706f2f5	2018-03-02 07:52:22.551953-06	5	21858	[21858] D 5 CORRIDOR 437	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21599] Counters\\D Cameras\\D 5 CORRIDOR 437	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
b0a467e5-631b-444f-8e7a-632018fc8ee3	2018-03-02 07:52:23.001998-06	5	21859	[21859] D 6 CORRIDOR 414 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21600] Counters\\D Cameras\\D 6 CORRIDOR 414 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
1135b530-2be2-40d7-95c9-f3204591ed91	2018-03-02 07:52:23.496047-06	5	21860	[21860] D 7 CORRIDOR 414 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21601] Counters\\D Cameras\\D 7 CORRIDOR 414 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
761a0e04-0033-497a-a2b8-30fd095da82d	2018-03-02 07:52:23.911089-06	5	21861	[21861] D 8 MA 410 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21602] Counters\\D Cameras\\D 8 MA 410 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
aa7122f7-2157-437a-b599-9cf7a670b670	2018-03-02 07:52:25.365234-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
a5a3de13-d603-41b9-a33e-52bf3e882b72	2018-03-02 07:52:25.889287-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
27160df9-f705-43a5-a2e6-9cd8a0d3148c	2018-03-02 07:52:26.351333-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
279faa2e-7c8c-44e0-bbcf-6db2fc84bb45	2018-03-02 07:52:27.913489-06	5	21686	[21686] A 1 MULTI-USE DINING 122 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21506] Counters\\A Cameras\\A 1 MULTI-USE DINING 122 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
4cda7a8a-db66-44fd-bc23-ec1e807e32ce	2018-03-02 07:52:29.649663-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
413a1709-0b8d-451d-88e3-b252c9dadaf0	2018-03-02 07:52:30.156713-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
801a2e6d-9862-4aa9-84b5-aa2474a0c88c	2018-03-02 07:52:30.613759-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
c83b498d-6d22-4aea-a828-0bfc4eddf3cb	2018-03-02 07:52:32.428941-06	5	21778	[21778] B 1 LIVING ROOM 211 Copy	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21536] Counters\\B Cameras\\B 1 LIVING ROOM 211	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
d96409f9-e958-485f-8741-b58abc88e94b	2018-03-02 07:52:33.142012-06	5	21779	[21779] B 1 LIVING ROOM 211 Copy (1)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21537] Counters\\B Cameras\\B 2 LIVING ROOM 211	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
24294879-c7a2-41df-a578-7d1620de11f6	2018-03-02 07:52:34.0251-06	5	21780	[21780] B 1 LIVING ROOM 211 Copy (2)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21538] Counters\\B Cameras\\B 3 LIVING ROOM 211 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
60ae1565-92ce-4e7a-b4c4-a827d7fcbcef	2018-03-02 07:52:34.764174-06	5	21781	[21781] B 1 LIVING ROOM 211 Copy (3)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21539] Counters\\B Cameras\\B 4 LIVING ROOM 211 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
5ebfbc82-82ed-461a-a6fa-12d7cdfe6505	2018-03-02 07:52:35.307228-06	5	21789	[21789] B 1 LIVING ROOM 211 Copy (4)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21540] Counters\\B Cameras\\B 5 COURTYARD 209	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
632c6e1a-1ff1-40d2-aed9-204373c83531	2018-03-02 07:52:35.784276-06	5	21790	[21790] B 1 LIVING ROOM 211 Copy (5)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21541] Counters\\B Cameras\\B 6 DINING 223 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
339f373e-6c99-433e-a0bc-1cefd877a948	2018-03-02 07:52:36.311329-06	5	21791	[21791] B 1 LIVING ROOM 211 Copy (6)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21542] Counters\\B Cameras\\B 7 DINING 223	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
8478dd8b-fe42-4878-a607-2095e197e978	2018-03-02 07:54:35.356232-06	5	21153	[21153] Area B Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
912cb823-9efa-4f9b-aace-000358b167ab	2018-03-02 07:54:35.455242-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
088241db-697f-4530-9196-1d25d05ff92e	2018-03-02 07:54:36.555352-06	5	21156	[21156] Area E Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
3ca91ff6-3230-40ad-bb0c-490c1dbf7461	2018-03-02 07:54:40.130709-06	5	21915	[21915] E 1 HALL 544 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21655] Counters\\E Cameras\\E 1 HALL 544 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
efd14613-ef99-40e8-af85-5b0172921c33	2018-03-02 07:54:41.259822-06	5	21916	[21916] E 2 HALL 544 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21656] Counters\\E Cameras\\E 2 HALL 544 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
9782be66-a167-4ae8-9759-970df75533f5	2018-03-02 07:54:42.694966-06	5	21155	[21155] Area D Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
5b65b2d6-36d1-49eb-8b0d-3b72bf588651	2018-03-02 07:54:45.385235-06	5	21857	[21857] D 4 CORRIDOR 437 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21598] Counters\\D Cameras\\D 4 CORRIDOR 437 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
33201a2a-691d-419a-8f15-8eb96a714e6a	2018-03-02 07:54:46.026299-06	5	21865	[21865] D 12 CLASSROOM 415	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21606] Counters\\D Cameras\\D 12 CLASSROOM 415	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
25fcafbb-fa6d-442d-ab40-3c609e984d9c	2018-03-02 07:54:46.559352-06	5	21873	[21873] D 20 CLASSROOM 428 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21614] Counters\\D Cameras\\D 20 CLASSROOM 428 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
740df89e-145f-4844-8901-b0d3fb28d1fd	2018-03-02 07:54:47.950491-06	5	21154	[21154] Area C Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
39fbaa1d-0144-4874-9baa-6aaa0d24909b	2018-03-02 07:54:48.463543-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
87e34bd2-acf5-4fed-bc92-1f12ae16f4c7	2018-03-02 07:54:48.677564-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
d6b76dec-3ef5-46ef-b516-ba63ea678098	2018-03-02 07:54:50.863783-06	5	21824	[21824] C 1 VEHICLE SALLY PORT 324	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21567] Counters\\C Cameras\\C 1 VEHICLE SALLY PORT 324	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
7055f8b2-16e6-4f69-9e8e-5646a9a71fc5	2018-03-04 10:02:04.070675-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
59e336df-72bd-4f9e-a60f-82b655a47154	2018-03-02 07:54:51.591855-06	5	21825	[21825] C 2 VEHICLE SALLY PORT 324	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21568] Counters\\C Cameras\\C 2 VEHICLE SALLY PORT 324	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
1a4ac484-321c-4206-96f9-6d5c62a8b69a	2018-03-02 07:54:52.606957-06	5	21154	[21154] Area C Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
97c8fcd5-7881-4a9c-a83f-cc6f7c84eaea	2018-03-02 07:54:52.73297-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
dd86da00-6c6e-47f0-b8cc-b4d5a3381420	2018-03-02 07:54:53.381034-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
b6145dfe-5908-4ca3-9322-1a86e4e3454f	2018-03-02 07:54:53.903087-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
3b1604b7-6a4a-4012-a99d-3206cfefa3e4	2018-03-02 07:54:53.907087-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
727eceed-ebf3-424e-8293-4382be18a524	2018-03-02 07:54:55.682264-06	5	21800	[21800] B 1 LIVING ROOM 211 Copy (15)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21551] Counters\\B Cameras\\B 16 COURTYARD 261 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
5f1998fa-88ca-4823-aad5-414f9a3ef4db	2018-03-02 07:54:56.232319-06	5	21807	[21807] B 1 LIVING ROOM 211 Copy (22)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21558] Counters\\B Cameras\\B23 SINGLE SLEEPING 225	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
14371642-dac2-4ffb-b73d-e430b13ff24a	2018-03-02 08:00:42.557949-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
bb0aee6a-3098-48e0-a478-d72cc474c91a	2018-03-02 08:00:42.757969-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
bbd7ea58-eda7-467a-ada5-f6c601c237a3	2018-03-02 08:00:43.247017-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e9fbc0bd-570e-4f90-bb05-40268763e0c8	2018-03-02 08:00:46.099303-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2f6366df-1b51-4eb0-9312-a087d50836da	2018-03-02 08:00:46.298323-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b3281fe9-d7a7-4340-96df-919c33293895	2018-03-02 08:00:46.999393-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e011789c-da58-43ff-aa35-a8352246dabd	2018-03-02 08:00:51.591852-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
157b36e2-d8b4-451b-925c-a7a0bf8c056c	2018-03-02 08:00:51.798873-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ddae7c91-17f4-4add-9921-1c1507fe7a8c	2018-03-02 08:00:55.105203-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
85e6cee9-b560-4ed0-9016-af7e26704947	2018-03-02 08:00:55.702263-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
74dc714b-f088-4118-b489-9efc21f23846	2018-03-02 08:00:55.909284-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
7c003889-432f-4102-884f-26f17a86c977	2018-03-02 08:00:56.590352-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
57cd8ea3-1759-488d-b002-f4784248f001	2018-03-02 08:00:57.390432-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
273c3d3f-9160-440c-9b42-4dc064da42e7	2018-03-02 08:00:57.599453-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8ab2ff97-18a0-4014-991c-20de33ecf950	2018-03-02 08:00:58.285521-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b4272ca8-87ff-4f0d-a508-2afff9113cb8	2018-03-02 08:00:58.920585-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e4879fee-4d5f-4103-af47-a64b71632dd3	2018-03-02 08:01:00.665759-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d941f6b5-6d25-4f75-9f09-2934751712c5	2018-03-02 08:01:04.600153-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
313264e2-ff69-4dff-b28e-b40366351ee4	2018-03-02 08:01:04.796172-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
464e869f-aca6-4151-b005-89dc3e907346	2018-03-02 08:01:05.0772-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
be905bea-8f91-433c-b4ac-89e364805e4c	2018-03-02 08:05:58.271517-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
2371590b-f3e3-4a0b-ae1f-15f9245bd39e	2018-03-02 08:07:20.751764-06	5	21778	[21778] B 1 LIVING ROOM 211 Copy	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21536] Counters\\B Cameras\\B 1 LIVING ROOM 211	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
7a196db1-0335-4466-a5b0-ab9110e1ca5e	2018-03-02 08:07:22.172906-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
13fbef9c-c3cd-485e-b8dd-547fcc928e7f	2018-03-02 08:07:22.406929-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
9bb356bf-87f7-4b3e-982d-1fe75101499e	2018-03-02 08:07:22.890978-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
c82f8c59-f18c-40a3-aaac-d97ac881a1ab	2018-03-02 08:07:23.094998-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
d49dbc7c-01a6-444e-b46e-af3099b9b0d6	2018-03-02 08:07:24.333122-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
28aa969f-d407-473a-8868-eb9b05388a56	2018-03-02 08:07:24.336122-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
92e7f027-a737-47d9-879c-ab98dd05aad3	2018-03-02 08:07:24.991188-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
b26f2a7f-bd60-4942-ad5e-9ca6cb51156b	2018-03-02 08:07:25.51724-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
6de634c4-0a6b-4dc1-a831-d89239026912	2018-03-02 08:07:25.525241-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
1f332f15-23d4-4fb1-bac0-9570a760956e	2018-03-02 08:07:28.721561-06	5	21779	[21779] B 1 LIVING ROOM 211 Copy (1)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21537] Counters\\B Cameras\\B 2 LIVING ROOM 211	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
3f16f909-428d-42b1-8af3-78d38ad3dc0f	2018-03-02 08:07:32.850974-06	5	21778	[21778] B 1 LIVING ROOM 211 Copy	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21536] Counters\\B Cameras\\B 1 LIVING ROOM 211	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
8472ab07-763c-46cc-a23c-aae525e021df	2018-03-02 08:07:35.158204-06	5	21779	[21779] B 1 LIVING ROOM 211 Copy (1)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21537] Counters\\B Cameras\\B 2 LIVING ROOM 211	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
b2e1b24a-27d7-42f5-b061-87967ac7d7e2	2018-03-02 08:07:36.1143-06	5	21780	[21780] B 1 LIVING ROOM 211 Copy (2)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21538] Counters\\B Cameras\\B 3 LIVING ROOM 211 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
ef8ceeae-dcc1-45a0-bdb4-abdda4c79615	2018-03-02 08:07:37.680457-06	5	21781	[21781] B 1 LIVING ROOM 211 Copy (3)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21539] Counters\\B Cameras\\B 4 LIVING ROOM 211 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
1fb0c2d6-3b32-4b6f-916a-8289b4047dee	2018-03-02 08:07:38.372526-06	5	21789	[21789] B 1 LIVING ROOM 211 Copy (4)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21540] Counters\\B Cameras\\B 5 COURTYARD 209	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
346abb5c-f2a6-49a5-aa1e-842cf0ae64cc	2018-03-02 08:07:40.360725-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
a694c1bd-156c-4743-b454-9174d30f0f4e	2018-03-02 08:07:40.873776-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
b5a0b0b1-588f-4ea5-bfd4-3c1110b148de	2018-03-02 08:07:42.662955-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
3042a1e7-b236-4956-9fee-c76ebea3b73e	2018-03-02 08:07:43.107999-06	5	21154	[21154] Area C Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
baca758b-0a4a-4bf2-8bab-9179d344eccf	2018-03-02 08:07:43.684057-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
08dcd967-5b42-4cf1-9e20-fbeb04cb9da3	2018-03-02 08:07:43.688057-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
c3908c96-f602-4e9c-94b8-51eefdab40a0	2018-03-02 08:07:46.746363-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
2cdd3103-6b50-48be-b0ad-9ed742f4eff5	2018-03-02 08:07:49.358624-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d140737a-780f-4b72-8dcf-8cf2b4e1da57	2018-03-02 08:07:49.360625-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
c497fd1e-f188-4155-8166-436eb0b65994	2018-03-02 08:07:51.956884-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
38772036-a4c0-42a1-a97d-849d2dca24fe	2018-03-02 08:07:52.491938-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
8f7088eb-c015-414c-9429-4c1e4125981d	2018-03-02 08:07:52.497938-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
aee40dc8-8e7f-45d5-a0a3-fa4368fc0fd4	2018-03-02 08:07:53.269015-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
7cb62303-e814-4fa6-b12a-02366f28bbec	2018-03-02 08:07:53.789067-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
702de1e6-54eb-4097-baca-068a584ea15c	2018-03-02 08:07:54.882177-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
7890cd30-8bb1-474f-8141-cf95efa0eb99	2018-03-02 08:07:58.008489-06	5	21153	[21153] Area B Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
25988a96-6431-4be3-9e6c-8a97f9890b2f	2018-03-02 08:07:58.01149-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
8855116d-b763-44b9-949b-d282118b5a1d	2018-03-02 08:08:15.511239-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
4844db2c-9490-4afe-892e-818722b4f9d7	2018-03-02 08:09:04.906178-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b4921c5f-1290-48fe-b9f0-b3acf803c142	2018-03-02 08:09:13.832071-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f4cceee6-fe29-4df9-bc4e-4a299dfdf283	2018-03-02 08:09:14.185106-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
aee70d55-3d3f-4921-a501-57cf06a9c0c1	2018-03-02 08:09:14.62515-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
03b0bb63-5c0e-48d9-b613-2dc04b5723d8	2018-03-02 08:09:14.966184-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b5827562-aea2-4403-b9c5-e4a5d97fb168	2018-03-02 08:09:15.172205-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
3b562424-baee-4084-9bb6-ac339128cbf6	2018-03-02 08:09:15.42323-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f1abe5f0-1f08-43e6-bb7d-99322117c82f	2018-03-02 08:09:15.718259-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
11be1e76-5af8-4f3a-af9b-dfdd20907569	2018-03-02 08:09:15.939282-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
eb44ac0c-bb26-48c6-a304-79528a18e611	2018-03-02 08:09:16.242312-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a59dd031-17e8-4bca-90e0-78a27b9e8fd0	2018-03-02 08:09:17.390427-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
15c07d58-0bbc-4018-81dc-c4834df28b35	2018-03-02 08:09:18.52054-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
fe1515ec-2e26-4624-bfbf-690a2c7bae2d	2018-03-02 08:09:18.81957-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ccc09a7f-161e-4bd2-9b8d-7769dbf3b22e	2018-03-02 08:09:21.581846-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
dc36c6c9-d436-41a5-9455-e68fa98b9653	2018-03-02 08:09:31.72886-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
aaf4d199-a020-4dc8-bb8b-ff95d826d154	2018-03-02 08:09:32.02189-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
0d6a1bba-c713-4d9e-bd60-aa92ebaa3cf3	2018-03-02 08:09:32.22691-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d9eeeb01-6ed4-4975-b326-75bb20ed8f70	2018-03-02 08:09:33.684056-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
75cfc110-82f3-44e6-a653-f7896e52211e	2018-03-02 08:09:33.967084-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1e3ddcbb-2c44-4ca7-a2c5-281b8edb22a7	2018-03-02 08:09:34.171105-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a93e2b81-65f2-4e01-87bb-1772f90fb404	2018-03-02 08:09:44.376125-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
09fc4e33-59be-4d77-9979-811dc38c201e	2018-03-02 08:10:25.897277-06	5	21154	[21154] Area C Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
75f8f613-f8a0-4cdb-a4fd-0b63a8d336d2	2018-03-02 08:10:25.905277-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
83d13f88-6c9c-4046-94a2-6f7514dd7b3f	2018-03-02 08:11:32.684955-06	5	21781	[21781] B 1 LIVING ROOM 211 Copy (3)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21539] Counters\\B Cameras\\B 4 LIVING ROOM 211 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
63024b08-ee44-4de6-8b82-1df5e8365028	2018-03-02 08:11:34.020088-06	5	21794	[21794] B 1 LIVING ROOM 211 Copy (9)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21545] Counters\\B Cameras\\B 10 LIVING ROOM 236 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
727181b6-c99b-4ee6-8af8-96d52946834c	2018-03-02 08:11:35.368223-06	5	21798	[21798] B 1 LIVING ROOM 211 Copy (13)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21549] Counters\\B Cameras\\B 14 DINING 224 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
93bb7caa-507e-4233-bb22-b992b2fd2361	2018-03-02 08:11:41.685855-06	5	21809	[21809] B 1 LIVING ROOM 211 Copy (24)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21560] Counters\\B Cameras\\B25 CALMING ROOM 252	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
20276264-2760-43fa-80bc-1db87b4e6148	2018-03-02 08:11:44.529139-06	5	21778	[21778] B 1 LIVING ROOM 211 Copy	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21536] Counters\\B Cameras\\B 1 LIVING ROOM 211	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
b95dab2f-6d26-418d-b425-c97d6a5d9ba9	2018-03-02 08:13:26.100295-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
785f4104-d22e-4428-9d22-7af56be75084	2018-03-02 08:13:26.635349-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
a337981d-06ed-4948-82b9-d044f5e68b4d	2018-03-02 08:13:26.642349-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
0fa86143-64a1-4b17-8ac7-c8eb70ddc7a0	2018-03-02 08:13:29.35062-06	5	21687	[21687] A 2 MULTI-USE DINING 122	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21507] Counters\\A Cameras\\A 2 MULTI-USE DINING 122	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
3938438e-d8e5-4796-8fd1-0da7d9d5b2d9	2018-03-02 08:13:30.600745-06	5	21689	[21689] A 4 MULTI-USE DINING 123	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21509] Counters\\A Cameras\\A 4 MULTI-USE DINING 123	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
dc4ce197-9bc3-42b6-91c8-798248d27cbd	2018-03-02 08:13:31.540839-06	5	21690	[21690] A 5 LIVING ROOM 113	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21510] Counters\\A Cameras\\A 5 LIVING ROOM 113	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
8de60533-6344-4ce0-96ec-d582983faa2d	2018-03-02 08:13:32.097895-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
cd561359-ba7f-4ad2-8bcd-e3423ab355b8	2018-03-02 08:13:32.108896-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
9dd355d4-1dad-4670-87e2-76ec8c493f28	2018-03-02 08:13:32.630948-06	5	21154	[21154] Area C Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
bd21e1ef-f456-4edb-b69b-03014f3f0b80	2018-03-02 08:13:33.149-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
58eef435-fa14-46e7-bae6-f44386bd2ed2	2018-03-02 08:13:33.153-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
abdb4487-3c90-4542-bd16-e31a2c32ba6b	2018-03-02 08:13:35.05119-06	5	21824	[21824] C 1 VEHICLE SALLY PORT 324	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21567] Counters\\C Cameras\\C 1 VEHICLE SALLY PORT 324	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
0c53af6b-95d0-4ceb-888c-bcbb9f07573a	2018-03-02 08:13:35.75026-06	5	21830	[21830] C 7 GROUP MALE 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21573] Counters\\C Cameras\\C 7 GROUP MALE 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
a71f250e-d4a5-4d1a-8b9c-1057f2cfec32	2018-03-02 08:13:36.332318-06	5	21842	[21842] C 19 CORRIDOR 308 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21585] Counters\\C Cameras\\C 19 CORRIDOR 308 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
f5c9f4c0-e483-4fcb-9159-12851ed0138e	2018-03-02 08:13:38.507536-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
25b3c318-f970-4bdf-bda0-13a998569c48	2018-03-02 08:13:41.184803-06	5	21853	[21853] D 1 CORRIDOR 437 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21595] Counters\\D Cameras\\D 1 CORRIDOR 437 	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
f767515d-fe45-4ec2-8026-5db0fca3c442	2018-03-02 08:14:20.966781-06	5	21913	[21913] None	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21654] Counters\\D Cameras\\None	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
95981aaf-43eb-46b3-9df0-a2054b91bb58	2018-03-02 08:16:48.628546-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
b917e8d8-5f30-4893-aeb8-51f4d171ecad	2018-03-02 08:16:49.1646-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
14dc00fa-5be2-47fe-ae27-d91bc757590c	2018-03-02 08:16:50.274711-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
55abd3a2-d045-4d3f-99d4-18ab52e85130	2018-03-02 09:33:28.911528-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
e5506451-3462-426d-9e15-34a158b98e09	2018-03-02 09:34:00.868724-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
20e375d0-aa47-44e0-853d-24bba263f779	2018-03-02 09:42:40.423674-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
910f19b6-fefc-4231-a0ab-710c332ceb7c	2018-03-02 09:42:40.465678-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
f5966e27-4c61-45fa-987d-4961d48e05d3	2018-03-02 09:42:40.998731-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
ff057005-7f78-46c3-aae7-a63730013d07	2018-03-02 10:07:41.809798-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
85b256db-f5f3-44c8-8b57-bc644f7a8a54	2018-03-02 10:08:12.358852-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2082e528-899c-436d-8feb-36a317bc231e	2018-03-02 10:08:12.388855-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a196d5c8-ec81-4378-8c8f-b429469a7ff3	2018-03-02 10:08:12.913908-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1584942f-ba93-4b81-a178-7f1ede5c6362	2018-03-02 10:08:14.199036-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
cf621d67-1732-45e9-8415-eda50e16014c	2018-03-02 10:08:14.404057-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
352f9d91-6994-4111-8257-b13da465c8c2	2018-03-02 10:08:14.912107-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d0fb636e-d75a-46c8-b45c-b89552bd3323	2018-03-02 10:08:15.24014-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f2086a71-97ed-4950-a440-65ba1b4311c3	2018-03-02 10:08:16.432259-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
87c115a5-2c63-4846-b515-781e203fae18	2018-03-02 10:08:17.044321-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
36515d3f-0e78-4b17-b7a7-16c49b936d52	2018-03-02 10:08:17.332349-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
aa92761c-872a-4f1a-b1dd-e418b7714091	2018-03-02 10:08:19.006517-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
00dacdba-a6bc-42e6-a6f8-a801c5e15e36	2018-03-02 10:08:19.400556-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
285543bd-5bdf-4018-b7ea-3e414aa59fd5	2018-03-02 10:08:21.680784-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
97e4843a-ff65-4274-a6d2-c7a57ecc1950	2018-03-02 10:08:23.862002-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
3a8b5afd-2a0b-475b-8d2e-b942e3d3a7bd	2018-03-02 10:08:27.8404-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
11453e7e-7ead-469e-9623-bc4b2cbd1f23	2018-03-02 10:08:28.081424-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
4999ae6b-b72d-4630-8403-489fa9156a0b	2018-03-02 10:08:28.331449-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
512ef424-46d9-4fda-a2d6-7dd7371f4bad	2018-03-02 10:08:37.63638-06	5	21848	[21848] C 25 HALL 378 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21591] Counters\\C Cameras\\C 25 HALL 378 	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a08640fb-c07e-48f7-9047-b32ac2db3a05	2018-03-02 10:08:50.64068-06	5	21322	[21322] Door 378	0	MouseDown	0	Pulse [19185] R8C5-16R\\Lock DR-378 Relay	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a73339e6-319d-4bb2-964f-07e75ee093ee	2018-03-02 10:09:05.627178-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
98f5dc78-4a45-4a4e-a40c-bbd83f31951c	2018-03-02 10:09:05.967212-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e6034ca4-a771-474d-993e-1d93c7899f4f	2018-03-02 10:09:06.211237-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
cdce0440-3620-4e1d-aea2-b109f29ae323	2018-03-02 10:09:25.205136-06	5	21691	[21691] A 6 LIVING ROOM 113 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21511] Counters\\A Cameras\\A 6 LIVING ROOM 113 	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d52a260b-9fc8-4a03-9217-829cac91c396	2018-03-02 10:09:46.799295-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
768e6212-8b84-406d-9a70-565936d265b2	2018-03-02 10:09:47.011316-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c016a429-81c4-4a87-be72-28d0c9192b90	2018-03-02 10:09:47.281343-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
855172d8-1770-4b8f-b97f-82828bfe2fa2	2018-03-02 10:09:48.421457-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
673a3583-6d82-4201-850c-eea0cd983ee3	2018-03-02 10:09:49.872603-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
aad63a15-86c9-4e06-b2d7-ef6bcdac461c	2018-03-02 10:09:50.190634-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
239f33f9-bdf1-4ca1-b05e-3f958148d090	2018-03-02 10:09:50.394655-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
bd56b08d-774a-49a7-aca0-7d1a0769d479	2018-03-02 10:09:51.167732-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
efc4faad-159c-4d3d-bacd-466413e68afe	2018-03-02 10:09:55.487164-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
3e27340e-0ebf-45be-a1f6-e1b8f9bb975f	2018-03-02 10:09:55.866202-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e4351bca-55c3-4f2c-ba91-42423bf22668	2018-03-02 10:09:56.402255-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
69b1fb67-7cac-4ef4-86bc-3538757d7820	2018-03-02 10:09:56.726288-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
0bc825b0-304f-4a4d-98af-c23d4e9c1baa	2018-03-02 10:09:57.023318-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d0f45278-c30b-48a7-9f46-1acb5d0b3113	2018-03-02 10:09:57.414357-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a5e49e7c-601f-465d-8ac0-96553d163d5f	2018-03-02 10:09:57.719387-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
adf1591a-322b-485a-a82a-2ecbfd523834	2018-03-02 10:09:58.042419-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8bdce160-4a6a-425b-9e86-84aac9ceba7f	2018-03-02 10:10:07.309346-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
88658622-75d7-48fd-aabd-a0ab01beda21	2018-03-02 10:21:55.709179-06	5	8331	[8331] Virtualize	0	MouseDown	0	VirtualizePanel [8221] R4C1-8IC	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c6730826-ee59-43a1-b7ab-476ea54dba42	2018-03-02 10:22:09.015509-06	5	8331	[8331] Virtualize	1	MouseDown	0	UnvirtualizePanel [8221] R4C1-8IC	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
713c8ed5-f41a-436c-862d-65560010be6d	2018-03-02 10:42:37.007296-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
79424693-77c9-4d95-b81a-0bf490fa0de6	2018-03-04 10:02:33.286596-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2ea70177-6c13-43f2-8f45-068691c4eacf	2018-03-02 11:36:18.555419-06	5	21154	[21154] Area C Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
fd6f8318-a4fb-4707-9bc3-69a53dd8890d	2018-03-02 11:36:18.581422-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
a2ce16ed-a4b1-46ff-8b73-fd3933a93414	2018-03-02 11:36:23.275891-06	5	21154	[21154] Area C Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
470adf64-0139-4d77-8d30-97a95645eca4	2018-03-02 11:36:23.520915-06	5	21154	[21154] Area C Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
3d5c02c8-e1b5-4360-8115-93251c547121	2018-03-02 11:36:23.596923-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
9b26017e-4fdc-4c7a-91d8-51c915e9f524	2018-03-02 11:36:24.356999-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
c7e43b40-4123-4c15-a6fb-cd4f30d10a41	2018-03-02 11:36:25.140077-06	5	21154	[21154] Area C Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
adde6c05-e6a8-430f-9c1b-d37d53e11cba	2018-03-02 11:36:25.509114-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
7d1450a9-2e28-4c18-a5ba-31a554a67028	2018-03-02 11:36:25.917155-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
2ae0d4ea-b679-4669-af45-a047f6d531ed	2018-03-02 11:36:26.417205-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
535ba6b6-d30b-4a8a-b71f-ad2c3235d8f1	2018-03-02 11:36:27.140277-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
c8c72e41-c863-4e91-adc7-5e2203440750	2018-03-02 11:36:27.528316-06	5	21154	[21154] Area C Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
c257a4f4-fc35-4c32-800f-b1ac353f675d	2018-03-02 11:36:28.021365-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
65bdfe14-766b-4bd1-8a25-ba333e3dc669	2018-03-02 11:36:28.772441-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
b73b043e-8aaa-4ca9-9487-3c759d31f957	2018-03-02 12:37:46.332221-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e4187433-4c7e-425c-86e8-69ab1e4f95e7	2018-03-02 14:15:52.092738-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
1b087017-2f5a-4259-aef7-c1a6e8045986	2018-03-02 14:16:24.145943-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
8dcefe13-0c57-4ac8-833d-d9d3acd7290b	2018-03-02 14:16:57.068235-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
8538d5bf-8320-4ab7-baeb-ed64ac6ee139	2018-03-02 15:14:32.583752-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
d2a35025-8a37-4e75-ad97-646a33959494	2018-03-02 15:14:33.130807-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
9d81e7b7-e8f8-473e-83bc-6ae7b9b5477b	2018-03-02 15:14:35.331027-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
f44773f2-0a2d-43aa-95fc-1c9d3a9ffb5d	2018-03-02 15:14:43.923886-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
9ba31920-9fd5-4154-971f-0e1a9b4ec5ca	2018-03-02 15:14:43.947888-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
e5d07925-bf62-4e02-900b-0e5fd995de8a	2018-03-02 15:14:46.953189-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
bc989c79-6e81-4385-bfd2-59f0343242e2	2018-03-02 15:14:47.473241-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
18e31d71-5433-45b9-8938-eed48158faf4	2018-03-02 15:14:49.228416-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
e8343e54-048e-4bc4-9456-e37813e35287	2018-03-02 15:14:49.553449-06	5	21154	[21154] Area C Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
cd3f71a2-e879-46fe-8586-16675894a0b9	2018-03-02 15:14:50.072501-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
df79c32d-657f-4b36-ba03-d808023e3165	2018-03-02 15:14:51.013595-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
2a1e1559-a1a0-4c3a-8277-138c314193de	2018-03-02 15:14:52.66476-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
e8cbdd22-ba27-4eca-967d-cf180bfd2457	2018-03-02 15:14:56.217115-06	5	21156	[21156] Area E Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
a9813a07-8d03-4cd7-8de8-ab8160b65baa	2018-03-02 15:14:57.594253-06	5	21155	[21155] Area D Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
af103722-2813-4f2e-b5a5-414674f23bdc	2018-03-02 15:15:08.288322-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
e6ca36de-c1e7-4bf9-9e67-0e1a0cb100a8	2018-03-02 15:15:08.808374-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
e4bcbf88-fa1f-4a72-b340-139cfb8dea85	2018-03-02 15:15:21.760669-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
bcd90865-7636-4af6-81ae-fcd239cdeff0	2018-03-02 15:15:38.547348-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
51dbe3e9-5861-4f93-a772-94a0c9ec5ebd	2018-03-02 15:15:38.595352-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
1a6e7abc-c84f-411d-8f14-27d56be686f7	2018-03-02 15:15:39.313424-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
28d027f0-77ea-47da-902f-ddd89bb9d074	2018-03-02 15:15:39.859479-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
b37acb7d-ba85-40b7-b322-f615bc7d736d	2018-03-02 15:15:39.865479-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
2492c989-32be-4b4c-8ac7-145290218a59	2018-03-02 15:15:50.303523-06	5	21801	[21801] B 1 LIVING ROOM 211 Copy (16)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21552] Counters\\B Cameras\\B 17 RESEARCH/READING 206 	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
51a6efa2-3642-49f5-9c8c-784c9a4e6f1e	2018-03-02 15:15:53.395832-06	5	21808	[21808] B 1 LIVING ROOM 211 Copy (23)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21559] Counters\\B Cameras\\B24 HALL 229	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
2c50afd0-f026-49b5-b340-d95d47f41be3	2018-03-02 15:16:04.823975-06	5	21272	[21272] Door 239	0	MouseDown	0	Pulse [17083] R7C5-16R\\DR-239 Trigger	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
526cabd4-b085-4c2e-aa5d-ff7928102382	2018-03-02 15:19:20.049496-06	5	21154	[21154] Area C Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
42a88655-2795-45fa-ac73-a92cd01ab838	2018-03-02 15:19:20.602551-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
75797908-6515-4280-a7fe-14f0bc6edda8	2018-03-02 15:19:21.527643-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
4d5005db-5ecb-4f00-8369-1e0746b7d499	2018-03-02 16:31:18.5273-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
bbbe2e55-269f-47e9-b255-cf8ea31599d2	2018-03-02 16:31:18.72132-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1943a1a0-48d5-4990-8d14-9f051c0bc034	2018-03-02 16:31:20.416489-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5f068fe8-8603-4f2b-8553-f788c306268c	2018-03-02 16:31:20.807528-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5cbde14b-8026-484c-a57f-9170db452638	2018-03-02 16:31:21.006548-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
72c5f218-ca37-4637-8193-bc9093f90deb	2018-03-02 16:31:22.900738-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
569c006f-cb85-471e-8295-4deafb4a243e	2018-03-02 16:31:23.342782-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a0857cf0-68ab-4560-b4c7-645fa4760bf9	2018-03-02 16:31:23.549802-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
faf1a51a-6b58-4c52-a94c-08532496bd01	2018-03-02 16:31:25.089956-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2ffc9cc5-3085-446e-9c9a-50e9d7f80661	2018-03-02 16:31:25.881036-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
54cd66a6-ff5d-408c-9b76-c42cd235dc16	2018-03-02 16:31:28.143262-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
42c9d622-a881-4f60-9ccf-4d35191de22c	2018-03-02 16:31:32.172665-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ec580ad3-3253-4934-8f53-ded61e3af966	2018-03-02 16:31:32.381686-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
eeb4e19b-899d-47bd-808b-9bf1e036a8d3	2018-03-02 16:31:32.589706-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8d84b259-99b9-4e26-b8da-c397a7b4d4d6	2018-03-02 16:31:33.712819-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9ec0ac9f-394f-4ded-997b-de8ffc9c6af8	2018-03-02 16:31:33.911839-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
832e4cfb-d979-408d-a8a6-a9ba38788ddc	2018-03-02 16:31:34.510898-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c395bce6-cea1-4306-8ec6-d56cc3de1bf1	2018-03-02 16:31:35.120959-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
736ce948-bfd2-4066-80e9-4f00a714d0bf	2018-03-02 16:31:35.32898-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
125551f2-3c66-4640-97fa-03f876154dfc	2018-03-02 16:31:35.331981-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
3e972fd7-5f70-48cf-bc34-995b4a0fc78e	2018-03-02 16:31:37.370184-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e9f72114-4068-47d7-a07e-5c69e0835dbe	2018-03-02 16:31:38.269274-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d88ed76f-ff4f-477a-8712-05f7c20115b4	2018-03-02 16:37:25.311975-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
15395f92-ed9c-4780-b89b-5a0d19248607	2018-03-02 16:37:25.509995-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e0864c00-2f55-4724-964d-3841b72b1479	2018-03-02 16:37:25.710015-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
80836748-19f6-4331-bc05-b0af50f7261d	2018-03-02 16:37:43.145758-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9f79267f-8d78-4e9c-9bb2-8bc69f2bf95b	2018-03-02 16:37:43.343778-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
61bdc11b-cbff-474f-ba11-ba023da16d5c	2018-03-02 16:37:45.036947-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c17164b7-642a-4e96-826f-0598dbe0ba63	2018-03-02 16:37:46.247068-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
aae2e548-50b3-47b5-a959-66d0be735050	2018-03-02 16:37:55.773021-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8d3eadc8-4069-4033-9f08-b9093d80b21c	2018-03-02 16:37:55.979041-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
58e28576-ea53-4c7b-9d99-1a67fce8a381	2018-03-02 16:37:56.189062-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ff844981-895d-4ab0-b9df-461fe68ecbda	2018-03-02 16:40:24.910933-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
35f5c40a-8e2f-48b7-9977-da1dfe9e27ca	2018-03-02 17:08:53.698795-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
d0b36062-65d6-4c15-9954-b0e459eeb8da	2018-03-03 08:56:12.289212-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b6a02f26-9184-4ce8-ba35-bf75b7de2199	2018-03-03 08:58:58.996882-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
196ac530-235b-4d1e-93b4-b6d96c7f3035	2018-03-03 09:03:38.289808-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9edb8208-fd53-46fa-ba5d-c0ab759a989a	2018-03-03 09:13:53.699343-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a8820312-d5d0-47a1-9750-9ea80884c880	2018-03-03 09:14:20.353008-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
51ac1a4c-d11d-4c6d-919e-3c97470f3c28	2018-03-03 09:19:46.921662-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c6f4909e-2b64-4530-87e7-718662cfcf58	2018-03-03 09:20:21.660135-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c82bdbe9-bae5-4971-9909-7f8c0f921568	2018-03-03 09:20:50.292998-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8fe32734-2b2a-4ee4-8b91-aa97888aaac9	2018-03-03 09:20:52.475216-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
15d393db-8a4e-4156-88d1-e1fc3e0664b4	2018-03-03 09:20:55.098479-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d01301de-5c03-4ca8-8192-7b8bcf168714	2018-03-03 09:20:55.887557-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d70411bb-cbbf-42bb-996f-d3dd2c292a0e	2018-03-03 09:20:57.387707-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
998d9cc8-206a-4e9b-aea0-29761c97c26f	2018-03-03 09:20:58.870856-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
3cb9d53a-ed7a-4e7e-9749-cd77ee2d5d84	2018-03-03 09:20:59.881957-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
3483c791-ba2f-4516-8e0b-0dfa66b92893	2018-03-03 09:21:01.040073-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
783a92d5-b150-401e-97d2-2f49c19541b4	2018-03-03 09:21:04.347403-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5a8ffa58-57dc-4904-a326-39f7f2e98350	2018-03-03 09:21:04.943463-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
dcaff0d4-9397-4b6e-a0c3-5bbef7ea5fa2	2018-03-03 09:21:08.191788-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
68c84dec-9129-4dfe-9451-dfabcd70aec1	2018-03-03 09:22:23.194287-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
eef34304-d8aa-4f58-9da6-d93f0ce89b9b	2018-03-03 09:22:51.332101-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d77e2f78-66bb-49ec-9338-697dbd12e3cb	2018-03-03 09:24:46.175584-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
80ed25bc-c026-4d2e-af43-ed671c52c576	2018-03-03 09:24:46.207587-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
27583962-4ebd-4f1c-a801-3977ec87afca	2018-03-03 09:24:48.716838-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
870ca29e-3e74-4298-9d92-1018dac274ee	2018-03-03 09:24:49.558922-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9b4d6fed-e53c-499a-911b-45a7ca17ef35	2018-03-03 09:24:51.481114-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
77083a57-eb80-44a2-aa6e-506bc605ff22	2018-03-03 09:24:52.490215-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d054f5a4-0960-44b7-8105-6d637b9c9331	2018-03-03 09:31:31.056068-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
27bb96b8-9c02-4ee4-8198-b6f7760b6d8a	2018-03-03 09:31:40.739036-06	5	21154	[21154] Area C Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9f49f43c-f75b-4869-a5f9-73fb51dd08c3	2018-03-03 09:31:40.999062-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
dca5a0d5-6005-4fe5-bf4c-3d0a0d6ccba5	2018-03-03 09:31:42.939256-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9817aa56-ef74-469f-8da0-33a6ff2d70b3	2018-03-03 09:31:47.835746-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ec1df43f-c036-4744-b146-42bdf04eec69	2018-03-03 09:31:49.334896-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f8d69a1a-cacb-40e1-b3fd-0f244fbbdda5	2018-03-03 09:31:51.067069-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
32ec6b2c-090f-4856-b7fa-1042ef55a205	2018-03-03 09:31:54.3794-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
fcf1112e-3d00-4191-b050-747d81dd3ae4	2018-03-03 09:31:56.697632-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8a751d1a-621e-442f-adcb-1abf873dd09c	2018-03-03 09:31:58.710833-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e950c1ad-c566-44dd-b953-546765970eef	2018-03-03 09:32:01.416104-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
3915f602-84be-48c6-bb89-17974049d2b7	2018-03-03 09:32:02.990261-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1066b355-3cdc-4b5c-a0c5-485a4c143609	2018-03-03 09:53:43.400289-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
dd0c6561-2159-4765-9150-09603c17ec49	2018-03-03 09:54:02.082157-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e6e84932-58c9-474b-a145-ab57f1d30bd0	2018-03-03 09:54:32.963245-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
854a7150-a84b-4a22-b71b-47dd807de445	2018-03-03 09:54:37.01465-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
7d0d9891-265c-4a84-886a-a7f9174b8597	2018-03-03 09:54:39.907939-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9314595b-b4df-4f82-88b2-4f5347bbb775	2018-03-03 09:54:45.749523-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
26ca80e7-a269-426f-a79b-4e93fea64dcf	2018-03-03 09:54:49.273876-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c5044db8-f358-4fb3-b6f3-5b849e945b6f	2018-03-03 09:56:21.940141-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
952e9704-8bc6-4b78-bfae-9224ed174fd1	2018-03-03 09:56:22.642212-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c8f800c4-2c1a-4030-8f49-f5316a9505f1	2018-03-03 09:56:25.178465-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
67aca9ed-ab8a-46f1-b964-976f8b0c28ca	2018-03-03 09:56:29.061854-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
402812dd-1d89-498c-a68e-1e8f370855d5	2018-03-03 09:56:30.32498-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
39f8a03d-85ea-4947-88fa-fc42f827f166	2018-03-03 09:56:31.358083-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e7dd038d-35ba-4b81-84bb-455bc238107a	2018-03-03 09:56:34.486396-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d0e85a30-1eb1-4b03-8c35-c5fc63122275	2018-03-03 09:56:35.114459-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
741655ef-02b8-43be-b9bc-e6b70ae531d0	2018-03-03 09:56:36.990646-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
706e6287-ec30-4d56-8178-50fb0c8be659	2018-03-03 09:56:37.593707-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6dc9c3ea-3832-416f-ba1e-cfb6ec89f1fb	2018-03-03 09:56:38.589806-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
0618a1bb-c10e-4de9-80f9-b11bfd0b1751	2018-03-03 09:56:39.176865-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b70319b0-1dfc-4c3f-93eb-07893d2845c9	2018-03-03 09:56:40.863034-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f0cba4ae-8b6e-4f19-8f36-e575a70e03a2	2018-03-03 09:56:41.456093-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
cb392a2f-24cb-4d72-b661-516417b6c858	2018-03-03 10:02:26.354579-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e095e5fe-e6a7-4837-bb69-3ca3b1451c90	2018-03-03 10:02:50.328976-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2e2c06f1-f71b-4fbe-b8f0-d10c7f74b34f	2018-03-03 10:02:57.006644-06	5	21154	[21154] Area C Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
df32a539-e669-4294-9e18-72b0bc465a0c	2018-03-03 10:02:57.225666-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
fd121560-a0e2-4124-bfe7-c0a25688bb10	2018-03-03 10:02:57.926736-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
7e08f0b4-500e-496e-be81-603a542bb67b	2018-03-03 10:03:00.052949-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5a116de5-75c5-48b5-bd2e-d69c3d89be70	2018-03-03 10:03:01.619105-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
888eb967-0a6c-47c9-9e41-82dedfcbc29d	2018-03-03 10:03:01.622106-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
026b9c8c-c87e-40a9-9e45-928ca4fad088	2018-03-03 10:03:01.639107-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
dcf44007-6b4d-47b2-807b-141eb786659e	2018-03-03 10:03:02.752219-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
be5fc608-5f22-414b-a42e-2be52c68c0e1	2018-03-03 10:03:05.455489-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5147cf3a-5d69-47ed-8788-76dddac1ad1f	2018-03-03 10:03:13.343278-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
559fe745-e83e-4c84-91f8-9d94510f5142	2018-03-03 10:03:27.228666-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
220592eb-33aa-4f51-9996-694e2512ade9	2018-03-03 10:04:21.341077-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
43967c66-065e-4beb-a878-95ebcabc115c	2018-03-03 10:58:38.008711-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
dcb767fb-081a-454d-91b3-b10d14b77002	2018-03-03 10:58:44.576368-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
28414a5f-77d1-4d49-986a-ce40dc380308	2018-03-03 11:04:25.495456-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
3af1cf03-86fd-4e93-bfc5-52ebbb48220e	2018-03-03 11:04:51.302037-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
67fe90da-e8cb-4deb-93ac-3ff1fd2c64e3	2018-03-03 11:05:51.119018-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [21228] Default Screen Group\\Area C	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
df1db26b-f4dd-4b51-89c1-65c1bd76a402	2018-03-03 11:05:51.172023-06	5	21154	[21154] Area C Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
38e0811f-3632-4ae3-b6c6-bd681ec11a25	2018-03-03 11:05:57.066612-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6be288fa-85b8-4317-a97d-b38f10b05244	2018-03-03 11:05:57.284634-06	5	21278	[21278] Area C Target Copy	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
63c73a4a-7647-473a-b20b-d02b387588ee	2018-03-03 11:05:57.582664-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2d64d177-7341-4d4a-99b8-b9165bc10816	2018-03-03 11:05:57.797685-06	5	21278	[21278] Area C Target Copy	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
0695b8fe-ff3b-409a-bd63-8f3207d00d05	2018-03-03 11:05:58.64777-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b9edf27f-d407-4060-89a0-6ec509532525	2018-03-03 11:05:58.863792-06	5	21278	[21278] Area C Target Copy	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a0d22fc0-98fa-443a-9cb7-9005bda4dda7	2018-03-03 11:05:59.358842-06	5	21278	[21278] Area C Target Copy	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8eec1359-db05-4dd0-8c88-b354586ebe46	2018-03-03 11:05:59.571863-06	5	21154	[21154] Area C Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1ef56082-2ecb-4dd1-bb04-8ac687af065e	2018-03-03 11:05:59.574863-06	5	21154	[21154] Area C Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8c86b362-6b02-4dce-a88d-4f8747205923	2018-03-03 11:07:16.982603-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
859c0383-6329-4107-ae1c-678e7210cd08	2018-03-03 11:07:20.363941-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c73eaf56-0df0-4209-9a64-411ddefb3014	2018-03-03 11:08:04.872392-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
32eef4cd-8188-4f51-9d41-9df464006453	2018-03-03 11:08:09.893894-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f45ef4fe-5d65-4a94-8268-949a9bedcf8c	2018-03-03 11:08:11.610065-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ba019275-203b-458c-832b-bd9fbf4c9c89	2018-03-03 11:09:06.268531-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ef570822-72f4-485b-bd36-bba054a1c488	2018-03-03 12:04:33.583229-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
36b32447-a96d-40df-8a96-601adac82be5	2018-03-03 12:05:36.982568-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
cb484fde-35b8-469c-87c1-99372f831d9b	2018-03-03 12:05:37.039574-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
da73717f-a605-4537-89c1-2ca04e2d2418	2018-03-03 12:05:56.329503-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
af14e935-8f69-4a62-8238-d6f2020e9a1b	2018-03-03 12:05:58.919762-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
36c43860-4180-4b19-9573-f380dc318a66	2018-03-03 12:06:07.571627-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
7d242d6d-4025-4131-a8f8-d7333e47016a	2018-03-03 12:06:15.374407-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
94ab5dd3-4944-4905-9305-ba52cc6b064b	2018-03-03 12:06:50.50692-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
69ce25f1-23e4-4ef5-8f3d-639862892a0e	2018-03-03 12:07:01.378007-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
2f03246f-8eb1-41a6-853c-ce8f9577f642	2018-03-03 12:07:32.043073-06	5	21155	[21155] Area D Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
79b9f0f5-187c-462a-a210-658407039dbb	2018-03-03 12:09:16.898558-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
ec778db0-5fb7-4678-bae7-1bdb5a952b8d	2018-03-03 12:13:07.816647-06	5	22092	[22092] Door 324A	0	MouseDown	0	Pulse [19179] R8C5-16R\\Lock DR-324A Relay	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
acd446ef-275f-4445-b4a2-2811e498760f	2018-03-03 12:20:24.538315-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
3751b5f6-7ed0-475f-b619-2f603bd6c544	2018-03-03 12:20:43.317193-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ac57e622-9250-49df-afbc-0e44bf87522e	2018-03-03 12:20:47.866647-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
03707025-2911-4097-9794-ab74a76735db	2018-03-03 12:20:52.570118-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
bed66c96-fb6a-413c-b4c8-cc614a1547cb	2018-03-03 12:20:57.140575-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5e056811-4d7f-413b-bffa-3fc688ac9450	2018-03-03 12:21:00.19288-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
015105b8-ab37-4a83-a8d3-491317c32e85	2018-03-03 12:21:08.544715-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
0b25b049-764a-4c13-8530-d57c0b366a7d	2018-03-03 12:21:30.028863-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
50f56f88-1d85-42f5-80fb-be80bdb9e031	2018-03-03 12:21:45.648425-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b93018fa-1183-496e-9e67-a59782b67de4	2018-03-03 12:21:50.281888-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a5a94eb0-529d-45d1-829d-160c80a668be	2018-03-03 12:21:59.441804-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
3c0b7ae2-4cc1-4cfb-9995-ed918b0d60c1	2018-03-03 12:22:06.193479-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
475e0a4b-371b-4849-83c5-3c713a2df717	2018-03-03 12:22:13.127173-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5e6ac733-80d5-488f-b540-b99bc8dcb328	2018-03-03 12:22:30.927953-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
720ac319-6f0a-4eb8-9982-ff6102cdbbb5	2018-03-03 12:22:34.414301-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b696362c-d814-400d-87b0-fa07201a6a72	2018-03-03 12:22:42.719132-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
98634156-abe8-4e63-930a-d9c40e815312	2018-03-03 12:22:51.477007-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
51f88c66-0234-499a-b577-82bdd3403a29	2018-03-03 12:23:00.343894-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[21062] a	\N	\N	00000000-0000-0000-0000-000000000000
79bf3cf6-fcc7-4433-8815-980b792997ec	2018-03-03 12:23:06.746534-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
40cebdcb-9c91-47e6-8234-d4a376a420dc	2018-03-03 12:23:33.726232-06	5	21278	[21278] Area C Target Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
0c3b6df8-ab18-41bb-8983-ad48874112eb	2018-03-03 12:23:38.534713-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
891f858e-3716-479f-a382-61cb587390e8	2018-03-03 12:23:49.916851-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
939004ca-3ba1-4259-910b-8a47196df962	2018-03-03 12:24:02.371096-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
8e78a2d9-b3b3-41d4-9028-8838f47d7ab1	2018-03-03 12:24:08.694728-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2075b798-4388-42c8-b501-49d71ec9b1af	2018-03-03 12:24:08.847744-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
f452a8b4-5c34-4bc2-b0ed-5c4fc8de5553	2018-03-03 12:24:20.60892-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
9a6a1d84-2963-4cc9-83ed-0b16dc073a20	2018-03-03 12:29:28.660722-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
5cab150b-294c-43a5-a2ad-889950f2b479	2018-03-03 12:29:28.686724-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6047a804-9c34-42de-9fdc-f1654945d230	2018-03-03 12:30:33.618217-06	5	21278	[21278] Area C Target Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
98ffbe26-1336-4ffd-9dab-b7dec02f4d60	2018-03-03 12:30:41.108966-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
53c42d97-f7f7-487f-b026-4e5770d0d6d1	2018-03-03 12:30:43.699225-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6155adcc-76c0-4a78-9e0f-16ce64152b04	2018-03-03 12:30:46.317487-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
79e86917-50f0-45ef-9a81-e98815a0060e	2018-03-03 12:30:50.94795-06	5	21278	[21278] Area C Target Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
bae1a10b-130e-466e-afee-73170abf1188	2018-03-03 12:31:01.630018-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1d2ca4e3-3336-4182-bfeb-cc1fc4e10c2d	2018-03-03 12:32:14.521306-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
3143ef80-5955-47d9-a0fd-3dd4d144f1a1	2018-03-03 12:32:18.805734-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2525aad8-410e-42b5-a7a8-914671f0d29e	2018-03-03 12:32:50.320886-06	5	21278	[21278] Area C Target Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
7a763ac9-a0d4-48db-a294-31faa139a0a9	2018-03-03 12:33:01.901044-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
69693b93-f347-4c88-80cd-2f9d3e621257	2018-03-03 12:33:11.017955-06	5	21278	[21278] Area C Target Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9ec4ef39-1781-4550-94d2-db4febb439a4	2018-03-03 12:33:45.141367-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8f301996-14b0-4a4e-bd9f-43c591e41da2	2018-03-03 12:33:49.832836-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
4f63f61f-7fbd-47cd-add2-2f8974cafebd	2018-03-03 12:33:53.881241-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
bbf7dd3f-eda1-4c94-852b-15aa7bdc4549	2018-03-03 12:33:57.863639-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
04777da1-09ac-4aa2-8fd0-4938c2244686	2018-03-03 12:34:04.053258-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9ee6e591-242f-4345-8d1b-5121ba929b12	2018-03-03 12:34:18.500703-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8f026243-35f1-4343-a6ab-11e0023cb505	2018-03-03 14:28:00.403825-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
e20bbbb9-064c-4aac-b6df-dc167364dd6c	2018-03-03 14:28:26.800464-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
7828af7f-6a6b-42d8-8516-56c23665acb1	2018-03-03 14:28:33.112095-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
44c0c880-2b3d-4a93-9e7e-57dfcde773d3	2018-03-03 14:28:34.753259-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
4aa6819f-0662-45e5-9d01-05c6fb206875	2018-03-03 14:28:37.005485-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
2991645d-e157-49b0-8e06-11d1e7b65455	2018-03-03 15:28:11.480569-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
43242b98-1bf6-464b-aa8c-61405514fb81	2018-03-03 15:31:56.390569-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
e59f6904-b3f8-4473-8a9a-18cca36963cc	2018-03-03 15:37:16.269431-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
9fb71e50-aca7-4601-8b97-8e5338de2457	2018-03-03 15:37:16.322436-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
48c9db62-3999-421d-835a-4c7d1c1a55f2	2018-03-03 15:37:22.983102-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
ac67b3da-7123-413e-9931-fb5f31e07112	2018-03-03 15:37:24.15922-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
13564514-415c-4812-8580-de7433b38b26	2018-03-03 15:37:28.042608-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
c0356568-0017-44f4-8b0a-dfd29f4f7c5c	2018-03-03 15:37:31.495953-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
4ab6df12-225b-4df5-b992-f02991b803c6	2018-03-03 15:37:38.35964-06	5	21156	[21156] Area E Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
12d2c559-dbd8-49c4-ba29-6feb8d95fef0	2018-03-03 16:08:15.834369-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
cfd79c65-2aa4-4e8d-a27e-2f1ad531569a	2018-03-03 16:08:29.824768-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d8cedbab-9125-441d-b5cc-534c05393eb9	2018-03-03 16:08:29.867772-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
424817e8-6fcc-465f-86be-105929b0ef3f	2018-03-03 16:08:30.730858-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
0ad4d93b-1859-46cf-9857-1f303caca1a8	2018-03-03 16:08:31.323918-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8ac0a8fb-2a6d-441b-b0ee-e9d8c561f97c	2018-03-03 16:09:05.695354-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2da00eed-2912-47d6-8717-3ba25e07f325	2018-03-03 16:09:08.534638-06	5	21815	[21815] B 1 LIVING ROOM 211 Copy (30)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21566] Counters\\B Cameras\\None	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
aa1f467b-9504-423b-a2ef-a3f15f058782	2018-03-03 16:09:11.958981-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
10218d41-2c3a-438a-adf0-5dc6e1242c12	2018-03-03 16:09:16.422427-06	5	21278	[21278] Area C Target Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
4f5f9dd4-5984-4793-837e-76692f4f94ee	2018-03-03 16:13:35.363319-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
fa3f5c0f-ce00-42b1-888f-ad86ed59a7bd	2018-03-03 16:15:03.867168-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
fcb129e3-790f-496d-bec4-b96e0e3c6739	2018-03-03 16:17:59.546734-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f0377906-f843-409c-b6e9-7cdd17ba63e4	2018-03-03 16:28:23.031076-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
8ed784b5-47c3-4cde-a596-862c71baaea7	2018-03-03 16:29:43.2741-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
628131a3-bbaa-4e07-9f37-5892f926d40b	2018-03-03 16:30:20.441816-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
aaa428cf-323f-4899-a1a2-00ada42f2363	2018-03-03 16:30:20.487821-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
845913c2-7e71-446e-8ddd-3b2407f137bd	2018-03-03 16:30:28.303602-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
c18f2a32-ea38-43c6-9998-894fedfef8bd	2018-03-03 16:30:37.835556-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
6d7e6306-8eca-4198-9b70-2ebf02e5f914	2018-03-03 16:46:13.280091-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
098cf3a0-713b-498e-b73c-81f72b233806	2018-03-03 16:47:12.123974-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e55652b0-6f0c-4fb0-b78c-8b69027e8640	2018-03-03 16:47:25.792341-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
98a85945-b3c4-4094-a3c2-95b5557711b0	2018-03-03 16:47:28.210583-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
350fb6ee-524d-4b4a-bbc4-3e13e9483b16	2018-03-03 16:47:29.68373-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
430f6e65-40b3-45c7-8e29-536365388ae1	2018-03-03 16:54:43.690127-06	5	22432	[22432] Area C Target  Right Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
88ca319d-8c14-4442-ba89-7ac438f43855	2018-03-03 16:54:53.080065-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
330ed029-4d10-4ddb-aca1-e1b10265967b	2018-03-03 16:54:55.145272-06	5	22432	[22432] Area C Target  Right Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
da4b15b1-586b-4760-b47d-d185bd3dd941	2018-03-03 16:56:48.582615-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[21062] a	\N	\N	00000000-0000-0000-0000-000000000000
ec06fc02-c973-46b2-be08-3d4a4e90a939	2018-03-03 16:56:55.375294-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
4535f967-44a3-40ce-b162-3647f1a4630f	2018-03-03 16:58:34.095165-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
bc448fb4-fb31-4cd7-9b5f-fcfd1ccd0e5f	2018-03-03 16:58:36.760431-06	5	22432	[22432] Area C Target  Right Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
83fb7641-a337-43a8-8864-1a267e84cd0c	2018-03-03 16:58:38.84464-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
aaf109ba-575d-42fc-a811-bf8c6ec40710	2018-03-03 16:58:41.395895-06	5	22432	[22432] Area C Target  Right Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d48e15ec-e3ce-4b65-b1eb-fc1ccf802274	2018-03-03 16:59:33.937148-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9554d27e-a2c1-476a-ab48-6cf84cf581f2	2018-03-03 16:59:38.384593-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
32fb737b-8065-4940-abc9-228c2ecd463d	2018-03-03 16:59:42.424997-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ff52e462-6f39-4499-aaa5-c12e9fbea95f	2018-03-03 17:00:09.123667-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d075ce06-59d5-4f5a-bf3e-b9ea8f050f28	2018-03-03 17:00:11.631917-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
458e7a66-3fe7-47cb-8965-b44d3750025a	2018-03-03 17:00:19.103665-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
7e06ed6e-a6a3-4d67-a5dd-98f16f599e89	2018-03-03 17:01:46.76943-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
241b6ad9-d8ae-4c87-ae50-85e21fdfaa4e	2018-03-03 17:04:10.817834-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
bdeb32b4-a232-4b73-a5f8-6725eb706d88	2018-03-03 17:04:15.723324-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f0b3ecd1-6a8e-457f-ae85-c1122b00c48d	2018-03-03 17:04:19.148667-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
bd4d01e8-a227-488b-b05d-cef02edb3802	2018-03-03 17:04:21.425894-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b2ee2bc3-741d-4fe0-b8d5-0f97925460c5	2018-03-03 17:04:22.78403-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
49f6735b-11ce-4602-b4cb-ad4e097317c5	2018-03-03 17:04:23.570109-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2dc6d46e-466e-4115-aed9-6d78eae8fd2d	2018-03-03 17:04:25.236275-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
62fa6a07-3d82-43a1-9d41-983fe9ff4dfb	2018-03-03 17:04:27.924544-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
faa4101c-a772-4a27-a53c-123ace60f36e	2018-03-03 17:04:28.707622-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e3f69cad-c085-464a-916f-2771436b44ca	2018-03-03 17:04:29.377689-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6dc6087d-9bff-49e0-9894-ec5290852d3b	2018-03-03 17:04:30.899842-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9de11e45-20df-45f2-a24a-d9cd68da8609	2018-03-03 17:04:31.607912-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c4e0122c-0907-4e26-af2d-29f827901166	2018-03-03 17:04:32.689021-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2ce60251-f077-4f47-a970-1426f45be7cb	2018-03-03 17:04:33.456097-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
11ad62c0-1746-4de6-a74c-bdf4cbf465c2	2018-03-03 17:04:35.929345-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1ac38199-feb7-4a9c-9350-aacf598c76e9	2018-03-03 17:04:38.88364-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ac2c13ad-ba8b-4295-adcb-204ecf16d271	2018-03-03 17:05:23.878139-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9ae58f49-3f5e-4378-a0fc-8cfbd8dbd66f	2018-03-03 17:05:24.855237-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c6c24138-7407-4390-9b36-13cb9e9c5d38	2018-03-03 17:10:27.311479-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
01683028-b662-4323-a6eb-23bc56f3d711	2018-03-03 17:10:29.873735-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
7623e759-fdcf-4c27-9cf6-7dde5dc17fc8	2018-03-03 17:10:32.694017-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
3f118fc1-9611-4a0e-8227-3922e9cc91c0	2018-03-03 17:13:00.140761-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
114533f0-da3d-4bad-b1f1-8c0ab2f99511	2018-03-03 17:13:01.975944-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
10745907-c9d2-44df-a64e-ef35fb6e04fb	2018-03-03 17:13:04.423189-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
19744fbf-8b77-4653-9034-e9462b29c73b	2018-03-03 17:13:06.695416-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
cd576da8-14fd-40fa-8fa9-8d3839482075	2018-03-03 17:13:08.650612-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
97e82fc7-2c9a-4526-8946-b18b0396bf83	2018-03-03 17:13:10.994846-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
66e160e2-80c8-46bd-a650-0697c16aaa0f	2018-03-03 17:13:14.724219-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8b83ff2f-898a-4e17-b147-02daadb34838	2018-03-03 17:14:05.171263-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
27b17ff3-1d85-4943-80bd-abb2c4ce217f	2018-03-03 17:14:07.204466-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b3e39fe1-7929-43f2-a5b9-e8eced1b3dd0	2018-03-03 17:14:08.614607-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f6948db9-fb1b-4175-85d5-1103e0aa874b	2018-03-03 17:14:10.547801-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2769e469-4ab9-443a-b078-9d0eb1edcddc	2018-03-03 17:14:12.251971-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
150625e6-7cf0-44d7-9e97-c3726f9044ed	2018-03-03 17:14:20.765822-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
478260b5-e4ff-440e-b93e-38903bb6c180	2018-03-03 17:14:37.84553-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b2f1151c-5490-48ca-822b-f17a5ecde4bb	2018-03-03 17:14:47.24447-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
707d1f13-4090-49a4-a602-b4ff5b5cb049	2018-03-03 17:14:48.798625-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
067083ec-1f76-443f-b5e3-522e1214dba9	2018-03-03 17:14:50.64281-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
515fb60c-e229-4e4c-a5a2-7a4bd4945484	2018-03-03 17:14:53.060051-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
4c3f12ae-996f-4ab8-846c-102db12eb28d	2018-03-03 17:14:54.003146-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a3c031b9-ddeb-4c95-8389-d765e351c3ad	2018-03-03 17:14:55.74232-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
17fa2753-f1d5-4a9c-9b5f-5223a7ba0895	2018-03-03 17:14:58.352581-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d90660a2-3c87-40b6-9a5f-219ca433d836	2018-03-03 17:15:00.067752-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
0ca241ca-3122-4b5e-b256-69f5473830bf	2018-03-03 17:15:01.551901-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
aa5617f8-1695-49a3-a8ac-d9b31dae487b	2018-03-03 17:15:02.34298-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
53e14e2c-0608-4b62-882b-4d2fbfda0452	2018-03-03 17:15:03.082054-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
af107dd4-3b24-4631-8f33-450a87d644c2	2018-03-03 17:15:03.915137-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f96a5385-72da-4c5e-846e-a1d416220a59	2018-03-03 17:15:04.902236-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
7a9d894d-e684-4f82-9f42-8c13e90bcc50	2018-03-03 17:27:05.956334-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
188cf43a-b570-4dea-b3e8-ae13cc8cca6d	2018-03-03 17:27:07.309469-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2578fa23-5e07-4116-9331-df766109d805	2018-03-03 17:27:09.186657-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
38df521b-fc05-4735-a5e5-f4eafa38dc43	2018-03-03 17:27:10.487787-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
dcd2c2f6-801e-472c-86a8-4fbd8df6e140	2018-03-03 17:27:11.971935-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
dbddad86-9880-4da2-9f34-87efcfd1f331	2018-03-03 17:27:14.141152-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
7800113b-50c6-4bdf-bc16-21691252724d	2018-03-03 17:27:33.595097-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
fc31a719-9bc6-4726-bb99-2b93109e56c6	2018-03-03 17:27:40.914829-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ead9880f-0a07-4f56-8133-afc7d317deca	2018-03-03 17:28:46.767414-06	5	21154	[21154] Area C Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
37a26823-08a2-4b77-904b-d09fd18867fe	2018-03-03 17:28:50.523789-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
234105c3-f8de-4839-adbe-54b2befa19ad	2018-03-03 17:28:52.401977-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
4376ad3e-c4e9-4530-86ce-f104e32a02e9	2018-03-03 17:28:54.381175-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
57dfa23e-c316-49d0-8599-3a9eb5e1fa34	2018-03-03 17:29:01.067844-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
7d28e6d8-a5dd-41fa-9b5e-f459480714f7	2018-03-03 17:29:02.195957-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8f139987-51bb-462b-a674-ec1162e07fc0	2018-03-03 17:29:03.503087-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
32f8d62e-ec1a-4feb-9aa8-d4032271921c	2018-03-03 17:29:05.902327-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8925e9f5-a4b6-45ec-b677-e55ccdc28192	2018-03-03 17:29:09.412678-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c0a6ff56-afbe-4294-aa9e-ae0e913b26ea	2018-03-03 17:29:10.23276-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5b26bb68-bb60-4f16-a4a9-f95d388b3deb	2018-03-03 17:29:10.491786-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ac5390e9-4738-44e6-9b35-d8c093ebddb4	2018-03-03 17:29:11.03084-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8c04c4ad-48f2-45dd-9385-c9f77a3d8a64	2018-03-03 17:29:11.03384-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
3d1e35a0-cbcc-483b-8e9d-f038db4dd4ee	2018-03-03 17:29:13.468084-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2b1250cc-8ef4-431a-8681-cab63853de4d	2018-03-03 17:29:14.788216-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6cabed75-4ab7-41ca-bfa7-7212df14db6a	2018-03-03 17:29:15.758313-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f7c6529d-2339-471b-ba1b-1d764aba423c	2018-03-03 17:29:17.83552-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
471b17dc-c474-43a8-8c22-a4773ec53e6c	2018-03-03 17:29:37.894526-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
68c39414-fa37-4beb-ab81-001377a9aefc	2018-03-03 17:29:45.164253-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
92634144-c4ad-420a-9de4-eae108807540	2018-03-03 17:30:50.634799-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
32cd79ec-2e2b-4b79-a4ec-cb51fcd8fb63	2018-03-03 17:34:53.695103-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
71497c00-fc5f-4ec1-b590-92b6e52d4570	2018-03-03 17:34:56.36737-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2f251b51-2823-4ce6-8d9b-a75dbe20272a	2018-03-03 17:35:00.242758-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
0894d80c-8e2d-4836-91e8-056aa403b0dd	2018-03-03 17:35:02.276961-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5cd57f2c-28bd-41d8-bb15-165c5ac648d9	2018-03-03 17:35:12.332967-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6267ab51-a377-419d-906f-81e2c6f78cab	2018-03-03 17:35:14.724206-06	5	21155	[21155] Area D Target	1	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [21242] Default Screen Group\\Area D	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d0cb1687-9b85-4642-8689-903b428eb066	2018-03-03 17:38:08.414573-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b601bdf1-d48a-45e5-90c0-5f35d475e181	2018-03-03 17:38:12.732005-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
440c5053-ef7e-40e9-9f6b-c4ab01c0d866	2018-03-03 17:42:13.135043-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
57bfaa10-0c4f-4811-9696-23e0607f8aa8	2018-03-03 17:59:22.774996-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
82e4b98f-b604-4590-b598-f79a62e49057	2018-03-03 18:04:02.684984-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a838b84d-58fa-42d4-a6da-32f9c079f777	2018-03-03 18:04:17.951511-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
13818c96-39aa-4d12-afde-8ed5a136fd7b	2018-03-03 18:06:47.711485-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1ee5d5c2-74d5-4aa9-93b0-a21631ef419f	2018-03-03 18:07:04.403154-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1bb45cc6-6b52-44ed-87d2-587fe3dc0485	2018-03-03 18:10:34.845197-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b40c8b1e-74fe-41cd-a9c3-5170d2d66ec8	2018-03-03 18:10:39.634675-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
43de841f-ed05-48f9-bc74-16422d22183d	2018-03-03 18:10:41.446857-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d85694be-e8ea-4bf0-9998-0cca719b4f47	2018-03-03 18:10:44.500162-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
42702a28-b53f-420d-b67f-19d1ab424bfe	2018-03-03 18:10:47.427455-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9c410291-3186-4602-be70-d55b0c096a1f	2018-03-03 18:10:52.718984-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d8a1e44c-9721-46e5-aa3a-37cbd47f3ee3	2018-03-03 18:11:07.852497-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1c0072c5-32ee-4285-a0cf-e103481ee466	2018-03-03 18:11:16.442356-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ee718f06-b5a2-40d5-afae-9358ddfc7579	2018-03-03 18:11:17.78049-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
3852b514-ba57-4f95-882a-64904e821565	2018-03-03 18:11:18.731585-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
266a7fc9-5ce8-40d7-8e0e-e22586a484db	2018-03-03 18:12:51.761887-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f12e3ae1-5642-4e30-8f12-ba06737a20f3	2018-03-03 18:12:52.445955-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2eb1d666-320f-4895-9803-a2edeab785be	2018-03-03 18:12:53.621073-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f3e53dd0-4a79-4f23-8220-01d90367ff3b	2018-03-03 18:12:54.859197-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
7ec8dfa5-0f2d-467e-b470-c16fcdd02e03	2018-03-03 18:12:56.49636-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6081c562-65a3-45e3-b5a5-3af22c458792	2018-03-03 18:12:57.275438-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
beec54b5-0d4b-44e9-b6d1-d9dd49d62237	2018-03-03 18:13:00.516762-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
29d0a86e-7ede-40e7-bf25-cbd241e766cf	2018-03-03 18:13:03.541065-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c8230b0f-6293-47aa-bd27-35078d0f2063	2018-03-03 18:13:08.245535-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e108f66d-210f-4503-901a-0ad779424ead	2018-03-03 18:13:11.066817-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8afdd643-65c8-4e64-8ea5-ae12712658ab	2018-03-03 18:13:15.846295-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ac30c66e-8c69-45cb-ba90-36bccc7a373c	2018-03-03 18:13:18.79659-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
baccea5c-0ee0-48e6-b9b2-4eac5d42defe	2018-03-03 18:13:22.09192-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
165f8a11-2910-46fa-9113-52686e133651	2018-03-03 18:13:27.243435-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
7e868bdd-7f9a-4edd-967b-e61a89759abd	2018-03-03 18:13:33.317042-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
4297cca0-db0d-45a4-9b3e-c0cd69fd1336	2018-03-03 18:13:36.980408-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8af86e9f-c5b4-45e0-8168-0715f22eb7dc	2018-03-03 18:13:40.486759-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5b344825-0dde-4875-b77f-801ae6663506	2018-03-03 18:13:43.241034-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a412bb46-0991-456c-b97e-668ad3c50a80	2018-03-03 18:13:44.447155-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e6e05a0c-5926-4b60-a0d4-e6712ff2a1f1	2018-03-03 18:13:45.185229-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
0e669b47-7d18-4451-b6bc-22b9cb473adb	2018-03-03 18:17:46.261334-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d94ed0da-b692-4def-bcae-67e4dffeb8cd	2018-03-03 18:17:47.484456-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a1f5e218-96a2-4efb-b3e6-ea3f24d98c82	2018-03-03 18:17:48.913599-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
4b4a1260-03aa-49cf-831f-1028a146e115	2018-03-03 18:17:49.549663-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
32f507ac-1e28-4d8f-910c-110872b96920	2018-03-03 18:17:51.749883-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b147edb1-d98b-48ff-bb5f-550fd0308f54	2018-03-03 18:17:54.380146-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c9125d93-34ca-4833-9e44-aa361c42e639	2018-03-05 08:22:48.609447-06	5	22441	[22441] Door 405A	0	MouseDown	0	Pulse [2306] R1C4-16R\\LOCK DR-405A Relay	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
919f2900-7f8f-4c51-97c8-ad7498a08fc9	2018-03-03 18:17:56.352343-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e5c5c0d7-4e93-49c5-9fc8-98dbf412ddd3	2018-03-03 18:18:06.543362-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9d62734b-455b-461b-8d21-ff8922691fce	2018-03-03 18:18:09.978705-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a41865ce-e2eb-4cf1-84e9-ec19840521ee	2018-03-03 18:18:11.910899-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1d2d8057-67f5-48d8-b11b-5dbf0a9454b6	2018-03-03 18:18:15.406248-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e1c80b7b-5250-4e15-82bd-ecc8af6c4c4e	2018-03-03 18:18:18.959603-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b107d813-d363-496b-a116-eff0d9c05db3	2018-03-03 18:18:21.582866-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
dcb14048-a9e0-457b-b6ed-f2da60f35ad6	2018-03-03 18:20:42.960002-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
80a4c320-64df-42d2-b420-8173e349efdb	2018-03-03 18:20:44.365142-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c70ee31f-ee7c-45b6-b91e-211448736a14	2018-03-03 18:42:24.0751-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2bcb0043-89e4-49cf-9fa4-11356290b7d1	2018-03-03 19:48:25.150168-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
3d396fb7-c2f0-45ce-a86c-28b42d6a271a	2018-03-03 19:49:12.787932-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
b2bd1e9c-5863-4871-a371-fcf2fe11cca5	2018-03-03 19:49:13.823035-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
d97e4b81-3544-4d13-8357-764b7fa73db7	2018-03-03 19:49:24.291082-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
b6685607-66cc-4357-bb1b-61b2bfa5a948	2018-03-03 19:49:25.300183-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
c7e53df9-6a0c-4f9d-8602-7e91f6a45571	2018-03-03 23:04:44.682004-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
9b05c0ae-8aae-44cd-b7c8-431704abe357	2018-03-04 09:09:45.549789-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
cd071316-0f9b-4e07-980e-7b78dd4b8ca5	2018-03-04 09:18:40.12024-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5b58f0af-b521-48bb-a2ab-4b0ad73511ed	2018-03-04 09:19:22.829511-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
208c7d21-a349-4f3b-9e82-e1c9cf741e09	2018-03-04 09:19:22.848513-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a4ce6bc0-b539-4d2c-9e7a-e5635d7cdce0	2018-03-04 09:19:23.81661-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a7a95f30-ec72-44f8-aa19-6638ed330651	2018-03-04 09:19:24.882716-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
404dba7a-7011-491c-bd02-30094adc15a2	2018-03-04 09:19:27.712999-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
12891a68-b459-4d15-aa01-bcf491fef36e	2018-03-04 09:19:28.337062-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
833c184d-7c2a-4804-871a-2aa29dae3b87	2018-03-04 09:19:29.7222-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5f611de3-3daf-48bb-a819-f1419fb5cbbb	2018-03-04 09:19:31.747403-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9438622c-a93b-4a41-a50b-4b50332f82cb	2018-03-04 09:19:35.998828-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
833890ae-65ef-4b97-9cfe-4b44bae98f5f	2018-03-04 09:19:39.316159-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f7274cad-b2ca-43a8-96cc-8301eb64073d	2018-03-04 09:19:41.52738-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
27dc1aa2-7922-4f75-8a1e-b81e93a18156	2018-03-04 09:19:45.212749-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6d943dd8-bb66-4d9e-a520-57e1ce79dce0	2018-03-04 09:19:47.760004-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
808c646d-54ea-4f71-95c5-22b5afe2c76e	2018-03-04 10:02:43.574625-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5b8ccb01-e880-4ae0-bf70-1416ba291596	2018-03-04 10:02:50.453313-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
7ad57349-3aee-41e8-8d8a-9690c093cfdb	2018-03-04 10:02:52.799548-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6276f937-828d-4071-a2d6-26dc25e7e71c	2018-03-04 10:02:55.869855-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
7744c27b-61de-4202-91e2-b6bf0f407cb3	2018-03-04 10:02:58.294097-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
00adfa85-f159-4741-a926-3b0c5da2173f	2018-03-04 10:03:00.061274-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
0f2a70eb-25d8-4c65-80c1-a40d4d28adbe	2018-03-04 10:03:03.430611-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
4edc6606-28cd-4fe3-b330-2a1f0656b46a	2018-03-04 10:03:21.417409-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6b24282d-9639-42d3-a306-eaeab54eb353	2018-03-04 10:30:48.957147-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
91565918-6268-4b11-b0e2-9cf2258b282c	2018-03-04 10:31:05.306781-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
272d08a4-b264-4397-8fb4-c27d4486e6b8	2018-03-04 10:42:57.787022-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
33846fb2-fc34-429c-b6e2-6875c0e3b98e	2018-03-04 10:42:58.005044-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
61f22481-03e5-43ea-ba3a-10669a974531	2018-03-04 10:42:58.498093-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6648a6ca-3805-4e33-a83b-143fc7fdbef5	2018-03-04 10:43:07.527996-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8ba1c5be-9bc0-49ae-973f-4fb895303bf1	2018-03-04 10:46:55.331774-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6ab287e9-82a0-4300-b1f1-bf09791af8ad	2018-03-04 12:10:35.572748-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9a691ecb-94c9-4e0c-aef5-5bcb6a68d464	2018-03-04 12:12:30.524242-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
7d063e73-c040-4044-a91b-2df1beb59f67	2018-03-04 14:35:48.197924-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
960a4800-b27f-4ad3-99a9-6f4922bdf945	2018-03-04 14:36:22.196323-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
8350c504-1293-4c2c-951b-0f7ddfad8e9a	2018-03-04 15:05:04.449531-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
69e55ce3-9e79-4344-97df-532469f50bf5	2018-03-04 15:05:11.956282-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9891c1fd-b23e-47e4-8cc7-9d7dea0091a5	2018-03-04 16:40:25.814611-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
588e1bd3-7fcc-4154-baed-060cb8577ad4	2018-03-04 16:40:42.631292-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a8121314-ea41-4138-8a36-9ad33799fca4	2018-03-04 16:44:51.582185-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
c66157e7-47fe-42b1-b931-4a039767568c	2018-03-04 16:44:52.361263-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
5e74edb0-94ba-483d-aa3f-895406ab98f3	2018-03-04 16:45:06.109637-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
54f948dd-160d-4937-8e82-d11fc553b8c0	2018-03-04 16:45:06.865713-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
cc7e2449-2126-4fe4-8895-1ed68b523113	2018-03-04 16:45:07.828809-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
c62afd35-01bb-4ed0-82ac-5e1460565ee3	2018-03-04 16:46:02.534279-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
da9c8733-228c-427d-a897-1b83cc5dc9e9	2018-03-04 16:46:05.215547-06	5	21153	[21153] Area B Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
75ac4c1d-c5da-41c4-a315-3037a067c06f	2018-03-04 16:46:05.493575-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
842ba630-5f41-47ce-8d43-9df8081b2ce4	2018-03-04 16:46:05.929619-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
2aa52c00-1456-4e41-97f4-46afe35d4104	2018-03-04 16:46:14.031429-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
e0c2e795-b2a9-4b01-9811-f74fd3a0b257	2018-03-04 16:46:23.993425-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
ff96d167-6985-4e5a-b961-c874db30f383	2018-03-04 16:46:28.012827-06	5	21156	[21156] Area E Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
8b3ed5de-ddc4-4590-9226-430c67d3b5ae	2018-03-04 16:46:55.313557-06	5	22432	[22432] Area C Target  Right Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
dc9aaa93-4730-44b8-b09c-54532f383adc	2018-03-04 17:07:46.337646-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
1091cfc4-758b-4cff-9672-2e083c6a68ea	2018-03-04 17:08:11.513164-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
e7a5fc13-6156-4ccc-b188-608e30d7b09e	2018-03-04 18:02:29.40392-06	3	0	Engine	0	CoreManager	0	Object reference not set to an instance of an object.	0	0	0	OnMessageReceived	\N	\N	   at IntelliSite.EngineService.EngineCoreManager.OnMessageReceived(Object sender, MessageBase message)	00000000-0000-0000-0000-000000000000
52879900-5c20-4700-8fe2-51c313971350	2018-03-04 18:03:58.691848-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
741971a3-2134-4f42-9dd1-4b398bdfa5d7	2018-03-04 18:03:58.733852-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
7fc7b8a5-9f0d-4988-be6c-8c6c0c383918	2018-03-04 18:04:06.161595-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
348906c8-49f3-4116-b32b-3edf30269686	2018-03-04 18:04:09.276907-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
f1887097-ddf1-484d-be6b-7f5669043fa6	2018-03-04 18:04:09.902969-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
bbd77ebf-b1f1-455d-a4b6-2b8252a5e92c	2018-03-04 18:04:10.034982-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
02943d0a-3d46-4100-85ba-4ec349c1ba68	2018-03-04 18:04:10.161995-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
6255a35f-2e7b-47cf-b404-97eb02396550	2018-03-04 18:04:12.851264-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
c8000b9b-fac8-4533-bdc3-e5a1cb278269	2018-03-04 18:04:12.854264-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
5eed6159-52ef-4b29-afef-1d26e52da0f4	2018-03-04 18:05:17.426721-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
9d2c6d02-61f3-436b-90ea-eb2fe7ed7751	2018-03-04 18:05:17.968775-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
b0cee816-6a41-47a0-b541-2bfffa2ef288	2018-03-04 18:05:36.611639-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
676cfc6f-98ae-4867-8cd5-31267ca829e8	2018-03-04 18:05:37.600738-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
b1afde29-a5df-4b63-a6bc-3603bb403a86	2018-03-04 18:05:37.605739-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
d54ca3e0-ab20-4439-a0a4-d4ac7a98b14f	2018-03-04 18:05:58.165794-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
b8978fdc-8663-4af9-aa59-d88f216364a8	2018-03-04 18:05:58.92687-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
454fe23c-531c-4189-8716-583f92865c85	2018-03-04 18:05:59.581936-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
247e580e-2875-4d92-abb4-8ba005dd86cd	2018-03-04 18:06:46.714649-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
487a0a65-111c-4d80-a1a1-464a1570a900	2018-03-04 18:06:47.479725-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
a8dcec27-c5c1-403c-b396-3cfa0596b23d	2018-03-04 18:09:43.229298-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
10776607-b6bf-4bcc-a32e-0e7f01c3e71d	2018-03-04 18:09:44.288404-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
b4714314-9e1f-4089-930b-da7d7b8654eb	2018-03-04 18:10:41.171092-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
b46913c7-7275-46f6-b134-52b47edd7795	2018-03-04 18:11:35.747549-06	5	21155	[21155] Area D Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
e3522563-d5a2-4868-8d68-3c362ee4050a	2018-03-04 18:11:37.15669-06	5	22435	[22435] Area D Target Left	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
a0fc713a-3721-4081-bf3c-cfff6733bd70	2018-03-04 18:11:41.138088-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
d395d774-5ffd-4dd3-84f8-1413d84f6098	2018-03-04 18:12:28.016776-06	5	21156	[21156] Area E Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
4485666b-de58-4f01-9e1b-9879b791dc0d	2018-03-04 18:12:59.878961-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
5831787b-48a0-45df-bf32-4c649f2952d1	2018-03-04 18:13:05.909564-06	5	22435	[22435] Area D Target Left	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
401f44ef-6f47-4bae-803e-8f2a8d3edce3	2018-03-04 18:13:08.824856-06	5	21156	[21156] Area E Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
619cbd72-6322-45c0-bedc-a7c5062e9184	2018-03-04 18:14:26.748648-06	5	22432	[22432] Area C Target  Right Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
75b230a1-dcbe-4b4f-b990-762ceb852ce1	2018-03-04 18:44:38.050888-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
1b116c08-336f-4db0-ab9e-6fee3e74a8e0	2018-03-04 18:45:01.141888-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
3e3c98bb-d454-4d93-a08f-5186970ed346	2018-03-04 18:57:13.900398-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f788e608-8851-4649-ab53-dcd668dd3c55	2018-03-04 18:57:17.758784-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a74825b3-0400-4e9a-b06c-985f5ffd8337	2018-03-04 18:57:18.703878-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
89226fc0-c0b2-4556-bc67-67f901b66cb2	2018-03-04 18:57:25.095518-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9304e6a3-e1de-4b1a-857f-7b34cb570e5e	2018-03-04 18:57:25.978606-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
14d35fbc-cc20-4b41-bae6-8f6317253e8d	2018-03-04 18:57:33.055313-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9ea4fac9-bc7f-4952-b71f-5b357bbaef61	2018-03-04 18:57:40.283036-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
32683788-152a-4281-bee9-110af3f67192	2018-03-04 18:57:44.445452-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c3d9b0ee-916f-4e54-881e-2a0763aac084	2018-03-04 18:57:48.373845-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
18c146be-54ec-4dbf-9c5e-0980e24b2262	2018-03-04 18:58:00.112019-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
7b4df9a7-653c-4810-a620-086a0300e78b	2018-03-04 18:58:07.169725-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
379c1652-e4fc-4b4e-9860-c15fc6aa83ac	2018-03-04 18:58:20.056013-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
cac9d641-e79b-43f6-810d-199b31ee94bc	2018-03-04 18:58:25.390546-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
594894e6-9060-4123-9c16-23fb0147a0ae	2018-03-04 18:58:28.685876-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b3013805-1250-4c89-badb-cd97f6dcc1d3	2018-03-04 18:58:31.221129-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
94bb252c-15e2-4106-99c8-b08ffc0e196a	2018-03-04 18:58:34.144422-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
afd363a2-a9cf-43b3-9ab1-c090eff010a0	2018-03-04 18:59:10.738081-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[21062] a	\N	\N	00000000-0000-0000-0000-000000000000
67675b62-a925-4e4e-a36a-f863ba4126c7	2018-03-04 18:59:17.396747-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
a9c6d2ad-18f3-4534-994b-c311ee50fda4	2018-03-04 19:06:59.750977-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
5bf00cd3-7246-45c9-ad8e-39d644838aea	2018-03-04 19:07:04.726475-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
dfb46d67-84f6-43db-96b1-c658bae934e7	2018-03-04 19:08:37.117713-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
851f2dec-4ab5-42f9-aa1a-9e2b1e2e1e76	2018-03-04 19:08:39.536955-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
b9a92406-c313-41fb-990e-73a8f0128e59	2018-03-04 19:08:51.711172-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
499bb456-5263-431f-be06-061bebabfe46	2018-03-04 19:08:52.516253-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
98e539d9-adf5-421c-bb6e-fd57a769598a	2018-03-04 19:09:30.119013-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f4cd25a1-2f3d-4a0f-9632-6735ab0ce31b	2018-03-04 19:09:36.511652-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
aa23de6a-4145-4c61-8766-ad6ec3ed101a	2018-03-04 19:09:39.248926-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a483f145-3c53-425b-a1be-92d6e5f70244	2018-03-05 07:32:40.462662-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
90c35230-ffe6-463e-8dea-e6defec8009e	2018-03-04 19:09:41.228123-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a5d5392f-2192-45c5-a783-c6eabd664110	2018-03-04 19:17:01.459142-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
c32351a8-3a47-4745-ab59-24b3d3b10227	2018-03-04 19:17:19.278924-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
7a68e18b-2c70-4a12-8365-df368c6bddad	2018-03-04 19:17:20.567053-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
08fd5646-6edc-45c5-be4b-727dd050ec49	2018-03-04 19:17:36.221618-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f0576484-4d68-4041-8364-62b09d80eaaa	2018-03-04 19:17:37.54475-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
97402e94-dcf9-45c5-b624-5a85e56d64e0	2018-03-04 19:17:59.086904-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6187e0e1-f27a-4765-a8d9-3083c7c2e4d9	2018-03-04 19:18:17.875783-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
7173c0b3-e8cd-46a3-8f03-42fc6c1a9c14	2018-03-04 19:18:40.078003-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
dfd69713-0510-40d4-9fb7-4fca603679f0	2018-03-04 19:18:51.085104-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
ed190fb7-7ec4-46d7-a767-1a9e9523119b	2018-03-04 19:26:18.39583-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
6c4d59a3-94ed-434a-b796-07e15ff97f7e	2018-03-04 19:26:59.005891-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
caa0451e-2324-43b4-abe3-90c31ee91139	2018-03-04 19:27:29.443934-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
18d4cc1e-d47c-4fd0-8848-219413b95068	2018-03-04 19:34:22.988285-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
47f1b26b-a3e5-4259-95ea-bc3280735f5e	2018-03-04 19:34:27.217708-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
2a6f5d9f-da06-41b4-ac98-e875cbedc4b8	2018-03-04 19:36:14.258411-06	5	22084	[22084] Door 324OHDW OPEN/CLOSE	0	MouseDown	0	Pulse [19513] R8C6-16R\\OPEN-324OHDW Trigger	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
de06de9a-d62b-489f-b34a-b1d352fe3438	2018-03-04 19:36:33.999384-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
c8fca70e-9874-4fdf-ad58-78c35c114172	2018-03-04 19:36:41.639148-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9c27c695-1142-4e18-809a-7962ed9f3273	2018-03-04 20:16:23.266287-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
02059b48-72aa-4408-a080-5076b97e94a2	2018-03-04 20:16:29.616922-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
8bdd8b40-5b57-466e-9294-83aaf1fd414d	2018-03-04 20:18:48.700829-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
49d9ef62-c153-4aa7-8da8-0150f9a91476	2018-03-04 20:49:56.970638-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9488ccf8-4ec5-4fbf-9406-ae3857777a52	2018-03-04 20:51:01.169057-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
242c699c-51b8-4980-9dc1-135966166983	2018-03-04 20:52:27.715711-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
debf689b-6f85-42b5-b166-a3b7697f4560	2018-03-04 21:03:43.748307-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
b6bad8c3-b310-444e-8c5b-9655d9fda54a	2018-03-04 21:03:58.258758-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
49b3b01c-b736-40a3-86e4-a7bf3e14b6e8	2018-03-04 21:08:18.448774-06	5	22432	[22432] Area C Target  Right Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
69d63a0b-7d7b-4518-93e2-b73600f8d41e	2018-03-04 21:08:47.039633-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f54765b3-08e9-4843-8fb5-a40023fb2095	2018-03-04 21:08:53.987328-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d53c6d5e-af66-4c6d-af53-d1cd13eb2128	2018-03-04 21:09:08.30676-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
d87fe42b-c439-4158-ba8f-21deb66135e9	2018-03-04 21:09:27.006629-06	5	0	\N	0	\N	0	Disconnected	0	0	0	\N	[293] master	\N	\N	00000000-0000-0000-0000-000000000000
b73d145a-712d-42c4-8d11-c358a5348d4b	2018-03-04 21:09:33.727301-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
472d1330-a6df-4d42-817b-2603b0a70b8b	2018-03-04 21:09:51.291058-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
3cfe507e-66bd-44e8-bd50-ad66643ef948	2018-03-04 21:09:54.684397-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
9f6d25cd-bf39-4d87-97e2-6a61c721d6bd	2018-03-05 07:50:42.326838-06	5	21156	[21156] Area E Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
0245681b-5714-47e7-917c-a12bb80517a3	2018-03-04 21:09:55.508479-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
cf40984a-7ab2-4a3d-9748-a434ab2c16e4	2018-03-04 21:09:58.569785-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
89adbe8c-5bbe-45a1-a621-0dac0190fd7f	2018-03-04 21:09:59.278856-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6c146fe4-3aa5-475b-b58b-cf3e2b1d32a1	2018-03-04 21:10:02.729201-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
14ffd73f-0c67-4c77-a753-d73195337c9e	2018-03-04 21:10:10.871015-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
99fbca4e-610c-42c0-bc19-9562e56af079	2018-03-04 21:10:17.131641-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
00d0c8c4-0d1c-4967-bfd5-1af799c7d769	2018-03-04 21:10:21.091037-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
e252fc15-33f2-47b1-a7b9-71dabfec068a	2018-03-04 21:10:28.32176-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
249f64cc-ed44-43b9-bd30-da79b6f2df83	2018-03-04 21:10:31.12204-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
6b45015d-e6d7-4aa0-a8bb-7aafaa8f8192	2018-03-04 21:12:19.491876-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f68887d0-5931-496b-b056-b78cb113375a	2018-03-04 21:42:04.316341-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
4971402c-00d2-440c-a557-215c55222417	2018-03-04 21:42:06.013511-06	5	21152	[21152] Area A Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
da3e0b29-484c-4ba8-a3c9-abcec1ae6975	2018-03-04 21:42:06.223532-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
99fa5d6c-9960-4886-919e-3e00b3d86a83	2018-03-04 21:42:06.743584-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
acefe7fc-fca8-4669-b472-d6dc1ab860e2	2018-03-04 21:42:08.950804-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
f4b6cdb2-f22c-471b-a309-c27cf94bf06e	2018-03-04 21:42:11.976107-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a36d2bf7-7018-47ce-a7a8-d6df8dd91e49	2018-03-04 21:42:14.556365-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
296bfc15-f6b5-4368-a13f-a156ec728caa	2018-03-04 21:42:16.833592-06	5	22435	[22435] Area D Target Left	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21150] Counters\\New Counter\\D Left\r\nDisplay [22437] Default Screen Group\\Area D Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
687925c0-7dc3-4ba5-ba20-4c917d2d1544	2018-03-04 21:42:18.467756-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
087ebf3c-ec93-4f0c-894d-aff29940b0ef	2018-03-04 21:42:27.593668-06	5	22432	[22432] Area C Target  Right Copy	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21149] Counters\\New Counter\\C Left\r\nDisplay [22060] Default Screen Group\\Area C Left	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
a5ba5869-fb5e-4bf5-b720-67c5af6bdbb1	2018-03-04 21:42:34.353344-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
1221b6a3-20aa-4f88-8481-7247a269b0ae	2018-03-04 21:42:46.71658-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[21041] OSSI-DNOVAK	[293] master	\N	00000000-0000-0000-0000-000000000000
fe1cb38b-0704-4360-82c7-bea99ce78f14	2018-03-04 23:05:01.346994-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
1e71c101-7aa0-42bb-86b8-8630f577498e	2018-03-05 07:21:47.945417-06	5	0	\N	0	\N	0	CreateSession: Invalid Login Credentials	0	0	0	\N	DLarrabee	a	\N	00000000-0000-0000-0000-000000000000
af369b0a-7b7b-4838-8bb9-9f9be3e39afb	2018-03-05 07:21:58.300452-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
682af4d4-a7db-436b-a92e-95177686bc64	2018-03-05 07:32:36.589275-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
f53beb3d-4ee1-4945-a000-0434a22ad51f	2018-03-05 07:32:36.64128-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
700a22ac-d7b5-4bf7-ae03-4872ba83871a	2018-03-05 07:32:37.649381-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
1e7a07fa-064f-4728-b4c2-7ca4d10ba357	2018-03-05 07:32:39.657582-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
9f14ca50-5145-40ae-81a0-645eba8c14c5	2018-03-05 07:32:40.44266-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
cbff777b-ede4-40a8-a47e-80443d165544	2018-03-05 07:32:42.601876-06	5	21278	[21278] Area C Target  Right	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
118e21b5-aadd-418d-a834-b588d0ddad6e	2018-03-05 07:32:47.923408-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
67f9fa67-bdba-4bd7-8bdd-78af2669652b	2018-03-05 07:32:50.697686-06	5	22435	[22435] Area D Target Left	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
7b08630b-bdbe-46d5-82d9-997728c78dfe	2018-03-05 07:32:55.117128-06	5	22432	[22432] Area C Target  Right Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
a9a7522c-9335-44bb-a833-eb62237bc943	2018-03-05 07:33:38.939509-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
568f41ab-30c9-4baf-980e-ac884ea0f93d	2018-03-05 07:35:58.910505-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
cc650b9a-e6ff-4a52-878b-267107e63ac3	2018-03-05 07:36:25.591173-06	5	21156	[21156] Area E Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21151] Counters\\New Counter\\E\r\nDisplay [21257] Default Screen Group\\Area E	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
7a07a1e0-bb59-4d15-a6f2-f99e2a072c8f	2018-03-05 07:38:22.989912-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
b0319e0b-d2ad-4e38-917c-fab9c2e58eaf	2018-03-05 07:38:23.755988-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
84ee5167-8751-423b-b135-eddb1aae1bd5	2018-03-05 07:38:23.759989-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
d8333330-56a4-4ae8-a1b3-01688e54c232	2018-03-05 07:38:25.319144-06	5	21153	[21153] Area B Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21148] Counters\\New Counter\\B\r\nDisplay [21213] Default Screen Group\\Area B	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
065a6251-f89f-4c95-9a04-61e7f09534a0	2018-03-05 07:38:26.27624-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
6f645bf6-ff78-49a6-910f-bc0bff43fc71	2018-03-05 07:38:26.298242-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
bc2684d1-f8fe-4628-a30f-a4924bf6e083	2018-03-05 07:38:30.068619-06	5	22432	[22432] Area C Target  Right Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
da1e672b-1b0f-4906-b186-3ba6b1ee85fb	2018-03-05 07:38:33.77399-06	5	21278	[21278] Area C Target  Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22433] Counters\\New Counter\\C Right\r\nDisplay [22236] Default Screen Group\\Area C Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
473990c6-0ba1-4361-95f1-eeab4364089d	2018-03-05 07:38:36.67428-06	5	22435	[22435] Area D Target Left	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
1fcc65b6-8b53-41cd-9586-5d76a02aefbe	2018-03-05 07:38:40.010613-06	5	22436	[22436] Area D Target Right	1	MouseDown	0	Display [22539] Default Screen Group\\Area D Right\r\nPlay [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
1f03173f-3c1c-4fca-91a4-d839ea2a00b1	2018-03-05 07:38:42.844897-06	5	21156	[21156] Area E Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
5ba45e25-f816-4854-b8fd-f6d2fedcbb0e	2018-03-05 07:38:47.817394-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
e7413ce0-faab-40e5-8a00-1fde955fe145	2018-03-05 07:39:14.090021-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
25256263-5140-483b-bc22-06f6fca6560b	2018-03-05 07:40:31.417753-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[293] master	\N	00000000-0000-0000-0000-000000000000
9c738c59-3988-44b2-a1d9-ae55b2075b1f	2018-03-05 07:49:35.73718-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
ab7bfabb-1f10-4a60-a8bd-70794864bed3	2018-03-05 07:50:26.9453-06	5	21152	[21152] Area A Target	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [21147] Counters\\New Counter\\A\r\nDisplay [290] Default Screen Group\\Area A	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
a7667fcb-0fe2-4ee9-98a7-a34a3179ba96	2018-03-05 07:50:26.991304-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
40800ecd-e2d5-4c37-9f6f-267620856f51	2018-03-05 07:50:27.565362-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
af2d3ce9-dd0e-4ebb-a086-32c83be84a24	2018-03-05 07:50:28.294435-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
999aa1cc-05a8-487d-8e34-5c7d150014f7	2018-03-05 07:50:28.859491-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
e5b81293-42e7-4ab5-bbf7-8d328aca6a62	2018-03-05 07:50:28.864492-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
f74b360e-2507-4625-9b66-30b57c7de9ea	2018-03-05 07:50:31.796785-06	5	21153	[21153] Area B Target	1	MouseEnter	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
51ecb0d6-6524-4b7a-88c0-07cbccf9f242	2018-03-05 07:50:31.799785-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
38f9e45a-4835-43bb-bb78-e23b15ce0999	2018-03-05 07:50:32.396845-06	5	22432	[22432] Area C Target  Right Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
ed2fcf38-7b47-4bda-8d14-3632046ae1f7	2018-03-05 07:50:34.560061-06	5	21278	[21278] Area C Target  Right	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
f4b34390-f521-44f4-9ca6-ed7048c66244	2018-03-05 07:50:37.713377-06	5	22435	[22435] Area D Target Left	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
bd271be0-9b5b-40d7-80ac-c312e26d0b89	2018-03-05 07:50:39.916597-06	5	22436	[22436] Area D Target Right	1	MouseDown	0	Display [22539] Default Screen Group\\Area D Right\r\nPlay [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
6b5abaaa-01b2-48f3-bd33-e78bb206ebd8	2018-03-05 07:50:47.9514-06	5	22435	[22435] Area D Target Left	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
8268da23-7aff-48d1-a40c-3dec14cca3ee	2018-03-05 07:50:52.397845-06	5	22499	[22499] D 34 GYM 455 	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21628] Counters\\D Cameras Left\\D 34 GYM 455 	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
1647805d-b7c6-43e8-b35b-aac0260b2cc5	2018-03-05 07:50:54.476053-06	5	21278	[21278] Area C Target  Right	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
2d9be7ac-cbe2-4d40-99b2-a7ebb7ccb538	2018-03-05 07:51:00.028608-06	5	22299	[22299] C 24 HALL 378	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [22323] Counters\\C Cameras Right\\C 24 HALL 378	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
2b410812-d580-4703-8bb9-62a0b0f96d33	2018-03-05 07:51:01.667772-06	5	22432	[22432] Area C Target  Right Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
c4a51968-1b9d-4582-b5b4-1a5596ee8d98	2018-03-05 07:51:04.205025-06	5	22127	[22127] None	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21594] Counters\\C Cameras Left\\None	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
6f0a9228-6fbe-452c-88d7-506b971bb728	2018-03-05 07:51:07.096315-06	5	22101	[22101] C 2 VEHICLE SALLY PORT 324	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21568] Counters\\C Cameras Left\\C 2 VEHICLE SALLY PORT 324	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
37bbc915-925b-4649-b10c-76c53b0f45b2	2018-03-05 07:51:08.879493-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
98f7983f-d388-40bd-bf09-4702dffd4f61	2018-03-05 07:51:09.423547-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
d32e6416-5bd6-4359-b0ac-a6344a54c253	2018-03-05 07:51:09.940599-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
5563bf3b-50ea-4117-a41d-a56e7fccb01b	2018-03-05 07:51:11.770782-06	5	21792	[21792] B 1 LIVING ROOM 211 Copy (7)	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21543] Counters\\B Cameras\\B 8 LIVING ROOM 236	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
25ab52d5-ab88-47d3-a6fd-10b4de71622d	2018-03-05 07:51:13.309936-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
673b7a98-ea38-4c3e-8de3-a8b19c39cb2e	2018-03-05 07:51:13.856991-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
5e06ba55-4c99-4861-b15f-ca762b0e0fef	2018-03-05 07:51:13.862991-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
5660ad09-1baa-44d5-8e30-91c913507a0a	2018-03-05 07:51:15.240129-06	5	21694	[21694] A 9 COURTYARD 114	0	MouseDown	0	Play [937] Click.wav\r\nResetCounter [21514] Counters\\A Cameras\\A 9 COURTYARD 114	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
7323f142-eb54-454b-bafa-c77a6c0a6225	2018-03-05 07:51:20.336638-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
538b0df5-e0ec-4347-abff-a7981ba3d4a9	2018-03-05 07:51:20.897695-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
165bae3b-b2f4-4f9e-ab8f-42d4c1a5171f	2018-03-05 07:51:20.902695-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
8c40b846-5cb3-4d28-a01f-935b4409bcbc	2018-03-05 07:51:21.864791-06	5	22432	[22432] Area C Target  Right Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
8325a653-8f70-4d8b-9330-3656ceb81f1d	2018-03-05 07:51:23.029908-06	5	21278	[21278] Area C Target  Right	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
b1de66ad-d400-4fb0-97b0-35f328126fe8	2018-03-05 07:51:24.670072-06	5	22435	[22435] Area D Target Left	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
1d26bd61-f68b-4863-926a-568d13cb81bb	2018-03-05 07:51:25.838189-06	5	22436	[22436] Area D Target Right	1	MouseDown	0	Display [22539] Default Screen Group\\Area D Right\r\nPlay [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
bbdcfcd4-42e0-44ae-9eb5-89400c3a0e3e	2018-03-05 07:51:26.932298-06	5	21156	[21156] Area E Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
898321eb-f430-4547-9115-81bf87429ea6	2018-03-05 07:51:28.114416-06	5	21152	[21152] Area A Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
195c540e-8214-422a-9ee4-d6b0af0cfffe	2018-03-05 07:51:28.65447-06	5	21152	[21152] Area A Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
0ac3bd1b-9c4a-4a64-a468-a60d652b6392	2018-03-05 07:51:28.658471-06	5	21152	[21152] Area A Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
74d1dbfd-1ab4-494e-941e-317e92aa8b17	2018-03-05 07:51:29.221527-06	5	21153	[21153] Area B Target	1	MouseDown	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
ab02415f-4a47-48a3-91eb-d676787d79af	2018-03-05 07:51:29.772582-06	5	21153	[21153] Area B Target	1	MouseUp	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
fce244b6-6840-445c-833b-d0f2fe12a7be	2018-03-05 07:51:49.563561-06	5	21153	[21153] Area B Target	1	MouseLeave	0	None\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone\r\nNone	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
f49f62e8-afcc-402e-aecd-32929a08b4d7	2018-03-05 07:51:52.920897-06	5	0	\N	0	\N	0	Logoff	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
61a9be91-bdc3-4a0e-b7c7-51a4060a9f2b	2018-03-05 08:21:21.967784-06	5	0	\N	0	\N	0	Logon	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
7b1ffff8-9736-4479-ab76-a8f85003b201	2018-03-05 08:22:00.146601-06	5	22436	[22436] Area D Target Right	0	MouseDown	0	Play [947] Wooshway.wav\r\nResetCounter [22434] Counters\\New Counter\\D Right\r\nDisplay [22539] Default Screen Group\\Area D Right	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
48e11998-6d02-4e1e-a9b2-5eb8f0857d41	2018-03-05 08:22:37.388325-06	5	22435	[22435] Area D Target Left	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
f4814119-0bd7-4057-973f-d0049a9f5fc6	2018-03-05 08:22:55.74516-06	5	21154	[21154] Area C Target	1	MouseDown	0	Display [22060] Default Screen Group\\Area C Left	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
d393fb00-aff9-4eae-88e5-86464c850ee8	2018-03-05 08:23:00.548641-06	5	21278	[21278] Area C Target  Right	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
808e26fd-45a7-4b0a-b299-88d26778aff8	2018-03-05 08:23:26.152201-06	5	22432	[22432] Area C Target  Right Copy	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
f5bbf489-b223-4834-918c-f4512cf132a6	2018-03-05 08:26:48.858469-06	5	21278	[21278] Area C Target  Right	1	MouseDown	0	Display [22236] Default Screen Group\\Area C Right\r\nPlay [947] Wooshway.wav	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
749b56e5-a584-4e8d-b480-3b510ad533c2	2018-03-05 08:26:54.223006-06	5	21156	[21156] Area E Target	1	MouseDown	0	\N	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
ac7b942b-faab-40a6-b255-19428bdfc7d2	2018-03-05 08:27:05.86317-06	5	21336	[21336] Door 514	0	MouseDown	0	Pulse [20289] 9C2-16R\\Lock Relay-514 Relay	0	0	0	\N	[4] DLarrabee	[21062] a	\N	00000000-0000-0000-0000-000000000000
\.


--
-- Data for Name: Activity_Statistics; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "Activity_Statistics" (id, event_type_id, rtu_id, rtu_name, point_id, point_name, state, status, card_number, site_code, card_format, card_holder_name, computer, "user", user_comments, token_id, active_time, inactive_time, acked_time, cleared_time, last_active, total_active, active_count) FROM stdin;
\.


--
-- Data for Name: ChangeType; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "ChangeType" (id, name) FROM stdin;
1	Node Add
2	Node Modify
3	Node Delete
4	Card Add
5	Card Modify
6	Card Delete
7	Personnel Add
8	Personnel Modify
9	Personnel Delete
10	Access Set Add
11	Access Set Modify
12	Access Set Delete
\.


--
-- Name: ChangeType_id_seq; Type: SEQUENCE SET; Schema: history; Owner: core
--

SELECT pg_catalog.setval('"ChangeType_id_seq"', 9, true);


--
-- Data for Name: EventType; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "EventType" (id, name) FROM stdin;
1	Card
2	I/O
3	Exception
4	Download
5	Client
6	Alarm
\.


--
-- Name: EventType_id_seq; Type: SEQUENCE SET; Schema: history; Owner: core
--

SELECT pg_catalog.setval('"EventType_id_seq"', 5, true);


--
-- Data for Name: ProjectChange; Type: TABLE DATA; Schema: history; Owner: core
--

COPY "ProjectChange" (id, "time", change_type_id, name, computer, "user", old_data, new_data) FROM stdin;
e639e94b-2196-4d1c-becd-ac6caa0efcd7	2018-02-26 13:16:00.877431-06	2	[165] Control Room	[4] DLarrabee	[293] master	\N	\N
85d9fd36-9e00-4de2-8c35-55cd96124f3f	2018-02-26 13:16:17.308074-06	1	[1039] New Area	[4] DLarrabee	[293] master	\N	\N
d24ca674-d0a2-47fe-b12f-731a6a2d49cb	2018-02-26 13:16:30.639407-06	2	[1039] Room 304	[4] DLarrabee	[293] master	\N	\N
04d5b0d7-df68-4b1f-9934-7a811138378b	2018-02-26 13:16:43.076651-06	1	[1040] New Area	[4] DLarrabee	[293] master	\N	\N
4b0756ef-0252-495d-a5f2-80dcb6bf52e8	2018-02-26 13:17:06.010944-06	2	[1040] Room 372	[4] DLarrabee	[293] master	\N	\N
462cd569-39af-4caf-8aab-5f56cbead7b6	2018-02-26 13:17:11.808524-06	1	[1041] New Area	[4] DLarrabee	[293] master	\N	\N
6fb4a094-c6b8-49d8-afa1-70e770c320eb	2018-02-26 13:17:30.209364-06	2	[1041] Room 474	[4] DLarrabee	[293] master	\N	\N
abbf1ddb-cb4f-4c86-aaa1-14abc0cd0f94	2018-02-26 13:17:55.97894-06	1	[1042] New MAC Driver	[4] DLarrabee	[293] master	\N	\N
58733b30-4f1c-4611-a4a0-da6d8441d0b6	2018-02-26 13:18:01.947537-06	2	[1042] New MAC Driver	[4] DLarrabee	[293] master	\N	\N
8539ccd8-1b72-48ed-bbf9-0ab4ccad8186	2018-02-26 13:18:32.97764-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
47a977e6-ae02-463b-92ce-5d713b305e2c	2018-02-26 13:19:23.167658-06	1	[1043] MAC	[4] DLarrabee	[293] master	\N	\N
864f6220-3138-4d92-8795-b8b0e04db1bf	2018-02-26 13:19:23.194661-06	1	[1044] *Always*	[4] DLarrabee	[293] master	\N	\N
840fd75f-2f11-4a9c-b407-30985e57f861	2018-02-26 13:19:23.369679-06	1	[1045] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
ad35f2f4-a72b-4ec7-a2a5-c64e6880a920	2018-02-26 13:19:23.38668-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
c84f8e7b-92f7-46b2-b696-130768e03bf4	2018-02-26 13:19:23.390681-06	1	[1187] Control Room Popup Screens	[4] DLarrabee	[293] master	\N	\N
3e0c67a7-93e1-42c7-b401-51a6f5c7febe	2018-02-26 13:19:24.768818-06	1	[1188] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
938ab5e4-616a-4458-9064-5bab1eb7c8e6	2018-02-26 13:19:24.922834-06	1	[1513] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
684eefc4-9eaf-401e-b274-17669c0adf9a	2018-02-26 13:19:24.942836-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
32731500-ae14-4216-ad66-912c3ee9f216	2018-02-26 13:19:26.302972-06	1	[1655] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
f632122c-331e-4981-b755-1297803818d4	2018-02-26 13:20:24.911832-06	1	[1980] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
4d6dd2c0-c488-4c39-a70c-640d294a6d78	2018-02-26 13:20:24.927834-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
9ce9378f-e60e-46f2-9cb7-1e24fe090a6b	2018-02-26 13:20:25.646906-06	1	[2074] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
86a53e99-c1f5-44e9-8dea-930947ee1cbd	2018-02-26 13:20:25.726914-06	1	[2300] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
680955c2-b183-4ce0-ab3d-d6c46f1224be	2018-02-26 13:20:25.746916-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
485ce311-74b3-4a1c-912a-05df295d4071	2018-02-26 13:20:26.576999-06	1	[2394] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
61b9b6e2-b829-4929-8ed1-25f7b2ce7c48	2018-02-26 13:20:26.661007-06	1	[2620] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
91c73e3d-d686-4c57-ae0e-1048178e779e	2018-02-26 13:20:26.679009-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
39b55964-6291-4dfe-942b-d6593e26eac7	2018-02-26 13:20:27.466088-06	1	[2714] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
0974aa60-2d6d-4d9c-ac4d-f20eb99e6648	2018-02-26 13:24:47.285067-06	1	[2940] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
dbc2db89-040a-4cb5-b115-587a0d677d59	2018-02-26 13:24:47.304069-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
37933016-8e28-480b-aefb-6015ca522f8e	2018-02-26 13:24:48.353174-06	1	[3042] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
46348988-191f-4c5a-884d-dc03209ffd53	2018-02-26 13:24:48.498188-06	1	[3380] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
e095f65e-e0c9-40b5-ba94-9c2a29f456aa	2018-02-26 13:24:48.51519-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
836496ee-6d61-49ef-bc33-9540f88d726b	2018-02-26 13:24:49.631301-06	1	[3482] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
244cf415-b57b-4814-ba8b-95fcec410295	2018-02-26 13:24:49.746313-06	1	[3820] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
d5be2ef1-75b0-435a-b9bf-c0dffe6f23c8	2018-02-26 13:24:49.769315-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
697098a2-23a9-4ca7-a8ea-33e645ce6334	2018-02-26 13:24:50.847423-06	1	[3922] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
aaa10a77-4301-4b63-889e-6f27fb8c31d2	2018-02-26 13:24:50.973436-06	1	[4260] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
cbc2179d-24cd-4851-9da9-8903792c62b3	2018-02-26 13:24:50.992438-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
f5152493-102d-4a43-b17a-2ef0d3e999e0	2018-02-26 13:24:52.12055-06	1	[4362] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
c79f0d03-86ab-42e3-af6c-5a8044496083	2018-02-26 13:24:52.245563-06	1	[4700] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
1648c27e-0d0c-40cf-abe1-9b7758969071	2018-02-26 13:24:52.266565-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
dc44f280-a819-466b-ae0b-f8857176a44b	2018-02-26 13:24:53.386677-06	1	[4802] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
c3ac7643-6d41-497f-a2b3-7f271c9002e2	2018-02-26 13:24:53.51669-06	1	[5140] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
50abf561-59f1-4e31-b844-156b3bf449fc	2018-02-26 13:24:53.536692-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
d8fca0c2-21d0-4b74-a859-1eca9c566d86	2018-02-26 13:24:54.690807-06	1	[5242] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
0cd6eda4-8708-4cc1-9523-5b9f5d0ee54f	2018-02-26 13:24:54.81582-06	1	[5580] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
a0202e96-4ce5-437d-a2f9-017524a50813	2018-02-26 13:24:54.836822-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
4572871a-cfe9-4fd3-91b7-b00a10949eba	2018-02-26 13:24:55.972936-06	1	[5682] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
fa59fba5-f4ea-47e3-8016-6b522046192b	2018-02-26 13:24:56.098948-06	1	[6020] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
e99e5183-c490-49fb-9c27-afba9af6cd4a	2018-02-26 13:24:56.128951-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
cfb7f867-97ca-4870-8643-75c988c9a135	2018-02-26 13:24:57.256064-06	1	[6122] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
72461e51-1b32-43d7-bd47-69682ae7d009	2018-02-26 13:24:57.371075-06	1	[6460] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
fc20793a-c8c0-426d-8082-7b2091144ede	2018-02-26 13:24:57.394078-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
8fafcdb6-0aad-4087-a874-3d2fb7c7d08b	2018-02-26 13:24:58.493188-06	1	[6562] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
a072e17b-83b3-49b3-9a9e-486e6ea1a9a2	2018-02-26 13:24:58.606199-06	1	[6900] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
caeac68f-8e8a-40a4-afb5-13c61598fc78	2018-02-26 13:24:58.631201-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
4b058603-3306-466f-adfe-344beea9a888	2018-02-26 13:24:59.725311-06	1	[7002] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
376c14be-28c2-4872-bbf2-84766d3c0d31	2018-02-26 13:24:59.842322-06	1	[7340] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
c8b9ff78-7322-41f8-bf9b-c5a10c774628	2018-02-26 13:24:59.866325-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
52f1b4a9-07fd-41cb-81ba-c0f0b6da065b	2018-02-26 13:25:00.996438-06	1	[7442] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
e59f206d-3a0a-4210-8065-61f2aebeb7ff	2018-02-26 13:25:01.11445-06	1	[7780] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
1a625668-59a0-4180-8231-0e331ce29fbc	2018-02-26 13:25:01.149453-06	2	[1042] Control RM MAC Driver	[4] DLarrabee	[293] master	\N	\N
f2cffb7c-1b86-4d64-ac37-0a05892be4a9	2018-02-26 13:25:02.261564-06	1	[7882] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
93ddad53-1aa7-4b50-bab0-4a5adc178b28	2018-02-26 13:30:50.036338-06	1	[8220] New MAC Driver	[4] DLarrabee	[293] master	\N	\N
a350797a-f921-4ce1-b052-f4672cf30a69	2018-02-26 13:31:07.137048-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
cf766b6c-6583-429f-a510-ffa15c19f194	2018-02-26 13:35:38.391171-06	1	[8221] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
fdbf1529-2c3d-4c98-8360-f046bc75b1bf	2018-02-26 13:35:38.438176-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
e44029e9-d5c7-49e3-9120-1e27d0b7a192	2018-02-26 13:35:38.442176-06	1	[8323] Room 304 Popup Screens	[4] DLarrabee	[293] master	\N	\N
44a9b555-fce0-4abd-a28f-4b44d8d0e9be	2018-02-26 13:35:39.451277-06	1	[8324] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
8796342e-464f-4b8c-af40-09d4cc9e0e51	2018-02-26 13:35:39.57929-06	1	[8662] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
0ed81cb5-d492-4775-8d03-c4b62b0db321	2018-02-26 13:35:39.601292-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
252f4992-ebfe-4128-9e34-82fc23625941	2018-02-26 13:35:40.700402-06	1	[8764] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
4fbbb241-d525-472a-80af-d27df6e8ae69	2018-02-26 13:35:40.822414-06	1	[9102] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
3c091e3c-530c-47cc-80e2-42e39f184843	2018-02-26 13:35:40.839416-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
622ed172-c32c-432a-aee0-088eb9f5315e	2018-02-26 13:35:41.956527-06	1	[9204] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
124a7ef2-235d-413a-b1df-bc54c15e073c	2018-02-26 13:35:42.089541-06	1	[9542] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
deb9a631-eeaf-41c3-aab4-877697b433fb	2018-02-26 13:35:42.105542-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
76d6c081-6421-4f99-9e47-3d5a4ab6d828	2018-02-26 13:35:43.209653-06	1	[9644] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
e61ae8f9-3f73-4601-a2e9-959c267a5982	2018-02-26 13:35:43.331665-06	1	[9982] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
22b52a7e-c6a8-4758-bbfb-b9c5daef1851	2018-02-26 13:35:43.349667-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
cbceb137-f432-41e9-acdc-b41ca1f8ad18	2018-02-26 13:35:44.509783-06	1	[10084] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
9a6ce809-cc91-4a30-91e3-cc4075ee4d00	2018-02-26 13:35:44.631795-06	1	[10422] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
f89519d1-b116-4043-a3ee-14544bd45bd6	2018-02-26 13:35:44.649797-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
7e6c0f60-bf34-449b-b26f-f0ee510a2479	2018-02-26 13:35:45.816913-06	1	[10524] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
0db6e579-20a3-4ac6-9f39-14f74374d973	2018-02-26 13:35:45.941926-06	1	[10862] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
b4207a33-67eb-489d-8a38-b224853014ce	2018-02-26 13:35:45.962928-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
803112c9-026c-4d6f-bbce-c4674be79f2c	2018-02-26 13:35:47.069039-06	1	[10964] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
fd51becd-9162-44f6-a19e-6c9683271444	2018-02-26 13:35:47.198052-06	1	[11302] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
0f47f43b-a3cd-433e-bf83-a72b626af712	2018-02-26 13:35:47.217053-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
8abeafdc-5bf5-46ed-ab21-a8a7df959015	2018-02-26 13:35:48.324164-06	1	[11404] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
e34e6945-c9f4-49ff-8daa-9d652a947cff	2018-02-26 13:35:48.455177-06	1	[11742] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
f569a4a8-56bf-4369-81ca-10cf66bda7c9	2018-02-26 13:35:48.48218-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
41d6cd0f-8013-4f64-91d4-289d25f94db4	2018-02-26 13:35:49.619294-06	1	[11844] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
cd26fabc-555f-43ed-b933-4f750732b47d	2018-02-26 13:35:49.744306-06	1	[12182] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
39451d8e-9f40-43f2-9167-9c3fdc1ab998	2018-02-26 13:35:49.772309-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
df1cd46c-6007-4140-b3af-f9e8f9707cba	2018-02-26 13:35:50.877419-06	1	[12284] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
6f2d3c55-2f87-42cc-94e9-a67281ce2075	2018-02-26 13:35:50.996431-06	1	[12622] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
ace6eeb0-53e6-4bc5-bdb3-dcb6dc2bfb67	2018-02-26 13:35:51.023434-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
74ddcd9f-a64f-4cf9-bb1a-a91dd3d21fbc	2018-02-26 13:35:52.094541-06	1	[12724] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
53e1c392-3ffc-4b4b-8a1a-1f954c10f98b	2018-02-26 13:35:52.241556-06	1	[13062] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
d011b0df-8ba3-4dda-b81c-98a306070308	2018-02-26 13:35:52.261558-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
cc95a0e9-86ea-45b0-9f15-226cba378873	2018-02-26 13:35:53.433675-06	1	[13164] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
277730ae-257a-43a8-b820-e29e695eeafa	2018-02-26 13:35:53.557687-06	1	[13502] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
aa7ffd8f-30b8-42be-a003-8431f67379f9	2018-02-26 13:35:53.58769-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
59b145e4-3d6e-4ede-81b4-27c06c74ae5a	2018-02-26 13:35:54.725804-06	1	[13604] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
1525e0fb-2791-4c0f-8e0d-f597b14fade0	2018-02-26 13:35:54.856817-06	1	[13942] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
b241a091-b95a-4f65-8502-2ea28ba2141c	2018-02-26 13:35:54.877819-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
a7220e2d-19fe-43b2-b53f-7c59d702bd21	2018-02-26 13:35:55.991931-06	1	[14044] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
7d0bd08f-9eff-4a8a-8555-6d7d26059fcb	2018-02-26 13:36:27.856117-06	1	[14382] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
0c994dfd-bd24-492d-9583-4a4471cab065	2018-02-26 13:36:27.877119-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
3debca5c-d0ea-4333-b6fc-bde94b552f76	2018-02-26 13:36:29.132245-06	1	[14524] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
25ff3fbd-b508-4145-bf49-f648e4012f06	2018-02-26 13:36:29.313263-06	1	[14849] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
2a62c7a5-a63e-4842-b6b9-8be91b29320e	2018-02-26 13:36:29.342266-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
eff0daad-c1c3-4b2f-9f18-443a05804fd4	2018-02-26 13:36:30.744406-06	1	[14991] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
280c3612-b4b3-4662-ac62-6647a8d1262b	2018-02-26 13:36:30.89142-06	1	[15316] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
66902123-05a2-41c6-911d-f6110dec1e64	2018-02-26 13:36:30.919423-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
f598be09-94ed-4e1f-8c33-fce876234816	2018-02-26 13:36:32.305562-06	1	[15458] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
fd6093db-be7c-49ab-8c53-324b28cc8790	2018-02-26 13:37:04.436775-06	1	[15783] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
eced6dae-7f7b-40a6-99dc-c061c3b24b96	2018-02-26 13:37:04.460777-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
4bcd00e5-97d5-421c-a871-cd3c9a70362f	2018-02-26 13:37:05.209852-06	1	[15877] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
a09133cc-c2c5-430d-b7ed-92eb0e19616b	2018-02-26 13:37:05.314862-06	1	[16103] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
cebc6588-b887-4aad-b258-620d9962f70a	2018-02-26 13:37:05.336865-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
9ec5c375-951c-477d-a1b1-c81bf687a136	2018-02-26 13:37:06.136945-06	1	[16197] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
86aa76de-c726-4fa4-9017-e5b3f6497b71	2018-02-26 13:37:06.224953-06	1	[16423] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
2a522c94-2f36-4fe8-b30e-bece3730e2ee	2018-02-26 13:37:06.247956-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
0cfd9f3d-77f9-4c30-b9bb-cc190e8021e6	2018-02-26 13:37:07.046036-06	1	[16517] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
87cfa773-6764-4229-ae08-a12770d13aaa	2018-02-26 13:37:07.151046-06	1	[16743] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
206ea769-fe05-4118-9c35-cd74891a0350	2018-02-26 13:37:07.175048-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
1bc785c0-34fa-47d0-ab41-2702a16d34c2	2018-02-26 13:37:07.970128-06	1	[16837] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
9ff5f28a-dfb7-4c61-996a-c9a6052df8f8	2018-02-26 13:37:08.072138-06	1	[17063] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
c86a111d-1e03-4c53-aa77-545156d49a1c	2018-02-26 13:37:08.103141-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[293] master	\N	\N
70d4e11d-f4f8-4a5a-9feb-d3f083f0333b	2018-02-26 13:37:08.951226-06	1	[17157] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
7582842c-5828-450a-95f9-8bfa53ddfcb6	2018-02-26 13:37:52.902621-06	1	[17383] New MAC Driver	[4] DLarrabee	[293] master	\N	\N
41b9a404-f5df-4f40-9563-a4f17d27a8c2	2018-02-26 13:38:04.564787-06	2	[17383] RM 372 MAC Driver	[4] DLarrabee	[293] master	\N	\N
81e921b6-009a-46a0-8786-d9d35c117b98	2018-02-26 13:38:56.671997-06	1	[17384] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
0168f936-9a3a-4a29-ad0d-53aa6b3af6c1	2018-02-26 13:38:56.688999-06	2	[17383] RM 372 MAC Driver	[4] DLarrabee	[293] master	\N	\N
76fb724f-5e89-4037-b03c-30b33c837b05	2018-02-26 13:38:56.693999-06	1	[17486] Room 372 Popup Screens	[4] DLarrabee	[293] master	\N	\N
3c38f9c3-87fd-485a-9aab-047857311a9d	2018-02-26 13:38:57.715101-06	1	[17487] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
d701c1ae-cc5f-49f7-8301-d78631192f94	2018-02-26 13:38:57.845114-06	1	[17825] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
0add2166-0080-4838-b74a-887c34fece79	2018-02-26 13:38:57.861116-06	2	[17383] RM 372 MAC Driver	[4] DLarrabee	[293] master	\N	\N
0cb48717-1d31-42fc-88d3-8afb538c75a1	2018-02-26 13:38:58.966226-06	1	[17927] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
5b0d7fa0-373e-4064-bebf-16fd9c6f286f	2018-02-26 13:38:59.093239-06	1	[18265] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
627713d8-2474-4cb9-96f9-ff28843668dc	2018-02-26 13:38:59.111241-06	2	[17383] RM 372 MAC Driver	[4] DLarrabee	[293] master	\N	\N
ac1a2ee1-7a01-409d-b9bb-c75c8524f86d	2018-02-26 13:39:00.243354-06	1	[18367] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
28da16fd-848a-49c8-8a42-4a1412973a10	2018-02-26 13:39:15.193849-06	1	[18705] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
1ff64fd3-226c-40cc-b158-4115157e6cd2	2018-02-26 13:39:15.214851-06	2	[17383] RM 372 MAC Driver	[4] DLarrabee	[293] master	\N	\N
4db89c59-45cb-4e40-99b1-b45d5d818129	2018-02-26 13:39:16.477977-06	1	[18847] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
15feaf09-9c9e-4b35-89e1-1dc27fdaf4e0	2018-02-26 13:39:51.169446-06	1	[19172] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
f58100b3-cbd6-49ca-87a3-534bb095227d	2018-02-26 13:39:51.215451-06	2	[17383] RM 372 MAC Driver	[4] DLarrabee	[293] master	\N	\N
28014582-4791-4a2f-aa13-863f934ee8ff	2018-02-26 13:39:51.941523-06	1	[19266] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
d127abcf-d2c2-4cfc-8f90-53bc4343e978	2018-02-26 13:40:06.753004-06	1	[19492] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
7314defd-2063-4a76-8ab9-7a21f37d1fc0	2018-02-26 13:40:06.772006-06	2	[17383] RM 372 MAC Driver	[4] DLarrabee	[293] master	\N	\N
058f79fb-dada-4e3c-a946-62984cfd343f	2018-02-26 13:40:07.500079-06	1	[19586] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
9ac8533a-b8af-49ac-a6ee-8146ba162fb7	2018-02-26 13:40:48.61019-06	1	[19812] New MAC Driver	[4] DLarrabee	[293] master	\N	\N
ed321bae-a9be-49fb-9995-13e2d6087207	2018-02-26 13:41:45.7189-06	2	[19812] RM 474 MAC Driver	[4] DLarrabee	[293] master	\N	\N
9c9dc007-4b35-4dd4-8975-1d07f67edd4a	2018-02-26 13:42:03.551683-06	1	[19813] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
cadcc87d-7330-4f16-85b9-363270f73391	2018-02-26 13:42:03.570685-06	2	[19812] RM 474 MAC Driver	[4] DLarrabee	[293] master	\N	\N
1db17b37-c645-4fb7-98aa-2cb4fb711e9a	2018-02-26 13:42:03.576686-06	1	[19955] Room 474 Popup Screens	[4] DLarrabee	[293] master	\N	\N
72e1d155-80e7-4894-b452-14fbcd7880dc	2018-02-26 13:42:04.860814-06	1	[19956] MLC-32I Panel	[4] DLarrabee	[293] master	\N	\N
f15e19f0-08ef-43f3-9434-6b6b3e423907	2018-02-26 13:42:21.916519-06	1	[20281] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
2e7c0727-c41b-4939-9e4c-1e5ec41ff893	2018-02-26 13:42:21.934521-06	2	[19812] RM 474 MAC Driver	[4] DLarrabee	[293] master	\N	\N
c1d4d597-d6c4-4eaa-ae4c-1b3ef39b3a55	2018-02-26 13:42:22.674595-06	1	[20375] MLC-16R Panel	[4] DLarrabee	[293] master	\N	\N
3ebafec1-602a-4de0-b10a-7b0a6a40a2cb	2018-02-26 13:42:50.271355-06	1	[20601] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
c217969d-5801-48e7-a15c-7ab581165f25	2018-02-26 13:42:50.289356-06	2	[19812] RM 474 MAC Driver	[4] DLarrabee	[293] master	\N	\N
a79d7503-afba-4ead-a600-1360b56892a9	2018-02-26 13:42:51.32346-06	1	[20703] MLC-8IC Panel	[4] DLarrabee	[293] master	\N	\N
85874ab1-d663-4ce4-9862-ed63dae9681e	2018-02-26 14:51:33.988685-06	2	[2942] IC-316-inB Call Button	[4] DLarrabee	[293] master	\N	\N
3050462a-1fa4-417e-b030-87b590d703e9	2018-02-26 14:51:34.082695-06	2	[2993] IC-316-inB Call Button Supervision	[4] DLarrabee	[293] master	\N	\N
351219a9-ed11-4d0a-bb9f-5574292a9f58	2018-02-27 15:18:07.462341-06	1	[21041] New Computer	[4] DLarrabee	[293] master	\N	\N
51efb388-6679-41ed-ad3d-05fd2bb2f325	2018-02-27 15:49:40.370613-06	2	[21041] OSSI-DNOVAK	[4] DLarrabee	[293] master	\N	\N
1cd733dc-b707-4746-a711-157aedb09740	2018-02-27 16:05:51.722738-06	3	[291] Title Pad	[21041] OSSI-DNOVAK	[293] master	\N	\N
3e810bd5-7966-4141-a3b6-791fce3e3f92	2018-02-27 16:06:03.564922-06	2	[290] LeadIn	[21041] OSSI-DNOVAK	[293] master	\N	\N
9cb1a35c-6949-4659-98fd-bc949ef6ad63	2018-02-27 16:06:29.268492-06	1	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
d0df7585-e0d9-42ca-963f-f339f5e19570	2018-02-27 16:06:54.584024-06	1	[21042] Floorplans	[21041] OSSI-DNOVAK	[293] master	\N	\N
d08a0478-99dd-4904-ba5a-9c84ffaf4dfd	2018-02-27 16:06:56.169182-06	2	[21042] Floorplans	[21041] OSSI-DNOVAK	[293] master	\N	\N
ea52f1b4-69d3-4131-b7c4-a54e891c4036	2018-02-27 16:07:06.941259-06	1	[21043] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
9daa3624-ddde-4c92-87c8-e363fff28e25	2018-02-27 16:07:08.799445-06	2	[21043] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
85826752-427c-4975-8ff9-a989cef78a77	2018-02-27 16:07:14.093974-06	1	[21044] Key-samp.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
3beb8186-1b71-4a68-90c5-57f1aa8d2cd5	2018-02-27 16:07:15.580123-06	2	[21044] Key-samp.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
95d997b7-70e3-4f6f-b9fd-af74a95f3abc	2018-02-27 16:07:31.745739-06	1	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
509d9fcd-bc44-40f9-b117-396c7bab8ddf	2018-02-27 16:09:06.297194-06	1	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
85a762b4-d530-4e6e-b971-5a5e211e498f	2018-02-27 16:09:30.26259-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
e0a8905d-583c-4daf-9b6d-492f2ed64334	2018-02-27 16:09:51.330696-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
67025d3d-f0e8-45cf-be96-4df27109e7d2	2018-02-27 16:10:49.040467-06	1	[21047] Tool 200x300.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
6498d803-81c6-415d-8bb8-8a83a95cdd8c	2018-02-27 16:11:01.800743-06	2	[21047] Tool 200x300.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
5cdddd90-78ae-4197-8199-33e6fb7fcfeb	2018-02-27 16:13:17.141275-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
72266821-f98e-4b64-8dd5-dfbee7285ffc	2018-02-27 16:16:19.833543-06	2	[291] Fill.png	[4] DLarrabee	[293] master	\N	\N
275a1d9c-8577-4567-9f86-9f70e42e1ce9	2018-02-27 16:16:39.663526-06	2	[291] Fill.png	[4] DLarrabee	[293] master	\N	\N
1f73e46c-ca4d-42f7-9508-dbf888f81352	2018-02-27 16:17:43.264885-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
361fbf99-cf76-4826-9d11-a897e323286b	2018-02-27 16:19:46.313189-06	2	[21045] PODs 3X Drop sd.png	[4] DLarrabee	[293] master	\N	\N
ba26fe3d-8997-460e-8cb1-f720cbb788c3	2018-02-27 16:20:04.619019-06	2	[291] Fill.png	[4] DLarrabee	[293] master	\N	\N
e3d83ec7-2b93-4c2e-b66b-f315ed175f8d	2018-02-27 16:20:33.975955-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
b71c41f9-1c0c-46d6-abdd-7803212e87e8	2018-02-27 16:20:39.911548-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
e94b4576-9683-41ef-b55b-4a5b2c685f61	2018-02-27 16:21:01.583715-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
770b83ed-2eda-4bc9-a004-f57d2c9757fa	2018-02-27 16:22:03.874944-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
fe01964d-5825-4b25-86b1-da266054453f	2018-02-27 16:22:54.715027-06	2	[291] Fill.png	[4] DLarrabee	[293] master	\N	\N
9c9e91f6-e0f9-47c8-be2c-14c7b80549f3	2018-02-27 16:23:53.084863-06	2	[291] Fill.png	[4] DLarrabee	[293] master	\N	\N
f8de1ca0-7fc5-4429-b37f-60d8bf382d7c	2018-02-27 16:24:20.479603-06	2	[291] Fill.png	[4] DLarrabee	[293] master	\N	\N
9fba4b2d-9c80-4fcc-ac11-393239ecfda1	2018-02-27 16:24:43.784933-06	2	[291] Fill.png	[4] DLarrabee	[293] master	\N	\N
0258d40f-2918-45b9-bafa-4764aba79ca8	2018-02-27 16:26:01.082662-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
82b19450-bf7c-4a37-8d47-9bf1e4511ec8	2018-02-27 16:26:11.569711-06	2	[293] master	[4] DLarrabee	[293] master	\N	\N
58560473-30f8-46f3-ae8e-f5f6d30ec900	2018-02-27 16:31:58.19937-06	2	[293] master	[4] DLarrabee	[293] master	\N	\N
04828cf2-5a2c-4226-a4ed-417af2f60a11	2018-02-27 16:39:58.289374-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
ccc0c42c-27bd-4e37-a2f8-725ef7fd1380	2018-02-27 16:40:19.762521-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
2766efa3-9ea1-41e7-818d-1fa9bdd93ff9	2018-02-27 16:41:24.482993-06	2	[121] Popup Queues	[21041] OSSI-DNOVAK	[293] master	\N	\N
0892663a-e094-4db0-9011-8993a2f46e3d	2018-02-27 16:41:26.750219-06	1	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
bffbc3be-5eb0-4a75-aac0-59812f8a8766	2018-02-27 16:41:31.039648-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
eddd67d4-fbbd-4de1-a1c9-8f10c08cbf24	2018-02-27 16:41:43.736918-06	1	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
b86ba9ce-3a4f-49a0-9c69-90be9d5ff117	2018-02-27 16:42:15.292073-06	2	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
479f3c93-e862-4c8d-a244-9d9e10e97ee3	2018-02-27 16:42:55.901134-06	3	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
a2d28268-301d-4979-92cf-24d8e6b2b04d	2018-02-27 16:43:24.229966-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
40c8d316-d72d-4379-8ca6-0b5763ee49a7	2018-02-27 16:43:45.355079-06	1	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
7a9b0eb1-1cdf-4713-a322-1fdf127f2db7	2018-02-27 16:44:34.915034-06	1	[21050] Virtual Points	[21041] OSSI-DNOVAK	[293] master	\N	\N
a58d231d-457d-4557-baaa-3bcb6fa00d70	2018-02-27 16:44:34.930036-06	1	[21051] New Virtual Point Group	[21041] OSSI-DNOVAK	[293] master	\N	\N
e556967f-f9ef-4082-b438-6c8c36bb28c9	2018-02-27 16:44:34.935036-06	1	[21052] New Virtual Point	[21041] OSSI-DNOVAK	[293] master	\N	\N
14dfde5d-62ac-4991-989a-6431203beb33	2018-02-27 16:44:36.951238-06	2	[21050] Virtual Points	[21041] OSSI-DNOVAK	[293] master	\N	\N
d2a2fff2-6273-40b3-833c-c786383fc1ff	2018-02-27 16:44:45.770119-06	2	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
5ba89dc5-5c42-4c73-8186-16b83f1544f1	2018-02-27 16:45:16.550197-06	2	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
71ba51db-d7ef-448d-9946-b53cd96be810	2018-02-27 16:45:48.168359-06	2	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
d8c16c7b-0ef5-4d8b-b1fb-a2a8c2590118	2018-02-27 16:46:05.337075-06	2	[21052] New Virtual Point	[21041] OSSI-DNOVAK	[293] master	\N	\N
f6471443-cd74-44d6-8cd3-a03c25d651fb	2018-02-27 16:47:38.375378-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
da72fbd1-779f-4fc0-a3d2-4797fb422586	2018-02-27 16:47:57.902331-06	2	[293] master	[21041] OSSI-DNOVAK	[293] master	\N	\N
4c94feed-8849-4b09-af2d-b1a44358fe14	2018-02-27 16:48:41.275668-06	2	[293] master	[21041] OSSI-DNOVAK	[293] master	\N	\N
b35ea7d1-0c93-4a76-8ac0-86f9ce34a993	2018-02-27 16:49:05.686108-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
b5fb6cf3-f8f9-4a7a-9fd5-7d0397a99c32	2018-02-27 16:49:57.839323-06	2	[21052] New Virtual Point	[21041] OSSI-DNOVAK	[293] master	\N	\N
183ccd89-2482-40fd-9c72-ee0bafa5d41b	2018-02-27 16:50:16.839223-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
20d338a9-7ccf-4f15-9199-45455d69c72f	2018-02-27 16:52:26.183156-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
42d651c5-199a-4ed4-9ff7-734010a92c16	2018-02-27 16:54:11.108648-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
173e406a-4426-405c-b5dd-65807d2f512e	2018-02-27 16:54:51.030639-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
c14d6cc9-984f-4867-a6b7-8378a49f84f7	2018-02-27 16:56:04.252961-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
06a155d9-ce3f-4d0e-90f8-354fcf62feea	2018-02-27 16:56:47.827318-06	2	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
08ede26f-022d-44d0-93e1-edd452929aef	2018-02-27 16:57:22.533788-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
1d4b57e8-68b7-475d-846f-0233a18589e5	2018-02-27 16:57:40.465581-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
ed3aed7d-1df7-4800-9bc1-71353c90ebf1	2018-02-27 16:58:23.838918-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
2ba84359-8dc3-4682-b477-4b3edb85a7e7	2018-02-27 17:00:00.699603-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
12ddf4e4-37c0-4436-86e8-ad035a12fedd	2018-02-27 17:01:02.344767-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
0acc4d4a-d326-4956-b77d-013e2f18e277	2018-02-27 17:01:39.922525-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
42043330-5a33-409d-a530-d371b2991064	2018-02-27 17:03:16.639195-06	3	[21047] Tool 200x300.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
2d3ddb2a-c195-441f-a325-ba779f8cc5ed	2018-02-27 17:03:37.412272-06	1	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
244b37c8-488f-45d1-ba6f-97145ddf5039	2018-02-27 17:03:56.240155-06	3	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
a52bed44-5023-4a69-9989-0406284aa575	2018-02-27 17:04:46.280158-06	1	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
0c22976f-d32c-4ac2-b80d-78a0563cfe98	2018-02-27 17:06:13.341864-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
5931b674-3bf1-41e8-a728-af2e9066003f	2018-02-27 17:06:24.857015-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
48884d6b-8ef1-48a2-8e92-a8ec7fb2bf46	2018-02-27 17:07:20.60659-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
51001c20-abfd-4957-8ef3-faead45f15aa	2018-02-27 17:07:45.986127-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
73df4133-8219-493f-9274-787178b1e176	2018-02-27 17:08:48.346363-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
3842b6b6-7c00-43f8-8f06-03200e4ad2a0	2018-02-27 17:09:10.509579-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
bb9cd11d-2ad9-477b-bc5d-bf36741e2b68	2018-02-27 17:12:38.793405-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
8fff1242-862d-48cc-ac33-a1acaf08927e	2018-02-27 17:12:49.859512-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
12d51475-1a4a-4a6f-a808-2f543b9910de	2018-02-27 17:15:11.223647-06	3	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
1ab4091f-1144-4b39-b14f-93f9f98aca95	2018-02-27 17:15:33.837908-06	1	[21047] Tool 200x300.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
1e93fdb7-0d9f-4d73-aba6-a877b7d3cf16	2018-02-27 17:15:54.882012-06	2	[21047] Tool 200x300.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
096a96b7-f71b-4f33-9f3a-09a17e7e54c8	2018-02-27 17:18:42.923814-06	2	[21047] Tool 200x300.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
d2bbf9a3-8c8e-42e0-86bc-661e2959c3a0	2018-02-27 17:21:01.89271-06	2	[21047] Tool 200x300.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
9d7195cf-12cc-4ede-94b8-8c69a04b25b3	2018-02-28 07:44:48.745999-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
9aad1b6e-1f4d-4432-bdfc-adac3bede893	2018-02-28 07:46:18.503974-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
7fbbc4ab-f625-4554-9a29-37bfe83a7589	2018-02-28 07:46:43.141438-06	3	[21047] Tool 200x300.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
717cc016-3679-458b-9227-a3eaac47e53e	2018-02-28 07:47:02.388362-06	1	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
a401c8b1-e617-4dbd-a328-a475926d9142	2018-02-28 07:47:17.292852-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
8a6062ba-8c4a-4275-80e3-2e58a779107a	2018-02-28 07:47:56.26775-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
fc252360-7a9c-46a7-8a18-861ce5ab8d52	2018-02-28 07:49:17.034825-06	3	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
af1efbf3-c79e-4fd9-aede-e483a74acab6	2018-02-28 07:49:17.222844-06	2	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
714008d5-bce7-4381-a7a9-9ba9ddba5075	2018-02-28 07:50:39.955117-06	1	[21049] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
115981e2-392a-4cb9-90b3-2ce49096c13b	2018-02-28 07:51:04.571578-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
41cdb722-87e3-4910-8ba3-8d117391dfe1	2018-02-28 07:51:15.134634-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
d799bb8c-e62b-4a13-b8e2-a8deb03c4407	2018-02-28 07:51:58.90001-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
78b57b61-28e1-48e3-8e55-0bc576a5f861	2018-02-28 07:52:18.383959-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
ecc0a61c-38be-4ca1-bccf-73f10ebff778	2018-02-28 07:53:00.10113-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
23c8f7b2-fa70-4f6f-8282-a40493d9b473	2018-02-28 07:53:39.595079-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
f36c22f6-880d-4927-a4a1-c13ce02da9ca	2018-02-28 07:53:58.153935-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
8af9be64-9c40-4100-8e99-ad9c562aa7b8	2018-02-28 07:54:05.616681-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
6cd7151c-68a2-4dbc-a169-f98ed8099a8e	2018-02-28 07:54:28.316951-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
23ad361e-f4cc-406e-bc83-c648e7f8daa2	2018-02-28 07:56:02.080326-06	1	[21053] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
c43b7bb1-379b-4984-aaaa-510172397f9b	2018-02-28 07:56:06.251743-06	3	[21047] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
9e5b887c-9fdb-499d-bdf2-9b4939a8d865	2018-02-28 07:56:06.443762-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
5ae4fffe-0a23-4726-9108-6b68ee6c882e	2018-02-28 07:58:07.547871-06	1	[21047] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
f2330b9d-4287-4ce4-95f4-64df4e992a1d	2018-02-28 07:58:20.127129-06	2	[21047] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
9889e011-91ce-47ba-adba-6aaa3571a8f7	2018-02-28 07:58:48.077924-06	2	[21047] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
20089baf-a90a-45fc-ab3d-555a9e958347	2018-02-28 07:59:00.671183-06	2	[21047] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
f998191b-8b5a-4733-a511-c1e71143b3c6	2018-02-28 07:59:42.787394-06	2	[21047] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
3cd55cae-9be8-4ce2-9386-4d9460aa431b	2018-02-28 08:00:13.193435-06	1	[21053] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
f39e1e4f-8a64-45f8-86e6-3a32abc4c4b8	2018-02-28 08:00:49.708086-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
748ea686-dc0a-4f65-8512-c24ce09a0429	2018-02-28 08:00:59.363051-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
ca202025-8f11-4ad7-a1e5-8b6a51eebf0f	2018-02-28 08:01:05.871702-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
9aea9049-5647-46f2-bd6c-4c90d0238b34	2018-02-28 08:01:19.965111-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
a0cea8f5-a760-47c6-974f-cfcdcffcb9d1	2018-02-28 08:01:52.05832-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
c5fdd379-ceee-443c-b8a5-3a6b78eda0ba	2018-02-28 08:03:05.109625-06	1	[21054] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
7a941d62-520e-4281-bfcd-281bdc2c4f8b	2018-02-28 08:03:25.000614-06	3	[21054] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
67a149f6-f77c-432d-9fa8-9e2d9bc45f10	2018-02-28 08:04:21.927306-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
29db88cd-8352-4e4b-aff1-9ab97ede446a	2018-02-28 08:06:55.959707-06	1	[21054] Buttons	[21041] OSSI-DNOVAK	[293] master	\N	\N
d85368fe-72e4-4d31-bc66-49fb322ad6bb	2018-02-28 08:06:57.505862-06	2	[21054] Buttons	[21041] OSSI-DNOVAK	[293] master	\N	\N
ed20c4a1-95c2-499f-90a9-b2e83f94d587	2018-02-28 08:07:48.524963-06	1	[21055] Rectangle 2 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
1b90b5b7-daf8-49ab-aae8-68b5f7156aee	2018-02-28 08:08:18.563967-06	3	[21055] Rectangle 2 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
5397072d-0525-4eb8-9baf-613e1b0fb5b4	2018-02-28 08:08:35.141625-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
f99b21ab-8b0e-44f5-a410-6f723cb55843	2018-02-28 08:08:42.988409-06	1	[21055] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
adfe8023-61e6-4dcd-bf97-d7870fa8b255	2018-02-28 08:09:01.449255-06	1	[21056] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
3828aa23-06fb-40e5-aaa7-6e2ac950ae65	2018-02-28 08:09:12.472357-06	1	[21057] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
657acb69-9bde-4a68-9260-a3e30bf49fa0	2018-02-28 08:09:21.257236-06	1	[21058] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
36bd67ce-5990-4880-968b-50428a01c71e	2018-02-28 08:09:27.936904-06	1	[21059] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
14ad38a4-2d27-485a-adfd-0f18ebce1984	2018-02-28 08:09:32.610371-06	1	[21060] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
04fdc01f-15fc-4f57-b681-1f81262b2018	2018-02-28 08:10:28.994009-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
a5988518-b06a-4d0f-b6d7-9b6cbadab436	2018-02-28 08:10:56.994808-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
cd812616-33e7-4398-848d-d587f473c12d	2018-02-28 08:11:53.981507-06	1	[21061] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
cf5946cd-0e02-4c21-b638-4b2eb877ba7b	2018-02-28 08:12:39.291037-06	2	[21061] Tool Bar Name	[21041] OSSI-DNOVAK	[293] master	\N	\N
5ee66c56-dac2-4d87-bb89-dc33ba20601d	2018-02-28 08:13:31.281236-06	2	[21061] Tool Bar Name	[21041] OSSI-DNOVAK	[293] master	\N	\N
288e7396-6ec3-4a32-b2dc-e4d583f7d1a8	2018-02-28 08:15:08.091916-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
b3f192ed-8903-49cb-9e9a-c1d229d15fc5	2018-02-28 08:15:30.078114-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
14ce77da-396b-4c2a-ad78-1d965c1b3e4c	2018-02-28 08:16:20.113117-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
122f03c9-2b91-4d3a-8f93-299ba4d66c69	2018-02-28 08:16:55.566662-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
754fc876-8e74-4aec-b566-7e9eb661a02f	2018-02-28 08:35:12.747369-06	1	[21062] master Copy	[4] DLarrabee	[293] master	\N	\N
8a57f15f-54b8-43b1-9288-1c5e87b4c5ba	2018-02-28 08:35:33.377432-06	2	[21062] a	[4] DLarrabee	[293] master	\N	\N
1834396f-3bdf-481b-8581-f73e9914a0ed	2018-02-28 08:37:57.003793-06	2	[1047] DPIS-316B Call Button	[4] DLarrabee	[21062] a	\N	\N
0fff1b42-0d04-44c5-b92f-f7a1fef83989	2018-02-28 08:37:57.027796-06	2	[1055] DPIS-337A Call Button	[4] DLarrabee	[21062] a	\N	\N
c1d35b79-9e2b-4f8d-a9ee-fa11a45f25fc	2018-02-28 08:37:57.043797-06	2	[1056] DPIS-338A Call Button	[4] DLarrabee	[21062] a	\N	\N
f79058e2-7093-49f9-b1fa-ec0da6372552	2018-02-28 08:37:57.056798-06	2	[1057] DPIS-343A Call Button	[4] DLarrabee	[21062] a	\N	\N
ccbc33b4-a799-432e-8a0f-fbc4a7c1cb42	2018-02-28 08:37:57.0718-06	2	[1058] DPIS-344A Call Button	[4] DLarrabee	[21062] a	\N	\N
b077029f-2c12-495a-9fbd-4ea7fe602b02	2018-02-28 08:37:57.085801-06	2	[1059] DPIS-346A Call Button	[4] DLarrabee	[21062] a	\N	\N
7162a333-a2e0-4282-aa5c-2ed0b8fc049d	2018-02-28 08:37:57.102803-06	2	[1060] DPIS-347A Call Button	[4] DLarrabee	[21062] a	\N	\N
6363f276-7e56-4de5-85a9-da2f40c5f2c0	2018-02-28 08:37:57.116804-06	2	[1061] DPIS-348A Call Button	[4] DLarrabee	[21062] a	\N	\N
f71f1ba5-32db-4909-a039-9cf2a38ace7f	2018-02-28 08:37:57.129806-06	2	[1062] DPIS-349A Call Button	[4] DLarrabee	[21062] a	\N	\N
3e2d8ffc-ffc8-4406-9aaa-b1a513ce0152	2018-02-28 08:37:57.133806-06	2	[1114] DPIS-316B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6206c0f6-6e5a-4b9f-9b15-a7a0947b72a6	2018-02-28 08:37:57.136806-06	2	[1115] DPIS-326A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
17947b76-81c9-4d2d-8991-37856d9613dc	2018-02-28 08:37:57.139807-06	2	[1116] DPIS-327A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d7b20ef8-5678-4522-83bb-dde4394190dc	2018-02-28 08:37:57.141807-06	2	[1117] DPIS-329A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fb4c56c3-7629-428a-aa4a-ba68af0499e3	2018-02-28 08:37:57.144807-06	2	[1118] DPIS-329B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
59417281-25fd-4689-b537-a2f02ab616a2	2018-02-28 08:37:57.148808-06	2	[1119] DPIS-334A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7dd910de-58de-4db3-bd66-a6328c48961a	2018-02-28 08:37:57.165809-06	2	[1120] DPIS-335A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1f923b8d-e51c-4de7-a9c9-6d6123e57433	2018-02-28 08:37:57.16981-06	2	[1121] DPIS-336A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
43828158-0098-410a-8f72-253c727fb7c2	2018-02-28 08:37:57.17381-06	2	[1122] DPIS-337A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
63c43930-6f62-4871-9bed-1d34405660f6	2018-02-28 08:37:57.177811-06	2	[1123] DPIS-338A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
62c741fb-3b18-481f-b18a-bbcc119f0c05	2018-02-28 08:37:57.181811-06	2	[1124] DPIS-343A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ab8999fd-ae12-4a27-b660-d650aaf36320	2018-02-28 08:37:57.185811-06	2	[1125] DPIS-344A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c9986704-c6e2-4a65-a7ed-c9008c36d28f	2018-02-28 08:37:57.188812-06	2	[1126] DPIS-346A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9939017b-bc94-401d-8842-936c741e3bfd	2018-02-28 08:37:57.192812-06	2	[1127] DPIS-347A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2369a06c-b888-42c3-99be-b6c78ee8125f	2018-02-28 08:37:57.196812-06	2	[1128] DPIS-348A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c1ba25d1-3a35-4f06-b62a-201b5fa3ae97	2018-02-28 08:37:57.199813-06	2	[1129] DPIS-349A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0105a944-d585-4120-bdd4-81705deb0506	2018-02-28 08:37:57.203813-06	2	[1130] DPIS-351A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4692b8e6-2f5b-4e8d-848c-55acfd39c09c	2018-02-28 08:37:57.207814-06	2	[1131] DPIS-351B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
bfda0ed2-7e7a-48e1-8137-84a475a71ec4	2018-02-28 08:37:57.210814-06	2	[1132] DPIS-352A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
5a0f721d-8c4a-4012-b766-367f496a6937	2018-02-28 08:37:57.214814-06	2	[1133] DPIS-405A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f2b001a2-585e-44b0-a608-37d824ca2121	2018-02-28 08:37:57.217815-06	2	[1134] DPIS-414A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d6b9c685-1ae4-40ba-9f32-ad87307c1d56	2018-02-28 08:37:57.221815-06	2	[1135] DPIS-414B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
da0a2e03-6109-4769-8b5d-977f242efec5	2018-02-28 08:37:57.224815-06	2	[1136] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4e82ebcb-816d-45d0-ac6c-98aa012c1df7	2018-02-28 08:37:57.227816-06	2	[1137] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
04478132-8288-4655-9114-a7bb3d7ec23b	2018-02-28 08:37:57.231816-06	2	[1138] DPIS-422A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
19b13851-03a6-4f3a-89c5-1fd4f76bb09c	2018-02-28 08:37:57.233816-06	2	[1139] DPIS-422B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
376ce571-dcec-4508-a1ae-6aa631f57208	2018-02-28 08:37:57.236816-06	2	[1140] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
981e3db6-7aef-4cd4-afa6-99c551dfdd22	2018-02-28 08:37:57.239817-06	2	[1141] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
34b7b064-796e-4acc-91e0-a126579c5ea2	2018-02-28 08:37:57.242817-06	2	[1142] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4cf467e1-b0d8-40f0-9c01-91861a77005a	2018-02-28 08:37:57.246817-06	2	[1143] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0e874896-eebb-462c-9719-5f057a1a2384	2018-02-28 08:37:57.249818-06	2	[1144] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
aeec9222-b2a4-4c97-8e8d-2fe38a5ddb6e	2018-02-28 08:37:57.252818-06	2	[1145] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ab87e33d-385b-4f03-96f0-14bb8016e12c	2018-02-28 08:37:57.309824-06	2	[1513] R1C2-32I	[4] DLarrabee	[21062] a	\N	\N
3127646e-bf89-49af-a2de-ee5b6d3cc865	2018-02-28 08:37:57.326825-06	2	[1515] DPIS-438A Call Button	[4] DLarrabee	[21062] a	\N	\N
a7493e84-facc-4e6d-a59c-386a8d46e94a	2018-02-28 08:37:57.341827-06	2	[1516] DPIS-439A Call Button	[4] DLarrabee	[21062] a	\N	\N
206db204-d470-49ba-bd41-1d698f1a0d56	2018-02-28 08:37:57.354828-06	2	[1517] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
400a2873-6ce7-4dd3-b0df-17fcc713ef9f	2018-02-28 08:37:57.37083-06	2	[1518] DPIS-443A Call Button	[4] DLarrabee	[21062] a	\N	\N
19319c0f-376f-410c-bf6d-80e79b571eb3	2018-02-28 08:37:57.388832-06	2	[1519] DPIS-443B Call Button	[4] DLarrabee	[21062] a	\N	\N
501b8ce5-84c7-49d4-aaa7-813e80ee0652	2018-02-28 08:37:57.403833-06	2	[1520] DPIS-444A Call Button	[4] DLarrabee	[21062] a	\N	\N
1528e22b-f0fd-4b20-a1ac-ec4be9aaa452	2018-02-28 08:37:57.421835-06	2	[1521] DPIS-444B Call Button	[4] DLarrabee	[21062] a	\N	\N
7e671275-f5ac-4b22-a7e0-e4bf0b21445c	2018-02-28 08:37:57.439837-06	2	[1522] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
e45cf027-b733-429c-9f50-a4363d12f560	2018-02-28 08:37:57.456838-06	2	[1523] DPIS-447A Call Button	[4] DLarrabee	[21062] a	\N	\N
cdaf86c5-6ae1-4d39-b00b-f56a0f7c9223	2018-02-28 08:37:57.47084-06	2	[1524] DPIS-447B Call Button	[4] DLarrabee	[21062] a	\N	\N
b50d1d66-ccc3-4d77-9598-b10abf35a1d2	2018-02-28 08:37:57.483841-06	2	[1525] DPIS-448A Call Button	[4] DLarrabee	[21062] a	\N	\N
ee403e38-4fc0-46da-9c05-698c5c90d6c0	2018-02-28 08:37:57.499843-06	2	[1526] DPIS-451A Call Button	[4] DLarrabee	[21062] a	\N	\N
329a06fe-70bd-44f7-827a-85e5e8d75ee7	2018-02-28 08:37:57.513844-06	2	[1527] DPIS-455A Call Button	[4] DLarrabee	[21062] a	\N	\N
61bd5da8-f508-4c9d-a521-d67461604605	2018-02-28 08:37:57.534846-06	2	[1528] DPIS-455B Call Button	[4] DLarrabee	[21062] a	\N	\N
e2ef2880-bf40-438d-9cc8-382df164c03a	2018-02-28 08:37:57.546847-06	2	[1529] DPIS-455D Call Button	[4] DLarrabee	[21062] a	\N	\N
a4c90410-1851-4381-98a5-e279d52c8523	2018-02-28 08:37:57.560849-06	2	[1530] DPIS-316B Call Button	[4] DLarrabee	[21062] a	\N	\N
87578d5f-0f50-408d-aaeb-5174a7b44898	2018-02-28 08:37:57.57385-06	2	[1531] DPIS-326A Call Button	[4] DLarrabee	[21062] a	\N	\N
5de9f3cd-1366-42c2-8b56-db7452531fed	2018-02-28 08:37:57.589852-06	2	[1532] DPIS-327A Call Button	[4] DLarrabee	[21062] a	\N	\N
f11f61c6-fdb6-4b8c-9a2b-929e46e81c94	2018-02-28 08:37:57.602853-06	2	[1533] DPIS-329A Call Button	[4] DLarrabee	[21062] a	\N	\N
d8a97d43-8000-4ec1-8da9-248905693e8a	2018-02-28 08:37:57.620855-06	2	[1534] DPIS-329B Call Button	[4] DLarrabee	[21062] a	\N	\N
4f6daf42-4096-483a-a008-f0b5e1c36d44	2018-02-28 08:37:57.633856-06	2	[1535] DPIS-334A Call Button	[4] DLarrabee	[21062] a	\N	\N
b207aacc-2b26-4750-8879-b413c16f34e3	2018-02-28 08:37:57.648858-06	2	[1536] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
21ca0e08-7095-4371-9534-f1d5080074b2	2018-02-28 08:37:57.665859-06	2	[1537] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
3f0e871c-fc77-4001-ad2c-cf3ac18c149e	2018-02-28 08:37:57.680861-06	2	[1538] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
666dbd73-9a1d-4548-890d-32da7bb09928	2018-02-28 08:37:57.697863-06	2	[1539] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
da0b196d-22d6-48b9-82a3-61303d81ea2e	2018-02-28 08:37:57.713864-06	2	[1540] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
5ee67fa3-caec-4f8f-b973-03831b59c8b4	2018-02-28 08:37:57.735866-06	2	[1541] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
377b8502-bd16-4ae2-b941-781c0e4be140	2018-02-28 08:37:57.753868-06	2	[1542] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
a127167d-b479-4740-b83c-ff1a9dcfa14e	2018-02-28 08:37:57.77087-06	2	[1543] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
dfcda9a4-5814-4a4d-86ea-0fb06d1f8f40	2018-02-28 08:37:57.784871-06	2	[1544] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
433a066a-680e-4ddb-8af1-5ee9aadc0e82	2018-02-28 08:37:57.803873-06	2	[1545] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
5c01129e-637f-4b3a-87a5-beb49ae898c7	2018-02-28 08:37:57.815874-06	2	[1546] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
5a547518-04ff-4344-9466-c50b4ce3359c	2018-02-28 08:37:57.819875-06	2	[1582] DPIS-438A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1a31bc00-507c-4229-a29d-33afac0bd5d7	2018-02-28 08:37:57.823875-06	2	[1583] DPIS-439A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6e29063b-dacc-41ee-a90e-7010aa718513	2018-02-28 08:37:57.825875-06	2	[1584] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
768b2303-7b0f-4826-87f8-fce193b1d20f	2018-02-28 08:37:57.828876-06	2	[1585] DPIS-443A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e94d45e9-cbf4-44f9-b868-dbdd3fd9f5ea	2018-02-28 08:37:57.831876-06	2	[1586] DPIS-443B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1f3c11f0-894d-4dbc-9bfb-140a058c54d8	2018-02-28 08:37:57.834876-06	2	[1587] DPIS-444A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4480ab6f-407e-4b77-9dab-13dd5799f880	2018-02-28 08:37:57.837877-06	2	[1588] DPIS-444B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f533f82c-d097-4fe5-b904-9290430af1bd	2018-02-28 08:37:57.840877-06	2	[1589] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6ebe421d-1321-4115-bf69-4ffa91ce5b1b	2018-02-28 08:37:57.843877-06	2	[1590] DPIS-447A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c96b85ef-3c3f-4bc9-8a98-7e7f26b44957	2018-02-28 08:37:57.847878-06	2	[1591] DPIS-447B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a640b901-fe89-49ea-b4c5-1bd017abc1c9	2018-02-28 08:37:57.850878-06	2	[1592] DPIS-448A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4c210021-6675-4864-8685-09a71e7743cf	2018-02-28 08:37:57.854878-06	2	[1593] DPIS-451A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2d5a02ac-7854-46ef-b3a9-5fd1d6275aa8	2018-02-28 08:37:57.858879-06	2	[1594] DPIS-455A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e49714d2-1749-467e-a86f-b26ec07d8a80	2018-02-28 08:37:57.861879-06	2	[1595] DPIS-455B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d77fb46d-513e-4065-8860-1ac613881746	2018-02-28 08:37:57.864879-06	2	[1596] DPIS-455D Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c8b6cb9e-9ade-476d-8c77-fb433307d84d	2018-02-28 08:37:57.86788-06	2	[1597] DPIS-316B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4634de8e-4a06-4d20-8cb5-b5656e13e803	2018-02-28 08:37:57.87088-06	2	[1598] DPIS-326A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f3063d95-7973-4cae-be3e-9ad6f771b510	2018-02-28 08:37:57.87488-06	2	[1599] DPIS-327A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
84686006-3aaf-40fb-8426-a7f0313c8faa	2018-02-28 08:37:57.877881-06	2	[1600] DPIS-329A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
46b583dd-a89f-40ce-86b2-09e1e69fe839	2018-02-28 08:37:57.880881-06	2	[1601] DPIS-329B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2eeac0fa-d51c-437a-af13-669b57f64542	2018-02-28 08:37:57.883881-06	2	[1602] DPIS-334A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e8e9a4fa-67dc-43cd-ad4a-61065d473f38	2018-02-28 08:37:57.887882-06	2	[1603] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0ca245e9-488a-4dc9-b332-2907f33d84d6	2018-02-28 08:37:57.891882-06	2	[1604] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9e758bec-3cf6-4960-b5bd-5256e55d6f12	2018-02-28 08:37:57.896882-06	2	[1605] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
5ff5ebca-94b9-4a42-9fd7-1eedafa51d90	2018-02-28 08:37:57.900883-06	2	[1606] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
79fabf08-3582-422a-9ec3-bd0af7c17032	2018-02-28 08:37:57.904883-06	2	[1607] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9b9bfde9-da7b-4564-a9db-b8fc7576af61	2018-02-28 08:37:57.907884-06	2	[1608] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c36bfb51-b3e9-404d-871d-b16b13b0edf1	2018-02-28 08:37:57.911884-06	2	[1609] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
50029455-34fd-401e-8e18-be16da5963c4	2018-02-28 08:37:57.914884-06	2	[1610] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c273afb2-e896-4780-9473-afcc1af80542	2018-02-28 08:37:57.918885-06	2	[1611] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
bb9e79e2-f450-460d-bd32-0a7fde4c3900	2018-02-28 08:37:57.922885-06	2	[1612] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
49d8921f-1114-4c4c-81e6-04ce915fc7c1	2018-02-28 08:37:57.925885-06	2	[1613] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6abf19cf-abcd-4cee-934f-d01f3b012038	2018-02-28 08:37:57.944887-06	2	[1980] R1C3-16R	[4] DLarrabee	[21062] a	\N	\N
57cfef88-6bbe-4e47-90f4-6d9ce7ade535	2018-02-28 08:37:57.964889-06	2	[1983] LOCK RELAY-316B Relay	[4] DLarrabee	[21062] a	\N	\N
e1ee396f-9a54-4621-b984-27fcf3dae910	2018-02-28 08:37:57.977891-06	2	[1984] LOCK RELAY-326A Relay	[4] DLarrabee	[21062] a	\N	\N
c7a4d106-c734-42c8-88bd-233c9b0ca567	2018-02-28 08:37:57.990892-06	2	[1985] LOCK RELAY-327A Relay	[4] DLarrabee	[21062] a	\N	\N
cea80bf1-01f0-4acc-80d3-688b0a25d89c	2018-02-28 08:37:58.005893-06	2	[1986] LOCK RELAY-329A Relay	[4] DLarrabee	[21062] a	\N	\N
548ee996-9a86-46bf-9d3c-c942861db3d0	2018-02-28 08:37:58.018895-06	2	[1987] LOCK RELAY-329B Relay	[4] DLarrabee	[21062] a	\N	\N
e510199e-9fb4-4c09-bbbb-ebde2b97a2b6	2018-02-28 08:37:58.032896-06	2	[1988] LOCK RELAY-334A Relay	[4] DLarrabee	[21062] a	\N	\N
ab437985-07f1-4693-b8c4-892fb781b283	2018-02-28 08:37:58.050898-06	2	[1989] LOCK RELAY-335A Relay	[4] DLarrabee	[21062] a	\N	\N
7a8fd87b-16b5-4e5a-be6e-3490f9f6dc8c	2018-02-28 08:37:58.0679-06	2	[1990] LOCK RELAY-336A Relay	[4] DLarrabee	[21062] a	\N	\N
0b4e2591-df46-49a1-9764-c859e43f1710	2018-02-28 08:37:58.086901-06	2	[1991] LOCK RELAY-337A Relay	[4] DLarrabee	[21062] a	\N	\N
1a3b4640-e06a-4e19-b499-4e3556d3544c	2018-02-28 08:37:58.103903-06	2	[1992] LOCK RELAY-338A Relay	[4] DLarrabee	[21062] a	\N	\N
26d84afc-f64f-4617-acc1-5b33514d6493	2018-02-28 08:37:58.119905-06	2	[1993] LOCK RELAY-343A Relay	[4] DLarrabee	[21062] a	\N	\N
117d3389-7e73-48fe-b9e3-a7bbe6603550	2018-02-28 08:37:58.133906-06	2	[1994] LOCK RELAY-344A Relay	[4] DLarrabee	[21062] a	\N	\N
e5ab8e8d-c674-4627-80e5-1214a49a6a44	2018-02-28 08:37:58.149908-06	2	[1995] LOCK RELAY-346A Relay	[4] DLarrabee	[21062] a	\N	\N
4f26a414-999a-4db9-9930-54f03de30ad0	2018-02-28 08:37:58.166909-06	2	[1996] LOCK RELAY-347A Relay	[4] DLarrabee	[21062] a	\N	\N
3a3828a9-adce-4a4f-ad2d-23b7ab07c50c	2018-02-28 08:37:58.181911-06	2	[1997] LOCK RELAY-348A Relay	[4] DLarrabee	[21062] a	\N	\N
49684a8e-898e-4f64-b320-e99e8f023ea2	2018-02-28 08:37:58.196912-06	2	[1998] LOCK RELAY-349A Relay	[4] DLarrabee	[21062] a	\N	\N
e11d4f71-a7f9-47b6-813c-2da73618a383	2018-02-28 08:37:58.215914-06	2	[2300] R1C4-16R	[4] DLarrabee	[21062] a	\N	\N
0ae3c3fd-31b9-4feb-a1fb-ddb531d20ca2	2018-02-28 08:37:58.233916-06	2	[2303] LOCK RELAY-351A Relay	[4] DLarrabee	[21062] a	\N	\N
780dc32e-29d8-4be4-9b0c-cc87314cfaeb	2018-02-28 08:37:58.249918-06	2	[2304] LOCK RELAY-351B Relay	[4] DLarrabee	[21062] a	\N	\N
138e37c4-c0c3-4142-836a-a43861318ed6	2018-02-28 08:37:58.264919-06	2	[2305] LOCK RELAY-352A Relay	[4] DLarrabee	[21062] a	\N	\N
ae3626f9-d611-40c8-be18-c25389f3f249	2018-02-28 08:37:58.280921-06	2	[2306] LOCK RELAY-405A Relay	[4] DLarrabee	[21062] a	\N	\N
4f957a1e-dd6e-4230-b325-eb1d6c6f2c68	2018-02-28 08:37:58.295922-06	2	[2307] LOCK RELAY-414A Relay	[4] DLarrabee	[21062] a	\N	\N
138a2e03-16f8-44a8-b438-bbc3289ddf3f	2018-02-28 08:37:58.308924-06	2	[2308] LOCK RELAY-414B Relay	[4] DLarrabee	[21062] a	\N	\N
36062271-8121-4669-a326-d039761c7598	2018-02-28 08:37:58.323925-06	2	[2309] LOCK RELAY-422A Relay	[4] DLarrabee	[21062] a	\N	\N
4a833345-f462-4943-a5ab-6eac5c7fd5be	2018-02-28 08:37:58.340927-06	2	[2310] LOCK RELAY-422B Relay	[4] DLarrabee	[21062] a	\N	\N
387228e8-33c5-474a-9ee4-cc7786dc16ed	2018-02-28 08:37:58.357929-06	2	[2311] LOCK RELAY-438A Relay	[4] DLarrabee	[21062] a	\N	\N
ccd78e2a-8440-4fc0-b4db-3618d2d23eaa	2018-02-28 08:37:58.37093-06	2	[2312] LOCK RELAY-439A Relay	[4] DLarrabee	[21062] a	\N	\N
55fcffb6-c54e-470a-b35c-3259d9f29cc2	2018-02-28 08:37:58.385931-06	2	[2313] LOCK RELAY-443A Relay	[4] DLarrabee	[21062] a	\N	\N
fe771b2f-340c-4bbd-b8a9-49c35a4c4544	2018-02-28 08:37:58.401933-06	2	[2314] LOCK RELAY-443B Relay	[4] DLarrabee	[21062] a	\N	\N
6d1b1580-d783-4581-b695-a1d2a02f5478	2018-02-28 08:37:58.415934-06	2	[2315] LOCK RELAY-444A Relay	[4] DLarrabee	[21062] a	\N	\N
41025f70-569e-4b4d-9dd3-e791ebc98c01	2018-02-28 08:37:58.432936-06	2	[2316] LOCK RELAY-444B Relay	[4] DLarrabee	[21062] a	\N	\N
807a9578-432b-49d1-8719-ec56c986b849	2018-02-28 08:37:58.447938-06	2	[2317] LOCK RELAY-447A Relay	[4] DLarrabee	[21062] a	\N	\N
11f94cfb-48bb-40c3-8317-0900687f2f06	2018-02-28 08:37:58.460939-06	2	[2318] LOCK RELAY-447B Relay	[4] DLarrabee	[21062] a	\N	\N
99be6aff-375a-4009-bab4-cdd1d68ae684	2018-02-28 08:37:58.47694-06	2	[2620] R1C5-16R	[4] DLarrabee	[21062] a	\N	\N
e0199eaf-7829-4b8c-a062-0bb4e55f3323	2018-02-28 08:37:58.510944-06	2	[2623] LOCK RELAY-448A Relay	[4] DLarrabee	[21062] a	\N	\N
7c8a715d-18d2-47b7-b97f-7576a26e6fff	2018-02-28 08:37:58.528946-06	2	[2624] LOCK RELAY-455A Relay	[4] DLarrabee	[21062] a	\N	\N
12419831-032e-4847-8ac7-33470107549d	2018-02-28 08:37:58.545947-06	2	[2625] LOCK RELAY-455B Relay	[4] DLarrabee	[21062] a	\N	\N
62e6cd10-c0d2-4c30-abdc-62c4e05a53d9	2018-02-28 08:37:58.562949-06	2	[2626] LOCK RELAY-455D Relay	[4] DLarrabee	[21062] a	\N	\N
7a0948f0-f7c4-45da-aaa8-79cfb9e9618d	2018-02-28 08:37:58.578951-06	2	[2627] LOCK RELAY-316B Relay	[4] DLarrabee	[21062] a	\N	\N
a146e79e-4949-4d9c-8b0d-116c5bf093f9	2018-02-28 08:37:58.591952-06	2	[2628] LOCK RELAY-326A Relay	[4] DLarrabee	[21062] a	\N	\N
e25e414c-3cb7-41a5-bd4d-0fab6618e26c	2018-02-28 08:37:58.607954-06	2	[2629] LOCK RELAY-327A Relay	[4] DLarrabee	[21062] a	\N	\N
f1462903-8b69-497a-b48d-6651acab8797	2018-02-28 08:37:58.621955-06	2	[2630] LOCK RELAY-329A Relay	[4] DLarrabee	[21062] a	\N	\N
8a3a3a7a-e96f-4379-9814-20a9c77869d6	2018-02-28 08:37:58.639957-06	2	[2631] LOCK RELAY-329B Relay	[4] DLarrabee	[21062] a	\N	\N
4dd0f990-c78e-4ff1-9153-688b65fff4a9	2018-02-28 08:37:58.654958-06	2	[2632] LOCK RELAY-334A Relay	[4] DLarrabee	[21062] a	\N	\N
0c7d5b61-c3c8-45b3-bd83-47f2af11ccc1	2018-02-28 08:37:58.66896-06	2	[2633] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
0bde82f6-10c7-4544-a169-30814fab7324	2018-02-28 08:37:58.687962-06	2	[2634] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
f346d9d4-5e94-400b-887c-50b9f8272c26	2018-02-28 08:37:58.706963-06	2	[2635] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
94a31da7-7038-4579-8804-39b2bcda532a	2018-02-28 08:37:58.720965-06	2	[2636] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
d8642f54-47a8-4a0b-b040-bab71db7547e	2018-02-28 08:37:58.735966-06	2	[2637] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
24fb1098-bf8f-4bc2-97a9-9810066a586d	2018-02-28 08:37:58.748968-06	2	[2638] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
54c04162-e6e6-4077-9fa3-82bd23d32886	2018-02-28 08:37:58.940987-06	2	[2940] R2C1-8IC	[4] DLarrabee	[21062] a	\N	\N
3d934094-5fdc-4f32-9d34-62f9517ea022	2018-02-28 08:37:58.953988-06	2	[2942] IC-316B-inB Call Button	[4] DLarrabee	[21062] a	\N	\N
92ab27fc-6315-4a7a-adf0-3d8c940e5713	2018-02-28 08:37:58.966989-06	2	[2943] IC-316B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
b825c521-3879-4b69-a1e7-f1eefa16f65e	2018-02-28 08:37:58.982991-06	2	[2944] IC-326A Call Button	[4] DLarrabee	[21062] a	\N	\N
7b728a6c-b180-498c-b5fc-f0ab9b535c1a	2018-02-28 08:37:58.999993-06	2	[2945] IC-326A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
86a827b1-85dd-4c34-9406-85248f15d97a	2018-02-28 08:37:59.013994-06	2	[2946] IC-327A Call Button	[4] DLarrabee	[21062] a	\N	\N
3d389f93-7ce0-41f7-a25c-d4a4e8593a23	2018-02-28 08:37:59.024995-06	2	[2947] IC-327A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
d75bfb0d-b354-4134-a0aa-d44f82b7bbd2	2018-02-28 08:37:59.038997-06	2	[2948] IC-329A Call Button	[4] DLarrabee	[21062] a	\N	\N
d56966ae-f631-424e-a867-09e69985af32	2018-02-28 08:37:59.051998-06	2	[2949] IC-329A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
a42b0a7d-c5e6-46a8-95d7-5cab9b1b23ff	2018-02-28 08:37:59.068-06	2	[2951] IC-316B-inB Relay	[4] DLarrabee	[21062] a	\N	\N
f45208c3-8482-4478-b77d-a68208f6c9b7	2018-02-28 08:37:59.083001-06	2	[2952] IC-316B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
b1432491-4fec-4008-b080-5d2327f32cc2	2018-02-28 08:37:59.100003-06	2	[2953] IC-326A Relay	[4] DLarrabee	[21062] a	\N	\N
d643bbab-2880-4af4-9040-b11e53074250	2018-02-28 08:37:59.117004-06	2	[2954] IC-326A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
1a28f384-8f67-47a7-8223-34e41b1397f4	2018-02-28 08:37:59.136006-06	2	[2955] IC-327A Relay	[4] DLarrabee	[21062] a	\N	\N
47a473e7-67ea-4232-9577-bcf203ada3cc	2018-02-28 08:37:59.149008-06	2	[2956] IC-327A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
57d85eb4-c507-4edb-b04a-696d186e0894	2018-02-28 08:37:59.163009-06	2	[2957] IC-329A Relay	[4] DLarrabee	[21062] a	\N	\N
74b9cc56-0a1d-46c5-9ba1-3109b1b36548	2018-02-28 08:37:59.178011-06	2	[2958] IC-329A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
bf89a337-876a-40e6-a8ee-23d8d93a8b1b	2018-02-28 08:37:59.181011-06	2	[2960] IC-316B-inB Connect	[4] DLarrabee	[21062] a	\N	\N
21cbbaec-3a0f-41cb-af9f-f78f4eae88b9	2018-02-28 08:37:59.184011-06	2	[2961] IC-316B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
7ea4a6d2-77da-4d28-9d92-07391ef4ca0d	2018-02-28 08:37:59.186011-06	2	[2962] IC-326A Connect	[4] DLarrabee	[21062] a	\N	\N
ac04d713-b550-4f22-b014-7724d3d29486	2018-02-28 08:37:59.190012-06	2	[2963] IC-326A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
7bc2eb32-5368-4022-b770-02c489ad8369	2018-02-28 08:37:59.193012-06	2	[2964] IC-327A Connect	[4] DLarrabee	[21062] a	\N	\N
b732a560-aba1-436c-8e78-0217f66ebefc	2018-02-28 08:37:59.197012-06	2	[2965] IC-327A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
16a70cad-4357-4387-9b79-79c79f86fcae	2018-02-28 08:37:59.199013-06	2	[2966] IC-329A Connect	[4] DLarrabee	[21062] a	\N	\N
a88621ff-7f82-4bb5-8c39-26169783486c	2018-02-28 08:37:59.203013-06	2	[2967] IC-329A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
b56a1966-4063-468d-9743-1be3fc75aa50	2018-02-28 08:37:59.206013-06	2	[2993] IC-316B-inB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d3ff1771-8e4b-4ff3-9948-edbcec2cec13	2018-02-28 08:37:59.209014-06	2	[2994] IC-316B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
38fc2f11-f30d-44f3-9d6c-87fbaa145937	2018-02-28 08:37:59.213014-06	2	[2995] IC-326A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fa1f77b8-591c-486d-84d3-7136764e8e15	2018-02-28 08:37:59.216014-06	2	[2996] IC-326A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
48095d9e-a67a-45d6-826b-56f3b15f98a0	2018-02-28 08:37:59.220015-06	2	[2997] IC-327A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
51b30c94-77bc-45ce-aa73-d9f042451802	2018-02-28 08:37:59.223015-06	2	[2998] IC-327A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
96bd573e-b879-4322-b11f-6482720c70c6	2018-02-28 08:37:59.227015-06	2	[2999] IC-329A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b02a9415-b35f-4b17-a25b-720c5b18f229	2018-02-28 08:37:59.231016-06	2	[3000] IC-329A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b9c2328e-433e-4e73-9698-17b74b4a7d6d	2018-02-28 08:37:59.234016-06	2	[3012] IC-316B-inB Call	[4] DLarrabee	[21062] a	\N	\N
cc49bdc7-19a1-448d-85a8-27d3ddfd56c3	2018-02-28 08:37:59.237016-06	2	[3013] IC-316B-outB Call	[4] DLarrabee	[21062] a	\N	\N
f774fa2b-2305-418b-b31b-c44e89f3e582	2018-02-28 08:37:59.240017-06	2	[3014] IC-326A Call	[4] DLarrabee	[21062] a	\N	\N
51fa6fa5-91df-43ef-b811-c9bb5a455883	2018-02-28 08:37:59.243017-06	2	[3015] IC-326A-outB Call	[4] DLarrabee	[21062] a	\N	\N
0af8be9d-f1b8-4712-8e26-deaf071e65f3	2018-02-28 08:37:59.246017-06	2	[3016] IC-327A Call	[4] DLarrabee	[21062] a	\N	\N
d498d452-23a5-4ad2-a0aa-0d8c619b7a91	2018-02-28 08:37:59.250018-06	2	[3017] IC-327A-outB Call	[4] DLarrabee	[21062] a	\N	\N
723cb006-4270-47cd-bdb8-df19e5fd4f66	2018-02-28 08:37:59.253018-06	2	[3018] IC-329A Call	[4] DLarrabee	[21062] a	\N	\N
ecb8ceb1-7d92-41bb-b661-037c28896488	2018-02-28 08:37:59.255018-06	2	[3019] IC-329A-outB Call	[4] DLarrabee	[21062] a	\N	\N
ac068223-4d67-4632-a6e1-eed1731e3e2d	2018-02-28 08:37:59.37603-06	2	[3380] R2C2-8IC	[4] DLarrabee	[21062] a	\N	\N
0515f318-b317-4d4d-a459-fa86a9b0c4f3	2018-02-28 08:37:59.392032-06	2	[3382] IC-329B Call Button	[4] DLarrabee	[21062] a	\N	\N
69b58ef4-6492-43a2-841d-aefd262fb28f	2018-02-28 08:37:59.407033-06	2	[3383] IC-329B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
8020b1dd-71b8-456f-9a55-6d99c6f58fb9	2018-02-28 08:37:59.425035-06	2	[3384] IC-334A Call Button	[4] DLarrabee	[21062] a	\N	\N
2aba85d2-8da7-415d-be64-5a3b7c8d9619	2018-02-28 08:37:59.442037-06	2	[3385] IC-334A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
4cf4dce8-0b8f-406b-94a3-08f11516fd5a	2018-02-28 08:37:59.455038-06	2	[3386] IC-335A Call Button	[4] DLarrabee	[21062] a	\N	\N
8c3e90ab-7c1f-4d89-83f5-199fe4d8a95a	2018-02-28 08:37:59.47004-06	2	[3387] IC-335A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
71b7aacf-6310-477f-ab99-bf12ea26fe0c	2018-02-28 08:37:59.485041-06	2	[3388] IC-336A Call Button	[4] DLarrabee	[21062] a	\N	\N
f543170d-0db1-4494-ba0a-74b5da35d171	2018-02-28 08:37:59.502043-06	2	[3389] IC-336A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
e79e89cc-a4de-4f15-97e2-438d620526f0	2018-02-28 08:37:59.515044-06	2	[3391] IC-329B Relay	[4] DLarrabee	[21062] a	\N	\N
d8e84a0b-29fc-4714-adc1-b3977b464cd0	2018-02-28 08:37:59.533046-06	2	[3392] IC-329B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
3a94ce19-0521-4966-a6ce-647f93da7944	2018-02-28 08:37:59.552048-06	2	[3393] IC-334A Relay	[4] DLarrabee	[21062] a	\N	\N
35cc504c-a3be-489c-a094-bdfc5e23edc2	2018-02-28 08:37:59.56905-06	2	[3394] IC-334A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
b7776f80-f73a-4cd4-8550-5664b472f861	2018-02-28 08:37:59.581051-06	2	[3395] IC-335A Relay	[4] DLarrabee	[21062] a	\N	\N
7b8b43e6-62fb-4bbc-b396-1cab52394627	2018-02-28 08:37:59.594052-06	2	[3396] IC-335A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
2b444853-5258-45fe-a17d-18aa69c2c6f9	2018-02-28 08:37:59.613054-06	2	[3397] IC-336A Relay	[4] DLarrabee	[21062] a	\N	\N
3fb30ce3-9eb7-4770-ad40-c15792514cad	2018-02-28 08:37:59.631056-06	2	[3398] IC-336A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
b3835a14-2a2c-4fc2-8cab-c7b12ebabad7	2018-02-28 08:37:59.635056-06	2	[3400] IC-329B Connect	[4] DLarrabee	[21062] a	\N	\N
26bf5daa-24e4-4056-bf7e-98927833fcd1	2018-02-28 08:37:59.639057-06	2	[3401] IC-329B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
3342c02f-4ae7-4232-a6ba-0025727f8884	2018-02-28 08:37:59.644057-06	2	[3402] IC-334A Connect	[4] DLarrabee	[21062] a	\N	\N
3355622b-809d-4014-b976-0c860f0faf4b	2018-02-28 08:37:59.649058-06	2	[3403] IC-334A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
24c73d84-6e5e-4f62-b27d-973b6137efae	2018-02-28 08:37:59.653058-06	2	[3404] IC-335A Connect	[4] DLarrabee	[21062] a	\N	\N
5f78d998-0954-42ad-ad3e-206f7748e36c	2018-02-28 08:37:59.655058-06	2	[3405] IC-335A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
e9e0a06e-d393-455a-8a40-672428a6620d	2018-02-28 08:37:59.659059-06	2	[3406] IC-336A Connect	[4] DLarrabee	[21062] a	\N	\N
5d2409a7-fd37-44f2-8d0c-96b986435b9f	2018-02-28 08:37:59.665059-06	2	[3407] IC-336A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
22389822-22e7-4cf2-844a-76de630dfbe2	2018-02-28 08:37:59.66906-06	2	[3433] IC-329B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
984aa9f5-a968-488b-8316-26b64aa3c985	2018-02-28 08:37:59.67306-06	2	[3434] IC-329B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8175f508-9413-4028-bd82-685d43ae3d18	2018-02-28 08:37:59.67706-06	2	[3435] IC-334A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f87f939b-d33d-4500-9cff-e9f47219ae6c	2018-02-28 08:37:59.681061-06	2	[3436] IC-334A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8fca813f-a9a9-4ef2-ad15-3b9005d1127c	2018-02-28 08:37:59.685061-06	2	[3437] IC-335A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1b8e13a2-1679-40fe-b7c5-12a9cfa1a292	2018-02-28 08:37:59.689062-06	2	[3438] IC-335A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
bb67440d-3fc3-4990-b3ef-4929a161d0cf	2018-02-28 08:37:59.692062-06	2	[3439] IC-336A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
19f10f64-6159-48b7-bf82-388b8550ea28	2018-02-28 08:37:59.696062-06	2	[3440] IC-336A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2449ded1-4878-4a76-8d1d-0558a6927074	2018-02-28 08:37:59.700063-06	2	[3452] IC-329B Call	[4] DLarrabee	[21062] a	\N	\N
827c95f6-e51d-4ea8-8e50-2a5f3c53a2cb	2018-02-28 08:37:59.703063-06	2	[3453] IC-329B-outB Call	[4] DLarrabee	[21062] a	\N	\N
4b86da82-654c-4dd4-8144-5bfb635a1fcc	2018-02-28 08:37:59.707063-06	2	[3454] IC-334A Call	[4] DLarrabee	[21062] a	\N	\N
ed5b8375-4821-44d9-8ec1-8ddda8f6feef	2018-02-28 08:37:59.711064-06	2	[3455] IC-334A-outB Call	[4] DLarrabee	[21062] a	\N	\N
80dd8a25-f902-423b-b7e0-a966509a97e4	2018-02-28 08:37:59.715064-06	2	[3456] IC-335A Call	[4] DLarrabee	[21062] a	\N	\N
255683e5-7cb2-48ae-8253-5bde87570b7b	2018-02-28 08:37:59.718065-06	2	[3457] IC-335A-outB Call	[4] DLarrabee	[21062] a	\N	\N
b4361b9b-fb77-4b39-98f1-b2d48cbdfbb7	2018-02-28 08:37:59.722065-06	2	[3458] IC-336A Call	[4] DLarrabee	[21062] a	\N	\N
39d9f501-f68c-4e06-baeb-a4b5ab893d0b	2018-02-28 08:37:59.727065-06	2	[3459] IC-336A-outB Call	[4] DLarrabee	[21062] a	\N	\N
1d73b0d6-feb0-4096-90f7-bff7caa55fd8	2018-02-28 08:37:59.854078-06	2	[3820] R2C3-8IC	[4] DLarrabee	[21062] a	\N	\N
67010d40-a402-4f72-993f-ad68efe77b5e	2018-02-28 08:37:59.86908-06	2	[3822] IC-337A Call Button	[4] DLarrabee	[21062] a	\N	\N
59d49741-dd0f-48d5-bff4-d5e8bdb6c40b	2018-02-28 08:37:59.884081-06	2	[3823] IC-337A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
eef93bcf-fa45-45a0-9218-2e77af06510e	2018-02-28 08:37:59.903083-06	2	[3824] IC-338A Call Button	[4] DLarrabee	[21062] a	\N	\N
3cf419b3-f0cc-4317-9d3b-94f762818719	2018-02-28 08:37:59.922085-06	2	[3825] IC-338A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
80576151-6826-4172-9524-e8823bca2397	2018-02-28 08:37:59.940087-06	2	[3826] IC-343A Call Button	[4] DLarrabee	[21062] a	\N	\N
e2f8912b-bdc4-4b22-985f-5a0ae6316b7d	2018-02-28 08:37:59.955088-06	2	[3827] IC-343A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
a58a8a97-1870-47b3-a069-fae3ba58b686	2018-02-28 08:37:59.96809-06	2	[3828] IC-344A Call Button	[4] DLarrabee	[21062] a	\N	\N
28e058ca-5eb4-4433-b46f-5869596463bc	2018-02-28 08:37:59.983091-06	2	[3829] IC-344A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
9c716877-f4fc-40ac-bf24-c452a51f5319	2018-02-28 08:38:00.000093-06	2	[3831] IC-337A Relay	[4] DLarrabee	[21062] a	\N	\N
7cbd7460-a71c-46b0-b295-d57236e28207	2018-02-28 08:38:00.015094-06	2	[3832] IC-337A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
9a9a7b66-7d7b-4867-bfc8-d67a04db6f79	2018-02-28 08:38:00.031096-06	2	[3833] IC-338A Relay	[4] DLarrabee	[21062] a	\N	\N
8539ee1e-beb6-4f87-9e70-177edd9b67d3	2018-02-28 08:38:00.050098-06	2	[3834] IC-338A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
9ddb70ad-001e-44e0-b1c6-43ce4c6ac39c	2018-02-28 08:38:00.0681-06	2	[3835] IC-343A Relay	[4] DLarrabee	[21062] a	\N	\N
a8606ff1-2313-47c2-83e3-d32fee47ce3b	2018-02-28 08:38:00.082101-06	2	[3836] IC-343A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
b5c308cd-065b-45ac-ab3a-275579cc1025	2018-02-28 08:38:00.101103-06	2	[3837] IC-344A Relay	[4] DLarrabee	[21062] a	\N	\N
871ad34b-96e7-4518-9ab7-0ff157623218	2018-02-28 08:38:00.115104-06	2	[3838] IC-344A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
4c741793-00f6-4d7d-ae24-6c70f2ce8bd8	2018-02-28 08:38:00.118105-06	2	[3840] IC-337A Connect	[4] DLarrabee	[21062] a	\N	\N
53c861be-8a0c-408f-9557-cd329b4d1da4	2018-02-28 08:38:00.121105-06	2	[3841] IC-337A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
d97aa646-7407-4fcc-bf7b-7679b781e7e7	2018-02-28 08:38:00.123105-06	2	[3842] IC-338A Connect	[4] DLarrabee	[21062] a	\N	\N
21e230cb-c794-42d8-b318-15b48e0a5fb2	2018-02-28 08:38:00.126105-06	2	[3843] IC-338A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
082122b0-0578-4263-9e37-0eeabc53620e	2018-02-28 08:38:00.130106-06	2	[3844] IC-343A Connect	[4] DLarrabee	[21062] a	\N	\N
b048c207-08bb-4961-ad7a-b0ef21589dcc	2018-02-28 08:38:00.134106-06	2	[3845] IC-343A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
7bc7c39e-e2d9-4746-a140-0a0e2c81139d	2018-02-28 08:38:00.137106-06	2	[3846] IC-344A Connect	[4] DLarrabee	[21062] a	\N	\N
b78eda9c-2860-4ad3-9820-b1505e9356dc	2018-02-28 08:38:00.140107-06	2	[3847] IC-344A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
65f63770-8ace-403d-93e4-76af7c04b8e2	2018-02-28 08:38:00.142107-06	2	[3873] IC-337A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
152a0d56-f482-4402-899e-486d717ca119	2018-02-28 08:38:00.147107-06	2	[3874] IC-337A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
57b4d320-6866-4a1e-a55b-04d22f914525	2018-02-28 08:38:00.150108-06	2	[3875] IC-338A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c49e1f90-d016-403f-8f3d-f885f78c6284	2018-02-28 08:38:00.154108-06	2	[3876] IC-338A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ad1ae164-5337-4672-a086-6db49de5c24e	2018-02-28 08:38:00.158109-06	2	[3877] IC-343A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e9d09d0f-8eb3-47b6-940a-4604aa64a4c8	2018-02-28 08:38:00.161109-06	2	[3878] IC-343A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f79a3c90-84f0-4ecc-8b95-51d8f91ef968	2018-02-28 08:38:00.164109-06	2	[3879] IC-344A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
da45703b-9e9d-4d27-84f6-1d73bc4e072d	2018-02-28 08:38:00.167109-06	2	[3880] IC-344A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
5db2bc95-1fe8-4fe4-824e-c255296bacde	2018-02-28 08:38:00.17011-06	2	[3892] IC-337A Call	[4] DLarrabee	[21062] a	\N	\N
d8decfdd-2d83-4538-ab7f-5c86170f2f7f	2018-02-28 08:38:00.17411-06	2	[3893] IC-337A-outB Call	[4] DLarrabee	[21062] a	\N	\N
fa5a5da2-3a11-4e6f-940a-9749c818a881	2018-02-28 08:38:00.17711-06	2	[3894] IC-338A Call	[4] DLarrabee	[21062] a	\N	\N
3b8eaf09-554e-4354-b6f3-2caf805a4ed8	2018-02-28 08:38:00.180111-06	2	[3895] IC-338A-outB Call	[4] DLarrabee	[21062] a	\N	\N
fac1260a-adb3-4d94-9db7-1068e02dbebf	2018-02-28 08:38:00.183111-06	2	[3896] IC-343A Call	[4] DLarrabee	[21062] a	\N	\N
687151af-8691-4e4f-a56d-ddb54e93bd6c	2018-02-28 08:38:00.186111-06	2	[3897] IC-343A-outB Call	[4] DLarrabee	[21062] a	\N	\N
7383f30a-4954-4a5d-ace7-9574293e9d19	2018-02-28 08:38:00.189112-06	2	[3898] IC-344A Call	[4] DLarrabee	[21062] a	\N	\N
3b7cdd17-1f75-4ed5-b4a7-1708ef96db1d	2018-02-28 08:38:00.193112-06	2	[3899] IC-344A-outB Call	[4] DLarrabee	[21062] a	\N	\N
27c77ff7-2bff-4ceb-bcb5-83fea0626865	2018-02-28 08:38:00.313124-06	2	[4260] R2C4-8IC	[4] DLarrabee	[21062] a	\N	\N
1eeb7078-f1d6-40b8-8500-bab140dccf0e	2018-02-28 08:38:00.327125-06	2	[4262] IC-346A Call Button	[4] DLarrabee	[21062] a	\N	\N
68470ad2-3a5e-47d3-a65e-9fdd2c613c1c	2018-02-28 08:38:00.343127-06	2	[4263] IC-346A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
ef84d3cd-8f1e-470e-82cd-ba59467d76bf	2018-02-28 08:38:00.362129-06	2	[4264] IC-347A Call Button	[4] DLarrabee	[21062] a	\N	\N
34b27b10-10fa-448f-9c54-daa8c0999e38	2018-02-28 08:38:00.379131-06	2	[4265] IC-347A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
a8c8841c-1e70-47d5-83e5-783772d91148	2018-02-28 08:38:00.394132-06	2	[4266] IC-348A Call Button	[4] DLarrabee	[21062] a	\N	\N
02cc1f2d-988d-44bf-9597-720cdbb20095	2018-02-28 08:38:00.406133-06	2	[4267] IC-348A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
6579179b-17df-4014-a1e3-aa5af1255dc1	2018-02-28 08:38:00.418135-06	2	[4268] IC-349A Call Button	[4] DLarrabee	[21062] a	\N	\N
565d6dd1-6197-4b05-b30f-b2709086adf7	2018-02-28 08:38:00.437136-06	2	[4269] IC-349A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
97fc7a4b-d3a2-4527-9317-bcd3cd8dd133	2018-02-28 08:38:00.452138-06	2	[4271] IC-346A Relay	[4] DLarrabee	[21062] a	\N	\N
503713cb-67e7-4158-abec-e4b568883c19	2018-02-28 08:38:00.464139-06	2	[4272] IC-346A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
7072ebf7-85f2-477d-bb85-b6b3ee701443	2018-02-28 08:38:00.478141-06	2	[4273] IC-347A Relay	[4] DLarrabee	[21062] a	\N	\N
9d5926c6-8d46-4c73-b5d3-085262e00dee	2018-02-28 08:38:00.491142-06	2	[4274] IC-347A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
73e51bdf-53fd-4014-8cb8-756a5437bc69	2018-02-28 08:38:00.503143-06	2	[4275] IC-348A Relay	[4] DLarrabee	[21062] a	\N	\N
f8c1363f-4430-4be9-9aa9-17afa7779209	2018-02-28 08:38:00.522145-06	2	[4276] IC-348A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
a678fdf8-489c-4c23-b0c8-ee31ca99fabc	2018-02-28 08:38:00.540147-06	2	[4277] IC-349A Relay	[4] DLarrabee	[21062] a	\N	\N
14235b59-e234-41b9-8cf3-3a9e5885f073	2018-02-28 08:38:00.556148-06	2	[4278] IC-349A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
5c7bb9ca-29e1-43f7-a211-bd1a1071af98	2018-02-28 08:38:00.559149-06	2	[4280] IC-346A Connect	[4] DLarrabee	[21062] a	\N	\N
c761c6a6-f791-4516-b8fb-66d177e03975	2018-02-28 08:38:00.563149-06	2	[4281] IC-346A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
7eee7655-e9c7-43d4-a38f-ea84a9dcfade	2018-02-28 08:38:00.566149-06	2	[4282] IC-347A Connect	[4] DLarrabee	[21062] a	\N	\N
8e9dc0eb-c52d-4f28-a695-7615a52a5822	2018-02-28 08:38:00.56915-06	2	[4283] IC-347A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
28558a54-7051-4262-97c1-a7cb299dd79e	2018-02-28 08:38:00.57215-06	2	[4284] IC-348A Connect	[4] DLarrabee	[21062] a	\N	\N
5ceb698a-8c58-463e-b41d-0c3c0f0b33dc	2018-02-28 08:38:00.57615-06	2	[4285] IC-348A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
d2da86f4-8f71-46e7-8172-260ac79f83fc	2018-02-28 08:38:00.579151-06	2	[4286] IC-349A Connect	[4] DLarrabee	[21062] a	\N	\N
ff628e28-7916-496d-a6c4-a64cba78063a	2018-02-28 08:38:00.583151-06	2	[4287] IC-349A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
ff81dbd6-f9a3-4a9b-ad14-d4fdf8da1baa	2018-02-28 08:38:00.586151-06	2	[4313] IC-346A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
eb84b414-0960-4428-9525-252a91d65f01	2018-02-28 08:38:00.590152-06	2	[4314] IC-346A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f317e08b-5ffc-4c81-930b-9d764bd21aa3	2018-02-28 08:38:00.594152-06	2	[4315] IC-347A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
aecf7480-ec96-49bb-9256-18dccd7eb5b1	2018-02-28 08:38:00.599153-06	2	[4316] IC-347A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
83123534-cb0c-437a-b4b0-d2ac70259add	2018-02-28 08:38:00.604153-06	2	[4317] IC-348A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
165bec75-9b71-496f-8345-bc6bf5c4f0f3	2018-02-28 08:38:00.607153-06	2	[4318] IC-348A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9097db22-3247-4e2a-9ba6-0c43213745ce	2018-02-28 08:38:00.611154-06	2	[4319] IC-349A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d8fc9498-734b-46c3-b6ff-7604a9146615	2018-02-28 08:38:00.617154-06	2	[4320] IC-349A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
700f0963-4aa3-43ff-aa87-2d6d3bd29b35	2018-02-28 08:38:00.620155-06	2	[4332] IC-346A Call	[4] DLarrabee	[21062] a	\N	\N
b2066cc7-935b-4583-8bda-0df6e59c8685	2018-02-28 08:38:00.623155-06	2	[4333] IC-346A-outB Call	[4] DLarrabee	[21062] a	\N	\N
36bcc66c-bc97-46c3-bbd8-b5e9067bc795	2018-02-28 08:38:00.627155-06	2	[4334] IC-347A Call	[4] DLarrabee	[21062] a	\N	\N
64f869b0-fc4f-4ffd-8c95-8d21c985f7d8	2018-02-28 08:38:00.630156-06	2	[4335] IC-347A-outB Call	[4] DLarrabee	[21062] a	\N	\N
8a8c4183-f1a7-4bac-af55-31a6a6881165	2018-02-28 08:38:00.632156-06	2	[4336] IC-348A Call	[4] DLarrabee	[21062] a	\N	\N
8530cd37-75d7-40d6-8d65-015a042e1731	2018-02-28 08:38:00.635156-06	2	[4337] IC-348A-outB Call	[4] DLarrabee	[21062] a	\N	\N
1c03e129-069c-4749-8937-7480ff1e9f22	2018-02-28 08:38:00.638157-06	2	[4338] IC-349A Call	[4] DLarrabee	[21062] a	\N	\N
604a0764-2691-4723-9970-bda5c3c159a9	2018-02-28 08:38:00.641157-06	2	[4339] IC-349A-outB Call	[4] DLarrabee	[21062] a	\N	\N
de7bf439-de3f-4705-8157-bbe1eb1c6059	2018-02-28 08:38:00.766169-06	2	[4700] R2C5-8IC	[4] DLarrabee	[21062] a	\N	\N
a74d39eb-82fa-4651-b172-f9e0d3c5bc32	2018-02-28 08:38:00.780171-06	2	[4702] IC-351A Call Button	[4] DLarrabee	[21062] a	\N	\N
44eedc0f-5301-466d-9f98-f71a7d412e58	2018-02-28 08:38:00.792172-06	2	[4703] IC-351A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
95051040-7839-43c5-a8f0-2528ed4b0217	2018-02-28 08:38:00.805173-06	2	[4704] IC-351B Call Button	[4] DLarrabee	[21062] a	\N	\N
8eb29c1d-f532-4f43-8b5b-5eaf081ed401	2018-02-28 08:38:00.824175-06	2	[4705] IC-351B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
d8233131-9719-4081-bd7e-ca27e37e3d50	2018-02-28 08:38:00.839177-06	2	[4706] IC-352A Call Button	[4] DLarrabee	[21062] a	\N	\N
bc9b4708-9e3e-40cb-a304-7768d4445e70	2018-02-28 08:38:00.853178-06	2	[4707] IC-352A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
3e940ebc-f014-4e03-ba8d-789a6e33d92f	2018-02-28 08:38:00.867179-06	2	[4708] IC-405A Call Button	[4] DLarrabee	[21062] a	\N	\N
184fd4f3-e676-4957-9828-6d48df354ade	2018-02-28 08:38:00.885181-06	2	[4709] IC-405A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
d1daea1d-cc64-4486-be0b-b09e6a598e21	2018-02-28 08:38:00.905183-06	2	[4711] IC-351A Relay	[4] DLarrabee	[21062] a	\N	\N
35d4ebd4-8b96-42f7-89e9-4653f68528a9	2018-02-28 08:38:00.924185-06	2	[4712] IC-351A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
b82e2b73-d0c3-4156-af95-984a8f5da7d0	2018-02-28 08:38:00.941187-06	2	[4713] IC-351B Relay	[4] DLarrabee	[21062] a	\N	\N
87930ee8-f4f4-4e3d-906d-417c303fa325	2018-02-28 08:38:00.954188-06	2	[4714] IC-351B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
7eced790-58c2-4305-9dfc-1a8929ca4f00	2018-02-28 08:38:00.96919-06	2	[4715] IC-352A Relay	[4] DLarrabee	[21062] a	\N	\N
d3828ddd-1ec8-4854-88ab-485a1c5147e8	2018-02-28 08:38:00.982191-06	2	[4716] IC-352A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
2c0be271-78bf-428c-9424-9683b77aba2e	2018-02-28 08:38:00.997192-06	2	[4717] IC-405A Relay	[4] DLarrabee	[21062] a	\N	\N
018b07d3-cd94-42b2-be50-a4d0df68d289	2018-02-28 08:38:01.016194-06	2	[4718] IC-405A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
872d4f56-dfe0-4ccf-bdb2-6f695987dcb0	2018-02-28 08:38:01.020195-06	2	[4720] IC-351A Connect	[4] DLarrabee	[21062] a	\N	\N
b9473487-0825-4851-9d4c-c39d466f7d1f	2018-02-28 08:38:01.024195-06	2	[4721] IC-351A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
8f9a8955-5c49-4178-8a47-b8531a09a074	2018-02-28 08:38:01.027195-06	2	[4722] IC-351B Connect	[4] DLarrabee	[21062] a	\N	\N
7daab42a-ccd5-432b-9500-2e87803a5fa6	2018-02-28 08:38:01.029196-06	2	[4723] IC-351B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
8ffbe9de-e2fd-48ad-adf8-b50459e357b6	2018-02-28 08:38:01.032196-06	2	[4724] IC-352A Connect	[4] DLarrabee	[21062] a	\N	\N
bfd51ce0-1dcb-427d-a21a-0ecdc6c01ff7	2018-02-28 08:38:01.035196-06	2	[4725] IC-352A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
786a0379-aaa0-48ca-9b34-d9a4435cf612	2018-02-28 08:38:01.039197-06	2	[4726] IC-405A Connect	[4] DLarrabee	[21062] a	\N	\N
9e1f0f89-ea3d-4b4b-9025-59b8e12516ef	2018-02-28 08:38:01.042197-06	2	[4727] IC-405A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
f62f464f-63dd-4596-871e-2235df38fb78	2018-02-28 08:38:01.046197-06	2	[4753] IC-351A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f95a2cf1-cf46-428a-94cf-c5767dc0d66d	2018-02-28 08:38:01.050198-06	2	[4754] IC-351A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6d6978d6-3411-48ee-93ce-95723995f2a1	2018-02-28 08:38:01.053198-06	2	[4755] IC-351B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
334a38f5-1f44-4b73-8d43-8fca5e14f8cc	2018-02-28 08:38:01.057198-06	2	[4756] IC-351B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3a8c8c5a-b335-4376-8bc0-a25adf4a3534	2018-02-28 08:38:01.061199-06	2	[4757] IC-352A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
15363011-7173-4e8c-a66d-4bdb0a723575	2018-02-28 08:38:01.064199-06	2	[4758] IC-352A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
767b05b7-072a-41fd-b040-baf911e787d2	2018-02-28 08:38:01.067199-06	2	[4759] IC-405A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2148081d-129f-41e3-b799-887d49b67afa	2018-02-28 08:38:01.0692-06	2	[4760] IC-405A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
16d13ef9-7be8-498d-8a2c-82f1c027d5c6	2018-02-28 08:38:01.0722-06	2	[4772] IC-351A Call	[4] DLarrabee	[21062] a	\N	\N
c6c58daf-3f24-43ec-9459-bb1c4810ae58	2018-02-28 08:38:01.0752-06	2	[4773] IC-351A-outB Call	[4] DLarrabee	[21062] a	\N	\N
6412be3c-e710-4304-8d90-606e37c45ca4	2018-02-28 08:38:01.078201-06	2	[4774] IC-351B Call	[4] DLarrabee	[21062] a	\N	\N
04b2cef3-d95b-4ae2-b65a-7b3f0da56803	2018-02-28 08:38:01.081201-06	2	[4775] IC-351B-outB Call	[4] DLarrabee	[21062] a	\N	\N
eff8035e-6fb6-41b7-aa1f-ba3d60c6f91a	2018-02-28 08:38:01.084201-06	2	[4776] IC-352A Call	[4] DLarrabee	[21062] a	\N	\N
5eff1b8c-0ad3-456e-b0a1-a56503639fff	2018-02-28 08:38:01.088202-06	2	[4777] IC-352A-outB Call	[4] DLarrabee	[21062] a	\N	\N
e04ec09a-b691-464f-b693-13c064184d9f	2018-02-28 08:38:01.091202-06	2	[4778] IC-405A Call	[4] DLarrabee	[21062] a	\N	\N
d6ecbc62-78c9-4d54-97e3-b3a54064f8cf	2018-02-28 08:38:01.094202-06	2	[4779] IC-405A-outB Call	[4] DLarrabee	[21062] a	\N	\N
94606c44-d444-4af1-9589-e53038d21525	2018-02-28 08:38:01.210214-06	2	[5140] R2C6-8IC	[4] DLarrabee	[21062] a	\N	\N
56ff47eb-166e-4e01-9cf5-f66f19d46c99	2018-02-28 08:38:01.226215-06	2	[5142] IC-414A Call Button	[4] DLarrabee	[21062] a	\N	\N
8888ca4f-6283-4a15-abcc-f4e67f86b960	2018-02-28 08:38:01.245217-06	2	[5143] IC-414A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
20ff18be-9ae2-40a5-b2bd-b214717181f6	2018-02-28 08:38:01.265219-06	2	[5144] IC-414B Call Button	[4] DLarrabee	[21062] a	\N	\N
f9543643-896e-499f-bb78-cfd8492e14a3	2018-02-28 08:38:01.279221-06	2	[5145] IC-414B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
eabb1337-fc34-4713-b9c4-3ad1ee2a3011	2018-02-28 08:38:01.295222-06	2	[5146] IC-422A Call Button	[4] DLarrabee	[21062] a	\N	\N
7d7659b7-b033-4db2-93af-c4ca901c6276	2018-02-28 08:38:01.313224-06	2	[5147] IC-422A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
3e086884-d43e-4bb5-aea0-e6915de18126	2018-02-28 08:38:01.326225-06	2	[5148] IC-422B Call Button	[4] DLarrabee	[21062] a	\N	\N
83a713c7-7bba-4027-826d-e143fdb8b79c	2018-02-28 08:38:01.342227-06	2	[5149] IC-422B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
94d641a2-ac1e-4637-b6de-13351d6c0b03	2018-02-28 08:38:01.353228-06	2	[5151] IC-414A Relay	[4] DLarrabee	[21062] a	\N	\N
3f103c5e-5412-4d72-a0af-33c9c4651529	2018-02-28 08:38:01.37023-06	2	[5152] IC-414A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
4b406ff1-10db-4d4f-9899-c74a17829434	2018-02-28 08:38:01.387231-06	2	[5153] IC-414B Relay	[4] DLarrabee	[21062] a	\N	\N
fa4275e3-9f4c-48eb-8c6c-24dcee6bb888	2018-02-28 08:38:01.406233-06	2	[5154] IC-414B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
45d07b8f-e4dc-442b-9e5a-af46fbaf695f	2018-02-28 08:38:01.424235-06	2	[5155] IC-422A Relay	[4] DLarrabee	[21062] a	\N	\N
7710f780-8be7-4eb9-9ad8-62511f42e178	2018-02-28 08:38:01.440237-06	2	[5156] IC-422A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
89d2289c-212b-4e99-a22b-1469aee8a7e3	2018-02-28 08:38:01.457238-06	2	[5157] IC-422B Relay	[4] DLarrabee	[21062] a	\N	\N
d84074b3-8ec7-4d15-b308-92ddd2e5ace2	2018-02-28 08:38:01.47224-06	2	[5158] IC-422B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
0cebf4fc-6f6c-478d-b912-ba1b78312177	2018-02-28 08:38:01.47624-06	2	[5160] IC-414A Connect	[4] DLarrabee	[21062] a	\N	\N
d6e3a7a0-9ebd-4fd5-9f19-6bd71ccbd66f	2018-02-28 08:38:01.478241-06	2	[5161] IC-414A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
8b28934d-94df-4494-af1f-df9a95904a8d	2018-02-28 08:38:01.482241-06	2	[5162] IC-414B Connect	[4] DLarrabee	[21062] a	\N	\N
aa54e978-9582-42c5-835a-f4268c24a95f	2018-02-28 08:38:01.485241-06	2	[5163] IC-414B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
d7d9a9d2-802f-432f-a61e-d347179813fa	2018-02-28 08:38:01.488242-06	2	[5164] IC-422A Connect	[4] DLarrabee	[21062] a	\N	\N
ef6adc38-227d-4380-a49a-9ab8ea67f917	2018-02-28 08:38:01.493242-06	2	[5165] IC-422A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
a068659b-5c39-4a99-bc97-4331cdd02287	2018-02-28 08:38:01.496242-06	2	[5166] IC-422B Connect	[4] DLarrabee	[21062] a	\N	\N
ea3cadb3-2fb9-4793-b21b-3b580eb5bc53	2018-02-28 08:38:01.500243-06	2	[5167] IC-422B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
3aff06eb-0d36-487d-b08c-bc8446e6b743	2018-02-28 08:38:01.503243-06	2	[5193] IC-414A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3c0f1e0a-9aca-47b3-a93c-4e65b08d6749	2018-02-28 08:38:01.507243-06	2	[5194] IC-414A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3c49af48-f8fd-46a7-b960-71e23f8555f2	2018-02-28 08:38:01.511244-06	2	[5195] IC-414B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6761fd86-4a3a-4608-afbb-f461092af634	2018-02-28 08:38:01.514244-06	2	[5196] IC-414B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
11b0a40e-dcda-4e73-947d-81568a9bf2f4	2018-02-28 08:38:01.518245-06	2	[5197] IC-422A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
599826e7-f890-45db-91fb-063ff6518489	2018-02-28 08:38:01.522245-06	2	[5198] IC-422A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e815b00e-b9da-4166-9c8e-0ac912fd43b1	2018-02-28 08:38:01.526245-06	2	[5199] IC-422B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
584571ca-74a6-444d-b184-a10d415458da	2018-02-28 08:38:01.530246-06	2	[5200] IC-422B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fc7d3e28-17cb-4276-8671-5f1ba88eb896	2018-02-28 08:38:01.534246-06	2	[5212] IC-414A Call	[4] DLarrabee	[21062] a	\N	\N
f5fd1c28-b2d6-43e8-8799-560950b40ae6	2018-02-28 08:38:01.538247-06	2	[5213] IC-414A-outB Call	[4] DLarrabee	[21062] a	\N	\N
248257b9-72ef-4ddd-89e5-81f62d6781a7	2018-02-28 08:38:01.542247-06	2	[5214] IC-414B Call	[4] DLarrabee	[21062] a	\N	\N
d469dba9-f06a-49e7-a7c8-15078ecc45ac	2018-02-28 08:38:01.545247-06	2	[5215] IC-414B-outB Call	[4] DLarrabee	[21062] a	\N	\N
c442dd9f-08da-4cda-86c0-78f088d27461	2018-02-28 08:38:01.549248-06	2	[5216] IC-422A Call	[4] DLarrabee	[21062] a	\N	\N
6b84d67f-24f2-4120-a428-8ba7a3363f52	2018-02-28 08:38:01.552248-06	2	[5217] IC-422A-outB Call	[4] DLarrabee	[21062] a	\N	\N
1c8c6f81-4729-4136-9ec7-36def0f36947	2018-02-28 08:38:01.556248-06	2	[5218] IC-422B Call	[4] DLarrabee	[21062] a	\N	\N
a695ced1-a07f-46b8-8c97-70bec5e0ce0d	2018-02-28 08:38:01.560249-06	2	[5219] IC-422B-outB Call	[4] DLarrabee	[21062] a	\N	\N
1e19814f-2d74-488b-8bd1-7b16da991a07	2018-02-28 08:38:01.684261-06	2	[5580] R2C7-8IC	[4] DLarrabee	[21062] a	\N	\N
48cff619-179e-45cd-b993-6c5fd4e66fd8	2018-02-28 08:38:01.699263-06	2	[5582] IC-438A Call Button	[4] DLarrabee	[21062] a	\N	\N
957a4929-8d46-4700-a681-13b121f81bee	2018-02-28 08:38:01.716264-06	2	[5583] IC-438A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
8e9b628e-c144-42fd-8497-191f01202710	2018-02-28 08:38:01.733266-06	2	[5584] IC-439A Call Button	[4] DLarrabee	[21062] a	\N	\N
71f72bc5-a0a3-43fe-8de3-fe51e976904f	2018-02-28 08:38:01.748268-06	2	[5585] IC-439A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
ef7b9037-1314-46ca-928d-0b7574eeb7fe	2018-02-28 08:38:01.761269-06	2	[5586] IC-443A Call Button	[4] DLarrabee	[21062] a	\N	\N
9866c2f4-8e7d-40b8-9077-eed61fab6d18	2018-02-28 08:38:01.77627-06	2	[5587] IC-443A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
a74bcc3d-f340-4300-96c4-e1631574567b	2018-02-28 08:38:01.791272-06	2	[5588] IC-443B Call Button	[4] DLarrabee	[21062] a	\N	\N
b1b65f9a-e731-4637-aeda-ba4c72920231	2018-02-28 08:38:01.805273-06	2	[5589] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
4475af5e-6709-4916-91f6-f1320a659fb6	2018-02-28 08:38:01.821275-06	2	[5591] IC-438A Relay	[4] DLarrabee	[21062] a	\N	\N
d1c8675d-25e5-45b6-9845-cb08062ffb57	2018-02-28 08:38:01.839277-06	2	[5592] IC-438A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
ad5cca84-509e-4eb7-b91d-500df1f5275b	2018-02-28 08:38:01.857278-06	2	[5593] IC-439A Relay	[4] DLarrabee	[21062] a	\N	\N
04cb7a28-8099-4c39-be09-1c817635396e	2018-02-28 08:38:01.87628-06	2	[5594] IC-439A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
a54ab875-291c-4af8-a275-2529fe6af94b	2018-02-28 08:38:01.892282-06	2	[5595] IC-443A Relay	[4] DLarrabee	[21062] a	\N	\N
355b75aa-2f81-489e-9ac1-e080479051f8	2018-02-28 08:38:01.909284-06	2	[5596] IC-443A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
eabbd778-85d8-4f9c-945d-22700d81e73f	2018-02-28 08:38:01.921285-06	2	[5597] IC-443B Relay	[4] DLarrabee	[21062] a	\N	\N
e54cce88-a333-4a3b-a437-1f5a2bed5daa	2018-02-28 08:38:01.937286-06	2	[5598] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
a6a6cc8d-b429-4ac0-bcf2-a1c0a984ab24	2018-02-28 08:38:01.940287-06	2	[5600] IC-438A Connect	[4] DLarrabee	[21062] a	\N	\N
90e8a76e-c85e-49ff-91b0-a389898fa5df	2018-02-28 08:38:01.943287-06	2	[5601] IC-438A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
460c50f2-0cc4-4f03-847f-59b6f7a55c4c	2018-02-28 08:38:01.946287-06	2	[5602] IC-439A Connect	[4] DLarrabee	[21062] a	\N	\N
9f1952f1-7379-4205-958d-e826782ae586	2018-02-28 08:38:01.950288-06	2	[5603] IC-439A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
702621fe-193b-47e7-8554-f4a02952eed2	2018-02-28 08:38:01.953288-06	2	[5604] IC-443A Connect	[4] DLarrabee	[21062] a	\N	\N
c357224f-be82-4404-91a2-c4b66a4b26b4	2018-02-28 08:38:01.955288-06	2	[5605] IC-443A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
dc6d347d-e45e-4be3-81b3-200c2c0a0a70	2018-02-28 08:38:01.958289-06	2	[5606] IC-443B Connect	[4] DLarrabee	[21062] a	\N	\N
7c25a2c9-1fd5-4108-b813-6b4bd22bcf9f	2018-02-28 08:38:01.962289-06	2	[5607] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
91599add-fd3b-4b07-9781-1938ed320fa9	2018-02-28 08:38:01.965289-06	2	[5633] IC-438A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
50c27162-711f-4fb6-a728-70633aa0a651	2018-02-28 08:38:01.96829-06	2	[5634] IC-438A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
76f996fa-35bb-4d68-9456-ac71f9445e7f	2018-02-28 08:38:01.97129-06	2	[5635] IC-439A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
35f825bc-d434-4468-baca-988c0b096264	2018-02-28 08:38:01.97529-06	2	[5636] IC-439A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
5c0d97b4-96a0-4312-81cc-f0a360111855	2018-02-28 08:38:01.978291-06	2	[5637] IC-443A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
130c753d-3802-4f9a-9927-e243ed79e9de	2018-02-28 08:38:01.981291-06	2	[5638] IC-443A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8e8a28e0-c578-4ffd-a50a-bb2081c924c4	2018-02-28 08:38:01.984291-06	2	[5639] IC-443B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2111bdae-e1b0-48b2-b190-e5fb405b17df	2018-02-28 08:38:01.988292-06	2	[5640] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
804f4677-dde2-4d05-a17c-1c3d32f07b7d	2018-02-28 08:38:01.991292-06	2	[5652] IC-438A Call	[4] DLarrabee	[21062] a	\N	\N
1ddab802-9c1c-456e-829c-1e9a6f3e6448	2018-02-28 08:38:01.995292-06	2	[5653] IC-438A-outB Call	[4] DLarrabee	[21062] a	\N	\N
a9e981f6-0d1a-48a5-ad0e-5d5c4f732a7d	2018-02-28 08:38:01.998293-06	2	[5654] IC-439A Call	[4] DLarrabee	[21062] a	\N	\N
2ec41304-d475-4503-849d-e8b34ad293c5	2018-02-28 08:38:02.001293-06	2	[5655] IC-439A-outB Call	[4] DLarrabee	[21062] a	\N	\N
31b43435-3b68-4407-8f9c-edc1ba7a97f3	2018-02-28 08:38:02.004293-06	2	[5656] IC-443A Call	[4] DLarrabee	[21062] a	\N	\N
9a2b26b5-3341-43c8-9c56-d339055770d5	2018-02-28 08:38:02.007293-06	2	[5657] IC-443A-outB Call	[4] DLarrabee	[21062] a	\N	\N
94c0ed0e-ae5c-449c-8b0e-c3a745000f56	2018-02-28 08:38:02.010294-06	2	[5658] IC-443B Call	[4] DLarrabee	[21062] a	\N	\N
d44b587a-e238-4128-a21a-30277cb784c5	2018-02-28 08:38:02.013294-06	2	[5659] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
174487b4-774c-4f30-8c43-49acd6e4488e	2018-02-28 08:38:02.157308-06	2	[6020] R3C1-8IC	[4] DLarrabee	[21062] a	\N	\N
b00dad46-b416-4f79-9327-eb8af800fb26	2018-02-28 08:38:02.17731-06	2	[6022] IC-443B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
1b8673c8-d0b3-49b4-b32a-98631fd26369	2018-02-28 08:38:02.197312-06	2	[6023] IC-444A Call Button	[4] DLarrabee	[21062] a	\N	\N
8409d5d0-cbf8-4641-b4df-5b2e63a931a1	2018-02-28 08:38:02.211314-06	2	[6024] IC-444A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
230569cb-e37e-41b7-a10e-4f4ccf1ec49b	2018-02-28 08:38:02.226315-06	2	[6025] IC-444B Call Button	[4] DLarrabee	[21062] a	\N	\N
24bc13f1-d520-436b-83ef-2f58bc4d5f25	2018-02-28 08:38:02.244317-06	2	[6026] IC-444B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
7d4ea3e0-766d-4735-9a0c-7987a0d3329c	2018-02-28 08:38:02.257318-06	2	[6027] IC-447A Call Button	[4] DLarrabee	[21062] a	\N	\N
7f1258d3-ad0f-4ea6-800f-eb1dcaca4a5f	2018-02-28 08:38:02.27332-06	2	[6028] IC-447A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
e8945eed-f553-4e4c-9fb9-fe843011f1fc	2018-02-28 08:38:02.290322-06	2	[6029] IC-447B Call Button	[4] DLarrabee	[21062] a	\N	\N
fe594e15-a8fa-493f-a529-ae2133515ee0	2018-02-28 08:38:02.304323-06	2	[6031] IC-443B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
9ad1a843-33be-4ddd-a3b3-81edc09ff4fe	2018-02-28 08:38:02.319325-06	2	[6032] IC-444A Relay	[4] DLarrabee	[21062] a	\N	\N
19397b5a-0b42-4f85-b76c-94eddd066df0	2018-02-28 08:38:02.334326-06	2	[6033] IC-444A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
7eda4698-3ec9-426b-a097-c13203f2102d	2018-02-28 08:38:02.352328-06	2	[6034] IC-444B Relay	[4] DLarrabee	[21062] a	\N	\N
734e7d6f-dad6-4a04-8798-2315d1baca8f	2018-02-28 08:38:02.366329-06	2	[6035] IC-444B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
bd2fb235-c623-490f-8fa1-ca05ca235aeb	2018-02-28 08:38:02.385331-06	2	[6036] IC-447A Relay	[4] DLarrabee	[21062] a	\N	\N
c89aae02-8e65-4e97-b0d3-1c603df6f45b	2018-02-28 08:38:02.405333-06	2	[6037] IC-447A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
274f3053-6c4c-4f4b-9355-09b11b3aa47e	2018-02-28 08:38:02.424335-06	2	[6038] IC-447B Relay	[4] DLarrabee	[21062] a	\N	\N
6646f9c4-2036-46ba-b874-f644fa9eacab	2018-02-28 08:38:02.428336-06	2	[6040] IC-443B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
acd8597d-77b3-491f-984d-8cb5554b2dc2	2018-02-28 08:38:02.432336-06	2	[6041] IC-444A Connect	[4] DLarrabee	[21062] a	\N	\N
9f2d03c5-c2dc-4dff-83f3-384f5c5a6bb8	2018-02-28 08:38:02.436336-06	2	[6042] IC-444A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
8f39e3c7-3d1c-4e29-b799-8ab3d89f83f6	2018-02-28 08:38:02.440337-06	2	[6043] IC-444B Connect	[4] DLarrabee	[21062] a	\N	\N
bf3a94f6-c707-492f-a7ba-1caa892d13a1	2018-02-28 08:38:02.444337-06	2	[6044] IC-444B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
229ec178-c4ea-411b-86ac-2a38317b2a59	2018-02-28 08:38:02.448338-06	2	[6045] IC-447A Connect	[4] DLarrabee	[21062] a	\N	\N
752ab55c-7e0b-4627-8e57-059671289ecd	2018-02-28 08:38:02.452338-06	2	[6046] IC-447A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
c5663eed-d9b4-43aa-a00f-e04ac37db78c	2018-02-28 08:38:02.455338-06	2	[6047] IC-447B Connect	[4] DLarrabee	[21062] a	\N	\N
fbd79a9c-f407-44cb-bc83-9cf79aa7cb7f	2018-02-28 08:38:02.458339-06	2	[6073] IC-443B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cc4a5bb0-bd17-4db6-9c10-8a48fc1c7d63	2018-02-28 08:38:02.461339-06	2	[6074] IC-444A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e94fcc01-0959-48f4-b9f7-0378a841653a	2018-02-28 08:38:02.464339-06	2	[6075] IC-444A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e4357725-759b-4c01-a0a7-39aa9163f830	2018-02-28 08:38:02.46834-06	2	[6076] IC-444B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2a8c9eda-eec7-4ac3-a7b2-827d8715f216	2018-02-28 08:38:02.47234-06	2	[6077] IC-444B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
942e35e5-11db-4924-bc39-932daca337ef	2018-02-28 08:38:02.47534-06	2	[6078] IC-447A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
db7aef93-0722-49b5-9597-3c2fc5761cdd	2018-02-28 08:38:02.478341-06	2	[6079] IC-447A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c02b3aec-5a06-4ad3-807a-35d71247072d	2018-02-28 08:38:02.481341-06	2	[6080] IC-447B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
34973709-d826-441b-9968-8bd2b5edd2ef	2018-02-28 08:38:02.484341-06	2	[6092] IC-443B-outB Call	[4] DLarrabee	[21062] a	\N	\N
dacc3e12-4218-4886-9a32-d62c4cf6465a	2018-02-28 08:38:02.487341-06	2	[6093] IC-444A Call	[4] DLarrabee	[21062] a	\N	\N
dbc87629-87d9-4099-97a8-93d9981809ae	2018-02-28 08:38:02.491342-06	2	[6094] IC-444A-outB Call	[4] DLarrabee	[21062] a	\N	\N
7ff7b169-dbfb-4b10-9057-4c6e022ff6a4	2018-02-28 08:38:02.493342-06	2	[6095] IC-444B Call	[4] DLarrabee	[21062] a	\N	\N
afff0b2f-58ec-40e6-9868-51c25dd6105d	2018-02-28 08:38:02.496342-06	2	[6096] IC-444B-outB Call	[4] DLarrabee	[21062] a	\N	\N
608efab6-e4a4-421f-9c8e-60a50e16e5c9	2018-02-28 08:38:02.500343-06	2	[6097] IC-447A Call	[4] DLarrabee	[21062] a	\N	\N
ed4de1af-52e5-464c-af79-dc9f80b9358d	2018-02-28 08:38:02.504343-06	2	[6098] IC-447A-outB Call	[4] DLarrabee	[21062] a	\N	\N
47b0315e-3d91-4833-a803-e857f2982cf2	2018-02-28 08:38:02.507343-06	2	[6099] IC-447B Call	[4] DLarrabee	[21062] a	\N	\N
99cdc431-257a-4546-850f-64e166c9a4f5	2018-02-28 08:38:02.625355-06	2	[6460] R3C2-8IC	[4] DLarrabee	[21062] a	\N	\N
07eaa3ef-50a7-4008-95da-ce7b8da81c61	2018-02-28 08:38:02.644357-06	2	[6462] IC-447B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
8d4ad009-83b0-41b8-a6ba-593e6be7906d	2018-02-28 08:38:02.656358-06	2	[6463] IC-448A Call Button	[4] DLarrabee	[21062] a	\N	\N
320ae2eb-00a2-4ea1-95b5-e136ab99875e	2018-02-28 08:38:02.66936-06	2	[6464] IC-448A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
9e4b58ca-8d8a-4a0f-857a-876bdeb5f97f	2018-02-28 08:38:02.684361-06	2	[6465] IC-455A Call Button	[4] DLarrabee	[21062] a	\N	\N
2576f237-6c08-4479-9c9d-8a6dd6bd4a44	2018-02-28 08:38:02.697362-06	2	[6466] IC-455A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
e248c02f-d686-46ce-b6f2-6287c75b9731	2018-02-28 08:38:02.709364-06	2	[6467] IC-455B Call Button	[4] DLarrabee	[21062] a	\N	\N
955982ce-c92d-478e-86a4-08e477e542bd	2018-02-28 08:38:02.728366-06	2	[6468] IC-455B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
b9ab1156-b8ef-48fb-879b-e714061c34fd	2018-02-28 08:38:02.744367-06	2	[6469] IC-455D Call Button	[4] DLarrabee	[21062] a	\N	\N
fbbc3249-1987-45c2-a9ec-1d3d6e31263e	2018-02-28 08:38:02.761369-06	2	[6471] IC-447B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
b50b8038-89b6-4187-a54b-cb16bce340e2	2018-02-28 08:38:02.77537-06	2	[6472] IC-448A Relay	[4] DLarrabee	[21062] a	\N	\N
00eb9927-ec57-46c8-b07b-b210aadd640a	2018-02-28 08:38:02.794372-06	2	[6473] IC-448A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
e9afdeba-dcc1-4888-8f0c-b27e2bd384f1	2018-02-28 08:38:02.811374-06	2	[6474] IC-455A Relay	[4] DLarrabee	[21062] a	\N	\N
f924dd0e-1f35-446c-9a09-e9efecdb6b0a	2018-02-28 08:38:02.830376-06	2	[6475] IC-455A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
aa0b49b5-14a0-4147-b89f-b3b3355165c8	2018-02-28 08:38:02.846377-06	2	[6476] IC-455B Relay	[4] DLarrabee	[21062] a	\N	\N
2195aa33-7ac5-49fa-87e6-cbb993a6d277	2018-02-28 08:38:02.865379-06	2	[6477] IC-455B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
188860f6-eeaa-4553-a05e-67668d22cbe9	2018-02-28 08:38:02.882381-06	2	[6478] IC-455D Relay	[4] DLarrabee	[21062] a	\N	\N
7dfb65c3-303f-4a8d-beaa-cdcd046cbff4	2018-02-28 08:38:02.885381-06	2	[6480] IC-447B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
02b2ad13-1db4-4e9c-ae06-94a7471078ba	2018-02-28 08:38:02.889382-06	2	[6481] IC-448A Connect	[4] DLarrabee	[21062] a	\N	\N
ffc739bf-d403-472b-a7f0-b597021bbbcd	2018-02-28 08:38:02.892382-06	2	[6482] IC-448A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
42e69cdb-9e15-4033-b5d1-36f964cd9f10	2018-02-28 08:38:02.896382-06	2	[6483] IC-455A Connect	[4] DLarrabee	[21062] a	\N	\N
73dfaf08-f0b5-47d8-ab28-d2492a03bd68	2018-02-28 08:38:02.900383-06	2	[6484] IC-455A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
7e3c00c3-45dd-44a6-9946-3045dcf4f870	2018-02-28 08:38:02.903383-06	2	[6485] IC-455B Connect	[4] DLarrabee	[21062] a	\N	\N
aff41ac8-02b0-4218-9558-3bafe5936edc	2018-02-28 08:38:02.907383-06	2	[6486] IC-455B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
3fae09c2-73dd-444c-9c49-4756b5a5f0f4	2018-02-28 08:38:02.910384-06	2	[6487] IC-455D Connect	[4] DLarrabee	[21062] a	\N	\N
213d07e5-c907-4c37-861a-b04e1bdcfdb2	2018-02-28 08:38:02.913384-06	2	[6513] IC-447B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
392e18b0-6b90-465e-a487-dc1b5b4ef372	2018-02-28 08:38:02.916384-06	2	[6514] IC-448A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
84e5e767-da7a-4291-aa63-a700e0e8e615	2018-02-28 08:38:02.920385-06	2	[6515] IC-448A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2cde1c63-3d56-487a-abfb-87250a469b0c	2018-02-28 08:38:02.923385-06	2	[6516] IC-455A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
98df24d0-cacd-4c9e-8a7d-ecfde54eee5d	2018-02-28 08:38:02.927385-06	2	[6517] IC-455A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
13f7f283-b572-4452-92cd-e5c4d8a2bece	2018-02-28 08:38:02.930386-06	2	[6518] IC-455B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2cfddf72-5edb-4881-b581-272f5d7c1431	2018-02-28 08:38:02.934386-06	2	[6519] IC-455B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8561d7cf-9ee4-4e65-9981-da907c8eb56c	2018-02-28 08:38:02.938387-06	2	[6520] IC-455D Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f740279d-ed10-4717-90df-6281204ae669	2018-02-28 08:38:02.941387-06	2	[6532] IC-447B-outB Call	[4] DLarrabee	[21062] a	\N	\N
16ebcfc2-619a-4ab2-a5ee-0e49949f93cd	2018-02-28 08:38:02.945387-06	2	[6533] IC-448A Call	[4] DLarrabee	[21062] a	\N	\N
cc19aac4-a869-4443-852f-15e4e2bfedec	2018-02-28 08:38:02.948388-06	2	[6534] IC-448A-outB Call	[4] DLarrabee	[21062] a	\N	\N
af13fe31-8286-4507-88c4-bb8bbfb1feb5	2018-02-28 08:38:02.952388-06	2	[6535] IC-455A Call	[4] DLarrabee	[21062] a	\N	\N
828b6a49-d3b2-4bb4-9623-ebf275ba827d	2018-02-28 08:38:02.955388-06	2	[6536] IC-455A-outB Call	[4] DLarrabee	[21062] a	\N	\N
78d23bc7-373a-49cd-819f-1b87094dd109	2018-02-28 08:38:02.959389-06	2	[6537] IC-455B Call	[4] DLarrabee	[21062] a	\N	\N
effdea55-738b-44f5-bbe6-fb7e1cd0da12	2018-02-28 08:38:02.962389-06	2	[6538] IC-455B-outB Call	[4] DLarrabee	[21062] a	\N	\N
38ffb9b3-10da-4ad3-9445-e194c62a9353	2018-02-28 08:38:02.965389-06	2	[6539] IC-455D Call	[4] DLarrabee	[21062] a	\N	\N
9b63039e-1525-4fa3-894c-905c71e15094	2018-02-28 08:38:03.085401-06	2	[6900] R3C3-8IC	[4] DLarrabee	[21062] a	\N	\N
221c0b40-3787-4e50-8799-9a2022102629	2018-02-28 08:38:03.098403-06	2	[6902] IC-455D-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
f9aa7345-476b-4174-aae2-1a4f127257e5	2018-02-28 08:38:03.112404-06	2	[6903] IC-316B Call Button	[4] DLarrabee	[21062] a	\N	\N
1c6a5b80-a2dd-46da-aef5-63ac5e23d478	2018-02-28 08:38:03.126405-06	2	[6904] IC-316B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
e5e101c5-cadb-4b58-92e8-42e4eeb40b75	2018-02-28 08:38:03.143407-06	2	[6905] IC-326A Call Button	[4] DLarrabee	[21062] a	\N	\N
d167fe3c-4002-4ed3-8a23-f4031e9b116b	2018-02-28 08:38:03.161409-06	2	[6906] IC-326A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
1cf3ece8-ee20-4fb8-b865-978890c493e0	2018-02-28 08:38:03.17441-06	2	[6907] IC-327A Call Button	[4] DLarrabee	[21062] a	\N	\N
66387084-6fca-4cb7-a739-cf5c99ea1ce2	2018-02-28 08:38:03.190412-06	2	[6908] IC-327A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
38d0bea2-a882-48e4-bdb8-eeaaf8dc49bb	2018-02-28 08:38:03.207413-06	2	[6909] IC-329A Call Button	[4] DLarrabee	[21062] a	\N	\N
29012d96-22bf-4d59-a2d5-7e35d3f424d0	2018-02-28 08:38:03.221415-06	2	[6911] IC-455D-outB Relay	[4] DLarrabee	[21062] a	\N	\N
232defd3-f788-48df-9cd4-497b2acedb92	2018-02-28 08:38:03.235416-06	2	[6912] IC-316B Relay	[4] DLarrabee	[21062] a	\N	\N
cda93c2d-c0f2-4aa9-9027-a90ba17a6f71	2018-02-28 08:38:03.252418-06	2	[6913] IC-316B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
1ac62f52-dfcc-48b9-83e3-a6a7f87290df	2018-02-28 08:38:03.27142-06	2	[6914] IC-326A Relay	[4] DLarrabee	[21062] a	\N	\N
aad01469-205b-4969-8278-fc7adfcd05aa	2018-02-28 08:38:03.286421-06	2	[6915] IC-326A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
81d5f1c1-d18a-4571-9e22-10bd71dcdb6d	2018-02-28 08:38:03.300423-06	2	[6916] IC-327A Relay	[4] DLarrabee	[21062] a	\N	\N
5f327392-8d69-434d-85a8-67715483acff	2018-02-28 08:38:03.316424-06	2	[6917] IC-327A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
74e421fd-4cc3-4c03-a9f6-886dcacb7f99	2018-02-28 08:38:03.336426-06	2	[6918] IC-329A Relay	[4] DLarrabee	[21062] a	\N	\N
4416c331-ce28-4e1f-9e00-3c46c8f7d9e0	2018-02-28 08:38:03.339427-06	2	[6920] IC-455D-outB Connect	[4] DLarrabee	[21062] a	\N	\N
18bbc61a-a0b9-424e-a151-4cfaa2c63029	2018-02-28 08:38:03.343427-06	2	[6921] IC-316B Connect	[4] DLarrabee	[21062] a	\N	\N
22b41bf8-6dfd-44c7-a825-240b0cd47ae0	2018-02-28 08:38:03.346427-06	2	[6922] IC-316B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
c999d093-f5df-4550-8675-c063bb2904bd	2018-02-28 08:38:03.350428-06	2	[6923] IC-326A Connect	[4] DLarrabee	[21062] a	\N	\N
5d6a288a-5759-4fca-9be8-d586d67752c7	2018-02-28 08:38:03.354428-06	2	[6924] IC-326A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
a441137c-b49e-4be9-88d8-165348fba6e0	2018-02-28 08:38:03.358429-06	2	[6925] IC-327A Connect	[4] DLarrabee	[21062] a	\N	\N
f522a429-1831-4225-a610-963ba5f0b758	2018-02-28 08:38:03.362429-06	2	[6926] IC-327A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
a45b2c7d-9c8c-4de4-b7d6-e49792e36d6f	2018-02-28 08:38:03.37043-06	2	[6927] IC-329A Connect	[4] DLarrabee	[21062] a	\N	\N
6a77a1ec-2534-487b-9252-5e15ca1706ca	2018-02-28 08:38:03.37443-06	2	[6953] IC-455D-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f2a92ea0-9ac9-407f-aadf-eb71217e4779	2018-02-28 08:38:03.379431-06	2	[6954] IC-316B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9fa4c043-8d78-4fb3-8533-b72f7d4c91dc	2018-02-28 08:38:03.385431-06	2	[6955] IC-316B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4a518fd7-5ecd-46f7-806f-deaaf681669b	2018-02-28 08:38:03.389432-06	2	[6956] IC-326A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8ade60d1-143f-4fcf-8b45-895012d43041	2018-02-28 08:38:03.392432-06	2	[6957] IC-326A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
348597d0-1080-481a-a12a-370d02771e1f	2018-02-28 08:38:03.396432-06	2	[6958] IC-327A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9d21adb3-aaae-42ea-b7ba-6a49ea34f7db	2018-02-28 08:38:03.400433-06	2	[6959] IC-327A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3122d14d-6066-4775-8bb5-a2f10122711a	2018-02-28 08:38:03.402433-06	2	[6960] IC-329A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3096f3ba-c61d-4164-8e63-2dcedbd00c4b	2018-02-28 08:38:03.405433-06	2	[6972] IC-455D-outB Call	[4] DLarrabee	[21062] a	\N	\N
a7adf7a5-b87c-4522-9c83-67de8d56817b	2018-02-28 08:38:03.410434-06	2	[6973] IC-316B Call	[4] DLarrabee	[21062] a	\N	\N
eb38dc08-da45-4aff-b475-50d4ebfbc452	2018-02-28 08:38:03.413434-06	2	[6974] IC-316B-outB Call	[4] DLarrabee	[21062] a	\N	\N
36f3f197-4541-4a47-ae55-dddd58ecd4cf	2018-02-28 08:38:03.417434-06	2	[6975] IC-326A Call	[4] DLarrabee	[21062] a	\N	\N
9b45fe07-f705-4790-a242-bc0fbc9475d3	2018-02-28 08:38:03.421435-06	2	[6976] IC-326A-outB Call	[4] DLarrabee	[21062] a	\N	\N
942cd4d8-ab63-4560-8665-791d085a7b43	2018-02-28 08:38:03.425435-06	2	[6977] IC-327A Call	[4] DLarrabee	[21062] a	\N	\N
5b1babcd-b62c-4581-b09a-e9540158de18	2018-02-28 08:38:03.428436-06	2	[6978] IC-327A-outB Call	[4] DLarrabee	[21062] a	\N	\N
a824680c-b90b-485d-8baa-6048ef8819ab	2018-02-28 08:38:03.433436-06	2	[6979] IC-329A Call	[4] DLarrabee	[21062] a	\N	\N
ad3b9771-abd5-462f-beb2-76b6049740af	2018-02-28 08:38:03.563449-06	2	[7340] R3C4-8IC	[4] DLarrabee	[21062] a	\N	\N
aa5ea962-9b60-412f-9987-7f535f801f45	2018-02-28 08:38:03.583451-06	2	[7342] IC-329A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
9d109318-a23d-4395-ac54-7fa347cb061b	2018-02-28 08:38:03.603453-06	2	[7343] IC-329B Call Button	[4] DLarrabee	[21062] a	\N	\N
6d50f046-28cc-4b7d-8a8e-782da76dfb63	2018-02-28 08:38:03.622455-06	2	[7344] IC-329B-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
6153a7a2-1747-4287-af84-a44d643c9aec	2018-02-28 08:38:03.637456-06	2	[7345] IC-334A Call Button	[4] DLarrabee	[21062] a	\N	\N
006d8d56-aa8a-4c00-8f04-6095b158095b	2018-02-28 08:38:03.656458-06	2	[7346] IC-334A-outB Call Button	[4] DLarrabee	[21062] a	\N	\N
35ff7c87-f48f-493b-b703-30e29e8b1423	2018-02-28 08:38:03.67346-06	2	[7347] IC-415IC Call Button	[4] DLarrabee	[21062] a	\N	\N
f5a718ba-cc23-40e8-a354-d093e0e32931	2018-02-28 08:38:03.691462-06	2	[7348] IC-418IC Call Button	[4] DLarrabee	[21062] a	\N	\N
89be9052-27f7-447a-851f-9fc33b31d147	2018-02-28 08:38:03.707463-06	2	[7349] IC-425IC Call Button	[4] DLarrabee	[21062] a	\N	\N
53af1632-dd0d-43b7-8096-43ae6a474ddb	2018-02-28 08:38:03.720465-06	2	[7351] IC-329A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
ab3a2fe3-8f0f-4ccb-9d72-ec16a3c26d9f	2018-02-28 08:38:03.740467-06	2	[7352] IC-329B Relay	[4] DLarrabee	[21062] a	\N	\N
5ceb6408-d137-492b-a428-360645b5123d	2018-02-28 08:38:03.757468-06	2	[7353] IC-329B-outB Relay	[4] DLarrabee	[21062] a	\N	\N
0b98ae12-08cb-4043-a23e-00fba8b3011b	2018-02-28 08:38:03.77247-06	2	[7354] IC-334A Relay	[4] DLarrabee	[21062] a	\N	\N
b7b9dd4b-4327-4b1a-9603-fab532bcf4bf	2018-02-28 08:38:03.786471-06	2	[7355] IC-334A-outB Relay	[4] DLarrabee	[21062] a	\N	\N
a49b0726-6a3c-4471-bf46-4b151c1677cf	2018-02-28 08:38:03.805473-06	2	[7356] IC-415IC Relay	[4] DLarrabee	[21062] a	\N	\N
c0c9db0c-d4d4-4e13-b072-c01681701cc6	2018-02-28 08:38:03.825475-06	2	[7357] IC-418IC Relay	[4] DLarrabee	[21062] a	\N	\N
3578819d-7643-47fb-a9e5-6ffc00fc50f7	2018-02-28 08:38:03.846477-06	2	[7358] IC-425IC Relay	[4] DLarrabee	[21062] a	\N	\N
dd7f6fc5-3b95-466d-86cc-0f2aa76f234e	2018-02-28 08:38:03.849478-06	2	[7360] IC-329A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
93c54f70-91d1-468a-827c-82276903a0bd	2018-02-28 08:38:03.854478-06	2	[7361] IC-329B Connect	[4] DLarrabee	[21062] a	\N	\N
eb0a9668-ae64-4a44-9774-29816c74619a	2018-02-28 08:38:03.859479-06	2	[7362] IC-329B-outB Connect	[4] DLarrabee	[21062] a	\N	\N
d8e4ad26-3f06-416d-b254-16f1ddb0cbf3	2018-02-28 08:38:03.863479-06	2	[7363] IC-334A Connect	[4] DLarrabee	[21062] a	\N	\N
53c598e7-7f57-40c1-8da5-29e6b73193d6	2018-02-28 08:38:03.86848-06	2	[7364] IC-334A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
36301edf-627d-4cad-b202-f6143a90fa91	2018-02-28 08:38:03.87248-06	2	[7365] IC-415IC Connect	[4] DLarrabee	[21062] a	\N	\N
2db98e3f-59eb-4595-b954-2682f9389523	2018-02-28 08:38:03.879481-06	2	[7366] IC-418IC Connect	[4] DLarrabee	[21062] a	\N	\N
7587245e-48e5-44c7-a560-d4fad7594a45	2018-02-28 08:38:03.883481-06	2	[7367] IC-425IC Connect	[4] DLarrabee	[21062] a	\N	\N
a86febfe-ffe3-4fc0-b978-de036edcb1b7	2018-02-28 08:38:03.887481-06	2	[7393] IC-329A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c2eea92b-abb3-4f22-9d39-43aad6dc7362	2018-02-28 08:38:03.890482-06	2	[7394] IC-329B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cf381c3d-207c-4906-80f7-cdc886febc96	2018-02-28 08:38:03.894482-06	2	[7395] IC-329B-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f750ec90-473d-4e44-91fa-250bb49d557d	2018-02-28 08:38:03.897482-06	2	[7396] IC-334A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9fc9884c-4048-462a-98cd-3005d3817da2	2018-02-28 08:38:03.901483-06	2	[7397] IC-334A-outB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b0a7a396-eb83-403b-8abe-14b265acb829	2018-02-28 08:38:03.905483-06	2	[7398] IC-415IC Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b0e6997f-1a35-4973-89c3-f1612b39d466	2018-02-28 08:38:03.909484-06	2	[7399] IC-418IC Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8cec7751-4270-4229-836f-b2cc7cf8cbbf	2018-02-28 08:38:03.912484-06	2	[7400] IC-425IC Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
76c02944-59ba-420b-9ece-5aeaac0ee0e7	2018-02-28 08:38:03.916484-06	2	[7412] IC-329A-outB Call	[4] DLarrabee	[21062] a	\N	\N
7157ece5-e5ad-4583-90f4-b800371ecada	2018-02-28 08:38:03.919485-06	2	[7413] IC-329B Call	[4] DLarrabee	[21062] a	\N	\N
6b1f12f6-9864-446d-b874-bd5417bc4a7b	2018-02-28 08:38:03.923485-06	2	[7414] IC-329B-outB Call	[4] DLarrabee	[21062] a	\N	\N
5caa7cb4-e267-47fe-851c-f435e9b91ff6	2018-02-28 08:38:03.927485-06	2	[7415] IC-334A Call	[4] DLarrabee	[21062] a	\N	\N
73996785-a057-4cd5-9b55-54221011b39a	2018-02-28 08:38:03.931486-06	2	[7416] IC-334A-outB Call	[4] DLarrabee	[21062] a	\N	\N
9a94ad90-d43f-4cf6-9604-99486bbb1d21	2018-02-28 08:38:03.936486-06	2	[7417] IC-415IC Call	[4] DLarrabee	[21062] a	\N	\N
7cd7bf07-82b3-4990-8919-831a6c9ebb77	2018-02-28 08:38:03.940487-06	2	[7418] IC-418IC Call	[4] DLarrabee	[21062] a	\N	\N
a9309fed-7149-4495-9979-7bdb1b83b608	2018-02-28 08:38:03.944487-06	2	[7419] IC-425IC Call	[4] DLarrabee	[21062] a	\N	\N
a5e28494-30c0-424c-969e-088da2c16cc8	2018-02-28 08:38:04.082501-06	2	[7780] R3C5-8IC	[4] DLarrabee	[21062] a	\N	\N
6523803b-8d18-4239-a10e-a049326d0394	2018-02-28 08:38:04.102503-06	2	[7782] IC-446IC Call Button	[4] DLarrabee	[21062] a	\N	\N
b4a4c0c3-e369-4385-b631-f241faa8e513	2018-02-28 08:38:04.142507-06	2	[7783] IC-448IC Call Button	[4] DLarrabee	[21062] a	\N	\N
d421b8b6-f2c1-4ee2-955d-ae61ea07660b	2018-02-28 08:38:04.157508-06	2	[7784] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
9ec38efe-7587-4919-8710-1b1176bb0b77	2018-02-28 08:38:04.17351-06	2	[7785] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
c88aa82d-583e-4636-a156-ac490a5caff5	2018-02-28 08:38:04.193512-06	2	[7786] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
8d9e188d-f59f-4117-b6fd-75e72f247c63	2018-02-28 08:38:04.208514-06	2	[7787] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
d2eea9f8-6979-4217-bea4-180004694e78	2018-02-28 08:38:04.221515-06	2	[7788] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
9d3a4dcf-72ea-489a-b81a-8cfbdc7c859d	2018-02-28 08:38:04.236516-06	2	[7789] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
91f884d4-aebf-49fd-be9d-ab526b53808f	2018-02-28 08:38:04.248518-06	2	[7791] IC-446IC Relay	[4] DLarrabee	[21062] a	\N	\N
49647e38-82ed-4b13-bfe2-5c7a3a119d85	2018-02-28 08:38:04.264519-06	2	[7792] IC-448IC Relay	[4] DLarrabee	[21062] a	\N	\N
01ed2483-737d-4b79-8f03-66f6b0d9c210	2018-02-28 08:38:04.278521-06	2	[7793] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
0ea652b7-14dc-4390-8eed-5bad3928455d	2018-02-28 08:38:04.298523-06	2	[7794] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
a285fa35-328b-422c-835c-525df8ebaec4	2018-02-28 08:38:04.313524-06	2	[7795] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
2147b7b4-7c73-44e5-9f92-8ac65c223caf	2018-02-28 08:38:04.325525-06	2	[7796] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
8fcb9eeb-8b51-4239-9b44-f65f135cd304	2018-02-28 08:38:04.339527-06	2	[7797] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
5f74644d-77af-4d60-bb08-4852be19b9b6	2018-02-28 08:38:04.359529-06	2	[7798] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
7696c0c8-464a-42a7-83f7-231088ffa6fb	2018-02-28 08:38:04.362529-06	2	[7800] IC-446IC Connect	[4] DLarrabee	[21062] a	\N	\N
95199862-5e3d-4e0d-b9f3-f2fb1123fa11	2018-02-28 08:38:04.365529-06	2	[7801] IC-448IC Connect	[4] DLarrabee	[21062] a	\N	\N
91fc5b88-cef9-4636-9be6-03ce53274eed	2018-02-28 08:38:04.36953-06	2	[7802] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
01588b70-2049-4629-98eb-0d4cf46c21b9	2018-02-28 08:38:04.37253-06	2	[7803] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
ba85eba9-868d-4282-bc79-f3ebd42126b6	2018-02-28 08:38:04.37653-06	2	[7804] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
bfde1388-aab5-4648-b1ac-b15f101a0d92	2018-02-28 08:38:04.378531-06	2	[7805] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
655be03e-f9f2-4a93-8151-86ffca60a1b3	2018-02-28 08:38:04.382531-06	2	[7806] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
27435ad6-1b35-42aa-959d-e138b1dd30ad	2018-02-28 08:38:04.385531-06	2	[7807] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
ae492a4f-3e53-40e1-a995-14918bdb1c54	2018-02-28 08:38:04.389532-06	2	[7833] IC-446IC Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
54f8cc11-83e5-4c0f-99db-4c81fd8e6ecf	2018-02-28 08:38:04.393532-06	2	[7834] IC-448IC Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2b2a19b5-f1c3-49e2-8f70-238648ca70fd	2018-02-28 08:38:04.397532-06	2	[7835] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
96143b87-6b37-4152-ad37-c9b4186bcbab	2018-02-28 08:38:04.401533-06	2	[7836] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d960e680-03d7-4038-a570-3ea15b5b07fc	2018-02-28 08:38:04.404533-06	2	[7837] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ac11f6f4-851a-4a72-b5b9-f7bf5bb1e7d6	2018-02-28 08:38:04.409534-06	2	[7838] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6c733718-00c8-4d8c-843d-c26d6d0a0944	2018-02-28 08:38:04.412534-06	2	[7839] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cdcc9d7d-91c4-4498-9ef5-e9e1ebec9e6b	2018-02-28 08:38:04.415534-06	2	[7840] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b0208619-aa1c-4a6f-a24c-3c18bc8019dc	2018-02-28 08:38:04.418535-06	2	[7852] IC-446IC Call	[4] DLarrabee	[21062] a	\N	\N
b44747de-5366-4755-a39e-c7e2fc69d17b	2018-02-28 08:38:04.421535-06	2	[7853] IC-448IC Call	[4] DLarrabee	[21062] a	\N	\N
ca2f6c3c-f9fe-414d-bf4e-d3bbe00ad53d	2018-02-28 08:38:04.424535-06	2	[7854] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
19728b55-2733-4b59-b689-361f9fb5ab1c	2018-02-28 08:38:04.428536-06	2	[7855] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
83ada74e-e8af-4bae-8b8b-de38fdbd5d75	2018-02-28 08:38:04.432536-06	2	[7856] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
183030eb-c71a-4d00-86f9-0ab5bd5eae1f	2018-02-28 08:38:04.436536-06	2	[7857] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
ee528b4b-d1fa-4223-b628-1e72ec5d7562	2018-02-28 08:38:04.439537-06	2	[7858] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
64598b00-1cea-4b13-93b5-2805297b2caf	2018-02-28 08:38:04.442537-06	2	[7859] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
7e58c63b-116c-4aef-85b1-bfd922803716	2018-02-28 08:41:37.715862-06	2	[1048] DPIS-326A Call Button	[4] DLarrabee	[21062] a	\N	\N
453f986d-4da6-4434-ab4c-0cb1a5881c59	2018-02-28 08:41:37.749866-06	2	[1049] DPIS-327A Call Button	[4] DLarrabee	[21062] a	\N	\N
8f894f35-22ed-494d-a6d2-174dd42d09f6	2018-02-28 08:41:37.764867-06	2	[1050] DPIS-329A Call Button	[4] DLarrabee	[21062] a	\N	\N
f89d9f31-5bc4-46e9-a3d6-3c63a1f2ccfb	2018-02-28 08:41:37.786869-06	2	[1051] DPIS-329B Call Button	[4] DLarrabee	[21062] a	\N	\N
ac31dcc7-e17c-4646-ac79-a083970a3e3e	2018-02-28 08:41:37.804871-06	2	[1052] DPIS-334A Call Button	[4] DLarrabee	[21062] a	\N	\N
d71b7f62-c336-4f74-a875-0ac192c57c2e	2018-02-28 08:41:37.819873-06	2	[1053] DPIS-335A Call Button	[4] DLarrabee	[21062] a	\N	\N
068b804c-8e8b-4da0-a078-e4577d1b2aca	2018-02-28 08:41:37.832874-06	2	[1054] DPIS-336A Call Button	[4] DLarrabee	[21062] a	\N	\N
29fbbf80-e93e-4207-974f-2ede6457bb40	2018-02-28 08:41:37.845875-06	2	[1063] DPIS-351A Call Button	[4] DLarrabee	[21062] a	\N	\N
a1442e51-9072-4cd5-bfac-1975426f4649	2018-02-28 08:41:37.860877-06	2	[1064] DPIS-351B Call Button	[4] DLarrabee	[21062] a	\N	\N
98da1e99-127b-4931-a870-ca1e4004ba8a	2018-02-28 08:41:37.875878-06	2	[1065] DPIS-352A Call Button	[4] DLarrabee	[21062] a	\N	\N
3d654c62-9795-4359-bb28-34c4cbb68fee	2018-02-28 08:41:37.88988-06	2	[1066] DPIS-405A Call Button	[4] DLarrabee	[21062] a	\N	\N
e2e0df57-c8cb-4ab1-950f-f6e36477f69f	2018-02-28 08:41:37.908881-06	2	[1067] DPIS-414A Call Button	[4] DLarrabee	[21062] a	\N	\N
29a57936-bd91-4750-8430-e1f6b8ed09ad	2018-02-28 08:41:37.924883-06	2	[1068] DPIS-414B Call Button	[4] DLarrabee	[21062] a	\N	\N
04d39611-8d40-4d92-9cb1-e9c4d17a52ea	2018-02-28 08:41:37.940885-06	2	[1069] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
f4ea1224-aaa6-45a8-bfda-e920bf970122	2018-02-28 08:41:37.959887-06	2	[1070] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
50cc65a3-0c2d-4c05-9830-b1917ab9cee4	2018-02-28 08:41:37.972888-06	2	[1071] DPIS-422A Call Button	[4] DLarrabee	[21062] a	\N	\N
78284296-0c61-4d78-9363-2da8cdc14763	2018-02-28 08:41:37.987889-06	2	[1072] DPIS-422B Call Button	[4] DLarrabee	[21062] a	\N	\N
9905840e-3228-4f95-bf2d-11a1a023feb3	2018-02-28 08:41:38.002891-06	2	[1073] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
d02d2652-5de3-49ab-a0ac-ae67f6a64eed	2018-02-28 08:41:38.019893-06	2	[1074] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
ad23f6f4-f247-444f-93ea-3017d068e731	2018-02-28 08:41:38.033894-06	2	[1075] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
0fce1c35-77ea-4449-8c38-d6134fad61a4	2018-02-28 08:41:38.064897-06	2	[1076] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
139b55a7-4bcd-4455-84b3-18abc77b1d6f	2018-02-28 08:41:38.080899-06	2	[1077] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
4bdfbe39-2164-4eb5-a6c1-550ac578c4e4	2018-02-28 08:41:38.103901-06	2	[1078] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
5bc09d4f-1ee6-47b7-9966-7ddc3a08e344	2018-02-28 08:44:42.560345-06	2	[8223] IC-134A-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
25de1809-6b96-4c72-a5ea-12286908fafd	2018-02-28 08:44:42.598349-06	2	[8232] IC-134A-InB Relay	[4] DLarrabee	[21062] a	\N	\N
ef1de0b2-fcdb-4ac6-97af-a09b3d91b391	2018-02-28 08:44:42.61535-06	2	[8233] IC-134A-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
3f82da78-63a2-4760-8a23-fe2229bbe3b0	2018-02-28 08:44:42.631352-06	2	[8234] IC-134B-InB Relay	[4] DLarrabee	[21062] a	\N	\N
38d8d2a3-55eb-4290-9ec0-4051fbcf9595	2018-02-28 08:44:42.647353-06	2	[8235] IC-134B-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
6192fad1-8c58-43d0-a7f8-8c83191974a6	2018-02-28 08:44:42.661355-06	2	[8236] IC-122-InB Relay	[4] DLarrabee	[21062] a	\N	\N
bb873ef8-649d-448f-8310-1a7df18a53fc	2018-02-28 08:44:42.678357-06	2	[8237] IC-122-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
a9ec6993-b7c5-4bf1-80d2-ae0e8225f816	2018-02-28 08:44:42.695358-06	2	[8238] IC-123-InB Relay	[4] DLarrabee	[21062] a	\N	\N
d0db335d-2bad-4d58-84d1-cb713fddc7b8	2018-02-28 08:44:42.71436-06	2	[8239] IC-123-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
c387a876-aa04-426c-b0b2-23e7a7b2ae3b	2018-02-28 08:44:42.718361-06	2	[8241] IC-134A-InB Connect	[4] DLarrabee	[21062] a	\N	\N
a7bfeae7-f61e-48e2-8584-4bd2293888b5	2018-02-28 08:44:42.722361-06	2	[8242] IC-134A-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
ad62d7b9-1365-4ff8-a6d1-15db93e0c318	2018-02-28 08:44:42.726361-06	2	[8243] IC-134B-InB Connect	[4] DLarrabee	[21062] a	\N	\N
eef35c7a-dd8b-45f0-93d7-b8d8514bad1c	2018-02-28 08:44:42.729362-06	2	[8244] IC-134B-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
631ff407-eed9-4643-bd7d-53907e9f4c3b	2018-02-28 08:44:42.733362-06	2	[8245] IC-122-InB Connect	[4] DLarrabee	[21062] a	\N	\N
7ff63ca2-6364-447c-944d-777a82af3a3a	2018-02-28 08:44:42.736362-06	2	[8246] IC-122-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
fc92533c-86ce-4962-8bde-08cd134efcf2	2018-02-28 08:44:42.741363-06	2	[8247] IC-123-InB Connect	[4] DLarrabee	[21062] a	\N	\N
1bb1b386-b194-4a0f-b961-376b1d3bca1f	2018-02-28 08:44:42.745363-06	2	[8248] IC-123-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
38f5cefb-f89f-4dc3-ae8c-e32ef8be53aa	2018-02-28 08:44:42.749364-06	2	[8274] IC-134A-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2d7e19ba-abcf-4751-957c-ea1504b66dde	2018-02-28 08:44:42.753364-06	2	[8275] IC-134A-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
222a3907-a7bc-4e05-ad89-f949b879d1ec	2018-02-28 08:44:42.756364-06	2	[8276] IC-134B-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f2502396-9394-44fc-a653-7e3d3857457b	2018-02-28 08:44:42.760365-06	2	[8277] IC-134B-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ff5c523b-3e90-40ec-b178-5798aa290a0e	2018-02-28 08:44:42.764365-06	2	[8278] IC-122-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fa5f7e0d-5367-4976-93b8-161df2d7ed43	2018-02-28 08:44:42.767365-06	2	[8279] IC-122-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6ea65e01-a24a-4983-a97c-7c0fb7b8e5c8	2018-02-28 08:44:42.771366-06	2	[8280] IC-123-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
03bb802e-5dc8-4969-bdbd-619ff3c0ffc9	2018-02-28 08:44:42.775366-06	2	[8281] IC-123-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
430877eb-9d0d-473f-b2fc-1dd5fab61490	2018-02-28 08:44:42.779367-06	2	[8293] IC-134A-InB Call	[4] DLarrabee	[21062] a	\N	\N
f7edcd66-b751-4c8d-b0d5-a9f0abbfe1b3	2018-02-28 08:44:42.783367-06	2	[8294] IC-134A-OutB Call	[4] DLarrabee	[21062] a	\N	\N
d7e7896d-9526-4591-8074-d307f9d05503	2018-02-28 08:44:42.786367-06	2	[8295] IC-134B-InB Call	[4] DLarrabee	[21062] a	\N	\N
654e04f2-3551-42ac-a171-3811d0e86382	2018-02-28 08:44:42.790368-06	2	[8296] IC-134B-OutB Call	[4] DLarrabee	[21062] a	\N	\N
cce654d6-3337-411b-a1b1-e215f73f36ff	2018-02-28 08:44:42.792368-06	2	[8297] IC-122-InB Call	[4] DLarrabee	[21062] a	\N	\N
d713d54e-46d1-4dda-9e7c-0cc2c114354b	2018-02-28 08:44:42.796368-06	2	[8298] IC-122-OutB Call	[4] DLarrabee	[21062] a	\N	\N
503de9e4-cf08-445b-8d67-d0d786af1b65	2018-02-28 08:44:42.799369-06	2	[8299] IC-123-InB Call	[4] DLarrabee	[21062] a	\N	\N
b31cece6-9684-4bea-b612-cd9613e6a208	2018-02-28 08:44:42.803369-06	2	[8300] IC-123-OutB Call	[4] DLarrabee	[21062] a	\N	\N
def61c08-627b-4ab9-913d-3cef8561b5d4	2018-02-28 08:44:42.931382-06	2	[8662] R4C2-8IC	[4] DLarrabee	[21062] a	\N	\N
4ec80233-85f5-461b-bbb6-07a91ff9d212	2018-02-28 08:44:42.947383-06	2	[8664] IC-136 Call Button	[4] DLarrabee	[21062] a	\N	\N
18551fc3-d2ea-4be5-8148-9448e0174e63	2018-02-28 08:44:42.963385-06	2	[8665] IC-137 Call Button	[4] DLarrabee	[21062] a	\N	\N
a76ed84f-5206-4e88-8c71-4ad8bf80a527	2018-02-28 08:44:42.981387-06	2	[8666] IC-138 Call Button	[4] DLarrabee	[21062] a	\N	\N
b90d94e3-9837-4b23-a94a-8b5a0c1d5a93	2018-02-28 08:44:42.996388-06	2	[8667] IC-141 Call Button	[4] DLarrabee	[21062] a	\N	\N
c67cb316-5a32-435b-9c34-eccadc13dd4c	2018-02-28 08:44:43.01039-06	2	[8668] IC-142 Call Button	[4] DLarrabee	[21062] a	\N	\N
0c5b5a3b-bc10-4797-a5a4-4455ee244e7f	2018-02-28 08:44:43.024391-06	2	[8669] IC-124 Call Button	[4] DLarrabee	[21062] a	\N	\N
86e79fe8-33bc-43a5-b433-ed3063475be2	2018-02-28 08:44:43.039393-06	2	[8670] IC-125 Call Button	[4] DLarrabee	[21062] a	\N	\N
46680fb5-e09c-4981-a341-4a6e62fdfc0c	2018-02-28 08:44:43.054394-06	2	[8671] IC-126 Call Button	[4] DLarrabee	[21062] a	\N	\N
29fca687-c578-4734-8a05-d3d0020e79ed	2018-02-28 08:44:43.071396-06	2	[8673] IC-136 Relay	[4] DLarrabee	[21062] a	\N	\N
b401e403-5fc8-4806-a751-42532f995ad5	2018-02-28 08:44:43.086397-06	2	[8674] IC-137 Relay	[4] DLarrabee	[21062] a	\N	\N
617e1b8e-3b78-44ee-8497-fda84ca6a4b1	2018-02-28 08:44:43.102399-06	2	[8675] IC-138 Relay	[4] DLarrabee	[21062] a	\N	\N
0291bc73-414d-488c-a97f-68e4bb99d9ce	2018-02-28 08:44:43.123401-06	2	[8676] IC-141 Relay	[4] DLarrabee	[21062] a	\N	\N
c788041f-b2ba-4cc3-ad19-d0552a7d14b1	2018-02-28 08:44:43.141403-06	2	[8677] IC-142 Relay	[4] DLarrabee	[21062] a	\N	\N
f2f1d20f-fedf-421d-9173-d9694332df76	2018-02-28 08:44:43.160405-06	2	[8678] IC-124 Relay	[4] DLarrabee	[21062] a	\N	\N
89b6ec9a-7999-4065-ac4b-7bc47ea97342	2018-02-28 08:44:43.178407-06	2	[8679] IC-125 Relay	[4] DLarrabee	[21062] a	\N	\N
e66a6484-b51d-4844-973a-588bd25f9d77	2018-02-28 08:44:43.194408-06	2	[8680] IC-126 Relay	[4] DLarrabee	[21062] a	\N	\N
4c000832-3909-4758-aaef-8594afe63564	2018-02-28 08:44:43.199409-06	2	[8682] IC-136 Connect	[4] DLarrabee	[21062] a	\N	\N
486e7501-0ccd-4bc4-af94-429c130d323a	2018-02-28 08:44:43.203409-06	2	[8683] IC-137 Connect	[4] DLarrabee	[21062] a	\N	\N
2a9f2055-8033-4b6b-af2a-3d4d7a2066ac	2018-02-28 08:44:43.20841-06	2	[8684] IC-138 Connect	[4] DLarrabee	[21062] a	\N	\N
96709a2d-5dd7-40fd-a714-ed7bf77db219	2018-02-28 08:44:43.21241-06	2	[8685] IC-141 Connect	[4] DLarrabee	[21062] a	\N	\N
c30cbeb0-13ea-4813-bd71-73a39e4dad90	2018-02-28 08:44:43.21641-06	2	[8686] IC-142 Connect	[4] DLarrabee	[21062] a	\N	\N
8613584e-3d00-46c0-a852-083a7c75d01f	2018-02-28 08:44:43.219411-06	2	[8687] IC-124 Connect	[4] DLarrabee	[21062] a	\N	\N
30a515d7-3a26-4278-8bea-5662cc4c7b3c	2018-02-28 08:44:43.222411-06	2	[8688] IC-125 Connect	[4] DLarrabee	[21062] a	\N	\N
b9e401e2-b3ac-4eba-9fa6-3493903686fc	2018-02-28 08:44:43.225411-06	2	[8689] IC-126 Connect	[4] DLarrabee	[21062] a	\N	\N
9887604f-064f-4e13-bbd0-c7c794ad3f9c	2018-02-28 08:44:43.227411-06	2	[8715] IC-136 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9fa6c8a8-c3b6-4f6e-a69c-081338d9adaa	2018-02-28 08:44:43.231412-06	2	[8716] IC-137 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3579cbbb-64b9-4e5e-af19-17d709b08346	2018-02-28 08:44:43.234412-06	2	[8717] IC-138 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
77bd38a5-214d-420c-bddb-b7474bc199c3	2018-02-28 08:44:43.237412-06	2	[8718] IC-141 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b287b424-3ec1-4a4f-85a2-832cbfe6b518	2018-02-28 08:44:43.240413-06	2	[8719] IC-142 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
70c67933-6926-4031-be9c-28858be4076f	2018-02-28 08:44:43.244413-06	2	[8720] IC-124 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
bccc9592-0548-49cf-b99a-a0efa95dea61	2018-02-28 08:44:43.247413-06	2	[8721] IC-125 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b2e79e15-26a3-4f61-a351-b651ed901799	2018-02-28 08:44:43.251414-06	2	[8722] IC-126 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
092c4d28-6205-44c8-b1a0-af9513ffbb32	2018-02-28 08:44:43.254414-06	2	[8734] IC-136 Call	[4] DLarrabee	[21062] a	\N	\N
8968cc00-1837-46f9-b8e7-1b5d6070da82	2018-02-28 08:44:43.256414-06	2	[8735] IC-137 Call	[4] DLarrabee	[21062] a	\N	\N
40b09a7e-e0e4-4535-8f07-b4621b3de225	2018-02-28 08:44:43.259415-06	2	[8736] IC-138 Call	[4] DLarrabee	[21062] a	\N	\N
75b0a372-ddcf-47d1-807b-287d07aa42d4	2018-02-28 08:44:43.263415-06	2	[8737] IC-141 Call	[4] DLarrabee	[21062] a	\N	\N
422344b1-b528-4a65-b821-f08b7db65702	2018-02-28 08:44:43.267415-06	2	[8738] IC-142 Call	[4] DLarrabee	[21062] a	\N	\N
45865b52-95f1-461f-9548-32aca062251d	2018-02-28 08:44:43.271416-06	2	[8739] IC-124 Call	[4] DLarrabee	[21062] a	\N	\N
a67321a2-acff-4289-a583-ad0c903bd7c5	2018-02-28 08:44:43.274416-06	2	[8740] IC-125 Call	[4] DLarrabee	[21062] a	\N	\N
b6b7b4fb-ae5a-42d2-a053-1de97862ec74	2018-02-28 08:44:43.278417-06	2	[8741] IC-126 Call	[4] DLarrabee	[21062] a	\N	\N
a696e455-7e47-48a1-847f-7a94f8851e2d	2018-02-28 08:44:43.429432-06	2	[9102] R4C3-8IC	[4] DLarrabee	[21062] a	\N	\N
93a83dc8-b62f-40a4-8cd6-f8e7e5ed322c	2018-02-28 08:44:43.448434-06	2	[9104] IC-128 Call Button	[4] DLarrabee	[21062] a	\N	\N
7e87835c-12c1-439e-8eb9-bef1e29db49d	2018-02-28 08:44:43.461435-06	2	[9105] IC-129 Call Button	[4] DLarrabee	[21062] a	\N	\N
df08cc8f-a13f-4e94-8565-7d3d823b6b87	2018-02-28 08:44:43.480437-06	2	[9106] IC-131 Call Button	[4] DLarrabee	[21062] a	\N	\N
a34aa477-f1e6-4f72-bfba-2bb8523fb335	2018-02-28 08:44:43.495438-06	2	[9107] IC-132 Call Button	[4] DLarrabee	[21062] a	\N	\N
08be0a7f-44f6-421d-8062-0db4a039a3a5	2018-02-28 08:44:43.51344-06	2	[9108] IC-115 Call Button	[4] DLarrabee	[21062] a	\N	\N
bad083d4-ce9e-4e8c-a267-2bff0edc9e64	2018-02-28 08:44:43.528442-06	2	[9109] IC-116 Call Button	[4] DLarrabee	[21062] a	\N	\N
60978938-ef48-4420-84ba-442ffe3c1c20	2018-02-28 08:44:43.543443-06	2	[9110] IC-117 Call Button	[4] DLarrabee	[21062] a	\N	\N
e41e1bc2-d1c7-446a-96d7-223f3a7024db	2018-02-28 08:44:43.559445-06	2	[9111] IC-119 Call Button	[4] DLarrabee	[21062] a	\N	\N
dd17286a-8a7e-43b0-8a1c-f0ebf76155bc	2018-02-28 08:44:43.577446-06	2	[9113] IC-128 Relay	[4] DLarrabee	[21062] a	\N	\N
d3c73223-77ec-4d57-9a30-808cf56a45a7	2018-02-28 08:44:43.592448-06	2	[9114] IC-129 Relay	[4] DLarrabee	[21062] a	\N	\N
a64e110e-d932-44a6-a76b-bbdd08bd9589	2018-02-28 08:44:43.60945-06	2	[9115] IC-131 Relay	[4] DLarrabee	[21062] a	\N	\N
1c48b455-40f1-4bae-bc57-6249e4cec753	2018-02-28 08:44:43.625451-06	2	[9116] IC-132 Relay	[4] DLarrabee	[21062] a	\N	\N
e0bfc60e-028d-4f54-a75a-c428871dd6d2	2018-02-28 08:44:43.637452-06	2	[9117] IC-115 Relay	[4] DLarrabee	[21062] a	\N	\N
e0932a2e-636e-4e63-b92d-84bdb342673d	2018-02-28 08:44:43.655454-06	2	[9118] IC-116 Relay	[4] DLarrabee	[21062] a	\N	\N
f4e2bc21-b99c-4b04-9261-c2bbf94432f0	2018-02-28 08:44:43.669456-06	2	[9119] IC-117 Relay	[4] DLarrabee	[21062] a	\N	\N
d1118b3c-ef47-4826-99c0-9685136a9228	2018-02-28 08:44:43.684457-06	2	[9120] IC-119 Relay	[4] DLarrabee	[21062] a	\N	\N
d29279ea-f211-49d0-856f-9c9c7bedd4eb	2018-02-28 08:44:43.688458-06	2	[9122] IC-128 Connect	[4] DLarrabee	[21062] a	\N	\N
87c9b8d6-b6e6-4b87-accf-14b5d45a64fd	2018-02-28 08:44:43.691458-06	2	[9123] IC-129 Connect	[4] DLarrabee	[21062] a	\N	\N
0c04efbc-ad99-45c3-ae75-d03486ec8272	2018-02-28 08:44:43.694458-06	2	[9124] IC-131 Connect	[4] DLarrabee	[21062] a	\N	\N
499f3dde-7961-4e19-bd8f-2615e22d7638	2018-02-28 08:44:43.698459-06	2	[9125] IC-132 Connect	[4] DLarrabee	[21062] a	\N	\N
acf85a82-742e-47d1-b70c-e9a971e7b039	2018-02-28 08:44:43.702459-06	2	[9126] IC-115 Connect	[4] DLarrabee	[21062] a	\N	\N
14494606-b2f9-4e0e-bfab-e4816f2dc2ca	2018-02-28 08:44:43.705459-06	2	[9127] IC-116 Connect	[4] DLarrabee	[21062] a	\N	\N
ef773ce4-a43b-4eca-ba8a-da4b4da1aa2a	2018-02-28 08:44:43.70946-06	2	[9128] IC-117 Connect	[4] DLarrabee	[21062] a	\N	\N
a52781a5-75dc-45ac-848d-e674330e3cfc	2018-02-28 08:44:43.71346-06	2	[9129] IC-119 Connect	[4] DLarrabee	[21062] a	\N	\N
148f2faf-3459-4f3d-bdd6-b0c0488bda55	2018-02-28 08:44:43.71746-06	2	[9155] IC-128 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a6762b7e-13c3-48cf-9152-e71da7ffc8ef	2018-02-28 08:44:43.720461-06	2	[9156] IC-129 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c7bf6f74-125d-496f-85b4-d34a830580db	2018-02-28 08:44:43.723461-06	2	[9157] IC-131 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0a9eb90e-838f-4598-bb04-2e1181ad4fcf	2018-02-28 08:44:43.726461-06	2	[9158] IC-132 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ce83eaef-2097-4c46-abc6-eaa42278eaaa	2018-02-28 08:44:43.729462-06	2	[9159] IC-115 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cadb4027-1173-4a36-8f82-c4cb5a0a8ac4	2018-02-28 08:44:43.732462-06	2	[9160] IC-116 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e68956c5-fa5e-4502-b7e4-7fbdd11b1bbe	2018-02-28 08:44:43.735462-06	2	[9161] IC-117 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0964c517-ca48-4256-893d-791361f7847b	2018-02-28 08:44:43.738463-06	2	[9162] IC-119 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e7d53b1e-5f65-4927-8a35-b54097aba38a	2018-02-28 08:44:43.741463-06	2	[9174] IC-128 Call	[4] DLarrabee	[21062] a	\N	\N
10d4a672-82b0-4fdd-b5bd-be0c5364e785	2018-02-28 08:44:43.744463-06	2	[9175] IC-129 Call	[4] DLarrabee	[21062] a	\N	\N
31f40b11-950c-48eb-8769-839661c63c46	2018-02-28 08:44:43.748464-06	2	[9176] IC-131 Call	[4] DLarrabee	[21062] a	\N	\N
40cbd762-a9bd-4540-99d4-d437474d8ed3	2018-02-28 08:44:43.751464-06	2	[9177] IC-132 Call	[4] DLarrabee	[21062] a	\N	\N
a0e5a0d5-e08f-4953-9973-4d59fb31f52c	2018-02-28 08:44:43.755464-06	2	[9178] IC-115 Call	[4] DLarrabee	[21062] a	\N	\N
9963a2bd-288e-432d-b29b-7b74c5ca9d85	2018-02-28 08:44:43.759465-06	2	[9179] IC-116 Call	[4] DLarrabee	[21062] a	\N	\N
8998fb21-f6db-4a14-9a5e-031abf829350	2018-02-28 08:44:43.762465-06	2	[9180] IC-117 Call	[4] DLarrabee	[21062] a	\N	\N
c0dd3326-4de1-4f9d-ac4d-17f8f638d743	2018-02-28 08:44:43.764465-06	2	[9181] IC-119 Call	[4] DLarrabee	[21062] a	\N	\N
b9e63ab0-c825-49ad-b138-79770bcad670	2018-02-28 08:44:43.901479-06	2	[9542] R4C4-8IC	[4] DLarrabee	[21062] a	\N	\N
904ccd6e-1451-48b9-8d09-ca1ccba06ae7	2018-02-28 08:44:43.91648-06	2	[9544] IC-121 Call Button	[4] DLarrabee	[21062] a	\N	\N
e3421032-fb77-4cd8-9ce0-2065a0b556f3	2018-02-28 08:44:43.928482-06	2	[9545] IC-114A-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
e5d49bf7-942a-40cf-840b-e9056f4f3fbf	2018-02-28 08:44:43.942483-06	2	[9546] IC-114A-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
2a4ee9e0-0192-40d7-a8d3-51d33aaad5f7	2018-02-28 08:44:43.958485-06	2	[9547] IC-114B-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
ffeffe8b-e0c6-4a37-892a-8f2120e9086f	2018-02-28 08:44:43.976486-06	2	[9548] IC-114B-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
63c89944-37e6-4c2a-b2f2-d116311600c6	2018-02-28 08:44:43.995488-06	2	[9549] IC-103 Call Button	[4] DLarrabee	[21062] a	\N	\N
424686f8-209d-4522-8722-92d341ce074a	2018-02-28 08:44:44.00849-06	2	[9550] IC-104 Call Button	[4] DLarrabee	[21062] a	\N	\N
f3840db6-3936-4e93-ba6b-312571c147e9	2018-02-28 08:44:44.021491-06	2	[9551] IC-105 Call Button	[4] DLarrabee	[21062] a	\N	\N
d97251ef-484e-46ad-ad90-49631ed16f9c	2018-02-28 08:44:44.034492-06	2	[9553] IC-121 Relay	[4] DLarrabee	[21062] a	\N	\N
a97567fc-f04d-41b2-b72a-c98c91be4622	2018-02-28 08:44:44.049494-06	2	[9554] IC-114A-InB Relay	[4] DLarrabee	[21062] a	\N	\N
c8208413-7615-4efa-a1f9-731b482343bd	2018-02-28 08:44:44.066495-06	2	[9555] IC-114A-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
c7b1b5e9-1be1-4288-a256-2876d2a2fec4	2018-02-28 08:44:44.081497-06	2	[9556] IC-114B-InB Relay	[4] DLarrabee	[21062] a	\N	\N
29585c15-2441-44d0-9097-81e3be18c07f	2018-02-28 08:44:44.098499-06	2	[9557] IC-114B-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
f76f6eeb-42ba-46d9-982f-6486cf52b44b	2018-02-28 08:44:44.1155-06	2	[9558] IC-103 Relay	[4] DLarrabee	[21062] a	\N	\N
cffb846c-2a45-41f1-b2db-25abbd6c1cfe	2018-02-28 08:44:44.178507-06	2	[9559] IC-104 Relay	[4] DLarrabee	[21062] a	\N	\N
30045a33-0ade-47f6-9252-0d1fc2550866	2018-02-28 08:44:44.192508-06	2	[9560] IC-105 Relay	[4] DLarrabee	[21062] a	\N	\N
14995abf-176e-4851-a6cb-1591d73b64ec	2018-02-28 08:44:44.197508-06	2	[9562] IC-121 Connect	[4] DLarrabee	[21062] a	\N	\N
b46b1e1b-0862-4c0a-a141-3c1179fa7955	2018-02-28 08:44:44.200509-06	2	[9563] IC-114A-InB Connect	[4] DLarrabee	[21062] a	\N	\N
7690cdb9-7375-4c54-9ecd-7030ef4eae70	2018-02-28 08:44:44.204509-06	2	[9564] IC-114A-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
346d55ba-1cfa-4b8b-a858-91b208315f6a	2018-02-28 08:44:44.20951-06	2	[9565] IC-114B-InB Connect	[4] DLarrabee	[21062] a	\N	\N
15cd0886-2caf-426c-a38a-fed31b14a857	2018-02-28 08:44:44.21451-06	2	[9566] IC-114B-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
15f14470-4075-4b3c-9f51-c447e3209133	2018-02-28 08:44:44.219511-06	2	[9567] IC-103 Connect	[4] DLarrabee	[21062] a	\N	\N
bc11fe12-1f14-45b3-811d-898df091eea5	2018-02-28 08:44:44.223511-06	2	[9568] IC-104 Connect	[4] DLarrabee	[21062] a	\N	\N
e09d296c-45b3-48c1-ba92-c1afb59be09e	2018-02-28 08:44:44.227511-06	2	[9569] IC-105 Connect	[4] DLarrabee	[21062] a	\N	\N
1c42d3af-c68c-4614-8707-91e325eeb2ad	2018-02-28 08:44:44.231512-06	2	[9595] IC-121 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
75a9726e-82fe-41a9-9281-85d8db095e09	2018-02-28 08:44:44.234512-06	2	[9596] IC-114A-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f6422463-f573-44e9-ab7e-51c3fa3db53c	2018-02-28 08:44:44.237512-06	2	[9597] IC-114A-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a04d13a5-584f-482e-91ff-28f8f1b70a8b	2018-02-28 08:44:44.240513-06	2	[9598] IC-114B-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2a56fe57-b6b0-480f-a767-0fb274da36e0	2018-02-28 08:44:44.243513-06	2	[9599] IC-114B-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4b91a2c7-ddc3-4afe-8f8f-82fe305a6f83	2018-02-28 08:44:44.246513-06	2	[9600] IC-103 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9d17ee03-3e8f-408f-b042-5b36e34592a5	2018-02-28 08:44:44.250514-06	2	[9601] IC-104 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fda1d173-03aa-4b55-89ac-12e018d53f90	2018-02-28 08:44:44.253514-06	2	[9602] IC-105 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
414000ff-13fb-4ccd-a7aa-c4b06790abdb	2018-02-28 08:44:44.257514-06	2	[9614] IC-121 Call	[4] DLarrabee	[21062] a	\N	\N
18915b57-ffc7-4a3e-be0e-acdf09542f8a	2018-02-28 08:44:44.260515-06	2	[9615] IC-114A-InB Call	[4] DLarrabee	[21062] a	\N	\N
0fc52616-7ea9-4acc-aee8-cd9f599924fc	2018-02-28 08:44:44.263515-06	2	[9616] IC-114A-OutB Call	[4] DLarrabee	[21062] a	\N	\N
f17fcbad-b984-456b-8877-8d6e256e6435	2018-02-28 08:44:44.266515-06	2	[9617] IC-114B-InB Call	[4] DLarrabee	[21062] a	\N	\N
613b4825-fa4c-45ed-8dab-38a0d193a1d6	2018-02-28 08:44:44.270516-06	2	[9618] IC-114B-OutB Call	[4] DLarrabee	[21062] a	\N	\N
26c1ff72-71f8-4a5e-98df-c2f684d881c8	2018-02-28 08:44:44.273516-06	2	[9619] IC-103 Call	[4] DLarrabee	[21062] a	\N	\N
55792135-3e2d-49cd-a2e0-2bd9cc00ef8a	2018-02-28 08:44:44.277516-06	2	[9620] IC-104 Call	[4] DLarrabee	[21062] a	\N	\N
c297d73a-46a3-4d58-8800-1f4a69c866b3	2018-02-28 08:44:44.280517-06	2	[9621] IC-105 Call	[4] DLarrabee	[21062] a	\N	\N
c6d2a1fb-421a-4b97-b2c3-0b8a956655fd	2018-02-28 08:44:44.422531-06	2	[9982] R4C5-8IC	[4] DLarrabee	[21062] a	\N	\N
616b6294-e540-4980-b467-f763f0e1bd02	2018-02-28 08:44:44.437532-06	2	[9984] IC-107 Call Button	[4] DLarrabee	[21062] a	\N	\N
11e624e8-bada-49bd-9b2f-dcd1094cfa7f	2018-02-28 08:44:44.454534-06	2	[9985] IC-108 Call Button	[4] DLarrabee	[21062] a	\N	\N
c25fdc9c-ca6c-4034-b7ed-df51aa1987fc	2018-02-28 08:44:44.469536-06	2	[9986] IC-109 Call Button	[4] DLarrabee	[21062] a	\N	\N
bacf1ecc-3316-4d0c-8f52-a618733ae45b	2018-02-28 08:44:44.482537-06	2	[9987] IC-112 Call Button	[4] DLarrabee	[21062] a	\N	\N
0f97733c-8515-4736-8ef2-f03b4cebe06b	2018-02-28 08:44:44.496538-06	2	[9988] IC-113-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
e6f0ca27-2912-42c5-a4e2-edd6379e09b7	2018-02-28 08:44:44.51254-06	2	[9989] IC-113-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
f7eb21c4-c519-434f-91ec-d24e3d30a257	2018-02-28 08:44:44.526541-06	2	[9990] IC-133-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
1264bc79-0243-45b0-96b6-dd09b874370d	2018-02-28 08:44:44.546543-06	2	[9991] IC-133-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
a85b1993-0e1f-410f-babd-04795f0da03e	2018-02-28 08:44:44.563545-06	2	[9993] IC-107 Relay	[4] DLarrabee	[21062] a	\N	\N
6ab8a8a4-1989-4aef-9d08-ce9ff230f28b	2018-02-28 08:44:44.579547-06	2	[9994] IC-108 Relay	[4] DLarrabee	[21062] a	\N	\N
9ad59b98-b8df-48c2-a02a-56a3b518bb71	2018-02-28 08:44:44.596548-06	2	[9995] IC-109 Relay	[4] DLarrabee	[21062] a	\N	\N
d3590a4a-3116-4785-9f7e-4473964cb909	2018-02-28 08:44:44.61355-06	2	[9996] IC-112 Relay	[4] DLarrabee	[21062] a	\N	\N
92184bcb-f391-469f-99b8-36da4c09da1b	2018-02-28 08:44:44.629552-06	2	[9997] IC-113-InB Relay	[4] DLarrabee	[21062] a	\N	\N
34ecaf7a-5f10-4091-97e1-6d4b766cfc15	2018-02-28 08:44:44.643553-06	2	[9998] IC-113-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
07a21975-2fd6-45c3-8f21-21732a2f87f2	2018-02-28 08:44:44.658555-06	2	[9999] IC-133-InB Relay	[4] DLarrabee	[21062] a	\N	\N
150a7ad5-9038-40c5-a5d7-4aaf51fdc345	2018-02-28 08:44:44.672556-06	2	[10000] IC-133-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
5a37b404-801a-4796-94a0-261d7662c090	2018-02-28 08:44:44.675556-06	2	[10002] IC-107 Connect	[4] DLarrabee	[21062] a	\N	\N
9096d066-2f5d-491f-955a-00b62e81386e	2018-02-28 08:44:44.678557-06	2	[10003] IC-108 Connect	[4] DLarrabee	[21062] a	\N	\N
8e6e6897-a2e1-4f94-8628-b64395af1037	2018-02-28 08:44:44.681557-06	2	[10004] IC-109 Connect	[4] DLarrabee	[21062] a	\N	\N
eb0fcff1-02d4-467d-8163-9f3eec953869	2018-02-28 08:44:44.684557-06	2	[10005] IC-112 Connect	[4] DLarrabee	[21062] a	\N	\N
5c3d31e7-1e84-4937-8856-beed8880cc4f	2018-02-28 08:44:44.688558-06	2	[10006] IC-113-InB Connect	[4] DLarrabee	[21062] a	\N	\N
990aee83-2823-4b7a-985c-a04de31f86ae	2018-02-28 08:44:44.691558-06	2	[10007] IC-113-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
5365feeb-d2de-4af4-b5ee-26a9bf55558b	2018-02-28 08:44:44.695558-06	2	[10008] IC-133-InB Connect	[4] DLarrabee	[21062] a	\N	\N
de2d733d-c20e-4442-ad92-2c6ccc3cc865	2018-02-28 08:44:44.699559-06	2	[10009] IC-133-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
f7ec6718-8b68-484b-bfdd-b261c2bcf55a	2018-02-28 08:44:44.702559-06	2	[10035] IC-107 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b35156da-0712-4669-856e-c20f699c082a	2018-02-28 08:44:44.706559-06	2	[10036] IC-108 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a2bc88b7-7967-4615-aa59-724a763b73d3	2018-02-28 08:44:44.70956-06	2	[10037] IC-109 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8591ad2a-442b-41b8-bfcf-f5ad863b690f	2018-02-28 08:44:44.71256-06	2	[10038] IC-112 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0678256d-77ab-4ed8-82cc-0de8e833ea7f	2018-02-28 08:44:44.71556-06	2	[10039] IC-113-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2334eec8-b616-4f58-9819-b9548027b23b	2018-02-28 08:44:44.718561-06	2	[10040] IC-113-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
11fff6de-37ef-4044-806b-a3d9c849ea49	2018-02-28 08:44:44.722561-06	2	[10041] IC-133-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
584b35d1-f30b-44bd-90b3-dc0c924da9c9	2018-02-28 08:44:44.725561-06	2	[10042] IC-133-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ab9bffcf-98af-48d4-b69d-f6b535a1df51	2018-02-28 08:44:44.729562-06	2	[10054] IC-107 Call	[4] DLarrabee	[21062] a	\N	\N
f70cdcb7-7b85-403b-880e-9a8ba839ae3b	2018-02-28 08:44:44.733562-06	2	[10055] IC-108 Call	[4] DLarrabee	[21062] a	\N	\N
c5d97ba8-34ce-41ab-958c-0745f080cac7	2018-02-28 08:44:44.736562-06	2	[10056] IC-109 Call	[4] DLarrabee	[21062] a	\N	\N
18ed9e8e-2db5-46a7-87e2-6e7f4f210a9c	2018-02-28 08:44:44.739563-06	2	[10057] IC-112 Call	[4] DLarrabee	[21062] a	\N	\N
714dae5f-1daf-4a0c-b0d0-7547058a61c2	2018-02-28 08:44:44.742563-06	2	[10058] IC-113-InB Call	[4] DLarrabee	[21062] a	\N	\N
343c4531-6c6a-40bc-80ab-63ad9e20ab01	2018-02-28 08:44:44.745563-06	2	[10059] IC-113-OutB Call	[4] DLarrabee	[21062] a	\N	\N
1cc11edf-0746-4013-b6c4-d9a5581acf9b	2018-02-28 08:44:44.748564-06	2	[10060] IC-133-InB Call	[4] DLarrabee	[21062] a	\N	\N
61db83f3-7202-40d1-b6f8-99a51a7cfdc8	2018-02-28 08:44:44.752564-06	2	[10061] IC-133-OutB Call	[4] DLarrabee	[21062] a	\N	\N
ee915394-4f06-4d29-acdb-6764918ee663	2018-02-28 08:44:44.869576-06	2	[10422] R4C6-8IC	[4] DLarrabee	[21062] a	\N	\N
a5069bd0-f9e1-4977-b005-6e1a3e620928	2018-02-28 08:44:44.888578-06	2	[10424] IC-145-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
d95b0f35-7564-43bd-b451-cea7431c7c2d	2018-02-28 08:44:44.902579-06	2	[10425] IC-145-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
07a9a4a4-b2e4-46d4-9dae-849fb12d8cbf	2018-02-28 08:44:44.91758-06	2	[10426] IC-146-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
7239ba96-81a8-4b0d-a418-6cf6ac89bef4	2018-02-28 08:44:44.931582-06	2	[10427] IC-146-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
21e0dd8f-2bf7-4a48-99e0-551a0e305f77	2018-02-28 08:44:44.945583-06	2	[10428] IC-156-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
ff717d59-f1ab-4c79-b1b9-60734efebfcf	2018-02-28 08:44:44.962585-06	2	[10429] IC-156-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
a8460964-a450-431e-8b36-bd3dab6d6975	2018-02-28 08:44:44.979587-06	2	[10430] IC-201 Call Button	[4] DLarrabee	[21062] a	\N	\N
b7a30e67-b906-43a2-9b98-000c0715b457	2018-02-28 08:44:44.994588-06	2	[10431] IC-202 Call Button	[4] DLarrabee	[21062] a	\N	\N
83a746a2-985f-4395-bfec-16137f340ce2	2018-02-28 08:44:45.00859-06	2	[10433] IC-145-InB Relay	[4] DLarrabee	[21062] a	\N	\N
5b03cea9-4ec4-43ec-bea7-3abe6c647df4	2018-02-28 08:44:45.023591-06	2	[10434] IC-145-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
65129bb0-146a-432f-85f2-15ff2171add4	2018-02-28 08:44:45.036592-06	2	[10435] IC-146-InB Relay	[4] DLarrabee	[21062] a	\N	\N
42b0ca2f-0b3c-40ad-a30c-661f9f8c3eae	2018-02-28 08:44:45.049594-06	2	[10436] IC-146-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
7b3b048d-8074-4497-88cc-957551758d9c	2018-02-28 08:44:45.064595-06	2	[10437] IC-156-InB Relay	[4] DLarrabee	[21062] a	\N	\N
ef98e28a-6dba-44c2-a1d1-0c3c3e634b65	2018-02-28 08:44:45.078597-06	2	[10438] IC-156-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
0566abcb-5aaf-4291-8d47-d9bcb8b309ea	2018-02-28 08:44:45.096598-06	2	[10439] IC-201 Relay	[4] DLarrabee	[21062] a	\N	\N
061fd55d-e01d-4fd0-b816-63434a5d95eb	2018-02-28 08:44:45.1116-06	2	[10440] IC-202 Relay	[4] DLarrabee	[21062] a	\N	\N
fa88885a-58e0-4369-b42f-a72d88e8ab46	2018-02-28 08:44:45.1156-06	2	[10442] IC-145-InB Connect	[4] DLarrabee	[21062] a	\N	\N
58617c43-ce80-406f-a0cd-ccfab57782a6	2018-02-28 08:44:45.118601-06	2	[10443] IC-145-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
2543f374-4aa9-441f-ba0e-dfa30043a66a	2018-02-28 08:44:45.122601-06	2	[10444] IC-146-InB Connect	[4] DLarrabee	[21062] a	\N	\N
9a2ebd97-9e15-43c8-92f3-9e002b98adc7	2018-02-28 08:44:45.125601-06	2	[10445] IC-146-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
fd09e0ed-8fab-48ca-afe7-8f3234098d5a	2018-02-28 08:44:45.129602-06	2	[10446] IC-156-InB Connect	[4] DLarrabee	[21062] a	\N	\N
c7214e04-46c7-4a19-82c3-b0834dbd4c07	2018-02-28 08:44:45.133602-06	2	[10447] IC-156-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
94531dbd-b005-4733-b522-5d45bdb449a5	2018-02-28 08:44:45.137602-06	2	[10448] IC-201 Connect	[4] DLarrabee	[21062] a	\N	\N
0152238a-a618-4102-bf09-4751b10b2107	2018-02-28 08:44:45.141603-06	2	[10449] IC-202 Connect	[4] DLarrabee	[21062] a	\N	\N
de496376-32c4-4637-bed3-cde85b58e8bf	2018-02-28 08:44:45.144603-06	2	[10475] IC-145-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
758612e7-3c8d-4777-90fd-eeb60ab1d97b	2018-02-28 08:44:45.148604-06	2	[10476] IC-145-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
00ce260f-4214-4c54-a302-69a3155e1757	2018-02-28 08:44:45.151604-06	2	[10477] IC-146-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
bfab769d-84a1-4eff-97d3-7d7504f0e4bc	2018-02-28 08:44:45.154604-06	2	[10478] IC-146-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c3153e38-4841-4b59-b2a7-b54f71119ffc	2018-02-28 08:44:45.158605-06	2	[10479] IC-156-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7d989f41-4174-431b-9daa-d1682df4a9ca	2018-02-28 08:44:45.161605-06	2	[10480] IC-156-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6ba02ff9-f2cf-4597-8ee5-541cb2b77dc2	2018-02-28 08:44:45.165605-06	2	[10481] IC-201 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b7a2ef54-2ffe-4485-936e-657a7b7b056f	2018-02-28 08:44:45.168606-06	2	[10482] IC-202 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b5863fe4-693e-401a-8924-22c80e237179	2018-02-28 08:44:45.171606-06	2	[10494] IC-145-InB Call	[4] DLarrabee	[21062] a	\N	\N
5385d66b-b8be-4f5f-beb3-55f6c583eb23	2018-02-28 08:44:45.175606-06	2	[10495] IC-145-OutB Call	[4] DLarrabee	[21062] a	\N	\N
c8bcc1d9-de6c-47a0-b0c9-a17e9e0df467	2018-02-28 08:44:45.179607-06	2	[10496] IC-146-InB Call	[4] DLarrabee	[21062] a	\N	\N
dac10462-9cf9-4731-929c-5c65d8253dba	2018-02-28 08:44:45.182607-06	2	[10497] IC-146-OutB Call	[4] DLarrabee	[21062] a	\N	\N
8db34b67-baca-4a92-bd03-f60b8ec0b997	2018-02-28 08:44:45.185607-06	2	[10498] IC-156-InB Call	[4] DLarrabee	[21062] a	\N	\N
18635f78-0003-4dc6-ac6f-b7e2aa9f495f	2018-02-28 08:44:45.188608-06	2	[10499] IC-156-OutB Call	[4] DLarrabee	[21062] a	\N	\N
1b0a3f70-970b-429d-a606-3f9e54b54e3e	2018-02-28 08:44:45.192608-06	2	[10500] IC-201 Call	[4] DLarrabee	[21062] a	\N	\N
3d8d042c-cc9a-40fb-acaf-cb8f8244f0bd	2018-02-28 08:44:45.195608-06	2	[10501] IC-202 Call	[4] DLarrabee	[21062] a	\N	\N
553d5827-8dae-4c94-ba7d-47e51dd859bb	2018-02-28 08:44:45.30962-06	2	[10862] R4C7-8IC	[4] DLarrabee	[21062] a	\N	\N
b7558bde-2e95-4b82-b46a-559e8ffa40f8	2018-02-28 08:44:45.325621-06	2	[10864] IC-203 Call Button	[4] DLarrabee	[21062] a	\N	\N
991393fe-8ea9-404b-ad86-d2a6dfdc4b54	2018-02-28 08:44:45.337622-06	2	[10865] IC-205 Call Button	[4] DLarrabee	[21062] a	\N	\N
44aa6c2e-692f-4c4e-9ebe-b779983b4d8a	2018-02-28 08:44:45.355624-06	2	[10866] IC-206 Call Button	[4] DLarrabee	[21062] a	\N	\N
b48c3822-1cbb-4278-b927-7b2eeb44aa3e	2018-02-28 08:44:45.369626-06	2	[10867] IC-207 Call Button	[4] DLarrabee	[21062] a	\N	\N
d0faa390-8db0-4fc9-a755-0f9734addecf	2018-02-28 08:44:45.384627-06	2	[10868] IC-209A-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
8faa3985-66e2-4eaa-9aa4-959c9c36df54	2018-02-28 08:44:45.404629-06	2	[10869] IC-209A-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
4c7cd888-a4ce-4925-b374-a68a73a09b9f	2018-02-28 08:44:45.41663-06	2	[10870] IC-209B-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
1b451575-8af6-49cc-8546-cac8c1c22683	2018-02-28 08:44:45.434632-06	2	[10871] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
2a920963-b1c0-4a33-bbd6-47ceb47d045d	2018-02-28 08:44:45.449634-06	2	[10873] IC-203 Relay	[4] DLarrabee	[21062] a	\N	\N
81f4eec0-4920-41ba-a76f-996a40296b7f	2018-02-28 08:44:45.469636-06	2	[10874] IC-205 Relay	[4] DLarrabee	[21062] a	\N	\N
c38edd66-b63d-421c-852a-c207074a6a08	2018-02-28 08:44:45.488638-06	2	[10875] IC-206 Relay	[4] DLarrabee	[21062] a	\N	\N
0064ee4c-bc1c-4cd5-809a-e50299d5ca3c	2018-02-28 08:44:45.504639-06	2	[10876] IC-207 Relay	[4] DLarrabee	[21062] a	\N	\N
3b70cb40-a300-4fcb-b69d-2fc2af43622a	2018-02-28 08:44:45.518641-06	2	[10877] IC-209A-InB Relay	[4] DLarrabee	[21062] a	\N	\N
e6379008-32f5-45bf-8b95-9fcb63511d39	2018-02-28 08:44:45.534642-06	2	[10878] IC-209A-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
1fb0f4d6-9d81-419a-b231-73e11a34857a	2018-02-28 08:44:45.554644-06	2	[10879] IC-209B-InB Relay	[4] DLarrabee	[21062] a	\N	\N
18c83d94-b3a5-448c-8922-930e65d3ce8e	2018-02-28 08:44:45.568646-06	2	[10880] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
5a9435b4-e389-4367-ab06-cc5a55cab158	2018-02-28 08:44:45.571646-06	2	[10882] IC-203 Connect	[4] DLarrabee	[21062] a	\N	\N
0cc0cad3-883f-480e-8121-3c18d03b1901	2018-02-28 08:44:45.574646-06	2	[10883] IC-205 Connect	[4] DLarrabee	[21062] a	\N	\N
7f411a07-0f52-415e-a29e-f1adde731f79	2018-02-28 08:44:45.577646-06	2	[10884] IC-206 Connect	[4] DLarrabee	[21062] a	\N	\N
f7a9396f-500d-4792-92da-a294f2d06d90	2018-02-28 08:44:45.580647-06	2	[10885] IC-207 Connect	[4] DLarrabee	[21062] a	\N	\N
d71311b8-af69-43bf-a5c4-a57611e21807	2018-02-28 08:44:45.583647-06	2	[10886] IC-209A-InB Connect	[4] DLarrabee	[21062] a	\N	\N
b7ecf4ee-eb76-49c0-aad9-36ba8b408d77	2018-02-28 08:44:45.587647-06	2	[10887] IC-209A-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
900d48a5-a855-42df-9d5e-c24ba1392fc6	2018-02-28 08:44:45.591648-06	2	[10888] IC-209B-InB Connect	[4] DLarrabee	[21062] a	\N	\N
9f74a8fb-c110-408e-a356-3ebcbe79a2c1	2018-02-28 08:44:45.599649-06	2	[10889] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
0f805f33-d538-427b-9482-2accdd21a1ec	2018-02-28 08:44:45.60965-06	2	[10915] IC-203 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
090a3ce8-976c-4c42-9275-639037ae2a5e	2018-02-28 08:44:45.61465-06	2	[10916] IC-205 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c5793553-6749-4a96-9772-2158aba65dad	2018-02-28 08:44:45.61765-06	2	[10917] IC-206 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
91e71cc2-664c-463a-9d86-e29179214b18	2018-02-28 08:44:45.621651-06	2	[10918] IC-207 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
458e27d0-d1b8-429f-a4c3-ff9d649933b8	2018-02-28 08:44:45.624651-06	2	[10919] IC-209A-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7795b6e5-94a5-4ea3-9531-76d2956a0488	2018-02-28 08:44:45.628652-06	2	[10920] IC-209A-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
97cf10bf-2fe9-45ad-8dd3-e69441c151d2	2018-02-28 08:44:45.632652-06	2	[10921] IC-209B-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
edb4d635-d2dd-46bb-97a9-f0f3b6697456	2018-02-28 08:44:45.637652-06	2	[10922] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
10f84db5-1006-4ac0-a23e-8ad9f4f42512	2018-02-28 08:44:45.641653-06	2	[10934] IC-203 Call	[4] DLarrabee	[21062] a	\N	\N
593ce223-4268-4428-b8c2-237950213203	2018-02-28 08:44:45.645653-06	2	[10935] IC-205 Call	[4] DLarrabee	[21062] a	\N	\N
7b8bbfff-1f73-4ec9-ae80-5e130a3bd790	2018-02-28 08:44:45.648654-06	2	[10936] IC-206 Call	[4] DLarrabee	[21062] a	\N	\N
c2418ebe-1751-458b-8373-ada38072b9e6	2018-02-28 08:44:45.651654-06	2	[10937] IC-207 Call	[4] DLarrabee	[21062] a	\N	\N
0ce5edd8-c5f6-4fc8-8666-cddf36af9e7d	2018-02-28 08:44:45.655654-06	2	[10938] IC-209A-InB Call	[4] DLarrabee	[21062] a	\N	\N
ccccfcfd-4b61-4f67-bafe-d879ce913be9	2018-02-28 08:44:45.658655-06	2	[10939] IC-209A-OutB Call	[4] DLarrabee	[21062] a	\N	\N
45e89fc4-c858-45c8-a248-9f06e9905a6d	2018-02-28 08:44:45.662655-06	2	[10940] IC-209B-InB Call	[4] DLarrabee	[21062] a	\N	\N
68bb3051-b365-4da1-8184-30b16661c956	2018-02-28 08:44:45.665655-06	2	[10941] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
65eb500c-18b3-4cb5-b7ec-c810a5b8d592	2018-02-28 08:44:45.782667-06	2	[11302] R5C8-8IC	[4] DLarrabee	[21062] a	\N	\N
8e858dab-5e84-4eb2-9737-f2664b108f62	2018-02-28 08:44:45.795668-06	2	[11304] IC-209B-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
6cab28a5-45a8-49e8-a668-4228f937a3d8	2018-02-28 08:44:45.80967-06	2	[11305] IC-211-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
27ead6a3-61f1-45b8-a7c4-905c3a8e5d7e	2018-02-28 08:44:45.824671-06	2	[11306] IC-211-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
187dd0a0-223c-4eda-ad97-ec52416b8a39	2018-02-28 08:44:45.839673-06	2	[11307] IC-213 Call Button	[4] DLarrabee	[21062] a	\N	\N
2627a0f3-2f4a-43a0-9f77-418c1cb6cf6b	2018-02-28 08:44:45.854674-06	2	[11308] IC-214 Call Button	[4] DLarrabee	[21062] a	\N	\N
8cd6bbbe-1f9b-4c40-8542-687e05383894	2018-02-28 08:44:45.867675-06	2	[11309] IC-215 Call Button	[4] DLarrabee	[21062] a	\N	\N
db23fe9e-97b3-47f4-96c4-59a3a3c84f3b	2018-02-28 08:44:45.882677-06	2	[11310] IC-216 Call Button	[4] DLarrabee	[21062] a	\N	\N
27fcacfb-e3a1-4e27-9cbe-699bda56716b	2018-02-28 08:44:45.900679-06	2	[11311] IC-218 Call Button	[4] DLarrabee	[21062] a	\N	\N
94f1afc8-cd1d-4d9c-8ecd-3198266912f1	2018-02-28 08:44:45.921681-06	2	[11313] IC-209B-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
907d4374-8494-45fe-b676-1d9510e229a5	2018-02-28 08:44:45.939683-06	2	[11314] IC-211-InB Relay	[4] DLarrabee	[21062] a	\N	\N
1930eb6c-f53f-44f8-ac41-1a10986240d4	2018-02-28 08:44:45.953684-06	2	[11315] IC-211-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
0eba95c3-c59f-484d-9982-6453ddc03148	2018-02-28 08:44:45.968686-06	2	[11316] IC-213 Relay	[4] DLarrabee	[21062] a	\N	\N
9c40910d-b896-4ddd-afe9-439ca80e8923	2018-02-28 08:44:45.981687-06	2	[11317] IC-214 Relay	[4] DLarrabee	[21062] a	\N	\N
34cc3710-7a72-4d71-9183-218a30f5973a	2018-02-28 08:44:45.997688-06	2	[11318] IC-215 Relay	[4] DLarrabee	[21062] a	\N	\N
92f242a1-44b2-4f81-9f9c-a05fea5925fb	2018-02-28 08:44:46.01269-06	2	[11319] IC-216 Relay	[4] DLarrabee	[21062] a	\N	\N
26434c97-e3d2-4e19-b7b6-059493774f4d	2018-02-28 08:44:46.025691-06	2	[11320] IC-218 Relay	[4] DLarrabee	[21062] a	\N	\N
f253d4a9-3b3d-4eb5-b6d5-6b9e4ab7e43a	2018-02-28 08:44:46.028692-06	2	[11322] IC-209B-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
b93429b3-caa7-4844-bf3a-6b94241cae42	2018-02-28 08:44:46.033692-06	2	[11323] IC-211-InB Connect	[4] DLarrabee	[21062] a	\N	\N
1ac9c9a7-bb63-4f7b-9de4-41dc1b44565d	2018-02-28 08:44:46.036692-06	2	[11324] IC-211-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
0b87e505-fe54-474e-ab57-c65c04fc0c86	2018-02-28 08:44:46.039693-06	2	[11325] IC-213 Connect	[4] DLarrabee	[21062] a	\N	\N
e1569dab-86f0-4185-955c-4bd06143b19c	2018-02-28 08:44:46.042693-06	2	[11326] IC-214 Connect	[4] DLarrabee	[21062] a	\N	\N
4567598d-d515-4780-a88f-30c086be8d33	2018-02-28 08:44:46.045693-06	2	[11327] IC-215 Connect	[4] DLarrabee	[21062] a	\N	\N
a2477d28-40e5-4eca-b4b3-f2b0a522e432	2018-02-28 08:44:46.049694-06	2	[11328] IC-216 Connect	[4] DLarrabee	[21062] a	\N	\N
6a05e2fc-c83b-460a-8e94-6f30bc5d091e	2018-02-28 08:44:46.052694-06	2	[11329] IC-218 Connect	[4] DLarrabee	[21062] a	\N	\N
983d2acc-42d4-4d6a-a0b5-ed946de6cb1f	2018-02-28 08:44:46.055694-06	2	[11355] IC-209B-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e854220d-9cac-44ef-b80f-69133036341c	2018-02-28 08:44:46.059695-06	2	[11356] IC-211-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9bf30d8c-650a-4c97-80b9-4868722119dc	2018-02-28 08:44:46.062695-06	2	[11357] IC-211-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b55c2165-d264-4299-9b3e-214895cdeef9	2018-02-28 08:44:46.066695-06	2	[11358] IC-213 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
66f30ad5-0d10-4f6d-a810-95d981093867	2018-02-28 08:44:46.070696-06	2	[11359] IC-214 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f8784466-584e-4887-80d3-7fdf88ec5411	2018-02-28 08:44:46.073696-06	2	[11360] IC-215 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4906c257-bb54-4cd4-8f72-7d4341092f03	2018-02-28 08:44:46.077696-06	2	[11361] IC-216 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7b1e9e4b-298f-472c-94c9-960152895472	2018-02-28 08:44:46.080697-06	2	[11362] IC-218 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0dc30d7a-5c2b-4c50-b6e2-9415861efeef	2018-02-28 08:44:46.083697-06	2	[11374] IC-209B-OutB Call	[4] DLarrabee	[21062] a	\N	\N
dcf6a1f9-bbbe-4590-950c-36e802219bf0	2018-02-28 08:44:46.087697-06	2	[11375] IC-211-InB Call	[4] DLarrabee	[21062] a	\N	\N
458e9c4d-e7f5-44f6-9ad4-3da719ffeb2b	2018-02-28 08:44:46.090698-06	2	[11376] IC-211-OutB Call	[4] DLarrabee	[21062] a	\N	\N
41d86418-9514-498e-b7fe-2e394dc227e3	2018-02-28 08:44:46.093698-06	2	[11377] IC-213 Call	[4] DLarrabee	[21062] a	\N	\N
db1b5baa-5e36-41de-a0bb-3a18e8aba3f2	2018-02-28 08:44:46.097698-06	2	[11378] IC-214 Call	[4] DLarrabee	[21062] a	\N	\N
2579971c-9c9a-461e-a77f-974f8c8f6192	2018-02-28 08:44:46.101699-06	2	[11379] IC-215 Call	[4] DLarrabee	[21062] a	\N	\N
42c5bd27-1cfb-4427-9d5e-2428818d0d7f	2018-02-28 08:44:46.104699-06	2	[11380] IC-216 Call	[4] DLarrabee	[21062] a	\N	\N
caf3fe7b-a932-400c-be06-3037c4c45e5f	2018-02-28 08:44:46.126701-06	2	[11381] IC-218 Call	[4] DLarrabee	[21062] a	\N	\N
cf272df9-3f30-4fb6-aa32-8b9cfd839f8f	2018-02-28 08:44:46.257714-06	2	[11742] R5C9-8IC	[4] DLarrabee	[21062] a	\N	\N
13a0501c-3536-4138-9025-8d42022c6249	2018-02-28 08:44:46.272716-06	2	[11744] IC-219 Call Button	[4] DLarrabee	[21062] a	\N	\N
0730f963-8cec-4491-bf9f-141cc71e440d	2018-02-28 08:44:46.292718-06	2	[11745] IC-221 Call Button	[4] DLarrabee	[21062] a	\N	\N
051d48ff-597e-439d-b24f-49c3b2a2a91c	2018-02-28 08:44:46.31172-06	2	[11746] IC-222 Call Button	[4] DLarrabee	[21062] a	\N	\N
1a08fa2f-892d-4fdd-88c0-a15cae34fa0e	2018-02-28 08:44:46.329722-06	2	[11747] IC-223-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
8edecc98-72cc-4082-a12b-cb949f22a389	2018-02-28 08:44:46.349724-06	2	[11748] IC-223-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
ce588580-1173-4113-b190-80303e86f1e6	2018-02-28 08:44:46.365725-06	2	[11749] IC-224-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
af98779b-b684-422e-a3f1-4e053bef5cf5	2018-02-28 08:44:46.384727-06	2	[11750] IC-224-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
7354f730-fe20-4b13-8799-5eedcca0dd8b	2018-02-28 08:44:46.404729-06	2	[11751] IC-225 Call Button	[4] DLarrabee	[21062] a	\N	\N
7de1977d-45e3-48b1-b928-765ed7417ff6	2018-02-28 08:44:46.418731-06	2	[11753] IC-219 Relay	[4] DLarrabee	[21062] a	\N	\N
ee0e3e5a-0a2b-4f48-bf11-0782dafd70b4	2018-02-28 08:44:46.433732-06	2	[11754] IC-221 Relay	[4] DLarrabee	[21062] a	\N	\N
3ce3da79-2a64-4c63-a6c6-3c198817f458	2018-02-28 08:44:46.451734-06	2	[11755] IC-222 Relay	[4] DLarrabee	[21062] a	\N	\N
f80b10cb-2f43-44d6-b05b-64aca05d1a2e	2018-02-28 08:44:46.468736-06	2	[11756] IC-223-InB Relay	[4] DLarrabee	[21062] a	\N	\N
649117e4-31a9-476b-b7d0-662d91ea6d52	2018-02-28 08:44:46.483737-06	2	[11757] IC-223-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
fd55d47e-8696-4bbb-8411-5cca4da206eb	2018-02-28 08:44:46.496738-06	2	[11758] IC-224-InB Relay	[4] DLarrabee	[21062] a	\N	\N
a026fd05-250d-4112-a721-7ef6c5018ec2	2018-02-28 08:44:46.50974-06	2	[11759] IC-224-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
a83c1085-592f-465f-947c-033d9900ac62	2018-02-28 08:44:46.521741-06	2	[11760] IC-225 Relay	[4] DLarrabee	[21062] a	\N	\N
bc640058-ee6d-4061-b10b-787c3bb06651	2018-02-28 08:44:46.525741-06	2	[11762] IC-219 Connect	[4] DLarrabee	[21062] a	\N	\N
ace402a4-6c8a-4bf3-a012-234ed81791b8	2018-02-28 08:44:46.527741-06	2	[11763] IC-221 Connect	[4] DLarrabee	[21062] a	\N	\N
750a79a2-f3fc-47fb-a6e5-d17130c1c1a8	2018-02-28 08:44:46.530742-06	2	[11764] IC-222 Connect	[4] DLarrabee	[21062] a	\N	\N
3ae180c4-2ef6-4859-8e85-f4b594b8103e	2018-02-28 08:44:46.533742-06	2	[11765] IC-223-InB Connect	[4] DLarrabee	[21062] a	\N	\N
a03bfeaf-13de-4971-939f-b0fd8195ad9c	2018-02-28 08:44:46.537742-06	2	[11766] IC-223-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
d0c11f40-9e75-4e66-a905-4fd3bd3b7ebd	2018-02-28 08:44:46.539743-06	2	[11767] IC-224-InB Connect	[4] DLarrabee	[21062] a	\N	\N
485230a2-132e-4109-9da0-e4f36d27bd14	2018-02-28 08:44:46.542743-06	2	[11768] IC-224-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
dc2991de-157b-44e9-8bfb-3a9d12175cdb	2018-02-28 08:44:46.545743-06	2	[11769] IC-225 Connect	[4] DLarrabee	[21062] a	\N	\N
dcc7371b-ba9c-4e88-a4f1-acb9e111b3ef	2018-02-28 08:44:46.549744-06	2	[11795] IC-219 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
671192cb-876b-4199-bebd-06be0fc8a20a	2018-02-28 08:44:46.552744-06	2	[11796] IC-221 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
51cbb7be-614f-4aa6-8998-933cc0b381c6	2018-02-28 08:44:46.556744-06	2	[11797] IC-222 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d5dbf1fd-c8c5-43d5-a7ba-2019e07b8441	2018-02-28 08:44:46.560745-06	2	[11798] IC-223-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
27ac93b1-2be1-47ef-8919-e95ec6bde829	2018-02-28 08:44:46.563745-06	2	[11799] IC-223-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
98418af0-51b3-4fad-abc3-6274417333ed	2018-02-28 08:44:46.567745-06	2	[11800] IC-224-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6882e702-157a-4520-8fb8-633ecea82eb7	2018-02-28 08:44:46.571746-06	2	[11801] IC-224-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
adef2f5a-a45a-4146-8125-a511066e976b	2018-02-28 08:44:46.575746-06	2	[11802] IC-225 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f21818f6-1ed2-4d76-ab8e-d404c543a8d5	2018-02-28 08:44:46.578747-06	2	[11814] IC-219 Call	[4] DLarrabee	[21062] a	\N	\N
da4e912f-070b-44f3-9460-f5f0fd5eeae9	2018-02-28 08:44:46.581747-06	2	[11815] IC-221 Call	[4] DLarrabee	[21062] a	\N	\N
79a71266-6222-47b3-92ef-6d3763c3a825	2018-02-28 08:44:46.584747-06	2	[11816] IC-222 Call	[4] DLarrabee	[21062] a	\N	\N
469839bf-91e0-4ce8-bee6-ee58318354b0	2018-02-28 08:44:46.587747-06	2	[11817] IC-223-InB Call	[4] DLarrabee	[21062] a	\N	\N
e3db93b2-d280-40ba-be7f-574ed655a943	2018-02-28 08:44:46.590748-06	2	[11818] IC-223-OutB Call	[4] DLarrabee	[21062] a	\N	\N
5e7af152-b830-4694-ad6b-8b105388eb0b	2018-02-28 08:44:46.593748-06	2	[11819] IC-224-InB Call	[4] DLarrabee	[21062] a	\N	\N
20b2a64a-9e79-455d-8ff9-e74bee7e40f5	2018-02-28 08:44:46.596748-06	2	[11820] IC-224-OutB Call	[4] DLarrabee	[21062] a	\N	\N
e1307581-e9f2-42b5-a8e0-0ccf9dc86cce	2018-02-28 08:44:46.600749-06	2	[11821] IC-225 Call	[4] DLarrabee	[21062] a	\N	\N
10418aa7-6d1f-4656-8822-50b0ff431f11	2018-02-28 08:44:46.729762-06	2	[12182] R5C10-8IC	[4] DLarrabee	[21062] a	\N	\N
96051f4f-fb7e-4168-8549-c9a0d05755c3	2018-02-28 08:44:46.744763-06	2	[12184] IC-226 Call Button	[4] DLarrabee	[21062] a	\N	\N
5e3cfb0e-0bb0-4b91-826b-cd21c26d8a7d	2018-02-28 08:44:46.759765-06	2	[12185] IC-227 Call Button	[4] DLarrabee	[21062] a	\N	\N
ce530faa-2764-4ff2-9dd9-f9aa5fad1abc	2018-02-28 08:44:46.775766-06	2	[12186] IC-228 Call Button	[4] DLarrabee	[21062] a	\N	\N
1c3ad15c-7a65-45f0-9640-7b025a24ac51	2018-02-28 08:44:46.789768-06	2	[12187] IC-231 Call Button	[4] DLarrabee	[21062] a	\N	\N
2b87db70-05a3-434f-9438-27283b7cb306	2018-02-28 08:44:46.804769-06	2	[12188] IC-232 Call Button	[4] DLarrabee	[21062] a	\N	\N
422131b0-9e5e-4811-8041-68b79f1b5f34	2018-02-28 08:44:46.820771-06	2	[12189] IC-233 Call Button	[4] DLarrabee	[21062] a	\N	\N
96b71497-4cf0-43aa-888a-d6d9cec1dd02	2018-02-28 08:44:46.835772-06	2	[12190] IC-235 Call Button	[4] DLarrabee	[21062] a	\N	\N
8d00bcbe-6b85-4cc1-b4c9-8ea5e09d2879	2018-02-28 08:44:46.848774-06	2	[12191] IC-236-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
ee01d9d3-f4ce-4334-afba-7b25ba3c9c77	2018-02-28 08:44:46.862775-06	2	[12193] IC-226 Relay	[4] DLarrabee	[21062] a	\N	\N
5253cb18-a0ef-4916-b0a2-1a6b0e716919	2018-02-28 08:44:46.876776-06	2	[12194] IC-227 Relay	[4] DLarrabee	[21062] a	\N	\N
25750030-08a6-4247-86b7-e7155c8a4c11	2018-02-28 08:44:46.892778-06	2	[12195] IC-228 Relay	[4] DLarrabee	[21062] a	\N	\N
c3d37c98-8c41-4e5d-aeb4-10bf65fa0cba	2018-02-28 08:44:46.907779-06	2	[12196] IC-231 Relay	[4] DLarrabee	[21062] a	\N	\N
654e9234-40ce-4517-9df1-03565e830efe	2018-02-28 08:44:46.922781-06	2	[12197] IC-232 Relay	[4] DLarrabee	[21062] a	\N	\N
4941bd73-8904-47ce-a4d6-8441dba7c89a	2018-02-28 08:44:46.941783-06	2	[12198] IC-233 Relay	[4] DLarrabee	[21062] a	\N	\N
2d46d0f6-b68d-42a7-8d2a-611691e032a0	2018-02-28 08:44:46.957784-06	2	[12199] IC-235 Relay	[4] DLarrabee	[21062] a	\N	\N
c1fe346e-6f57-41d2-9803-a5177819df57	2018-02-28 08:44:46.973786-06	2	[12200] IC-236-InB Relay	[4] DLarrabee	[21062] a	\N	\N
abca8c31-c382-4596-a4ef-4a1abe980014	2018-02-28 08:44:46.978787-06	2	[12202] IC-226 Connect	[4] DLarrabee	[21062] a	\N	\N
c68d041c-1a27-4c5b-8d69-aec6ae00356d	2018-02-28 08:44:46.981787-06	2	[12203] IC-227 Connect	[4] DLarrabee	[21062] a	\N	\N
736928b2-a45d-42f9-ad59-59eb3e7b3dbd	2018-02-28 08:44:46.985787-06	2	[12204] IC-228 Connect	[4] DLarrabee	[21062] a	\N	\N
c8bf4d39-7efb-40ce-891d-50d4ea3f175f	2018-02-28 08:44:46.988788-06	2	[12205] IC-231 Connect	[4] DLarrabee	[21062] a	\N	\N
e1d8c7f2-412d-4b05-ba28-30c3338e50ca	2018-02-28 08:44:46.991788-06	2	[12206] IC-232 Connect	[4] DLarrabee	[21062] a	\N	\N
65e6d80d-b360-46aa-b020-9378150745dd	2018-02-28 08:44:46.994788-06	2	[12207] IC-233 Connect	[4] DLarrabee	[21062] a	\N	\N
88dadf70-6c39-42f1-bcd9-e05bd0557145	2018-02-28 08:44:46.997788-06	2	[12208] IC-235 Connect	[4] DLarrabee	[21062] a	\N	\N
276cd9fb-b50a-406b-b1aa-10828d5c45fe	2018-02-28 08:44:47.001789-06	2	[12209] IC-236-InB Connect	[4] DLarrabee	[21062] a	\N	\N
5387c21b-d027-4863-a15f-644d7266e5cb	2018-02-28 08:44:47.004789-06	2	[12235] IC-226 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
979bb92b-272a-4792-92d5-583e2e51a360	2018-02-28 08:44:47.007789-06	2	[12236] IC-227 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cfd24cb4-6f0f-44c4-9138-703a61a16319	2018-02-28 08:44:47.01179-06	2	[12237] IC-228 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4d72e55d-fbd8-4369-8207-26209d3053f9	2018-02-28 08:44:47.01479-06	2	[12238] IC-231 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0abc2757-fbf7-4352-bcbb-779b4b79c831	2018-02-28 08:44:47.018791-06	2	[12239] IC-232 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1ec614dd-dc1d-4193-8d14-5a54cf93d77d	2018-02-28 08:44:47.022791-06	2	[12240] IC-233 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
65acb96c-b1f6-47a0-988f-832b8bafc98e	2018-02-28 08:44:47.025791-06	2	[12241] IC-235 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
30016fee-92a5-475f-a07b-b7c2579e4a81	2018-02-28 08:44:47.028792-06	2	[12242] IC-236-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
203d915b-86ac-41e7-b5e7-6e5bf4e327fa	2018-02-28 08:44:47.031792-06	2	[12254] IC-226 Call	[4] DLarrabee	[21062] a	\N	\N
af53cf15-f11c-48f9-ae8c-30458b6d5ccf	2018-02-28 08:44:47.034792-06	2	[12255] IC-227 Call	[4] DLarrabee	[21062] a	\N	\N
22f7552a-1e9b-4580-a45d-eaf9b67f848c	2018-02-28 08:44:47.038793-06	2	[12256] IC-228 Call	[4] DLarrabee	[21062] a	\N	\N
785c002c-51e5-4d41-b975-09e0a0153eb2	2018-02-28 08:44:47.042793-06	2	[12257] IC-231 Call	[4] DLarrabee	[21062] a	\N	\N
284353a6-2f18-4151-a33a-33411b1a86d8	2018-02-28 08:44:47.045793-06	2	[12258] IC-232 Call	[4] DLarrabee	[21062] a	\N	\N
c7b8865b-8e83-46c3-b78e-1ebf97e91645	2018-02-28 08:44:47.049794-06	2	[12259] IC-233 Call	[4] DLarrabee	[21062] a	\N	\N
781548e1-165e-4fa5-950b-f9535c273f8e	2018-02-28 08:44:47.052794-06	2	[12260] IC-235 Call	[4] DLarrabee	[21062] a	\N	\N
7d60efdb-6321-4e21-a33f-b49ae881377d	2018-02-28 08:44:47.055794-06	2	[12261] IC-236-InB Call	[4] DLarrabee	[21062] a	\N	\N
5ebe9d69-c1cd-4cfc-b260-d5eac29a9d82	2018-02-28 08:44:47.171806-06	2	[12622] R5C11-8IC	[4] DLarrabee	[21062] a	\N	\N
50eaf267-701d-4609-9df2-6d77aea2eb34	2018-02-28 08:44:47.186807-06	2	[12624] IC-236-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
41cf3511-f5c0-442b-bd29-30249552ee2f	2018-02-28 08:44:47.200809-06	2	[12625] IC-237A-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
841824c6-dd94-42d2-8883-772097115fff	2018-02-28 08:44:47.21281-06	2	[12626] IC-237A-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
5a2bfe28-d333-4f24-ae3f-700aff41b781	2018-02-28 08:44:47.227811-06	2	[12627] IC-237B-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
e681c9ff-47e7-4e40-9cbd-79fbf5ec5832	2018-02-28 08:44:47.246813-06	2	[12628] IC-237B-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
171d07ef-15a0-4d35-9e68-0bf4637f6eb1	2018-02-28 08:44:47.265815-06	2	[12629] IC-239 Call Button	[4] DLarrabee	[21062] a	\N	\N
bc99a7c4-99ba-4a70-8f47-0df2be52bb48	2018-02-28 08:44:47.285817-06	2	[12630] IC-241 Call Button	[4] DLarrabee	[21062] a	\N	\N
c2ba8d77-476b-483b-886e-4a316defc73c	2018-02-28 08:44:47.303819-06	2	[12631] IC-242 Call Button	[4] DLarrabee	[21062] a	\N	\N
c6166419-b175-418c-ad18-d3331e0d066a	2018-02-28 08:44:47.318821-06	2	[12633] IC-236-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
0657df6b-4f51-4d36-bb22-eaf1e230da7e	2018-02-28 08:44:47.335822-06	2	[12634] IC-237A-InB Relay	[4] DLarrabee	[21062] a	\N	\N
3c15f7d4-daaa-4b73-88b0-30f8015f933a	2018-02-28 08:44:47.351824-06	2	[12635] IC-237A-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
6cd4f4c3-8c82-41d5-8a94-e6b1f8adb21b	2018-02-28 08:44:47.366825-06	2	[12636] IC-237B-InB Relay	[4] DLarrabee	[21062] a	\N	\N
cf77f4b2-5989-422c-af8a-fe3554630592	2018-02-28 08:44:47.385827-06	2	[12637] IC-237B-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
65abcb2a-c99a-4fc4-a404-3a752ae2ffb8	2018-02-28 08:44:47.405829-06	2	[12638] IC-239 Relay	[4] DLarrabee	[21062] a	\N	\N
030da0ea-313d-4851-bc5e-68d6bf8e83ea	2018-02-28 08:44:47.418831-06	2	[12639] IC-241 Relay	[4] DLarrabee	[21062] a	\N	\N
f73fb1b0-4aee-4b11-bdc3-652c7c17a325	2018-02-28 08:44:47.436832-06	2	[12640] IC-242 Relay	[4] DLarrabee	[21062] a	\N	\N
9b943ddc-b947-40c4-ae48-460f0eeb45ae	2018-02-28 08:44:47.439833-06	2	[12642] IC-236-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
73a61714-46f2-4cf9-9545-3cd0e1536bc0	2018-02-28 08:44:47.442833-06	2	[12643] IC-237A-InB Connect	[4] DLarrabee	[21062] a	\N	\N
5aaba650-5fd4-42f2-9165-fec0e53956c3	2018-02-28 08:44:47.445833-06	2	[12644] IC-237A-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
17da4933-0499-4825-905f-e352e9ed5ed8	2018-02-28 08:44:47.449834-06	2	[12645] IC-237B-InB Connect	[4] DLarrabee	[21062] a	\N	\N
b8185096-160a-4618-b2cd-e6cd896edeb3	2018-02-28 08:44:47.453834-06	2	[12646] IC-237B-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
6fd7be84-2e5f-4272-be1d-f1907812cf03	2018-02-28 08:44:47.457834-06	2	[12647] IC-239 Connect	[4] DLarrabee	[21062] a	\N	\N
8d56c29d-07d6-4181-abc1-4e5b8e7b1258	2018-02-28 08:44:47.461835-06	2	[12648] IC-241 Connect	[4] DLarrabee	[21062] a	\N	\N
0cdd6e49-e8af-419d-8a86-916853d6c09b	2018-02-28 08:44:47.465835-06	2	[12649] IC-242 Connect	[4] DLarrabee	[21062] a	\N	\N
dfbf3ed4-fe91-4eee-bf70-4c3e702ad74e	2018-02-28 08:44:47.468836-06	2	[12675] IC-236-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ceef82e5-5371-4991-9c7c-567c8465e5f1	2018-02-28 08:44:47.471836-06	2	[12676] IC-237A-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cc3aff40-ae81-4d98-a70e-c1c903c339aa	2018-02-28 08:44:47.474836-06	2	[12677] IC-237A-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
eb0842a3-c61a-477d-9acd-17579e401648	2018-02-28 08:44:47.479837-06	2	[12678] IC-237B-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f2825ecb-b1b1-4335-ad34-a1459bcf5b8b	2018-02-28 08:44:47.482837-06	2	[12679] IC-237B-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2b8281a2-eb18-42c7-b2bb-99ada8ab8638	2018-02-28 08:44:47.484837-06	2	[12680] IC-239 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8fbb726b-70b7-44fa-a32a-0ea6950a9179	2018-02-28 08:44:47.488838-06	2	[12681] IC-241 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
318b010c-7dee-4d5c-ae7b-bd48f1caf0ba	2018-02-28 08:44:47.492838-06	2	[12682] IC-242 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a538ff11-bcbe-4af2-82cd-68c822b412b9	2018-02-28 08:44:47.495838-06	2	[12694] IC-236-OutB Call	[4] DLarrabee	[21062] a	\N	\N
f4a6f73c-f46f-47d9-82a7-0dcedd3c7764	2018-02-28 08:44:47.499839-06	2	[12695] IC-237A-InB Call	[4] DLarrabee	[21062] a	\N	\N
a07a67a7-8251-4ff7-b8be-98895a3a69b1	2018-02-28 08:44:47.503839-06	2	[12696] IC-237A-OutB Call	[4] DLarrabee	[21062] a	\N	\N
6235497e-fecb-4dd7-a3a1-4e112ef2f57f	2018-02-28 08:44:47.507839-06	2	[12697] IC-237B-InB Call	[4] DLarrabee	[21062] a	\N	\N
d26cd23d-7116-4310-b717-f60610732296	2018-02-28 08:44:47.51184-06	2	[12698] IC-237B-OutB Call	[4] DLarrabee	[21062] a	\N	\N
0281c239-f81e-46ef-84db-2d49ed608065	2018-02-28 08:44:47.51584-06	2	[12699] IC-239 Call	[4] DLarrabee	[21062] a	\N	\N
280f5baf-ba8d-4642-9778-17d3bcf57d98	2018-02-28 08:44:47.518841-06	2	[12700] IC-241 Call	[4] DLarrabee	[21062] a	\N	\N
9f6a6a7c-ebac-4410-a76c-656dfae81ad5	2018-02-28 08:44:47.521841-06	2	[12701] IC-242 Call	[4] DLarrabee	[21062] a	\N	\N
1181c81f-2d32-4121-98ec-8996b407b190	2018-02-28 08:44:47.642853-06	2	[13062] R5C12-8IC	[4] DLarrabee	[21062] a	\N	\N
b9c0a114-5d0a-43b0-96d0-a90155b21af8	2018-02-28 08:44:47.655854-06	2	[13064] IC-243 Call Button	[4] DLarrabee	[21062] a	\N	\N
651899f3-0304-41b6-8541-c7edc17dd7c4	2018-02-28 08:44:47.669856-06	2	[13065] IC-245 Call Button	[4] DLarrabee	[21062] a	\N	\N
6ff68f36-5fa4-46f6-be7b-2ca691512fb0	2018-02-28 08:44:47.681857-06	2	[13066] IC-246-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
c6f8c973-713a-44e9-bebe-e9bf569fbecf	2018-02-28 08:44:47.694858-06	2	[13067] IC-246-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
f6e6cd3e-0644-4f1f-b8c4-a8f0758f328c	2018-02-28 08:44:47.71286-06	2	[13068] IC-247-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
697221bc-415e-4bb1-8496-f2b04fe7f980	2018-02-28 08:44:47.729862-06	2	[13069] IC-247-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
7d3c17e9-ad73-464e-9b59-9d4ec860e7bc	2018-02-28 08:44:47.744863-06	2	[13070] IC-248-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
69f17218-157c-415b-819d-f6608c18cbc9	2018-02-28 08:44:47.759865-06	2	[13071] IC-248-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
eeb42a3f-3c80-4095-8242-80d58f1f0b9e	2018-02-28 08:44:47.772866-06	2	[13073] IC-243 Relay	[4] DLarrabee	[21062] a	\N	\N
160b536c-790c-42e3-b644-9fa99a6b930c	2018-02-28 08:44:47.787867-06	2	[13074] IC-245 Relay	[4] DLarrabee	[21062] a	\N	\N
3ba976a2-32ee-46d1-b2ad-e2a9266ca2af	2018-02-28 08:44:47.805869-06	2	[13075] IC-246-InB Relay	[4] DLarrabee	[21062] a	\N	\N
e75bfbb1-742f-4719-9e71-1168153c8c0e	2018-02-28 08:44:47.822871-06	2	[13076] IC-246-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
c7008c44-f539-4bbf-bbf4-31a6bcfcd43d	2018-02-28 08:44:47.836872-06	2	[13077] IC-247-InB Relay	[4] DLarrabee	[21062] a	\N	\N
e1866f33-40e9-4399-afec-eb4fbc80b780	2018-02-28 08:44:47.886877-06	2	[13078] IC-247-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
dbba5b33-1c0f-4471-a12b-9e1aab14dc7d	2018-02-28 08:44:47.907879-06	2	[13079] IC-248-InB Relay	[4] DLarrabee	[21062] a	\N	\N
1ce10d51-d7cc-4569-a597-961201fe9672	2018-02-28 08:44:47.927881-06	2	[13080] IC-248-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
bf1a8b54-3da5-4819-a6c6-4097fcaa0f06	2018-02-28 08:44:47.935882-06	2	[13082] IC-243 Connect	[4] DLarrabee	[21062] a	\N	\N
e25749f4-67e8-47ad-86a2-7fdf93745169	2018-02-28 08:44:47.939883-06	2	[13083] IC-245 Connect	[4] DLarrabee	[21062] a	\N	\N
37e4c705-22c9-4484-b235-718894f3f156	2018-02-28 08:44:47.943883-06	2	[13084] IC-246-InB Connect	[4] DLarrabee	[21062] a	\N	\N
afa6adf4-2568-45c8-a59e-6d889b85f12e	2018-02-28 08:44:47.947883-06	2	[13085] IC-246-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
94f03042-82e0-4347-acfb-b8c079847efc	2018-02-28 08:44:47.952884-06	2	[13086] IC-247-InB Connect	[4] DLarrabee	[21062] a	\N	\N
ca96e616-0a81-42fd-a88c-53dfe65ebf78	2018-02-28 08:44:47.956884-06	2	[13087] IC-247-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
411e6d05-48b9-4531-a504-d4d03c4ebfc1	2018-02-28 08:44:47.960885-06	2	[13088] IC-248-InB Connect	[4] DLarrabee	[21062] a	\N	\N
e42641ed-388c-41ba-b66e-b1909dc9e10d	2018-02-28 08:44:47.963885-06	2	[13089] IC-248-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
aa311b8c-3f5d-4b87-92dc-015aa92a8479	2018-02-28 08:44:47.968886-06	2	[13115] IC-243 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
286235e8-500f-4d8b-87f2-f56edb6523b3	2018-02-28 08:44:47.973886-06	2	[13116] IC-245 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a797836a-ec0f-4d1d-841a-472deda58b4b	2018-02-28 08:44:47.976886-06	2	[13117] IC-246-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
afaf9730-1ac6-4c7a-8bdf-ff73269e2873	2018-02-28 08:44:47.979887-06	2	[13118] IC-246-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e427a165-674c-4621-8fe5-968a1bff9edf	2018-02-28 08:44:47.984887-06	2	[13119] IC-247-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
960b5107-dca2-4c78-a62a-736a9306cf94	2018-02-28 08:44:47.987887-06	2	[13120] IC-247-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
141e46bd-ca18-4415-9a13-d9384369adfe	2018-02-28 08:44:47.990888-06	2	[13121] IC-248-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c83fc147-eda8-429e-b0a2-7abb06c8db52	2018-02-28 08:44:47.994888-06	2	[13122] IC-248-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0639f4b6-74c1-4442-b5e7-ea4bd7a54a7a	2018-02-28 08:44:47.997888-06	2	[13134] IC-243 Call	[4] DLarrabee	[21062] a	\N	\N
6574f679-ca14-4838-8f04-1fbcb5dd3110	2018-02-28 08:44:47.999889-06	2	[13135] IC-245 Call	[4] DLarrabee	[21062] a	\N	\N
a219aad7-7ae7-41d8-9ba0-3e6c3816dad7	2018-02-28 08:44:48.003889-06	2	[13136] IC-246-InB Call	[4] DLarrabee	[21062] a	\N	\N
ed678721-9810-4e49-ba6e-a0b0600c4850	2018-02-28 08:44:48.007889-06	2	[13137] IC-246-OutB Call	[4] DLarrabee	[21062] a	\N	\N
884768e1-77bf-4238-92f7-992e7a00be64	2018-02-28 08:44:48.00989-06	2	[13138] IC-247-InB Call	[4] DLarrabee	[21062] a	\N	\N
e4a7fbd0-a128-4eca-af6d-495e280e6413	2018-02-28 08:44:48.01389-06	2	[13139] IC-247-OutB Call	[4] DLarrabee	[21062] a	\N	\N
2f4b32af-3780-4a35-866c-ddc602118310	2018-02-28 08:44:48.01789-06	2	[13140] IC-248-InB Call	[4] DLarrabee	[21062] a	\N	\N
bfa70ea3-14c0-4a04-bc41-c2b67c4b0972	2018-02-28 08:44:48.020891-06	2	[13141] IC-248-OutB Call	[4] DLarrabee	[21062] a	\N	\N
8c7c4d3b-1c3c-459b-bc0a-27ab6ff50a8f	2018-02-28 08:44:48.148904-06	2	[13502] R5C13-8IC	[4] DLarrabee	[21062] a	\N	\N
869ef515-3f04-4729-bda3-2ed2b6d0fd70	2018-02-28 08:44:48.161905-06	2	[13504] IC-252-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
1ad59bf7-758d-4a70-ac9b-6b346ccf8876	2018-02-28 08:44:48.176906-06	2	[13505] IC-252-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
a1ab24a9-f8fc-41a2-b956-8e64d674610d	2018-02-28 08:44:48.193908-06	2	[13506] IC-253-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
b14e32cd-4008-4cd9-b833-8afa80578615	2018-02-28 08:44:48.21391-06	2	[13507] IC-253-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
419b1fce-1b50-4823-9da5-b27ccbe577ac	2018-02-28 08:44:48.225911-06	2	[13508] IC-259-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
bc0002c0-f688-445e-9826-7067b091f83a	2018-02-28 08:44:48.249914-06	2	[13509] IC-259-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
3b38ce95-29a0-40b0-9825-56134335ed17	2018-02-28 08:44:48.264915-06	2	[13510] IC-261-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
9383d767-7f52-4eeb-88e6-57c4cae02bd1	2018-02-28 08:44:48.91098-06	2	[14020] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
3a890c35-7fa2-41e3-b336-eb07b75f3364	2018-02-28 08:44:48.278917-06	2	[13511] IC-261-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
63f7df78-f905-42c8-b40f-ff59ef0c6f26	2018-02-28 08:44:48.291918-06	2	[13513] IC-252-InB Relay	[4] DLarrabee	[21062] a	\N	\N
aa5e1d06-79cb-43ce-b5f1-61f2dc63e9c6	2018-02-28 08:44:48.302919-06	2	[13514] IC-252-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
0affa18a-281f-4083-91d6-e59577cdb63b	2018-02-28 08:44:48.31492-06	2	[13515] IC-253-InB Relay	[4] DLarrabee	[21062] a	\N	\N
ad1ad388-6c14-41a9-a863-b5ffd4d15be6	2018-02-28 08:44:48.331922-06	2	[13516] IC-253-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
f3f63439-6202-4354-aa8f-70c0680a41d5	2018-02-28 08:44:48.348924-06	2	[13517] IC-259-InB Relay	[4] DLarrabee	[21062] a	\N	\N
3f216149-a0cb-4d64-a256-31845f73e9f5	2018-02-28 08:44:48.367925-06	2	[13518] IC-259-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
63e0624f-0f3e-4a20-a2b4-0d0cd81208e9	2018-02-28 08:44:48.385927-06	2	[13519] IC-261-InB Relay	[4] DLarrabee	[21062] a	\N	\N
68509f94-8090-4504-92c4-d72b58766a01	2018-02-28 08:44:48.400929-06	2	[13520] IC-261-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
8c023afc-7344-42d2-8057-44c839654695	2018-02-28 08:44:48.403929-06	2	[13522] IC-252-InB Connect	[4] DLarrabee	[21062] a	\N	\N
6deac0de-dcbe-46e8-bdd6-35ba23bc05a2	2018-02-28 08:44:48.406929-06	2	[13523] IC-252-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
bc0af506-88df-414e-a357-d0b1bc896b5d	2018-02-28 08:44:48.41093-06	2	[13524] IC-253-InB Connect	[4] DLarrabee	[21062] a	\N	\N
915b9d78-ec4c-4f0f-8386-f1afc72f91e8	2018-02-28 08:44:48.41393-06	2	[13525] IC-253-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
3f1355cb-88ae-46bc-be01-3b5bee607bcf	2018-02-28 08:44:48.41793-06	2	[13526] IC-259-InB Connect	[4] DLarrabee	[21062] a	\N	\N
86ce15e5-66e0-4013-a328-4eaecdb5285b	2018-02-28 08:44:48.421931-06	2	[13527] IC-259-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
b50dacda-d887-4558-bbac-2a7fd7219a55	2018-02-28 08:44:48.424931-06	2	[13528] IC-261-InB Connect	[4] DLarrabee	[21062] a	\N	\N
9922885c-8aa5-42c8-8c22-d17d7a1593f1	2018-02-28 08:44:48.428932-06	2	[13529] IC-261-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
dbc18ed7-c566-41b8-b0a2-a050d92d9e74	2018-02-28 08:44:48.431932-06	2	[13555] IC-252-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3b212414-c90c-4408-94db-ace54043d456	2018-02-28 08:44:48.434932-06	2	[13556] IC-252-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7f7aba00-431e-4230-a154-56cfb76d192e	2018-02-28 08:44:48.436932-06	2	[13557] IC-253-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
96896048-8f12-4f29-96e9-9938f3209574	2018-02-28 08:44:48.440933-06	2	[13558] IC-253-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
df756367-1d15-4a31-bb1c-436f4bb2ce8f	2018-02-28 08:44:48.443933-06	2	[13559] IC-259-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
987f6960-e083-440c-9d1d-0bca18b0be75	2018-02-28 08:44:48.446933-06	2	[13560] IC-259-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
74ce4408-afd6-44cf-b03b-1b45fd731f75	2018-02-28 08:44:48.449934-06	2	[13561] IC-261-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
80f0eacd-9261-43be-ba26-1dc08317a35a	2018-02-28 08:44:48.453934-06	2	[13562] IC-261-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
90dcb64d-602b-4324-a6c3-d792ff040b4c	2018-02-28 08:44:48.455934-06	2	[13574] IC-252-InB Call	[4] DLarrabee	[21062] a	\N	\N
c96e0829-8235-4095-80b8-e458dd63a824	2018-02-28 08:44:48.458935-06	2	[13575] IC-252-OutB Call	[4] DLarrabee	[21062] a	\N	\N
d5fde55d-1076-40ff-aac8-370acf41f5a1	2018-02-28 08:44:48.462935-06	2	[13576] IC-253-InB Call	[4] DLarrabee	[21062] a	\N	\N
6ea03e26-d61b-4ab4-a098-bf164216b8e0	2018-02-28 08:44:48.466935-06	2	[13577] IC-253-OutB Call	[4] DLarrabee	[21062] a	\N	\N
856044d5-efbf-42b7-b3ec-41cf0afe513d	2018-02-28 08:44:48.469936-06	2	[13578] IC-259-InB Call	[4] DLarrabee	[21062] a	\N	\N
90199e66-ccd9-44f6-9275-1836ea316225	2018-02-28 08:44:48.471936-06	2	[13579] IC-259-OutB Call	[4] DLarrabee	[21062] a	\N	\N
fd7521cb-6103-4624-ad9a-5047a3fc33b1	2018-02-28 08:44:48.475936-06	2	[13580] IC-261-InB Call	[4] DLarrabee	[21062] a	\N	\N
70aa68af-5747-4b39-a717-89152eddddea	2018-02-28 08:44:48.479937-06	2	[13581] IC-261-OutB Call	[4] DLarrabee	[21062] a	\N	\N
6fb8276b-bf5f-4190-b577-8e807b050a4c	2018-02-28 08:44:48.597948-06	2	[13942] R5C14-8IC	[4] DLarrabee	[21062] a	\N	\N
9aa3914f-3aaa-4560-b7e6-30ac51a4004e	2018-02-28 08:44:48.60995-06	2	[13944] IC-301A-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
984fa3ea-bfa6-49e2-a995-21f3f77c98af	2018-02-28 08:44:48.622951-06	2	[13945] IC-301A-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
6092e7cb-0e78-4876-83fb-0299b6a7f60c	2018-02-28 08:44:48.634952-06	2	[13946] IC-301B-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
044e08ea-1ca6-4fae-9db4-2155771092f9	2018-02-28 08:44:48.649954-06	2	[13947] IC-301B-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
2e20104a-ccc9-48f7-b587-7ab75aeb0e58	2018-02-28 08:44:48.663955-06	2	[13948] IC-306-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
aee25318-0601-442d-a1ce-ecec5f766590	2018-02-28 08:44:48.676956-06	2	[13949] IC-306-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
e3200054-9920-46d8-8b41-3d9374b9ad42	2018-02-28 08:44:48.691958-06	2	[13950] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
3def4f7f-5771-4656-ac94-40531d5aa1c3	2018-02-28 08:44:48.704959-06	2	[13951] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
6bf10415-d4f9-44f8-9ba4-69563dbfd1ef	2018-02-28 08:44:48.719961-06	2	[13953] IC-301A-InB Relay	[4] DLarrabee	[21062] a	\N	\N
7afbf4df-ab3b-499a-ad54-61db75bf6897	2018-02-28 08:44:48.736962-06	2	[13954] IC-301A-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
03769987-c294-4a38-b322-8491f6223556	2018-02-28 08:44:48.751964-06	2	[13955] IC-301B-InB Relay	[4] DLarrabee	[21062] a	\N	\N
d0450c15-89f0-4993-971c-c08e900e6ceb	2018-02-28 08:44:48.764965-06	2	[13956] IC-301B-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
78d6f0c6-1cbd-46e9-830e-313299b44996	2018-02-28 08:44:48.779967-06	2	[13957] IC-306-InB Relay	[4] DLarrabee	[21062] a	\N	\N
525043c7-e2ca-4873-b05f-e0097ab68ed6	2018-02-28 08:44:48.796968-06	2	[13958] IC-306-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
a058e3c4-2e76-452d-8b79-46169d958266	2018-02-28 08:44:48.81397-06	2	[13959] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
9ce3f917-151b-432d-b3db-7b0cd1584090	2018-02-28 08:44:48.831972-06	2	[13960] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
dc21e49a-625a-48bc-a6ef-b3040af45ee0	2018-02-28 08:44:48.834972-06	2	[13962] IC-301A-InB Connect	[4] DLarrabee	[21062] a	\N	\N
f18ef73f-bcf0-48c3-b3ba-07f041f9cce8	2018-02-28 08:44:48.838973-06	2	[13963] IC-301A-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
3325bee5-48fb-4925-b1a3-0e9bc53c5539	2018-02-28 08:44:48.840973-06	2	[13964] IC-301B-InB Connect	[4] DLarrabee	[21062] a	\N	\N
4d5afe1f-30f0-424c-9fab-58e77ec923be	2018-02-28 08:44:48.845973-06	2	[13965] IC-301B-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
3d18cf21-433d-4418-8f5a-d59224045f9a	2018-02-28 08:44:48.848974-06	2	[13966] IC-306-InB Connect	[4] DLarrabee	[21062] a	\N	\N
52b324ae-ec26-4165-95b0-19e5893651a2	2018-02-28 08:44:48.852974-06	2	[13967] IC-306-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
34b46eaf-c92c-4e5a-b1e7-5b6c4be47fbb	2018-02-28 08:44:48.855974-06	2	[13968] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
37891ec2-98d0-4d19-8f61-335e356f8859	2018-02-28 08:44:48.859975-06	2	[13969] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
2cb8deb0-e553-4da2-a34d-38d547de4bd0	2018-02-28 08:44:48.863975-06	2	[13995] IC-301A-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b55d3ab9-1e92-415b-9a3c-4a515d17ec96	2018-02-28 08:44:48.867975-06	2	[13996] IC-301A-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
08da4b65-df8b-44f5-b35f-f65d0e6fa7be	2018-02-28 08:44:48.870976-06	2	[13997] IC-301B-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
895f1d47-9aff-44ac-aae4-c52c2e1c8fa4	2018-02-28 08:44:48.873976-06	2	[13998] IC-301B-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e775298b-7ab1-43b2-9ac4-bdd9792200bf	2018-02-28 08:44:48.877976-06	2	[13999] IC-306-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
021bcd20-8118-48c5-82e6-3c770dbd933d	2018-02-28 08:44:48.880977-06	2	[14000] IC-306-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6fbb9219-f6d1-4f89-991b-8f799aa5f6a5	2018-02-28 08:44:48.884977-06	2	[14001] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
aaf86521-baaf-4da4-9c12-7d86ad47f1b9	2018-02-28 08:44:48.887977-06	2	[14002] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
79d40cc0-06d8-4501-b9aa-78f4dfe49351	2018-02-28 08:44:48.890978-06	2	[14014] IC-301A-InB Call	[4] DLarrabee	[21062] a	\N	\N
d5394f77-782f-4976-bade-c8cd793153d2	2018-02-28 08:44:48.894978-06	2	[14015] IC-301A-OutB Call	[4] DLarrabee	[21062] a	\N	\N
76608e10-c94d-46d4-8296-1e306dc8c35d	2018-02-28 08:44:48.897978-06	2	[14016] IC-301B-InB Call	[4] DLarrabee	[21062] a	\N	\N
0d0bd695-eac0-4f44-9d43-5ed77ec6ef30	2018-02-28 08:44:48.901979-06	2	[14017] IC-301B-OutB Call	[4] DLarrabee	[21062] a	\N	\N
8b46ce9f-c0a9-4c46-af51-4d3812d39ced	2018-02-28 08:44:48.904979-06	2	[14018] IC-306-InB Call	[4] DLarrabee	[21062] a	\N	\N
7c005262-7c9f-483a-9bb0-c7aef473b803	2018-02-28 08:44:48.907979-06	2	[14019] IC-306-OutB Call	[4] DLarrabee	[21062] a	\N	\N
dcf47283-4522-405c-b26f-c24a435d594c	2018-02-28 08:44:48.91498-06	2	[14021] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
a92d0ab5-0649-467c-af3e-243e9d410f83	2018-02-28 08:44:48.932982-06	2	[14382] R6C1-32I	[4] DLarrabee	[21062] a	\N	\N
8f70c4a1-7b07-45a3-8c0c-379c4e5f05df	2018-02-28 08:44:48.950984-06	2	[14384] DPIS-103 Call Button	[4] DLarrabee	[21062] a	\N	\N
a40f7213-53b1-41af-8121-893d2fd80f36	2018-02-28 08:44:48.966985-06	2	[14385] DPIS-104 Call Button	[4] DLarrabee	[21062] a	\N	\N
90339d9d-965e-4a27-a7b0-6f4bb04c01fb	2018-02-28 08:44:48.984987-06	2	[14386] DPIS-105 Call Button	[4] DLarrabee	[21062] a	\N	\N
bcd666d2-a840-4c52-abad-b8b9519492ab	2018-02-28 08:44:48.998989-06	2	[14387] DPIS-107 Call Button	[4] DLarrabee	[21062] a	\N	\N
ff0c8666-8f1a-43c8-a09b-15017b8448b5	2018-02-28 08:44:49.01499-06	2	[14388] DPIS-108 Call Button	[4] DLarrabee	[21062] a	\N	\N
694593ae-7db5-49da-b8e8-36abd441d1da	2018-02-28 08:44:49.029992-06	2	[14389] DPIS-109 Call Button	[4] DLarrabee	[21062] a	\N	\N
cfe3b1ff-f086-4b36-ae98-bf481c3990d0	2018-02-28 08:44:49.043993-06	2	[14390] DPIS-112 Call Button	[4] DLarrabee	[21062] a	\N	\N
36d3b0bd-3eb7-41a6-bffa-ccbda6dfccdc	2018-02-28 08:44:49.058995-06	2	[14391] DPIS-113 Call Button	[4] DLarrabee	[21062] a	\N	\N
7f363c25-c6b0-4d85-91a4-e03927a23d4a	2018-02-28 08:44:49.072996-06	2	[14392] DPIS-114A Call Button	[4] DLarrabee	[21062] a	\N	\N
b65be589-4010-4fc7-b7b2-d24913996e38	2018-02-28 08:44:49.085997-06	2	[14393] DPIS-114B Call Button	[4] DLarrabee	[21062] a	\N	\N
84f363e4-16e0-4515-85ac-90aa78880b2e	2018-02-28 08:44:49.101999-06	2	[14394] DPIS-115 Call Button	[4] DLarrabee	[21062] a	\N	\N
0e151550-25f1-488b-8757-814c085e52e2	2018-02-28 08:44:49.120001-06	2	[14395] DPIS-116 Call Button	[4] DLarrabee	[21062] a	\N	\N
fe21c550-fb37-4c93-bf60-a363a47f7bac	2018-02-28 08:44:49.137002-06	2	[14396] DPIS-117 Call Button	[4] DLarrabee	[21062] a	\N	\N
947874b1-0cff-4e37-a4ad-b4f60326b3b5	2018-02-28 08:44:49.152004-06	2	[14397] DPIS-119 Call Button	[4] DLarrabee	[21062] a	\N	\N
20c6d9c7-c134-4f8c-b5f1-1704e234b88e	2018-02-28 08:44:49.170006-06	2	[14398] DPIS-121 Call Button	[4] DLarrabee	[21062] a	\N	\N
37c717ab-08b0-4a6e-bc75-884c08dc4973	2018-02-28 08:44:49.185007-06	2	[14399] DPIS-122 Call Button	[4] DLarrabee	[21062] a	\N	\N
dc3ef3c4-eada-488c-bb00-b92c65b8621c	2018-02-28 08:44:49.205009-06	2	[14400] DPIS-123 Call Button	[4] DLarrabee	[21062] a	\N	\N
d5958e4d-0ffe-494c-8977-797bbe8ab394	2018-02-28 08:44:49.224011-06	2	[14401] DPIS-124 Call Button	[4] DLarrabee	[21062] a	\N	\N
cf5f0cc5-d308-4bee-ba7e-83c32a6e9d8b	2018-02-28 08:44:49.238012-06	2	[14402] DPIS-125 Call Button	[4] DLarrabee	[21062] a	\N	\N
d5939e77-8a73-426a-9c01-75bf056b6356	2018-02-28 08:44:49.254014-06	2	[14403] DPIS-126 Call Button	[4] DLarrabee	[21062] a	\N	\N
8a81be04-6f76-435a-9ca6-0889568dd8ec	2018-02-28 08:44:49.270016-06	2	[14404] DPIS-128 Call Button	[4] DLarrabee	[21062] a	\N	\N
4e8dbd8f-2ca7-4297-a2e1-ffed120c43bb	2018-02-28 08:44:49.284017-06	2	[14405] DPIS-129 Call Button	[4] DLarrabee	[21062] a	\N	\N
6a0782bf-b1c1-49a8-9db4-98ed85be776e	2018-02-28 08:44:49.300019-06	2	[14406] DPIS-131 Call Button	[4] DLarrabee	[21062] a	\N	\N
ba0cde73-a5c2-48ea-b646-2dafa579ba4f	2018-02-28 08:44:49.31802-06	2	[14407] DPIS-132 Call Button	[4] DLarrabee	[21062] a	\N	\N
244ab338-346d-421d-b30b-c21b2361a0ff	2018-02-28 08:44:49.337022-06	2	[14408] DPIS-133 Call Button	[4] DLarrabee	[21062] a	\N	\N
863533d9-5746-429c-a497-1715b23d320d	2018-02-28 08:44:49.354024-06	2	[14409] DPIS-134A Call Button	[4] DLarrabee	[21062] a	\N	\N
085e4fb6-84d2-4906-bc97-3f896659c551	2018-02-28 08:44:49.371026-06	2	[14410] DPIS-134B Call Button	[4] DLarrabee	[21062] a	\N	\N
74b951d4-5738-4ad7-9642-61c7bc02c098	2018-02-28 08:44:49.391028-06	2	[14411] DPIS-136 Call Button	[4] DLarrabee	[21062] a	\N	\N
d7f3506e-9f7b-44c4-9a59-90f1742fc2e8	2018-02-28 08:44:49.40903-06	2	[14412] DPIS-137 Call Button	[4] DLarrabee	[21062] a	\N	\N
cabac291-cf92-44e0-adf3-19df6286a453	2018-02-28 08:44:49.427031-06	2	[14413] DPIS-138 Call Button	[4] DLarrabee	[21062] a	\N	\N
b67647cb-df76-4720-bbbc-259ef127262a	2018-02-28 08:44:49.442033-06	2	[14414] INPUT 31 Call Button	[4] DLarrabee	[21062] a	\N	\N
73c14506-c08c-4caa-99e8-a98b04fc2b56	2018-02-28 08:44:49.456034-06	2	[14415] DPIS-141 Call Button	[4] DLarrabee	[21062] a	\N	\N
89fa32fe-f9cf-4a5c-bf41-ed750e2a3781	2018-02-28 08:44:49.460035-06	2	[14451] DPIS-103 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1438b03a-b94e-46b6-beb7-3bdae34b8581	2018-02-28 08:44:49.465035-06	2	[14452] DPIS-104 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b4eca65b-1055-46ac-9d17-74e06fe27339	2018-02-28 08:44:49.469036-06	2	[14453] DPIS-105 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e0845c42-f711-48b5-ae91-2ab65be94b03	2018-02-28 08:44:49.472036-06	2	[14454] DPIS-107 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
94f7a580-31e3-4484-b336-9b462397049c	2018-02-28 08:44:49.475036-06	2	[14455] DPIS-108 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a14d94a9-2695-4133-ae33-f2c6e27267db	2018-02-28 08:44:49.478036-06	2	[14456] DPIS-109 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
5ee3b899-b76f-4324-9538-895516139eb9	2018-02-28 08:44:49.482037-06	2	[14457] DPIS-112 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
43b21d27-3d9c-4eaa-bbc9-b684926c78ee	2018-02-28 08:44:49.486037-06	2	[14458] DPIS-113 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1f905245-6fa1-4d61-af67-d0d3f90dc3c1	2018-02-28 08:44:49.490038-06	2	[14459] DPIS-114A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
10ba8983-5cb5-460f-8bb0-17dcfca10a08	2018-02-28 08:44:49.494038-06	2	[14460] DPIS-114B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b6ea9a62-17b9-4641-b912-7820b81ba978	2018-02-28 08:44:49.498038-06	2	[14461] DPIS-115 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
5a6704a3-e293-409b-9265-9d7e42363e4a	2018-02-28 08:44:49.502039-06	2	[14462] DPIS-116 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2e5f6943-5f24-4707-b66f-8e5e95a03e30	2018-02-28 08:44:49.506039-06	2	[14463] DPIS-117 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
bb1d447b-17d1-46d6-822e-8bc4affbac05	2018-02-28 08:44:49.51004-06	2	[14464] DPIS-119 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c1532011-9a33-4d1c-9d6c-dd84586be8cd	2018-02-28 08:44:49.51304-06	2	[14465] DPIS-121 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7d7ea78e-ca6e-408e-912c-cfd05fbfb920	2018-02-28 08:44:49.51704-06	2	[14466] DPIS-122 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
576165c0-7f0d-4ce6-8412-4db21ec0059b	2018-02-28 08:44:49.521041-06	2	[14467] DPIS-123 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b309d79d-d920-4c53-9b62-6e950fd50e82	2018-02-28 08:44:49.525041-06	2	[14468] DPIS-124 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3c5ade2a-fb04-48b1-8ec6-503db2b0d733	2018-02-28 08:44:49.528041-06	2	[14469] DPIS-125 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7a9dfd91-e2e9-4ebc-a25f-f202ca9edd15	2018-02-28 08:44:49.530042-06	2	[14470] DPIS-126 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4c459a4b-21d5-438f-9094-ccf075ae8324	2018-02-28 08:44:49.534042-06	2	[14471] DPIS-128 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6517690e-c014-4b11-bd85-824ad756c0fa	2018-02-28 08:44:49.536042-06	2	[14472] DPIS-129 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
05382080-f19b-4d69-bb2c-ec995ca0052c	2018-02-28 08:44:49.539043-06	2	[14473] DPIS-131 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
04f185d8-4553-4a98-90e1-9419ede5ffff	2018-02-28 08:44:49.543043-06	2	[14474] DPIS-132 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
816878f5-43ae-4394-93b1-8e89d54f6c25	2018-02-28 08:44:49.546043-06	2	[14475] DPIS-133 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a0015d2a-4a7c-45a5-891f-249c63a3fbad	2018-02-28 08:44:49.548043-06	2	[14476] DPIS-134A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8a532f95-2f0f-4db2-9a1d-abb7cba5c559	2018-02-28 08:44:49.551044-06	2	[14477] DPIS-134B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3fc9e5b5-4a3a-45ab-a97e-e38755b00837	2018-02-28 08:44:49.554044-06	2	[14478] DPIS-136 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c71831e7-6bde-4970-ba18-1b57d450a417	2018-02-28 08:44:49.557044-06	2	[14479] DPIS-137 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
accfb7ec-f9d1-43a4-88ca-6f1fb6c91e3f	2018-02-28 08:44:49.560045-06	2	[14480] DPIS-138 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
dd34a4f3-32a6-457c-8438-ce8b76d67d47	2018-02-28 08:44:49.563045-06	2	[14481] INPUT 31 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9f45c28e-2bdf-4fc6-9d4b-6c1d7a214fc3	2018-02-28 08:44:49.567045-06	2	[14482] DPIS-141 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a55daacb-45ae-4fc4-8c81-dbd557f509ff	2018-02-28 08:44:49.582047-06	2	[14849] R6C2-32I	[4] DLarrabee	[21062] a	\N	\N
d3923564-9470-4c75-8939-57c6182fa5bf	2018-02-28 08:44:49.595048-06	2	[14851] DPIS-142 Call Button	[4] DLarrabee	[21062] a	\N	\N
25a9a1f9-87bb-4da3-aef4-2b6c4e15e4c1	2018-02-28 08:44:49.61505-06	2	[14852] DPIS-145 Call Button	[4] DLarrabee	[21062] a	\N	\N
f962bfde-f2a0-47d0-9366-ad3dd2e488f9	2018-02-28 08:44:49.629052-06	2	[14853] DPIS-146 Call Button	[4] DLarrabee	[21062] a	\N	\N
4e7195b5-a4e4-43c8-b18a-35cce44a46f4	2018-02-28 08:44:49.647053-06	2	[14854] DPIS-201 Call Button	[4] DLarrabee	[21062] a	\N	\N
a9e7bd79-4e60-4314-b447-188609d50560	2018-02-28 08:44:49.660055-06	2	[14855] DPIS-202 Call Button	[4] DLarrabee	[21062] a	\N	\N
db7078d9-b3d1-4bb0-b0fe-302393c32406	2018-02-28 08:44:49.674056-06	2	[14856] DPIS-203 Call Button	[4] DLarrabee	[21062] a	\N	\N
40689b8d-db33-47d4-8b0e-2f8911ff5018	2018-02-28 08:44:49.689058-06	2	[14857] DPIS-205 Call Button	[4] DLarrabee	[21062] a	\N	\N
374302d3-8fec-4446-896d-30c7d8aa5033	2018-02-28 08:44:49.708059-06	2	[14858] DPIS-206 Call Button	[4] DLarrabee	[21062] a	\N	\N
422932eb-cda6-44b0-b5ec-90de9ffbe622	2018-02-28 08:44:49.720061-06	2	[14859] DPIS-207 Call Button	[4] DLarrabee	[21062] a	\N	\N
e1f47527-8474-4c67-9341-061068a2d0ab	2018-02-28 08:44:49.735062-06	2	[14860] DPIS-209A Call Button	[4] DLarrabee	[21062] a	\N	\N
ea1c33b4-9a34-4569-a38d-335f0972d614	2018-02-28 08:44:49.754064-06	2	[14861] DPIS-209B Call Button	[4] DLarrabee	[21062] a	\N	\N
d4294db5-d1a7-4d31-a199-7697f58837cf	2018-02-28 08:44:49.769066-06	2	[14862] DPIS-211 Call Button	[4] DLarrabee	[21062] a	\N	\N
2f28f16c-6128-4daf-8068-ca72678ea7c2	2018-02-28 08:44:49.784067-06	2	[14863] DPIS-213 Call Button	[4] DLarrabee	[21062] a	\N	\N
d7bbbca9-907c-40a8-9d56-023cd7b3fce7	2018-02-28 08:44:49.802069-06	2	[14864] DPIS-214 Call Button	[4] DLarrabee	[21062] a	\N	\N
e409d195-5c2f-4c04-a666-88a416de7c15	2018-02-28 08:44:49.81607-06	2	[14865] DPIS-215 Call Button	[4] DLarrabee	[21062] a	\N	\N
40dd2ffc-0629-4d94-9ff6-3ac07f1cdf79	2018-02-28 08:44:49.835072-06	2	[14866] DPIS-216 Call Button	[4] DLarrabee	[21062] a	\N	\N
24783416-0ddb-49c3-bf83-002857dfa501	2018-02-28 08:44:49.849074-06	2	[14867] DPIS-218 Call Button	[4] DLarrabee	[21062] a	\N	\N
ae900e3e-a037-49fb-9548-b0e1afe8c578	2018-02-28 08:44:49.862075-06	2	[14868] DPIS-219 Call Button	[4] DLarrabee	[21062] a	\N	\N
1ab10291-9fc4-4149-bf6c-9934dd035871	2018-02-28 08:44:49.875076-06	2	[14869] DPIS-221 Call Button	[4] DLarrabee	[21062] a	\N	\N
2a00107d-bfef-4faf-8c13-25ae3d9c000e	2018-02-28 08:44:49.887077-06	2	[14870] DPIS-222 Call Button	[4] DLarrabee	[21062] a	\N	\N
d1f24953-2b29-4be1-880a-507118b1a62b	2018-02-28 08:44:49.900079-06	2	[14871] DPIS-223 Call Button	[4] DLarrabee	[21062] a	\N	\N
d329db8b-96c1-4328-bdfd-4d309182cd28	2018-02-28 08:44:49.91108-06	2	[14872] DPIS-224 Call Button	[4] DLarrabee	[21062] a	\N	\N
2d42353d-3664-43f5-a1ef-ecd5f09331b5	2018-02-28 08:44:49.931082-06	2	[14873] DPIS-225 Call Button	[4] DLarrabee	[21062] a	\N	\N
1a320053-36a7-46e0-8d47-805b1dd364a8	2018-02-28 08:44:49.947083-06	2	[14874] DPIS-226 Call Button	[4] DLarrabee	[21062] a	\N	\N
72e9cd6f-4814-45bd-9d93-9d7ae2478cdb	2018-02-28 08:44:49.962085-06	2	[14875] DPIS-227 Call Button	[4] DLarrabee	[21062] a	\N	\N
27c85e94-3c84-4465-a1cd-8a1294ddff28	2018-02-28 08:44:49.979087-06	2	[14876] DPIS-228 Call Button	[4] DLarrabee	[21062] a	\N	\N
b6274cc6-c282-4fe2-be70-5744aaee1914	2018-02-28 08:44:49.994088-06	2	[14877] DPIS-231 Call Button	[4] DLarrabee	[21062] a	\N	\N
671903a0-7e48-43dd-a5bc-e7b6ba763ad2	2018-02-28 08:44:50.008089-06	2	[14878] DPIS-232 Call Button	[4] DLarrabee	[21062] a	\N	\N
9559ef7d-1307-441e-8496-ffece17c276d	2018-02-28 08:44:50.024091-06	2	[14879] DPIS-233 Call Button	[4] DLarrabee	[21062] a	\N	\N
287bae1b-a45b-47cf-b3db-6f22c855118a	2018-02-28 08:44:50.038092-06	2	[14880] DPIS-235 Call Button	[4] DLarrabee	[21062] a	\N	\N
7d43ec6d-6c46-4b4a-add7-41fca3e22366	2018-02-28 08:44:50.054094-06	2	[14881] DPIS-236 Call Button	[4] DLarrabee	[21062] a	\N	\N
07bbf3da-6d4d-40ae-8037-3550f880a7a9	2018-02-28 08:44:50.067095-06	2	[14882] DPIS-237A Call Button	[4] DLarrabee	[21062] a	\N	\N
fd03c095-bd20-4da8-8953-5d1f14b18b91	2018-02-28 08:44:50.071096-06	2	[14918] DPIS-142 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a6573647-99e7-4d1a-bdea-17e529e486e1	2018-02-28 08:44:50.075096-06	2	[14919] DPIS-145 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ad37d71e-062c-44bc-9264-27c6f225c9bd	2018-02-28 08:44:50.078096-06	2	[14920] DPIS-146 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e855b1fd-4bee-449a-a417-da06095c4476	2018-02-28 08:44:50.083097-06	2	[14921] DPIS-201 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
028d7f02-4a7a-4d49-b2f2-4b0764a53d7c	2018-02-28 08:44:50.087097-06	2	[14922] DPIS-202 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d0399781-ddef-4a55-b3f2-e32205d56693	2018-02-28 08:44:50.090098-06	2	[14923] DPIS-203 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4354ca48-0d88-4927-84e5-40b5e378df5a	2018-02-28 08:44:50.094098-06	2	[14924] DPIS-205 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7d3c40ed-6d6e-43a6-90b7-1fcb182d863e	2018-02-28 08:44:50.098098-06	2	[14925] DPIS-206 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9ee5bd50-7ea0-428a-91b2-2b096cfd036c	2018-02-28 08:44:50.101099-06	2	[14926] DPIS-207 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ccbf213e-ca67-4988-a34c-6870e3ac183b	2018-02-28 08:44:50.105099-06	2	[14927] DPIS-209A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
083f5a38-0a20-4c6f-bc25-832e4fd876bd	2018-02-28 08:44:50.132102-06	2	[14928] DPIS-209B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
df0a967e-4838-4272-ae77-c6d84a6e72cd	2018-02-28 08:44:50.136102-06	2	[14929] DPIS-211 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
aea0005f-1580-4e5b-a8c1-f99aa1f0006a	2018-02-28 08:44:50.139103-06	2	[14930] DPIS-213 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ed54d3fe-da69-448d-bd09-fa28793eec16	2018-02-28 08:44:50.143103-06	2	[14931] DPIS-214 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c6139fc0-5c53-454e-8c22-ccc46a51846a	2018-02-28 08:44:50.147103-06	2	[14932] DPIS-215 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
df0f91c5-c890-4468-87db-3c2b2ef844e3	2018-02-28 08:44:50.150104-06	2	[14933] DPIS-216 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7c4f7b6b-fb0b-4827-a603-a72fc14b626e	2018-02-28 08:44:50.154104-06	2	[14934] DPIS-218 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0a3b2a2a-2fa8-466a-9510-a6cd7eb9ffc3	2018-02-28 08:44:50.158104-06	2	[14935] DPIS-219 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9ed9a8c9-f9e9-4e1d-8f12-3e147775239c	2018-02-28 08:44:50.161105-06	2	[14936] DPIS-221 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d59bce2c-fef5-4c89-be5f-21bc018fd153	2018-02-28 08:44:50.165105-06	2	[14937] DPIS-222 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
dabb4df6-6c82-4d23-ab70-2c1bce1873a1	2018-02-28 08:44:50.168105-06	2	[14938] DPIS-223 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
75a035f1-6f1b-4a8f-a298-8ed3a0bc055c	2018-02-28 08:44:50.172106-06	2	[14939] DPIS-224 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cc9c8b2e-f7eb-40bd-9bbd-16f11c82eae6	2018-02-28 08:44:50.175106-06	2	[14940] DPIS-225 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e98eece2-5ba8-4a0b-a765-727e5d5b225c	2018-02-28 08:44:50.179107-06	2	[14941] DPIS-226 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d313c569-08e4-4621-8eed-79441646ad96	2018-02-28 08:44:50.181107-06	2	[14942] DPIS-227 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6d01a785-48ef-4735-aed2-4895c0cf1ed7	2018-02-28 08:44:50.184107-06	2	[14943] DPIS-228 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
40290ee3-f3b7-4b18-85e5-61c28c4d0321	2018-02-28 08:44:50.187107-06	2	[14944] DPIS-231 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7f44418b-f46e-4d0a-80c5-c5b7c0cd1aca	2018-02-28 08:44:50.190108-06	2	[14945] DPIS-232 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
addf6b62-5909-4ef6-9ece-286afe2393c1	2018-02-28 08:44:50.193108-06	2	[14946] DPIS-233 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e86f8bd1-0586-4fe7-9c9f-f287f3849a96	2018-02-28 08:44:50.197108-06	2	[14947] DPIS-235 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
db94f3e6-15ae-4dc9-89b4-5c99b1c1f239	2018-02-28 08:44:50.201109-06	2	[14948] DPIS-236 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f15c62db-8dce-4096-8ab7-e59daaa34b01	2018-02-28 08:44:50.204109-06	2	[14949] DPIS-237A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a15f0c9b-8088-45c1-8f10-fc82ba5f9a8d	2018-02-28 08:44:50.223111-06	2	[15316] R6C3-32I	[4] DLarrabee	[21062] a	\N	\N
1b453839-677f-4d1c-9670-1f473d519974	2018-02-28 08:44:50.237112-06	2	[15318] DPIS-237B Call Button	[4] DLarrabee	[21062] a	\N	\N
2b703ca9-b5be-4877-ba45-281b0ba2541c	2018-02-28 08:44:50.251114-06	2	[15319] DPIS-239 Call Button	[4] DLarrabee	[21062] a	\N	\N
23b87505-3e2c-4149-9c68-8d69a3a41ac2	2018-02-28 08:44:50.265115-06	2	[15320] DPIS-241 Call Button	[4] DLarrabee	[21062] a	\N	\N
535eaab5-c18b-45d3-bb6e-50686bc635ab	2018-02-28 08:44:50.281117-06	2	[15321] DPIS-242 Call Button	[4] DLarrabee	[21062] a	\N	\N
0f95d9a9-a65a-4197-9fa5-dbfdb29da46a	2018-02-28 08:44:50.298118-06	2	[15322] DPIS-243 Call Button	[4] DLarrabee	[21062] a	\N	\N
2a73858c-c176-4396-9ba0-f3f1207a515f	2018-02-28 08:44:50.31412-06	2	[15323] DPIS-245 Call Button	[4] DLarrabee	[21062] a	\N	\N
ae754a4c-71c3-4e25-9f0c-b038357f5ed6	2018-02-28 08:44:50.328121-06	2	[15324] DPIS-246 Call Button	[4] DLarrabee	[21062] a	\N	\N
0da41e71-8dc9-4390-91f3-42d207da6b1e	2018-02-28 08:44:50.345123-06	2	[15325] DPIS-247 Call Button	[4] DLarrabee	[21062] a	\N	\N
2f033106-3dea-42e3-a3ec-02a2143f23a7	2018-02-28 08:44:50.360125-06	2	[15326] DPIS-248 Call Button	[4] DLarrabee	[21062] a	\N	\N
6da2c54f-f769-4afc-ab1d-edd0d4c0fa5d	2018-02-28 10:11:26.895726-06	2	[3820] R2C3-8IC	[4] DLarrabee	[21062] a	\N	\N
dad12c6d-278a-44f1-9ca9-5455ffa87350	2018-02-28 08:44:50.375126-06	2	[15327] DPIS-252 Call Button	[4] DLarrabee	[21062] a	\N	\N
69770508-3a16-4dfa-9ff2-76a65b58f423	2018-02-28 08:44:50.389128-06	2	[15328] DPIS-253 Call Button	[4] DLarrabee	[21062] a	\N	\N
3e018281-5a10-4442-8121-56a34796f24f	2018-02-28 08:44:50.404129-06	2	[15329] DPIS-259 Call Button	[4] DLarrabee	[21062] a	\N	\N
e633db6c-1b88-4457-9db9-ab8d7be67179	2018-02-28 08:44:50.422131-06	2	[15330] DPIS-261 Call Button	[4] DLarrabee	[21062] a	\N	\N
fe93d5bc-34ee-4fa2-966b-5a2c4032a467	2018-02-28 08:44:50.437132-06	2	[15331] DPIS-301A Call Button	[4] DLarrabee	[21062] a	\N	\N
095e16a3-4441-48b7-b748-6b61c676edc4	2018-02-28 08:44:50.458134-06	2	[15332] DPIS-301B Call Button	[4] DLarrabee	[21062] a	\N	\N
20e42c32-73fc-4f29-8e54-bd37caa7de3e	2018-02-28 08:44:50.479137-06	2	[15333] DPIS-306 Call Button	[4] DLarrabee	[21062] a	\N	\N
0308931b-cd79-47bc-a979-3b0a25a197ea	2018-02-28 08:44:50.496138-06	2	[15334] DPIS-102 Call Button	[4] DLarrabee	[21062] a	\N	\N
3710f2b3-ae4c-488f-a32f-a30b49509409	2018-02-28 08:44:50.51814-06	2	[15335] DPIS-111 Call Button	[4] DLarrabee	[21062] a	\N	\N
9d4fc0a9-34ba-4133-9cf4-d0ba19a32689	2018-02-28 08:44:50.538142-06	2	[15336] DPIS-135 Call Button	[4] DLarrabee	[21062] a	\N	\N
34d4bdea-9ef6-4dbf-a0c1-9505cb276248	2018-02-28 08:44:50.557144-06	2	[15337] DPIS-143 Call Button	[4] DLarrabee	[21062] a	\N	\N
d4df8d43-3fdf-435f-b8fc-9ee3e488c1da	2018-02-28 08:44:50.576146-06	2	[15338] DPIS-208 Call Button	[4] DLarrabee	[21062] a	\N	\N
79938503-9c8e-4e54-90a6-0fa9eebd2f9f	2018-02-28 08:44:50.592148-06	2	[15339] DPIS-212 Call Button	[4] DLarrabee	[21062] a	\N	\N
c8032406-94d0-4e8f-83e0-ccd20008f758	2018-02-28 08:44:50.607149-06	2	[15340] DPIS-234 Call Button	[4] DLarrabee	[21062] a	\N	\N
1d1c6702-a631-4944-8f9b-4644aaaf07a7	2018-02-28 08:44:50.626151-06	2	[15341] DPIS-238 Call Button	[4] DLarrabee	[21062] a	\N	\N
a4e236c4-d75d-4d5e-a03d-80cff517991a	2018-02-28 08:44:50.644153-06	2	[15342] DURESS-113 Call Button	[4] DLarrabee	[21062] a	\N	\N
585d77cb-eaa3-4fb4-8c2c-552f5d80bef3	2018-02-28 08:44:50.664155-06	2	[15343] DURESS-133 Call Button	[4] DLarrabee	[21062] a	\N	\N
d06e7cb0-939b-40c5-abf2-e64eeb63186c	2018-02-28 08:44:50.683157-06	2	[15344] DURESS-211 Call Button	[4] DLarrabee	[21062] a	\N	\N
30897f6b-60ba-481e-ad83-3bd0c3ea7cd1	2018-02-28 08:44:50.703159-06	2	[15345] DURESS-236 Call Button	[4] DLarrabee	[21062] a	\N	\N
c303aaa7-92b5-441d-8e20-65a3cc9c5dd5	2018-02-28 08:44:50.725161-06	2	[15346] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
92f58ed5-d282-4d88-b383-9e187f9c48b9	2018-02-28 08:44:50.741163-06	2	[15347] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
b3b32201-5394-4e99-bf1c-bfcbddf55b7e	2018-02-28 08:44:50.758164-06	2	[15348] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
7ec493de-5829-4146-89ab-8f82eeeef169	2018-02-28 08:44:50.775166-06	2	[15349] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
16cf4056-d1b9-49a1-9a64-0efb91afcb71	2018-02-28 08:44:50.779167-06	2	[15385] DPIS-237B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c02d7377-ccf8-457e-b7ab-431caa38daed	2018-02-28 08:44:50.783167-06	2	[15386] DPIS-239 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3bf55576-bf83-41e7-a5d5-a28bab0a3e55	2018-02-28 08:44:50.786167-06	2	[15387] DPIS-241 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cb121cf5-25d1-40f5-93e9-d068485e763a	2018-02-28 08:44:50.790168-06	2	[15388] DPIS-242 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e18ac1d6-bd59-430a-8cc6-ae090852da68	2018-02-28 08:44:50.794168-06	2	[15389] DPIS-243 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2ea7f91e-2aeb-4ba8-bd87-c6ae9e5e8236	2018-02-28 08:44:50.797168-06	2	[15390] DPIS-245 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c31ef77f-d9dd-42fb-942a-ff049b7e68ef	2018-02-28 08:44:50.801169-06	2	[15391] DPIS-246 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0c11b388-dd7f-4bdb-8323-79306103ac35	2018-02-28 08:44:50.805169-06	2	[15392] DPIS-247 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fc84f6d0-95a1-43d4-87c3-428ba966fc28	2018-02-28 08:44:50.80917-06	2	[15393] DPIS-248 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f3f87582-f0b5-4435-bc63-bf5c9c46d450	2018-02-28 08:44:50.81217-06	2	[15394] DPIS-252 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b4cfb5e9-b44e-4e4f-9a50-32f372170801	2018-02-28 08:44:50.81617-06	2	[15395] DPIS-253 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0f437c1d-d419-4477-830a-a2b372a68e46	2018-02-28 08:44:50.820171-06	2	[15396] DPIS-259 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
96939acc-310f-4edc-a03e-fab6e11540ac	2018-02-28 08:44:50.824171-06	2	[15397] DPIS-261 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
afd6e0f7-f30b-4ba5-9608-0861c2e6b28f	2018-02-28 08:44:50.828171-06	2	[15398] DPIS-301A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fe2a4c8c-3d8d-4c17-a16a-9b8adab9d7ec	2018-02-28 08:44:50.832172-06	2	[15399] DPIS-301B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ab293d67-03a7-425c-94e0-209b699b69ff	2018-02-28 08:44:50.835172-06	2	[15400] DPIS-306 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d238f675-282f-4c48-8c6f-6d987f26f28a	2018-02-28 08:44:50.850174-06	2	[15401] DPIS-102 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7a10f79f-13e2-47da-b6ff-4e1442d7e08f	2018-02-28 08:44:50.853174-06	2	[15402] DPIS-111 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9389f6a5-469f-4652-9610-8c090b0a7905	2018-02-28 08:44:50.857174-06	2	[15403] DPIS-135 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2371fe03-5c4a-4341-a532-e94ef05fcf74	2018-02-28 08:44:50.861175-06	2	[15404] DPIS-143 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b8ef0ab1-53e8-4c71-bd88-30e26cd1df6e	2018-02-28 08:44:50.865175-06	2	[15405] DPIS-208 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
01c3989d-2cf4-4348-b68b-b20013213af7	2018-02-28 08:44:50.869176-06	2	[15406] DPIS-212 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
087aebf3-f04e-43b6-98e4-74813366f0b7	2018-02-28 08:44:50.872176-06	2	[15407] DPIS-234 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1214c3a4-c36c-4c74-a0d3-40cf52c22c16	2018-02-28 08:44:50.876176-06	2	[15408] DPIS-238 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2e282557-d922-4fe2-8d13-a49471d5f60f	2018-02-28 08:44:50.880177-06	2	[15409] DURESS-113 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2ee08a9d-9693-431c-92e0-ff0e4ee4757e	2018-02-28 08:44:50.884177-06	2	[15410] DURESS-133 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
965c5b3c-e54f-4fba-a609-1b874ac1d7a4	2018-02-28 08:44:50.887177-06	2	[15411] DURESS-211 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d55108aa-5b76-4372-97c7-0ea28feb1d94	2018-02-28 08:44:50.891178-06	2	[15412] DURESS-236 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d0454746-5404-4b11-96e3-88d378718218	2018-02-28 08:44:50.894178-06	2	[15413] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f721d54f-5d42-4be2-adcb-c33d5d2977f2	2018-02-28 08:44:50.898178-06	2	[15414] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1822d75d-76c3-4546-afa4-8df91f205059	2018-02-28 08:44:50.901179-06	2	[15415] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2837e193-88af-45b1-b07b-aff3a96dd6f1	2018-02-28 08:44:50.905179-06	2	[15416] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
120f2534-f6c8-45b4-9dc9-dcf7fbb2eacf	2018-02-28 08:44:50.926181-06	2	[15783] R7C1-16R	[4] DLarrabee	[21062] a	\N	\N
561b9b78-2a4e-40bf-85cf-0ace367093c7	2018-02-28 08:44:50.944183-06	2	[15786] Lock Relay-103 Relay	[4] DLarrabee	[21062] a	\N	\N
d3d1d421-0392-4932-bcb2-3f83c1d5c3c1	2018-02-28 08:44:50.964185-06	2	[15787] Lock Relay-104 Relay	[4] DLarrabee	[21062] a	\N	\N
e7c3670f-a5eb-4a82-aeb0-f51f595ed895	2018-02-28 08:44:50.982187-06	2	[15788] Lock Relay-105 Relay	[4] DLarrabee	[21062] a	\N	\N
65c7738d-5375-402b-bf7e-be17c4326726	2018-02-28 08:44:50.995188-06	2	[15789] Lock Relay-107 Relay	[4] DLarrabee	[21062] a	\N	\N
36efe552-c88f-40e5-9043-012e478b0091	2018-02-28 08:44:51.00919-06	2	[15790] Lock Relay-108 Relay	[4] DLarrabee	[21062] a	\N	\N
6fd9859d-4464-4f8f-968a-35d39806ddc1	2018-02-28 08:44:51.027191-06	2	[15791] Lock Relay-109 Relay	[4] DLarrabee	[21062] a	\N	\N
a12a998b-ed9b-44f7-a6d2-df944a5cc8f7	2018-02-28 08:44:51.040193-06	2	[15792] Lock Relay-112 Relay	[4] DLarrabee	[21062] a	\N	\N
0830e090-0e6b-4b59-aa81-947453f5d672	2018-02-28 08:44:51.052194-06	2	[15793] Lock Relay-113 Relay	[4] DLarrabee	[21062] a	\N	\N
28824490-5e38-4bdf-beeb-3dcceab95845	2018-02-28 08:44:51.066195-06	2	[15794] Lock Relay-114A Relay	[4] DLarrabee	[21062] a	\N	\N
801b37b6-df14-4d44-8706-d62dbb288e15	2018-02-28 08:44:51.084197-06	2	[15795] Lock Relay-114B Relay	[4] DLarrabee	[21062] a	\N	\N
795419f0-bd05-4974-80a9-91f3542ed932	2018-02-28 08:44:51.103199-06	2	[15796] Lock Relay-115 Relay	[4] DLarrabee	[21062] a	\N	\N
f9ce60b3-c8d4-4f7f-80ae-c10f64c0d34c	2018-02-28 08:44:51.123201-06	2	[15797] Lock Relay-116 Relay	[4] DLarrabee	[21062] a	\N	\N
527d9e94-4032-4d1c-9d1b-0bd791254d44	2018-02-28 08:44:51.135202-06	2	[15798] Lock Relay-117 Relay	[4] DLarrabee	[21062] a	\N	\N
bf19ae6b-ff8e-4fe6-9fdc-8bdf14240a48	2018-02-28 08:44:51.148203-06	2	[15799] Lock Relay-119 Relay	[4] DLarrabee	[21062] a	\N	\N
dc8edaae-bd22-47f9-a53e-60021c5d9877	2018-02-28 08:44:51.160205-06	2	[15800] Lock Relay-121 Relay	[4] DLarrabee	[21062] a	\N	\N
efc1b451-6d32-4193-84ce-a19a8d6e7146	2018-02-28 08:44:51.174206-06	2	[15801] Lock Relay-122 Relay	[4] DLarrabee	[21062] a	\N	\N
7a8988b6-86aa-4454-b715-80b63e354bff	2018-02-28 08:44:51.189208-06	2	[16103] R7C2-16R	[4] DLarrabee	[21062] a	\N	\N
3c31138b-10c3-4e6f-bffc-e294d4b70cb1	2018-02-28 08:44:51.206209-06	2	[16106] Lock Relay-123 Relay	[4] DLarrabee	[21062] a	\N	\N
04e4ca70-ca79-4f65-baa0-7f0b9be0faed	2018-02-28 08:44:51.219211-06	2	[16107] Lock Relay-124 Relay	[4] DLarrabee	[21062] a	\N	\N
006438ed-27ce-405d-85e6-fd459b6ecf6c	2018-02-28 08:44:51.232212-06	2	[16108] Lock Relay-125 Relay	[4] DLarrabee	[21062] a	\N	\N
b7fdeb88-d61b-4dc8-90dd-86f71394695f	2018-02-28 08:44:51.244213-06	2	[16109] Lock Relay-126 Relay	[4] DLarrabee	[21062] a	\N	\N
cdd43357-b0b0-4c1f-95de-f7763811ec61	2018-02-28 08:44:51.257214-06	2	[16110] Lock Relay-128 Relay	[4] DLarrabee	[21062] a	\N	\N
a7fa431e-3dde-4cb8-b15a-b8a3869ba613	2018-02-28 08:44:51.275216-06	2	[16111] Lock Relay-129 Relay	[4] DLarrabee	[21062] a	\N	\N
54c58a76-df83-4a6d-b89d-0e083b36a762	2018-02-28 08:44:51.287217-06	2	[16112] Lock Relay-131 Relay	[4] DLarrabee	[21062] a	\N	\N
e8496893-b5eb-404b-bd07-55367ce853df	2018-02-28 08:44:51.299219-06	2	[16113] Lock Relay-132 Relay	[4] DLarrabee	[21062] a	\N	\N
e680ef5d-e6f0-4d5e-bafc-65aa19d537a2	2018-02-28 08:44:51.31422-06	2	[16114] Lock Relay-133 Relay	[4] DLarrabee	[21062] a	\N	\N
0650d150-0ba9-47a5-bcc3-6d996d1f77b2	2018-02-28 08:44:51.328221-06	2	[16115] Lock Relay-134A Relay	[4] DLarrabee	[21062] a	\N	\N
b70a647a-26ae-4e49-ba50-9fb9f604b143	2018-02-28 08:44:51.343223-06	2	[16116] Lock Relay-134B Relay	[4] DLarrabee	[21062] a	\N	\N
7a6c437b-ed1d-43d8-b5b0-73d7cdb0fad1	2018-02-28 08:44:51.358224-06	2	[16117] Lock Relay-136 Relay	[4] DLarrabee	[21062] a	\N	\N
e1997fd2-a297-43f1-8cbc-efa1ecb48f85	2018-02-28 08:44:51.378226-06	2	[16118] Lock Relay-137 Relay	[4] DLarrabee	[21062] a	\N	\N
78b8979a-7c9d-45a9-8ed6-e9be07e7c294	2018-02-28 08:44:51.392228-06	2	[16119] Lock Relay-138 Relay	[4] DLarrabee	[21062] a	\N	\N
ed4146dc-a7dd-4aa0-9b67-4ce9663e407f	2018-02-28 08:44:51.41023-06	2	[16120] Lock Relay-141 Relay	[4] DLarrabee	[21062] a	\N	\N
c86f8907-ce43-4a0b-aeba-8eb119714fad	2018-02-28 08:44:51.428231-06	2	[16121] Lock Relay-142 Relay	[4] DLarrabee	[21062] a	\N	\N
657a3b80-f3c2-46b5-8c55-7ab269496645	2018-02-28 08:44:51.444233-06	2	[16423] R7C3-16R	[4] DLarrabee	[21062] a	\N	\N
f575b61d-73fe-4e53-914f-2b1261f9239e	2018-02-28 08:44:51.459235-06	2	[16426] Lock Relay-145 Relay	[4] DLarrabee	[21062] a	\N	\N
503df045-8168-4112-a093-ba76ea16902a	2018-02-28 08:44:51.475236-06	2	[16427] Lock Relay-146 Relay	[4] DLarrabee	[21062] a	\N	\N
a57643d0-c5eb-4256-a1e8-204d18b6ed45	2018-02-28 08:44:51.490238-06	2	[16428] Lock Relay-201 Relay	[4] DLarrabee	[21062] a	\N	\N
cb9f6d3a-71a6-4c80-a4f9-abb29b07107c	2018-02-28 08:44:51.507239-06	2	[16429] Lock Relay-202 Relay	[4] DLarrabee	[21062] a	\N	\N
861749ca-e36e-4ffc-91d2-b56629e7b1bb	2018-02-28 08:44:51.520241-06	2	[16430] Lock Relay-203 Relay	[4] DLarrabee	[21062] a	\N	\N
3dde91a5-ca4b-4a51-bc63-6bf1203a2357	2018-02-28 08:44:51.534242-06	2	[16431] Lock Relay-205 Relay	[4] DLarrabee	[21062] a	\N	\N
66055264-c5c3-47bd-8bf1-c13f8a985c23	2018-02-28 08:44:51.549244-06	2	[16432] Lock Relay-206 Relay	[4] DLarrabee	[21062] a	\N	\N
47ea1b7e-2a1a-495b-b24e-ca6174049aa6	2018-02-28 08:44:51.562245-06	2	[16433] Lock Relay-207 Relay	[4] DLarrabee	[21062] a	\N	\N
a8df1cd9-d19b-4919-bab5-9e78085ff8fe	2018-02-28 08:44:51.582247-06	2	[16434] Lock Relay-209A Relay	[4] DLarrabee	[21062] a	\N	\N
4c05d720-f9e3-4c82-9b23-03ddf52542f5	2018-02-28 08:44:51.597248-06	2	[16435] Lock Relay-209B Relay	[4] DLarrabee	[21062] a	\N	\N
5b619376-6adf-4f6f-914a-13ae7bf21e5f	2018-02-28 08:44:51.61425-06	2	[16436] Lock Relay-211 Relay	[4] DLarrabee	[21062] a	\N	\N
dd90e5b9-fd45-4cd2-adf7-f3c92e6a7d6e	2018-02-28 08:44:51.629252-06	2	[16437] Lock Relay-213 Relay	[4] DLarrabee	[21062] a	\N	\N
0ddf5f42-db99-4f1c-893d-70bf69c02e6a	2018-02-28 08:44:51.647253-06	2	[16438] Lock Relay-214 Relay	[4] DLarrabee	[21062] a	\N	\N
13630d8b-875f-4c0b-9763-3e4f6ca629da	2018-02-28 08:44:51.660255-06	2	[16439] Lock Relay-215 Relay	[4] DLarrabee	[21062] a	\N	\N
9d5f9a3a-75fe-4709-bab6-f27dbc58263d	2018-02-28 08:44:51.677256-06	2	[16440] Lock Relay-216 Relay	[4] DLarrabee	[21062] a	\N	\N
5f27795e-1a9d-45f2-ba4a-1437b7bcc3c8	2018-02-28 08:44:51.690258-06	2	[16441] Lock Relay-218 Relay	[4] DLarrabee	[21062] a	\N	\N
77d63f2f-d0b8-4253-b5a6-32d9015cfa5f	2018-02-28 08:44:51.707259-06	2	[16743] R7C4-16R	[4] DLarrabee	[21062] a	\N	\N
95dca945-b7c7-4229-ba30-02bc3b908d93	2018-02-28 08:44:51.720261-06	2	[16746] Lock Relay-219 Relay	[4] DLarrabee	[21062] a	\N	\N
fd3248fe-4b5e-4e91-859b-fa2ca240d0bd	2018-02-28 08:44:51.736262-06	2	[16747] Lock Relay-221 Relay	[4] DLarrabee	[21062] a	\N	\N
0569cfbc-3859-479f-857f-c4f4add677ca	2018-02-28 08:44:51.752264-06	2	[16748] Lock Relay-222 Relay	[4] DLarrabee	[21062] a	\N	\N
bd02f04c-67ea-4686-8f72-4591b4639148	2018-02-28 08:44:51.765265-06	2	[16749] Lock Relay-223 Relay	[4] DLarrabee	[21062] a	\N	\N
eaa6123a-8c33-42c0-9458-3384257f5b2a	2018-02-28 08:44:51.778266-06	2	[16750] Lock Relay-224 Relay	[4] DLarrabee	[21062] a	\N	\N
53fccf2d-8aad-417f-b5e9-b6a374deebf3	2018-02-28 08:44:51.790268-06	2	[16751] Lock Relay-225 Relay	[4] DLarrabee	[21062] a	\N	\N
64289b52-4ae0-45c5-8b1e-fa1e5fa203ba	2018-02-28 08:44:51.81027-06	2	[16752] Lock Relay-226 Relay	[4] DLarrabee	[21062] a	\N	\N
559b7636-4f62-4c37-97b7-401aa43871f1	2018-02-28 08:44:51.827271-06	2	[16753] Lock Relay-227 Relay	[4] DLarrabee	[21062] a	\N	\N
fc99349f-969a-4c2a-bcc2-7042e9defff2	2018-02-28 08:44:51.844273-06	2	[16754] Lock Relay-228 Relay	[4] DLarrabee	[21062] a	\N	\N
e30ce8fc-09ab-4c2d-b296-7534e043fa5d	2018-02-28 08:44:51.857274-06	2	[16755] Lock Relay-231 Relay	[4] DLarrabee	[21062] a	\N	\N
b0fe3b56-994e-4fe2-a2f9-0b932b1da530	2018-02-28 08:44:51.871276-06	2	[16756] Lock Relay-232 Relay	[4] DLarrabee	[21062] a	\N	\N
15c5b8d5-4f7b-46f6-b2f5-9e657eb6620d	2018-02-28 08:44:51.886277-06	2	[16757] Lock Relay-233 Relay	[4] DLarrabee	[21062] a	\N	\N
822c322a-bf3b-4b15-b6d0-1b1feecd08d8	2018-02-28 08:44:51.901279-06	2	[16758] Lock Relay-235 Relay	[4] DLarrabee	[21062] a	\N	\N
bb9f17cd-2d29-48f2-8711-c3ed56f94c54	2018-02-28 08:44:51.91528-06	2	[16759] Lock Relay-236 Relay	[4] DLarrabee	[21062] a	\N	\N
c23536fb-a322-45c2-8758-9bb4e16c9b12	2018-02-28 08:44:51.931282-06	2	[16760] Lock Relay-237A Relay	[4] DLarrabee	[21062] a	\N	\N
157707a6-785a-41a3-a239-ec615212f6ba	2018-02-28 08:44:51.945283-06	2	[16761] Lock Relay-237B Relay	[4] DLarrabee	[21062] a	\N	\N
96fd86f9-ab07-4d78-b7ff-6a9f02d18fbb	2018-02-28 08:44:51.961285-06	2	[17063] R7C5-16R	[4] DLarrabee	[21062] a	\N	\N
d2680c60-a460-4b35-83d2-0132b1389de9	2018-02-28 08:44:51.976286-06	2	[17066] Lock Relay-239 Relay	[4] DLarrabee	[21062] a	\N	\N
eaf93e81-1ad1-45c8-91f0-b0be272bf77a	2018-02-28 08:44:51.991288-06	2	[17067] Lock Relay-241 Relay	[4] DLarrabee	[21062] a	\N	\N
d5a4ee71-2305-4f54-b128-ebea9e4851aa	2018-02-28 08:44:52.006289-06	2	[17068] Lock Relay-242 Relay	[4] DLarrabee	[21062] a	\N	\N
86c18b6e-1a4f-4edb-bb3d-fbb1a277c0af	2018-02-28 08:44:52.035292-06	2	[17069] Lock Relay-243 Relay	[4] DLarrabee	[21062] a	\N	\N
58047327-d603-467c-aba4-36a53d66c4d0	2018-02-28 08:44:52.050294-06	2	[17070] Lock Relay-245 Relay	[4] DLarrabee	[21062] a	\N	\N
1eb9efa2-96ee-4ab0-84aa-71c2ca3113ba	2018-02-28 08:44:52.064295-06	2	[17071] Lock Relay-246 Relay	[4] DLarrabee	[21062] a	\N	\N
9a4e4c05-8eeb-4877-93bb-dab9ffc899e3	2018-02-28 08:44:52.075296-06	2	[17072] Lock Relay-247 Relay	[4] DLarrabee	[21062] a	\N	\N
54919ccd-09d8-4a0b-9c41-144a51708c76	2018-02-28 08:44:52.088297-06	2	[17073] Lock Relay-248 Relay	[4] DLarrabee	[21062] a	\N	\N
94a2793a-92c6-4a34-8f45-061c62682a1a	2018-02-28 08:44:52.104299-06	2	[17074] Lock Relay-252 Relay	[4] DLarrabee	[21062] a	\N	\N
faf0529c-4d60-466e-87db-c8b219a96c2e	2018-02-28 08:44:52.119301-06	2	[17075] Lock Relay-253 Relay	[4] DLarrabee	[21062] a	\N	\N
f79fcbe3-5846-4d42-92ac-9b61e6a76914	2018-02-28 08:44:52.134302-06	2	[17076] Lock Relay-259 Relay	[4] DLarrabee	[21062] a	\N	\N
36b541c0-64db-45a0-a934-44c2a8c47699	2018-02-28 08:44:52.153304-06	2	[17077] Lock Relay-261 Relay	[4] DLarrabee	[21062] a	\N	\N
6edcb973-c96d-4567-a45f-44e55c77a24e	2018-02-28 08:44:52.171306-06	2	[17078] Lock Relay-301A Relay	[4] DLarrabee	[21062] a	\N	\N
2f122ef1-5de3-4b33-878e-3926b1531506	2018-02-28 08:44:52.193308-06	2	[17079] Lock Relay-301B Relay	[4] DLarrabee	[21062] a	\N	\N
0510ec12-e236-4fee-b5a5-2ffc74abc52e	2018-02-28 08:44:52.206309-06	2	[17080] Lock Relay-306 Relay	[4] DLarrabee	[21062] a	\N	\N
995cc6a2-0554-4add-851d-732a5cf2b0c4	2018-02-28 08:44:52.229312-06	2	[17081] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
b25a2d43-bc61-4e40-b267-498cd39ad3a9	2018-02-28 08:47:44.876575-06	2	[8224] IC-134A-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
5677c5fd-4cfb-4e21-a771-367d3112d52e	2018-02-28 08:47:44.905577-06	2	[8225] IC-134B-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
0b2bb1cb-5811-4879-8747-36e077173950	2018-02-28 08:47:44.919579-06	2	[8226] IC-134B-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
d97bbae4-16e3-4a6f-868f-6ba6dcd4a17b	2018-02-28 08:47:44.938581-06	2	[8227] IC-122-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
41e3a626-c96e-498b-9368-90dccb106dc6	2018-02-28 08:47:44.954582-06	2	[8228] IC-122-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
633b0246-158f-4b57-8160-cd2195d484fa	2018-02-28 08:47:44.969584-06	2	[8229] IC-123-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
e4c12334-cfe1-40c5-a290-ce5349f6f164	2018-02-28 08:47:44.985585-06	2	[8230] IC-123-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
2c7f672e-8f74-485a-be4b-d3e107166ce2	2018-02-28 08:49:26.326719-06	2	[17386] IC-307-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
3176b28e-d502-4276-a70b-fa0213e1d773	2018-02-28 08:49:26.363722-06	2	[17395] IC-307-InB Relay	[4] DLarrabee	[21062] a	\N	\N
f59dfa95-0e76-4b30-bf78-fec8507cbfaf	2018-02-28 08:49:26.381724-06	2	[17396] IC-307-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
a76fc45e-e1a6-4a05-b32e-d4a74d29a1cb	2018-02-28 08:49:26.401726-06	2	[17397] IC-309-InB Relay	[4] DLarrabee	[21062] a	\N	\N
04f94ccb-0a8e-42f5-9ec4-97c645227f17	2018-02-28 08:49:26.416728-06	2	[17398] IC-309-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
cc07d2fb-c246-4057-9595-8b2fa943b6c6	2018-02-28 08:49:26.433729-06	2	[17399] IC-314-InB Relay	[4] DLarrabee	[21062] a	\N	\N
9c64d390-30da-4bae-991f-ea7aea8626e1	2018-02-28 08:49:26.448731-06	2	[17400] IC-314-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
4f6c2cc3-fff9-425d-9588-3c8fcc1acf26	2018-02-28 08:49:26.465732-06	2	[17401] IC-322-InB Relay	[4] DLarrabee	[21062] a	\N	\N
5d8d7e6b-d599-4ab1-911f-38e7db461bf9	2018-02-28 08:49:26.480734-06	2	[17402] IC-322-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
c0455b75-ce65-43be-be20-fbec21257c00	2018-02-28 08:49:26.484734-06	2	[17404] IC-307-InB Connect	[4] DLarrabee	[21062] a	\N	\N
26f75a88-3007-46ba-958a-821b3bf18fad	2018-02-28 08:49:26.489735-06	2	[17405] IC-307-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
06e1228c-7b29-4574-a0a9-2e8d82a3e830	2018-02-28 08:49:26.492735-06	2	[17406] IC-309-InB Connect	[4] DLarrabee	[21062] a	\N	\N
56c7137f-deaa-4ddc-b693-e32915c90094	2018-02-28 08:49:26.496736-06	2	[17407] IC-309-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
08bfcd9c-a8a9-4bb3-abde-84661bda985d	2018-02-28 08:49:26.500736-06	2	[17408] IC-314-InB Connect	[4] DLarrabee	[21062] a	\N	\N
6644e383-8df6-4f49-88c3-e5b9c962cd8e	2018-02-28 08:49:26.504736-06	2	[17409] IC-314-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
5061343f-2da9-44cc-b32c-a1733540c575	2018-02-28 08:49:26.509737-06	2	[17410] IC-322-InB Connect	[4] DLarrabee	[21062] a	\N	\N
bd90b7d8-15f7-4966-9146-13fe40951239	2018-02-28 08:49:26.512737-06	2	[17411] IC-322-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
fe93e7ba-76bc-44f0-b914-5083f61bdeb6	2018-02-28 08:49:26.516738-06	2	[17437] IC-307-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
12f5ba35-351b-43e5-9c0a-570ced45afe8	2018-02-28 08:49:26.521738-06	2	[17438] IC-307-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
54baee6d-ed9f-4564-aeda-4996c95c3382	2018-02-28 08:49:26.524738-06	2	[17439] IC-309-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7394a743-6df4-4666-b254-fbad27a6342a	2018-02-28 08:49:26.528739-06	2	[17440] IC-309-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d20b51e1-2010-4d66-9d85-15f029b15ef0	2018-02-28 08:49:26.533739-06	2	[17441] IC-314-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
77d7010e-2c12-456e-962e-75d386a39a9f	2018-02-28 08:49:26.53674-06	2	[17442] IC-314-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3fb8cd9d-f93b-47cd-901d-78e43065ae16	2018-02-28 08:49:26.54074-06	2	[17443] IC-322-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
49b1d132-6eb7-42dd-b269-8531ab568fdf	2018-02-28 08:49:26.54374-06	2	[17444] IC-322-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
43dd3365-b5c7-4eeb-aaf0-b25a27d0f560	2018-02-28 08:49:26.546741-06	2	[17456] IC-307-InB Call	[4] DLarrabee	[21062] a	\N	\N
768914b5-33af-4c60-8ca3-0486a3535f5f	2018-02-28 08:49:26.549741-06	2	[17457] IC-307-OutB Call	[4] DLarrabee	[21062] a	\N	\N
e5298c89-1779-4400-b460-06f2542f6686	2018-02-28 08:49:26.552741-06	2	[17458] IC-309-InB Call	[4] DLarrabee	[21062] a	\N	\N
48590441-1369-4315-bf06-370442460d23	2018-02-28 08:49:26.555741-06	2	[17459] IC-309-OutB Call	[4] DLarrabee	[21062] a	\N	\N
3c9a56e2-1c78-4987-8f25-0ff6f8b9fb51	2018-02-28 08:49:26.558742-06	2	[17460] IC-314-InB Call	[4] DLarrabee	[21062] a	\N	\N
3b432241-2304-4f72-8927-91b8b0691a51	2018-02-28 08:49:26.562742-06	2	[17461] IC-314-OutB Call	[4] DLarrabee	[21062] a	\N	\N
21031bf8-97fd-4bbd-9236-82f0b4db2e2f	2018-02-28 08:49:26.565742-06	2	[17462] IC-322-InB Call	[4] DLarrabee	[21062] a	\N	\N
1a9f5b75-0302-4ae6-b4d4-01d357006976	2018-02-28 08:49:26.568743-06	2	[17463] IC-322-OutB Call	[4] DLarrabee	[21062] a	\N	\N
d2d059aa-8685-4735-8694-7837bfa72ec9	2018-02-28 08:49:26.688755-06	2	[17825] R8C2-8IC	[4] DLarrabee	[21062] a	\N	\N
53acc688-e3a9-4c5b-baaa-c8b5678edcba	2018-02-28 08:49:26.703756-06	2	[17827] IC-324A-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
e47b3cb1-a8be-46e5-a55c-6695c10ddad7	2018-02-28 08:49:26.718758-06	2	[17828] IC-324A-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
5bd419c8-c437-43fc-9794-f2c3d4489558	2018-02-28 08:49:26.73676-06	2	[17829] IC-324B-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
efc8990a-e7e9-42ed-aedc-170768c2faf8	2018-02-28 08:49:26.750761-06	2	[17830] IC-324B-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
82bc2765-5b3b-4aa1-8ad9-214f2c74f313	2018-02-28 08:49:26.766763-06	2	[17831] IC-324C-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
77ae2870-2dbb-4526-baef-864b14d21558	2018-02-28 08:49:26.784764-06	2	[17832] IC-324C-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
a38aaf76-6f26-4139-b23c-6e5123ea30eb	2018-02-28 08:49:26.798766-06	2	[17833] IC-333-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
32a27192-407d-4c1b-8c0a-296ba0781778	2018-02-28 08:49:26.813767-06	2	[17834] IC-333-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
a823dd4e-faa5-44e7-ae0b-4e64b8ad1085	2018-02-28 08:49:26.828769-06	2	[17836] IC-324A-InB Relay	[4] DLarrabee	[21062] a	\N	\N
48382ad0-d134-49e1-8120-fb3321188d5a	2018-02-28 08:49:26.847771-06	2	[17837] IC-324A-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
b3be6d58-853a-474c-9147-4544759db389	2018-02-28 08:49:26.862772-06	2	[17838] IC-324B-InB Relay	[4] DLarrabee	[21062] a	\N	\N
84822b54-4765-4d37-8b16-013c19f7acc0	2018-02-28 08:49:26.880774-06	2	[17839] IC-324B-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
44dd8784-71d3-4648-ae05-2f32ffa01ff4	2018-02-28 08:49:26.898776-06	2	[17840] IC-324C-InB Relay	[4] DLarrabee	[21062] a	\N	\N
148e2563-9e48-4fda-9d67-87deef108135	2018-02-28 08:49:26.913777-06	2	[17841] IC-324C-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
c6d253ee-5099-473a-a7a2-c5e5539c5117	2018-02-28 08:49:26.932779-06	2	[17842] IC-333-InB Relay	[4] DLarrabee	[21062] a	\N	\N
e9a14c8a-b671-4239-8133-ed54159f2be7	2018-02-28 08:49:26.946781-06	2	[17843] IC-333-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
b9bb6f00-cf91-4a5b-8619-7d5864cd9b70	2018-02-28 08:49:26.949781-06	2	[17845] IC-324A-InB Connect	[4] DLarrabee	[21062] a	\N	\N
56076059-5005-4863-b1ad-abc8632a9da5	2018-02-28 08:49:26.952781-06	2	[17846] IC-324A-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
98c18fbe-4995-4aab-bfb6-ad9273c7e0d3	2018-02-28 08:49:26.956782-06	2	[17847] IC-324B-InB Connect	[4] DLarrabee	[21062] a	\N	\N
f29916ee-06fb-4330-8ab2-ea2d1d2addb7	2018-02-28 08:49:26.960782-06	2	[17848] IC-324B-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
65016e7a-5d1a-400f-a465-d95ae76d07b8	2018-02-28 08:49:26.963782-06	2	[17849] IC-324C-InB Connect	[4] DLarrabee	[21062] a	\N	\N
e9a975f4-8d07-4571-8dff-332427b2a1f6	2018-02-28 08:49:26.968783-06	2	[17850] IC-324C-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
7dcd9e3e-a361-4b82-b749-16094becaa1d	2018-02-28 08:49:26.971783-06	2	[17851] IC-333-InB Connect	[4] DLarrabee	[21062] a	\N	\N
be9abc4c-b013-499c-8657-3d4324c1dc77	2018-02-28 08:49:26.975783-06	2	[17852] IC-333-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
7c4f1aab-72bf-4e7c-9217-525119d681df	2018-02-28 08:49:26.978784-06	2	[17878] IC-324A-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
59b81082-20a2-4f7d-8082-0ceef1027542	2018-02-28 08:49:26.980784-06	2	[17879] IC-324A-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7b7eab47-b6b6-47cf-8e7a-a9e5df166b30	2018-02-28 08:49:26.984784-06	2	[17880] IC-324B-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1830a341-b822-4db0-9fc9-a51e928ca18e	2018-02-28 08:49:26.988785-06	2	[17881] IC-324B-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4ca1e9dd-da8b-43cc-af9b-91fa8cdc4a5f	2018-02-28 08:49:26.992785-06	2	[17882] IC-324C-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1c5ddcd7-11dd-4a25-98cc-db7d706cbe67	2018-02-28 08:49:26.996786-06	2	[17883] IC-324C-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3c419b5a-ef2f-4caf-a41f-f4ef2589ba88	2018-02-28 08:49:27.000786-06	2	[17884] IC-333-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
495eb224-e9cf-4f64-83e8-85b3f667d560	2018-02-28 08:49:27.004786-06	2	[17885] IC-333-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9241f98b-ab4c-4d38-a672-e37871194760	2018-02-28 08:49:27.008787-06	2	[17897] IC-324A-InB Call	[4] DLarrabee	[21062] a	\N	\N
85304745-95ac-4bfd-806b-389ce868dfe9	2018-02-28 08:49:27.011787-06	2	[17898] IC-324A-OutB Call	[4] DLarrabee	[21062] a	\N	\N
b3f7f5b3-bfd2-41e2-8b7f-5cbc85656e52	2018-02-28 08:49:27.014787-06	2	[17899] IC-324B-InB Call	[4] DLarrabee	[21062] a	\N	\N
b92da8e9-9273-46e4-8617-3c9b82eb610b	2018-02-28 08:49:27.018788-06	2	[17900] IC-324B-OutB Call	[4] DLarrabee	[21062] a	\N	\N
4c5cc692-5dcd-4bf7-8341-2dc7434a56a1	2018-02-28 08:49:27.022788-06	2	[17901] IC-324C-InB Call	[4] DLarrabee	[21062] a	\N	\N
fe9a597c-c65a-4560-8b14-b7690ca46835	2018-02-28 08:49:27.026789-06	2	[17902] IC-324C-OutB Call	[4] DLarrabee	[21062] a	\N	\N
08a4b84e-0418-4cee-807f-2e7a4f3c785b	2018-02-28 08:49:27.030789-06	2	[17903] IC-333-InB Call	[4] DLarrabee	[21062] a	\N	\N
6ce5a4d9-dad8-4308-94c3-53a557c58107	2018-02-28 08:49:27.033789-06	2	[17904] IC-333-OutB Call	[4] DLarrabee	[21062] a	\N	\N
153ec5cc-eb62-448e-8875-14e365b8aeff	2018-02-28 08:49:27.148801-06	2	[18265] R8C3-8IC	[4] DLarrabee	[21062] a	\N	\N
9faddd63-86f5-48de-8fc1-f69baee2d4b9	2018-02-28 08:49:27.160802-06	2	[18267] IC-330A-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
dd01642f-c40e-43db-b0cd-4a0f64811d7d	2018-02-28 08:49:27.173803-06	2	[18268] IC-330A-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
69e72b75-dd28-4375-a720-49bde530b090	2018-02-28 08:49:27.186805-06	2	[18269] IC-330B-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
85de22ad-a274-4490-ab77-308817dc781b	2018-02-28 08:49:27.198806-06	2	[18270] IC-330B-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
fa56df9a-d563-47cb-a715-b2e8b6beb7a7	2018-02-28 08:49:27.211807-06	2	[18271] IC-378-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
af8a9a26-0cf4-4e2a-aa45-6d3a82b6c3b9	2018-02-28 08:49:27.226809-06	2	[18272] IC-378-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
57a85a9d-0061-49fe-81db-3ef7fd35edeb	2018-02-28 08:49:27.24081-06	2	[18273] IC-448-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
b5f2eafd-9e23-4c32-890f-00db32002c65	2018-02-28 08:49:27.252811-06	2	[18274] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
68c89330-10d2-45a4-a936-bbfcdd648fe4	2018-02-28 08:49:27.265812-06	2	[18276] IC-330A-InB Relay	[4] DLarrabee	[21062] a	\N	\N
48a05d77-2c4d-4fe4-a4dd-98b3de460e1c	2018-02-28 08:49:27.279814-06	2	[18277] IC-330A-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
9ec5f304-42f6-4c99-9132-c262452a70fd	2018-02-28 08:49:27.296816-06	2	[18278] IC-330B-InB Relay	[4] DLarrabee	[21062] a	\N	\N
5ef040d2-c109-4d1b-b1c3-69aa844bb16c	2018-02-28 08:49:27.318818-06	2	[18279] IC-330B-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
9033ceec-9594-4958-8ddd-6f2d7ae8b02c	2018-02-28 08:49:27.331819-06	2	[18280] IC-378-InB Relay	[4] DLarrabee	[21062] a	\N	\N
5a17c8f6-fc04-4ce8-951b-a50938b400c2	2018-02-28 08:49:27.346821-06	2	[18281] IC-378-OutB Relay	[4] DLarrabee	[21062] a	\N	\N
43619f27-170b-44b7-b189-90ef1fb877c1	2018-02-28 08:49:27.365822-06	2	[18282] IC-448-InB Relay	[4] DLarrabee	[21062] a	\N	\N
d9b53394-8e95-46ba-b1c9-98aaa23c73fe	2018-02-28 08:49:27.379824-06	2	[18283] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
6414af9d-4ca6-46c9-b91d-724957ada5df	2018-02-28 08:49:27.382824-06	2	[18285] IC-330A-InB Connect	[4] DLarrabee	[21062] a	\N	\N
11cca620-bd85-4eb5-baa9-ebe85518deb7	2018-02-28 08:49:27.386825-06	2	[18286] IC-330A-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
a304a32d-4371-4058-88db-f71b4b4e881a	2018-02-28 08:49:27.389825-06	2	[18287] IC-330B-InB Connect	[4] DLarrabee	[21062] a	\N	\N
b5fd0abf-d9f3-4c28-b0d4-f90a5ed731f2	2018-02-28 08:49:27.392825-06	2	[18288] IC-330B-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
a9dc3b1e-13c1-4e69-8776-40a5781a97fa	2018-02-28 08:49:27.395825-06	2	[18289] IC-378-InB Connect	[4] DLarrabee	[21062] a	\N	\N
50aa9096-a65e-44c7-b6b1-9054c222fd06	2018-02-28 08:49:27.398826-06	2	[18290] IC-378-OutB Connect	[4] DLarrabee	[21062] a	\N	\N
d743a42e-e446-4b3a-b7cd-f88805182492	2018-02-28 08:49:27.401826-06	2	[18291] IC-448-InB Connect	[4] DLarrabee	[21062] a	\N	\N
0b69d8bc-967d-4d4e-87b1-183493fb0d2f	2018-02-28 08:49:27.406827-06	2	[18292] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
7a3eba2a-13ba-4a2e-b698-94b44a0283a5	2018-02-28 08:49:27.409827-06	2	[18318] IC-330A-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f9657eb2-f6ba-4182-96b1-e36b7f02c880	2018-02-28 08:49:27.412827-06	2	[18319] IC-330A-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
dc4471d4-3d04-413e-8cba-6df6e1d4cd73	2018-02-28 08:49:27.417828-06	2	[18320] IC-330B-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
5bc23778-7b82-49d1-88a9-610e04c22e6f	2018-02-28 08:49:27.421828-06	2	[18321] IC-330B-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a8d79d07-4f66-4959-aa74-5ab62c2f228f	2018-02-28 08:49:27.424828-06	2	[18322] IC-378-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f60118e9-4cb9-4966-8d71-5528d2c029d9	2018-02-28 08:49:27.427829-06	2	[18323] IC-378-OutB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f83630d1-529b-49c0-a1a6-d6b5991c410d	2018-02-28 08:49:27.430829-06	2	[18324] IC-448-InB Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f0faed20-8f27-4c56-a46c-63b4e4741cc5	2018-02-28 08:49:27.433829-06	2	[18325] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3ea4adff-c77f-4947-bf64-524b5f265275	2018-02-28 08:49:27.43683-06	2	[18337] IC-330A-InB Call	[4] DLarrabee	[21062] a	\N	\N
405e342f-4223-41f4-a802-3554bf30c63f	2018-02-28 08:49:27.43983-06	2	[18338] IC-330A-OutB Call	[4] DLarrabee	[21062] a	\N	\N
5a115ea4-2f24-4400-ae7f-9c49c85929b7	2018-02-28 08:49:27.44283-06	2	[18339] IC-330B-InB Call	[4] DLarrabee	[21062] a	\N	\N
7d0ec597-de05-4c59-aa44-bd0d7c27cb38	2018-02-28 08:49:27.44583-06	2	[18340] IC-330B-OutB Call	[4] DLarrabee	[21062] a	\N	\N
0c56386c-3eed-432a-ab71-8a9d5362a754	2018-02-28 08:49:27.448831-06	2	[18341] IC-378-InB Call	[4] DLarrabee	[21062] a	\N	\N
507cee11-0013-4250-b406-40e73c5bc5fa	2018-02-28 08:49:27.451831-06	2	[18342] IC-378-OutB Call	[4] DLarrabee	[21062] a	\N	\N
844a815d-c52c-489e-ba7d-ed2c1c449f67	2018-02-28 08:49:27.454831-06	2	[18343] IC-448-InB Call	[4] DLarrabee	[21062] a	\N	\N
3e2312eb-dc29-4257-8758-83ef7865417a	2018-02-28 08:49:27.456832-06	2	[18344] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
fe23b7ed-6339-42fd-b063-837469cb101d	2018-02-28 08:49:27.477834-06	2	[18705] R8C4-32I	[4] DLarrabee	[21062] a	\N	\N
d9b1c07d-832e-4f5d-9c73-6308279925ed	2018-02-28 08:49:27.495835-06	2	[18707] DPIS-307 Call Button	[4] DLarrabee	[21062] a	\N	\N
6f499cf9-5f0b-4e96-9363-6fb0771c0988	2018-02-28 08:49:27.509837-06	2	[18708] DPIS-309 Call Button	[4] DLarrabee	[21062] a	\N	\N
84c319f8-6476-4b0e-988d-35d1eb65e9d4	2018-02-28 08:49:27.528839-06	2	[18709] DPIS-314 Call Button	[4] DLarrabee	[21062] a	\N	\N
bd32b303-6c18-4cb7-925e-e62338b9d9f6	2018-02-28 08:49:27.54384-06	2	[18710] DPIS-322 Call Button	[4] DLarrabee	[21062] a	\N	\N
118f9a1c-fa77-4dcc-b68a-6c2414580afd	2018-02-28 08:49:27.557842-06	2	[18711] DPIS-324A Call Button	[4] DLarrabee	[21062] a	\N	\N
ce7f0bd7-c864-4dd5-9151-e1b3cbdfec3a	2018-02-28 08:49:27.572843-06	2	[18712] DPIS-324B Call Button	[4] DLarrabee	[21062] a	\N	\N
e8088dbc-4cc3-417f-99bb-41893c735e73	2018-02-28 08:49:27.589845-06	2	[18713] DPIS-324C Call Button	[4] DLarrabee	[21062] a	\N	\N
eb891e86-2bc7-4022-901c-fe789a5e0cb9	2018-02-28 08:49:27.605846-06	2	[18714] DPIS-333 Call Button	[4] DLarrabee	[21062] a	\N	\N
1f13f7f2-77ff-4332-a1c8-bdf74d16a20a	2018-02-28 08:49:27.619848-06	2	[18715] DPIS-330A Call Button	[4] DLarrabee	[21062] a	\N	\N
cfc41f3a-0026-4cae-a55b-0b9bd44d9ebb	2018-02-28 08:49:27.633849-06	2	[18716] DPIS-330B Call Button	[4] DLarrabee	[21062] a	\N	\N
da7d616c-7a6a-48f2-8e1d-d05152e9813e	2018-02-28 08:49:27.647851-06	2	[18717] DPIS-378 Call Button	[4] DLarrabee	[21062] a	\N	\N
8a84242d-a315-4bcc-ab73-b4e045c817d3	2018-02-28 08:49:27.660852-06	2	[18718] DPIS-414A Call Button	[4] DLarrabee	[21062] a	\N	\N
0fabcb94-c959-4275-859e-5176f318830e	2018-02-28 08:49:27.675853-06	2	[18719] DPIS-414B Call Button	[4] DLarrabee	[21062] a	\N	\N
3ad42578-6912-485c-aef5-a7241441f2b8	2018-02-28 08:49:27.689855-06	2	[18720] DPIS-323OHD Call Button	[4] DLarrabee	[21062] a	\N	\N
3d56b5a1-5b10-492d-a9c7-41ab5c50bd45	2018-02-28 08:49:27.704856-06	2	[18721] DPIS-324OHDE Call Button	[4] DLarrabee	[21062] a	\N	\N
29f3878e-2cb3-4ce8-854e-e5036d3e7c42	2018-02-28 08:49:27.719858-06	2	[18722] DPIS-324OHDW Call Button	[4] DLarrabee	[21062] a	\N	\N
93eff471-b4eb-4485-bcf6-74a45ae21ec5	2018-02-28 08:49:27.732859-06	2	[18723] DPIS-342 Call Button	[4] DLarrabee	[21062] a	\N	\N
b75199e4-9d7c-4a16-aef2-7f7e19f764cf	2018-02-28 08:49:27.747861-06	2	[18724] DURESS-415 Call Button	[4] DLarrabee	[21062] a	\N	\N
fa7d8932-3123-4125-b07c-21a55a46eef0	2018-02-28 08:49:27.764862-06	2	[18725] DURESS-418 Call Button	[4] DLarrabee	[21062] a	\N	\N
8c5c64e9-6f3a-4b72-8215-82557c8f34c2	2018-02-28 08:49:27.778864-06	2	[18726] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
3abb801d-6cc4-43fb-98a1-acc75ef2a7e7	2018-02-28 08:49:27.796866-06	2	[18727] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
169e42b1-26a6-4c29-9be4-5b73e46c8dc8	2018-02-28 08:49:27.811867-06	2	[18728] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
9fd03a52-8f6a-4228-bd77-863c090142f0	2018-02-28 08:49:27.826869-06	2	[18729] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
98f0be94-6c34-4d3d-8b03-7394c9b2a514	2018-02-28 08:49:27.84087-06	2	[18730] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
56a34ff7-f902-4f5a-a4d7-af05152c79f3	2018-02-28 08:49:27.854871-06	2	[18731] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
3539ef6b-9175-494c-bf42-66f4398e0540	2018-02-28 08:49:27.872873-06	2	[18732] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
3d0f1874-8d1e-4527-99b6-fb79a494d156	2018-02-28 08:49:27.887875-06	2	[18733] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
0ce6f1f7-5ff8-43a5-a102-aa78d19072ca	2018-02-28 08:49:27.899876-06	2	[18734] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
1f87f613-ff9d-475a-9cae-a5e4d2ee31c8	2018-02-28 08:49:27.914877-06	2	[18735] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
6c1bb293-e980-40c0-9890-90c184b80bc8	2018-02-28 08:49:27.929879-06	2	[18736] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
9d6035f5-b134-4856-a6b2-9de64ed2787f	2018-02-28 08:49:27.94388-06	2	[18737] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
4b8b31bb-c9c5-401d-bbd4-2f5b5642b2bf	2018-02-28 08:49:27.960882-06	2	[18738] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
b7779b86-3027-416a-95ce-7b7b99620e20	2018-02-28 08:49:27.963882-06	2	[18774] DPIS-307 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b021e795-f533-463d-b710-ddd0d0484818	2018-02-28 08:49:27.967883-06	2	[18775] DPIS-309 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7da22d96-9765-411f-9fbf-a6ab0377d560	2018-02-28 08:49:27.970883-06	2	[18776] DPIS-314 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9765b78b-4dc4-4b2c-a132-9bba027f38b9	2018-02-28 08:49:27.974883-06	2	[18777] DPIS-322 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
36596b15-3a13-4c46-a4d3-7e2118cd24b3	2018-02-28 08:49:27.977884-06	2	[18778] DPIS-324A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
bb00fb76-ac78-4ae5-adf8-85633ebbc6a6	2018-02-28 08:49:27.981884-06	2	[18779] DPIS-324B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d7957e56-8dd9-4764-ac78-88863455dc46	2018-02-28 08:49:27.985884-06	2	[18780] DPIS-324C Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
83b3e59a-5952-40ad-9cb3-734808ea119f	2018-02-28 08:49:27.989885-06	2	[18781] DPIS-333 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cf87df75-d6bf-4efc-b64d-ff8d905081e0	2018-02-28 08:49:27.992885-06	2	[18782] DPIS-330A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
40622772-0c2d-4e6b-98f8-fe9160ba6a69	2018-02-28 08:49:27.996886-06	2	[18783] DPIS-330B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0a28a3f3-6229-40b9-ab2a-1c9f7ae24677	2018-02-28 08:49:27.999886-06	2	[18784] DPIS-378 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
46647e70-e933-4227-bdf7-958c8445b826	2018-02-28 08:49:28.003886-06	2	[18785] DPIS-414A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3457204f-3ee5-4998-b9f1-cbcf5ea614d4	2018-02-28 08:49:28.007887-06	2	[18786] DPIS-414B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f63acc80-4d7f-4b77-9838-00f96c90a42d	2018-02-28 08:49:28.011887-06	2	[18787] DPIS-323OHD Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
75f67e13-1f6f-4e1d-bf83-e5a238679fde	2018-02-28 08:49:28.014887-06	2	[18788] DPIS-324OHDE Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
448044a5-3651-46bb-9a77-eae3a6c9a014	2018-02-28 08:49:28.018888-06	2	[18789] DPIS-324OHDW Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
444a95ec-0c79-481b-91ba-594c51bbca83	2018-02-28 08:49:28.022888-06	2	[18790] DPIS-342 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
95f556c6-f7b9-40c7-ac82-58c19f8794c2	2018-02-28 08:49:28.025888-06	2	[18791] DURESS-415 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
0312bbd6-5894-438f-8cd3-b655c2311e40	2018-02-28 08:49:28.029889-06	2	[18792] DURESS-418 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f6558712-555a-43a3-baee-d476357bf2ae	2018-02-28 08:49:28.033889-06	2	[18793] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
2277e472-a6e1-4074-95b6-bbd4e3e88001	2018-02-28 08:49:28.03689-06	2	[18794] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fec53df9-b6ab-4f1e-9cd0-7d13c6f3091e	2018-02-28 08:49:28.03989-06	2	[18795] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fe50715c-645d-431c-9045-ca1e72e29a4b	2018-02-28 08:49:28.04389-06	2	[18796] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
38b59018-d773-41a5-8fd5-bc1f4714bc1d	2018-02-28 08:49:28.047891-06	2	[18797] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3c728caa-3455-4c9a-8d72-a9ba9834163e	2018-02-28 08:49:28.050891-06	2	[18798] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c9b1ef30-5c79-4fdf-8861-fbe58ff20a5b	2018-02-28 08:49:28.053891-06	2	[18799] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
fb52ab96-ff81-4847-841c-05de8aad10e6	2018-02-28 08:49:28.057892-06	2	[18800] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
1a83f043-62b3-49d7-a509-5a3283da50f5	2018-02-28 08:49:28.060892-06	2	[18801] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
671fe295-98f3-4dff-8073-b123edc3a8df	2018-02-28 08:49:28.064892-06	2	[18802] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8b8db511-4ab1-4a52-9651-d34620c98d81	2018-02-28 08:49:28.068893-06	2	[18803] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f954f6c0-ca60-4af9-9e01-d6e9a9b2145f	2018-02-28 08:49:28.073893-06	2	[18804] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
8cff4b54-253c-4ee8-a104-39d222cf5a53	2018-02-28 08:49:28.076894-06	2	[18805] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
19dbbeb2-e0a3-4ea7-9e68-f73b8536002b	2018-02-28 08:49:28.097896-06	2	[19172] R8C5-16R	[4] DLarrabee	[21062] a	\N	\N
1f1666d3-aca7-4cc6-a1ec-0ef338084953	2018-02-28 08:49:28.111897-06	2	[19175] Lock Relay-307 Relay	[4] DLarrabee	[21062] a	\N	\N
dc703218-33b3-4ee5-85d5-b39607dd1d1e	2018-02-28 08:49:28.127899-06	2	[19176] Lock Relay-309 Relay	[4] DLarrabee	[21062] a	\N	\N
306663c1-4039-41f9-b9d3-1443342d1f10	2018-02-28 08:49:28.164902-06	2	[19177] Lock Relay-314 Relay	[4] DLarrabee	[21062] a	\N	\N
18dc8973-302f-4684-85bd-b99fe90aae88	2018-02-28 08:49:28.180904-06	2	[19178] Lock Relay-322 Relay	[4] DLarrabee	[21062] a	\N	\N
2631a38b-95b3-4220-a534-ebc74fe26818	2018-02-28 08:49:28.195905-06	2	[19179] Lock Relay-324A Relay	[4] DLarrabee	[21062] a	\N	\N
78290819-4b9c-4e8a-88cb-2df2545741b6	2018-02-28 08:49:28.213907-06	2	[19180] Lock Relay-324B Relay	[4] DLarrabee	[21062] a	\N	\N
755b8c7f-ca94-4f58-97d5-f7fc64841dbd	2018-02-28 08:49:28.225908-06	2	[19181] Lock Relay-324C Relay	[4] DLarrabee	[21062] a	\N	\N
b79791e9-d42d-4d6b-91f2-eba9545e0fd8	2018-02-28 08:49:28.24091-06	2	[19182] Lock Relay-333 Relay	[4] DLarrabee	[21062] a	\N	\N
aa49bd99-30de-4e72-b772-051098fc384f	2018-02-28 08:49:28.255911-06	2	[19183] Lock Relay-330A Relay	[4] DLarrabee	[21062] a	\N	\N
cfdbc989-19f9-4778-b6e7-e9f24f5c28c7	2018-02-28 08:49:28.270913-06	2	[19184] Lock Relay-330B Relay	[4] DLarrabee	[21062] a	\N	\N
8ac1bac8-374f-4e30-ad12-d06c8083e512	2018-02-28 08:49:28.289915-06	2	[19185] Lock Relay-378 Relay	[4] DLarrabee	[21062] a	\N	\N
8cf41944-bd7e-47a5-8c32-c20604c708ac	2018-02-28 08:49:28.305916-06	2	[19186] Lock Relay-414A Relay	[4] DLarrabee	[21062] a	\N	\N
94b16024-5b19-4d3f-b7fe-03de628f738d	2018-02-28 08:49:28.321918-06	2	[19187] Lock Relay-414B Relay	[4] DLarrabee	[21062] a	\N	\N
970464ad-aaf6-4c42-9980-0b9f2a84e11d	2018-02-28 08:49:28.33992-06	2	[19188] OPEN Relay-323OHD Relay	[4] DLarrabee	[21062] a	\N	\N
085f9ba8-0195-40ac-8075-7b8e37924615	2018-02-28 08:49:28.354921-06	2	[19189] CLOSE Relay-323OHD Relay	[4] DLarrabee	[21062] a	\N	\N
798c17d8-cd18-45e8-a066-ff8b38195735	2018-02-28 08:49:28.368923-06	2	[19190] OPEN Relay-324OHDE Relay	[4] DLarrabee	[21062] a	\N	\N
131ee065-c33d-410e-b3ec-4fb215324a49	2018-02-28 08:49:28.384924-06	2	[19492] R8C6-16R	[4] DLarrabee	[21062] a	\N	\N
7eb9c3bf-e67f-4106-8d69-838a135bee77	2018-02-28 08:49:28.398926-06	2	[19495] CLOSE Relay-324OHDE Relay	[4] DLarrabee	[21062] a	\N	\N
1861836e-90ae-4094-a865-772061e1e30e	2018-02-28 08:49:28.411927-06	2	[19496] OPEN Relay-324OHDW Relay	[4] DLarrabee	[21062] a	\N	\N
c52e2ba0-2653-4e29-b8ae-42d2bade3579	2018-02-28 08:49:28.431929-06	2	[19497] CLOSE Relay-324OHDW Relay	[4] DLarrabee	[21062] a	\N	\N
cdb8b266-5852-4c53-a881-18e8f4358d91	2018-02-28 08:49:28.447931-06	2	[19498] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
3481996d-a29c-4682-9548-921206799b9a	2018-02-28 08:49:28.462932-06	2	[19499] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
9f945148-833a-49d0-a5a4-10a5030087d5	2018-02-28 08:49:28.476934-06	2	[19500] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
09cc6728-00e7-4c2d-ae52-80efaa0c2cd0	2018-02-28 08:49:28.493935-06	2	[19501] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
ae83b064-83df-4ce6-a8c6-4e97762961ca	2018-02-28 08:49:28.511937-06	2	[19502] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
a2a0fb22-c5e5-4f27-84b9-1418fb6b06e8	2018-02-28 08:49:28.527939-06	2	[19503] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
6d88ff37-9363-4da3-826d-2a70dde3a046	2018-02-28 08:49:28.54494-06	2	[19504] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
924fcb8c-cabd-4b43-adaa-a7eb841748ce	2018-02-28 08:49:28.560942-06	2	[19505] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
94095587-fa34-429a-a656-fc8e2a2da02c	2018-02-28 08:49:28.573943-06	2	[19506] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
fba7cd39-3d48-41f8-9466-f891df002867	2018-02-28 08:49:28.586945-06	2	[19507] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
a469a232-9e87-4c6f-bfff-53ffd5c0e376	2018-02-28 08:49:28.602946-06	2	[19508] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
c7644cee-baab-4427-b111-6182282762e9	2018-02-28 08:49:28.618948-06	2	[19509] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
a8b0cab4-4e3a-4624-8368-2f034d86e020	2018-02-28 08:49:28.635949-06	2	[19510] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
9fe0ea68-1164-456c-aa1f-49ff02f02364	2018-02-28 08:51:01.129198-06	2	[17387] IC-307-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
be680401-2912-42af-9653-091322051dc5	2018-02-28 08:51:01.145199-06	2	[17388] IC-309-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
4589694d-acf9-4478-b8ff-0a6e8992265d	2018-02-28 08:51:01.185203-06	2	[17389] IC-309-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
421f7bab-874c-4621-ad06-8ad6721aff4c	2018-02-28 08:51:01.197205-06	2	[17390] IC-314-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
0ec05b1f-829a-46da-bb16-18733f45e316	2018-02-28 08:51:01.214206-06	2	[17391] IC-314-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
85257160-be79-4982-9ee6-daecf38e74e0	2018-02-28 08:51:01.231208-06	2	[17392] IC-322-InB Call Button	[4] DLarrabee	[21062] a	\N	\N
b24982d2-f1b5-448a-a17a-e614c125353e	2018-02-28 08:51:01.25221-06	2	[17393] IC-322-OutB Call Button	[4] DLarrabee	[21062] a	\N	\N
154e9a0f-34bf-4399-889b-6b6bbe103313	2018-02-28 08:53:50.774161-06	2	[19815] DPIS-429A Call Button	[4] DLarrabee	[21062] a	\N	\N
792c0058-ccaa-447d-938c-e9b1e4495ef2	2018-02-28 08:53:50.795163-06	2	[19823] DURESS-428 Call Button	[4] DLarrabee	[21062] a	\N	\N
3783283b-7797-4873-8e13-f1402970edbc	2018-02-28 08:53:50.812164-06	2	[19824] DURESS-463 Call Button	[4] DLarrabee	[21062] a	\N	\N
7228b789-63dd-4d11-b518-9336fba3e3a6	2018-02-28 08:53:50.831166-06	2	[19825] DURESS-465 Call Button	[4] DLarrabee	[21062] a	\N	\N
575fe924-63aa-4fe8-af43-223e00e5ed38	2018-02-28 08:53:50.849168-06	2	[19826] DURESS-514 Call Button	[4] DLarrabee	[21062] a	\N	\N
b1886a28-c389-4a0d-9e86-d53cb583f6bc	2018-02-28 08:53:50.86517-06	2	[19827] DURESS-529 Call Button	[4] DLarrabee	[21062] a	\N	\N
7ff05f67-e714-4541-bf53-aa67e91d2d51	2018-02-28 08:53:50.881171-06	2	[19828] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
63c64c14-81df-4509-a356-7903cd27d7ef	2018-02-28 08:53:50.897173-06	2	[19829] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
b28d176a-0449-4393-beb1-e36d9de24290	2018-02-28 08:53:50.914175-06	2	[19830] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
2df45bf9-1ee9-4282-a7bf-32c01285b6ff	2018-02-28 08:53:50.917175-06	2	[19882] DPIS-429A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d872861b-6148-475f-9bef-88c1b32bb713	2018-02-28 08:53:50.921175-06	2	[19883] DPIS-429B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
4ac343ff-8330-4738-83b6-39f5a88d0cff	2018-02-28 08:53:50.925176-06	2	[19884] DPIS-429C Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a4560df6-d4b0-42c0-b784-23cf8b65dd35	2018-02-28 08:53:50.929176-06	2	[19885] DPIS-456 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
df0b6f84-16dc-44a2-8a46-36d70265e5d4	2018-02-28 08:53:50.932176-06	2	[19886] DPIS-461 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b202b66c-0eaf-4ba8-bca4-a45344e99664	2018-02-28 08:53:50.936177-06	2	[19887] DPIS-514 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
93e5730b-b17d-4f9e-817e-f493cd1032ef	2018-02-28 08:53:50.942177-06	2	[19888] DPIS-529 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
e3ffbbc8-fab8-4d37-81de-572e490c16c1	2018-02-28 08:53:50.948178-06	2	[19889] DURESS-425 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
32bd6f1a-29fc-4bf9-a3bf-b8db8306c2c8	2018-02-28 08:53:50.952178-06	2	[19890] DURESS-428 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
03122984-7dd3-4b1e-a9bc-dc30598a73cb	2018-02-28 08:53:50.956179-06	2	[19891] DURESS-463 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d85c212f-d33e-4c2b-b5e9-47a146fe71e6	2018-02-28 08:53:50.961179-06	2	[19892] DURESS-465 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
be5c74eb-77f7-45d2-bf53-917bc2f9dce0	2018-02-28 08:53:50.96518-06	2	[19893] DURESS-514 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
97be0c19-0f1d-4d27-975e-fc698c03d647	2018-02-28 08:53:50.96818-06	2	[19894] DURESS-529 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
5d94d7de-1290-463b-8c7d-9fe7a622be55	2018-02-28 08:53:50.97218-06	2	[19895] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7aaaddb9-e83e-48de-a40f-98286fe1fd6a	2018-02-28 08:53:50.976181-06	2	[19896] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7aca3d19-f791-411b-928f-d8353b535e89	2018-02-28 08:53:50.979181-06	2	[19897] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b3f9a28d-a9bf-4082-8510-78cc96194592	2018-02-28 08:53:50.983182-06	2	[19898] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cf757eb9-fa56-4b99-bb34-080db6ac2b2e	2018-02-28 08:53:50.986182-06	2	[19899] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
aca73be8-ba7b-4812-b1c0-1a1b0fb484f7	2018-02-28 08:53:50.990182-06	2	[19900] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
3ade715b-c2d7-492f-b4aa-9b953451e82f	2018-02-28 08:53:50.993183-06	2	[19901] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
12615925-e2a8-4ac5-ba75-88ef28aaf9c2	2018-02-28 08:53:50.998183-06	2	[19902] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
77edcb70-5d87-4822-b879-159b0fe10cb1	2018-02-28 08:53:51.003184-06	2	[19903] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
180802ef-83c0-49ec-9a07-7be2e2060aae	2018-02-28 08:53:51.008184-06	2	[19904] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a8a7b97b-a827-413a-b807-a1370f84631e	2018-02-28 08:53:51.012184-06	2	[19905] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cd6a499e-f750-438c-9eb1-7f71e780a01f	2018-02-28 08:53:51.016185-06	2	[19906] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
b0c2d8c5-218a-41a2-bad8-cd17f353c511	2018-02-28 08:53:51.021185-06	2	[19907] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
536b27e2-a896-478a-a6af-2b2330332b0c	2018-02-28 08:53:51.025186-06	2	[19908] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
83dc7cd5-6474-48c0-9f39-2c81f39c25c8	2018-02-28 08:53:51.028186-06	2	[19909] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c99656a8-22d5-4d20-a559-5685c896d11a	2018-02-28 08:53:51.032186-06	2	[19910] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
6f321ecc-16df-466b-ae40-954c2fcb4509	2018-02-28 08:53:51.035187-06	2	[19911] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d5b6ab0a-ddf4-4085-aa47-fb7adfe6dfae	2018-02-28 08:53:51.039187-06	2	[19912] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
36ef5097-a800-4f99-b93e-c6096590d6e2	2018-02-28 08:53:51.042187-06	2	[19913] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
509c05f2-18c4-48f0-8e19-2dd6aeed8d03	2018-02-28 08:53:51.059189-06	2	[20281] 9C2-16R	[4] DLarrabee	[21062] a	\N	\N
5f93ba0d-cee8-486c-ac97-4f2d3d87b90d	2018-02-28 08:53:51.073191-06	2	[20284] Lock Relay-429A Relay	[4] DLarrabee	[21062] a	\N	\N
35b6846d-0626-4437-8c73-6ff7205b4a95	2018-02-28 08:53:51.088192-06	2	[20285] Lock Relay-429B Relay	[4] DLarrabee	[21062] a	\N	\N
ca301e3b-ccc5-479c-920e-930c059adbaf	2018-02-28 08:53:51.103194-06	2	[20286] Lock Relay-429C Relay	[4] DLarrabee	[21062] a	\N	\N
04ec9d76-c5cb-4771-b76a-18c68ba43844	2018-02-28 08:53:51.118195-06	2	[20287] Lock Relay-456 Relay	[4] DLarrabee	[21062] a	\N	\N
db6da50a-16f7-4b88-9e54-6870b6dd74f3	2018-02-28 08:53:51.136197-06	2	[20288] Lock Relay-461 Relay	[4] DLarrabee	[21062] a	\N	\N
5875b1e0-0541-4c46-941c-e8be74eb712b	2018-02-28 08:53:51.155199-06	2	[20289] Lock Relay-514 Relay	[4] DLarrabee	[21062] a	\N	\N
91240c7d-f43d-4406-9cfc-1ee6f5056af7	2018-02-28 08:53:51.1702-06	2	[20290] Lock Relay-529 Relay	[4] DLarrabee	[21062] a	\N	\N
da61152c-e152-4435-86ec-19eaecfd26c9	2018-02-28 08:53:51.184202-06	2	[20291] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
708408bd-3744-4e0a-9745-0293d8ddb592	2018-02-28 08:53:51.203204-06	2	[20292] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
ae78cf98-57f9-43c0-9428-6e9163529942	2018-02-28 08:53:51.218205-06	2	[20293] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
69795e86-3c09-4f00-a9cf-d9fca63da6da	2018-02-28 08:53:51.232206-06	2	[20294] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
9358186b-09e5-4b19-bce2-ee57518ce68f	2018-02-28 08:53:51.247208-06	2	[20295] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
58f34282-301b-439f-b037-fa6c287a9a13	2018-02-28 08:53:51.26721-06	2	[20296] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
525a1191-62fc-4495-945d-ba875b2f2fea	2018-02-28 08:53:51.282211-06	2	[20297] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
7d047920-8fbb-4866-8fb3-9267bdc94f8a	2018-02-28 08:53:51.295213-06	2	[20298] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
ec6b9d96-d76c-439a-aa67-4c9d4ce123b9	2018-02-28 08:53:51.308214-06	2	[20299] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
002a556a-dd98-40ab-8cb2-9b501a882212	2018-02-28 08:53:51.440227-06	2	[20601] 9C3-8IC	[4] DLarrabee	[21062] a	\N	\N
0ef09080-7e20-4569-ba71-3724d9b7309d	2018-02-28 08:53:51.460229-06	2	[20603] IC-429A Call Button	[4] DLarrabee	[21062] a	\N	\N
ef5b0ee8-98d8-4331-8c2d-51ab3e741e2e	2018-02-28 08:53:51.475231-06	2	[20604] IC-429B Call Button	[4] DLarrabee	[21062] a	\N	\N
a986351a-eb02-4093-b177-a834ba481167	2018-02-28 08:53:51.492232-06	2	[20605] IC-429C Call Button	[4] DLarrabee	[21062] a	\N	\N
484fd5fa-a0f1-4257-a5d6-5aa892478c09	2018-02-28 08:53:51.511234-06	2	[20606] IC-456 Call Button	[4] DLarrabee	[21062] a	\N	\N
1cc880b3-402c-40a5-8dfd-92e4b95a6da6	2018-02-28 08:53:51.527236-06	2	[20607] IC-461 Call Button	[4] DLarrabee	[21062] a	\N	\N
6ae6b3fb-2f99-4d15-a6dc-d891f9532e8d	2018-02-28 08:53:51.547238-06	2	[20608] IC-514 Call Button	[4] DLarrabee	[21062] a	\N	\N
dbd959a8-5c53-499a-b021-fc6e7849f35f	2018-02-28 08:53:51.562239-06	2	[20609] IC-529 Call Button	[4] DLarrabee	[21062] a	\N	\N
391fc5e2-1f29-4a36-a5bf-13a22080213e	2018-02-28 08:53:51.577241-06	2	[20610] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
28d2c684-2277-498c-b5f5-c36360d051a9	2018-02-28 08:53:51.591242-06	2	[20612] IC-429A Relay	[4] DLarrabee	[21062] a	\N	\N
318725be-9031-4f21-8833-89f7f4481ec5	2018-02-28 08:53:51.605244-06	2	[20613] IC-429B Relay	[4] DLarrabee	[21062] a	\N	\N
d0e66387-db4b-4556-b624-3ac6d1b852af	2018-02-28 08:53:51.617245-06	2	[20614] IC-429C Relay	[4] DLarrabee	[21062] a	\N	\N
e02e514d-d0e9-4de4-9bff-4dafa31883ee	2018-02-28 08:53:51.630246-06	2	[20615] IC-456 Relay	[4] DLarrabee	[21062] a	\N	\N
e61d8280-37ab-4a42-97f7-77fb5cda9be1	2018-02-28 08:53:51.644248-06	2	[20616] IC-461 Relay	[4] DLarrabee	[21062] a	\N	\N
0c15f750-5946-4a58-a2d7-ba900be44f76	2018-02-28 08:53:51.657249-06	2	[20617] IC-514 Relay	[4] DLarrabee	[21062] a	\N	\N
7125415c-08e2-4b19-b76e-102b75279935	2018-02-28 08:53:51.675251-06	2	[20618] IC-529 Relay	[4] DLarrabee	[21062] a	\N	\N
1f253830-5006-42b7-bcf5-ee912bde3047	2018-02-28 08:53:51.689252-06	2	[20619] Not Used Relay	[4] DLarrabee	[21062] a	\N	\N
476a2999-d6ac-46f1-8a16-b8a175b4e47e	2018-02-28 08:53:51.692252-06	2	[20621] IC-429A Connect	[4] DLarrabee	[21062] a	\N	\N
4ff8abbc-495a-41ea-a57c-bde329d8a01d	2018-02-28 08:53:51.696253-06	2	[20622] IC-429B Connect	[4] DLarrabee	[21062] a	\N	\N
974a52d3-c8a1-476e-b470-98861c6f8499	2018-02-28 08:53:51.699253-06	2	[20623] IC-429C Connect	[4] DLarrabee	[21062] a	\N	\N
6f4d7a87-5edc-41a2-83bc-1a825e2f2e19	2018-02-28 08:53:51.701253-06	2	[20624] IC-456 Connect	[4] DLarrabee	[21062] a	\N	\N
f065f4fb-2406-4137-b2da-24dc761705e6	2018-02-28 08:53:51.704254-06	2	[20625] IC-461 Connect	[4] DLarrabee	[21062] a	\N	\N
61273c86-a3d6-4c11-bd7d-1ba822491f1e	2018-02-28 08:53:51.707254-06	2	[20626] IC-514 Connect	[4] DLarrabee	[21062] a	\N	\N
831f98a3-0e99-4ee5-92ca-e2dc6d372410	2018-02-28 08:53:51.710254-06	2	[20627] IC-529 Connect	[4] DLarrabee	[21062] a	\N	\N
87f41903-7c30-4ca9-a507-3c3244209fb9	2018-02-28 08:53:51.713255-06	2	[20628] Not Used Connect	[4] DLarrabee	[21062] a	\N	\N
fd17b03d-ed72-4196-99e9-8f6d81ba3018	2018-02-28 08:53:51.716255-06	2	[20654] IC-429A Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
d7353274-babf-4be7-a050-13fe0244595d	2018-02-28 08:53:51.720255-06	2	[20655] IC-429B Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
47ab9547-2eb4-4dac-88df-7dcfb48c493c	2018-02-28 08:53:51.724256-06	2	[20656] IC-429C Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
aa62a4b0-339b-4d18-ab4e-4fba45b02717	2018-02-28 08:53:51.727256-06	2	[20657] IC-456 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
7b5a6777-e653-4dcd-9525-c403c2c55eac	2018-02-28 08:53:51.731256-06	2	[20658] IC-461 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ddf6c821-8179-4b28-b784-d5f872e38fed	2018-02-28 08:53:51.735257-06	2	[20659] IC-514 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f302caeb-4e4c-46db-b728-3c66e5c1bd9b	2018-02-28 08:53:51.739257-06	2	[20660] IC-529 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
aee0ed60-51d8-42c1-baa8-ce63543e9940	2018-02-28 08:53:51.742257-06	2	[20661] Not Used Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f8dc717d-2efc-465e-8027-4d108d7bc97a	2018-02-28 08:53:51.745258-06	2	[20673] IC-429A Call	[4] DLarrabee	[21062] a	\N	\N
425ed275-f41f-4e82-b1ba-023b503a1c2d	2018-02-28 08:53:51.749258-06	2	[20674] IC-429B Call	[4] DLarrabee	[21062] a	\N	\N
4aaf2dd5-2131-4610-8249-bacf055f342e	2018-02-28 08:53:51.752258-06	2	[20675] IC-429C Call	[4] DLarrabee	[21062] a	\N	\N
f79f2589-7eb0-4f58-9dc5-dbdabee240e8	2018-02-28 08:53:51.755259-06	2	[20676] IC-456 Call	[4] DLarrabee	[21062] a	\N	\N
fe2ffb87-74fa-43ed-84e9-5f93e87a9244	2018-02-28 08:53:51.759259-06	2	[20677] IC-461 Call	[4] DLarrabee	[21062] a	\N	\N
92a8fbf4-5f6c-4547-81f6-ac82aee287d6	2018-02-28 08:53:51.762259-06	2	[20678] IC-514 Call	[4] DLarrabee	[21062] a	\N	\N
95e9b49e-6fc7-412f-97cf-da49f103b37c	2018-02-28 08:53:51.76526-06	2	[20679] IC-529 Call	[4] DLarrabee	[21062] a	\N	\N
07f7acda-43e1-43eb-8fa2-388031f365eb	2018-02-28 08:53:51.76826-06	2	[20680] Not Used Call	[4] DLarrabee	[21062] a	\N	\N
edf2ee37-b27b-40fb-9d09-74d0ec419328	2018-02-28 08:54:18.400923-06	2	[19816] DPIS-429B Call Button	[4] DLarrabee	[21062] a	\N	\N
ea8d69e4-6f5b-4a0d-ae56-a797c76b2245	2018-02-28 08:54:18.439927-06	2	[19817] DPIS-429C Call Button	[4] DLarrabee	[21062] a	\N	\N
3ff6ee28-98aa-4a91-b370-b6484f3e4a9c	2018-02-28 08:54:18.483931-06	2	[19818] DPIS-456 Call Button	[4] DLarrabee	[21062] a	\N	\N
5f6ea9ae-f894-47b5-a3a0-61cd566892e3	2018-02-28 08:54:18.519935-06	2	[19819] DPIS-461 Call Button	[4] DLarrabee	[21062] a	\N	\N
7b42acc5-a5d6-4f53-b284-e0f872b85272	2018-02-28 08:54:18.546938-06	2	[19820] DPIS-514 Call Button	[4] DLarrabee	[21062] a	\N	\N
bb193c5e-351b-4e97-9353-d2923574372d	2018-02-28 08:54:18.56894-06	2	[19821] DPIS-529 Call Button	[4] DLarrabee	[21062] a	\N	\N
911d81a8-d37d-4986-b577-4ec2ed87d122	2018-02-28 08:54:18.588942-06	2	[19822] DURESS-425 Call Button	[4] DLarrabee	[21062] a	\N	\N
679562a5-6897-4bba-9415-6e4d813ee67e	2018-02-28 08:54:18.606944-06	2	[19831] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
2040415b-041e-4482-81d5-98a7ed2bac4f	2018-02-28 08:54:18.624945-06	2	[19832] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
48a3656d-f294-412a-817d-f142f973aef3	2018-02-28 08:54:18.645948-06	2	[19833] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
24ea7f03-9690-43e9-bf06-3b2f46473ae9	2018-02-28 08:54:18.66595-06	2	[19834] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
2a5a0909-f587-445f-8c96-553c62c3360b	2018-02-28 08:54:18.686952-06	2	[19835] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
d446051c-d1a5-42d0-a411-bbbf350cbac0	2018-02-28 08:54:18.707954-06	2	[19836] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
f7c77d5e-7848-43da-a327-b6cba738ef84	2018-02-28 08:54:18.728956-06	2	[19837] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
db6f3bc8-aeef-4664-a617-7f58aa9b8457	2018-02-28 08:54:18.752958-06	2	[19838] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
dd243bea-97cb-4f93-ba3c-fcbd8e22464d	2018-02-28 08:54:18.780961-06	2	[19839] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
2cf73e21-65d0-475f-aad6-44025d5dff90	2018-02-28 08:54:18.810964-06	2	[19840] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
e6e5b7b9-064a-44c4-b9c3-94d1fe30b256	2018-02-28 08:54:18.831966-06	2	[19841] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
7bb6d82c-aeca-4e6a-91a6-e703f5d7b1cb	2018-02-28 08:54:18.850968-06	2	[19842] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
72acd0ef-8982-44c3-9029-ccd6e19c5334	2018-02-28 08:54:18.87097-06	2	[19843] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
5c7c5f80-a60b-4ef7-ab4d-5533734e82cd	2018-02-28 08:54:18.893972-06	2	[19844] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
5baa31cf-e5cb-4cb1-ab4c-3b9472d35480	2018-02-28 08:54:18.908974-06	2	[19845] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
6d68689a-d7ca-4456-8530-e1d79a80e0a8	2018-02-28 08:54:18.929976-06	2	[19846] Not Used Call Button	[4] DLarrabee	[21062] a	\N	\N
84dd4814-9942-4dc3-b93e-e836966e7318	2018-02-28 08:54:49.588041-06	2	[19813] 9C1-32I	[4] DLarrabee	[21062] a	\N	\N
f701090c-cb92-44fd-954f-050c78bccf3a	2018-02-28 08:55:16.919774-06	2	[17384] R8C1-8IC	[4] DLarrabee	[21062] a	\N	\N
30992d70-2e72-4768-b519-e6813bbf2384	2018-02-28 08:55:17.447827-06	2	[17384] R8C1-8IC	[4] DLarrabee	[21062] a	\N	\N
5f3d271a-56de-4a53-9c2e-2c07d9d0a499	2018-02-28 08:55:39.044987-06	2	[8221] R4C1-8IC	[4] DLarrabee	[21062] a	\N	\N
e0bba9ea-f1a9-4991-8dfc-bc8881e52bf4	2018-02-28 08:55:49.018984-06	2	[1513] R1C2-32I	[4] DLarrabee	[21062] a	\N	\N
ef5a180e-03a8-466b-b907-23531f31db72	2018-02-28 08:55:59.467029-06	2	[1045] R1C1-32I	[4] DLarrabee	[21062] a	\N	\N
034bfd16-087d-4f02-9871-ad65ba8b958d	2018-02-28 09:04:04.498527-06	2	[290] LeadIn	[4] DLarrabee	[293] master	\N	\N
0f6b9785-eb5b-4cca-ab37-01b65c8405a5	2018-02-28 09:34:56.01266-06	2	[1042] Control RM MAC I/O Driver	[4] DLarrabee	[293] master	\N	\N
727cc583-9ff6-4a29-9df5-dd3897227456	2018-02-28 09:35:05.764635-06	1	[21063] New MAC Driver	[4] DLarrabee	[293] master	\N	\N
b8e56a6f-cc94-488c-9710-a5ecfc2bb0c1	2018-02-28 09:35:08.184877-06	2	[21063] New MAC Driver	[4] DLarrabee	[293] master	\N	\N
94b1292a-2520-4b7c-9b0e-f095bc4dd2e1	2018-02-28 09:35:49.02296-06	2	[21063] Control RM 8iC MAC Driver	[4] DLarrabee	[293] master	\N	\N
6b28907d-ee6b-415e-b54b-ab4893fc87d1	2018-02-28 10:09:24.609499-06	2	[1042] Control RM MAC I/O Driver	[4] DLarrabee	[21062] a	\N	\N
1529046c-54d2-4fa3-907c-494ad2c87785	2018-02-28 10:11:26.718709-06	2	[21063] Control RM 8iC MAC Driver	[4] DLarrabee	[21062] a	\N	\N
0e1bb896-21f8-4f38-b5ae-02ff282a5d84	2018-02-28 10:11:26.766713-06	2	[2940] R2C1-8IC	[4] DLarrabee	[21062] a	\N	\N
6cdca4cf-22c1-48cd-9c81-992e2d715e49	2018-02-28 10:11:26.82972-06	2	[3380] R2C2-8IC	[4] DLarrabee	[21062] a	\N	\N
9b8ca66a-e28b-41b1-843b-d6b5a4390991	2018-02-28 10:11:26.966733-06	2	[4260] R2C4-8IC	[4] DLarrabee	[21062] a	\N	\N
09b9c7e0-18d3-4ec9-a7c3-2e18af8a7af9	2018-02-28 10:11:27.044741-06	2	[4700] R2C5-8IC	[4] DLarrabee	[21062] a	\N	\N
ec9301c4-470d-44a7-b070-70ef4536c599	2018-02-28 10:11:27.117748-06	2	[5140] R2C6-8IC	[4] DLarrabee	[21062] a	\N	\N
49544cb9-ca2f-4681-ac65-37761bbdf118	2018-02-28 10:11:27.190756-06	2	[5580] R2C7-8IC	[4] DLarrabee	[21062] a	\N	\N
615ab9b9-ddbb-4dc9-91fc-31e7cc5041b2	2018-02-28 10:11:27.252762-06	2	[6020] R3C1-8IC	[4] DLarrabee	[21062] a	\N	\N
bd52cfb4-4962-4afa-ae68-fbdd03bd76d1	2018-02-28 10:11:27.312768-06	2	[6460] R3C2-8IC	[4] DLarrabee	[21062] a	\N	\N
356ef9cb-9ce0-478f-a806-aeae76a96755	2018-02-28 10:11:27.378775-06	2	[6900] R3C3-8IC	[4] DLarrabee	[21062] a	\N	\N
df907452-db09-4644-b1ff-8f268844c3ab	2018-02-28 10:11:27.439781-06	2	[7340] R3C4-8IC	[4] DLarrabee	[21062] a	\N	\N
5b5b2f1d-378b-450b-82ee-f5f88015423d	2018-02-28 10:11:27.493786-06	2	[7780] R3C5-8IC	[4] DLarrabee	[21062] a	\N	\N
c2794caf-ce2f-4c9a-938c-5c558d9d56c0	2018-02-28 10:57:14.20843-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
7aa5595c-fca5-4634-b9ba-82bdf67ddfc9	2018-02-28 10:57:23.148324-06	2	[21047] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
ae40db77-175c-4a96-ad2c-7c7c5a6128b1	2018-02-28 10:57:47.870796-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
b65240c2-076a-44dc-a92a-f64e8763fe08	2018-02-28 10:57:55.202529-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
4a353103-7395-43e2-9722-8e24a5f21b3f	2018-02-28 10:58:59.361944-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
d4e686a6-18e1-47a7-8b72-2874ada4bdad	2018-02-28 10:59:30.571065-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
cbd4e4f1-7bb5-4520-a7ec-640b45e46231	2018-02-28 10:59:50.495057-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
9ff1bf3c-7f50-41cd-a0ec-5090b3c41a39	2018-02-28 11:00:08.544862-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
229de839-1824-4fcb-a13d-1a7ed0fb7cce	2018-02-28 11:02:01.425149-06	1	[21076] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
6e7043c8-4a80-445e-871e-9432c92e1157	2018-02-28 11:02:44.803486-06	3	[21076] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
10600343-2db3-4c74-ab71-60e15cd8c95c	2018-02-28 11:03:39.672973-06	2	[290] LeadIn	[21041] OSSI-DNOVAK	[293] master	\N	\N
096a5006-ecd6-4ecd-8f8f-b31a4ea78a5e	2018-02-28 11:05:05.538558-06	1	[21076] New MAC Driver	[4] DLarrabee	[21062] a	\N	\N
ed330568-ea47-4b55-bf4c-3e4519e116cc	2018-02-28 11:05:09.504955-06	2	[21076] New MAC Driver	[4] DLarrabee	[21062] a	\N	\N
8769d99a-69e0-422e-aa79-fa66b17d0a60	2018-02-28 11:05:45.526557-06	2	[21055] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
534ecb87-5a61-4325-ab25-71e39a586328	2018-02-28 11:05:50.412045-06	2	[8220] RM 304 MAC Driver	[4] DLarrabee	[21062] a	\N	\N
98ccae8f-b221-4af7-9dc8-1eaf5ee5fb00	2018-02-28 11:07:02.450248-06	2	[21076] New MAC Driver	[4] DLarrabee	[21062] a	\N	\N
f74a3eb7-ffdc-479d-aea6-5bb345342a10	2018-02-28 11:07:02.46325-06	2	[14382] R6C1-32I	[4] DLarrabee	[21062] a	\N	\N
8669e128-d943-466b-81e1-73c55ab6802d	2018-02-28 11:07:02.477251-06	2	[14849] R6C2-32I	[4] DLarrabee	[21062] a	\N	\N
05b8d92b-9f6c-4cda-ba56-2e1c5a1125aa	2018-02-28 11:07:02.488252-06	2	[15316] R6C3-32I	[4] DLarrabee	[21062] a	\N	\N
88c5bf63-45cf-42b1-9fa6-91815aaa35ba	2018-02-28 11:07:34.808484-06	2	[21076] RM 304 32i MAC Driver	[4] DLarrabee	[21062] a	\N	\N
9ba6b39d-f1c4-481a-aabc-eb0fccbd8a71	2018-02-28 11:08:02.512254-06	1	[21077] New MAC Driver	[4] DLarrabee	[21062] a	\N	\N
6d9b4c7b-9601-41e4-82dd-39180559246e	2018-02-28 11:08:07.302733-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
eb9cbeec-1d2a-43ea-9245-f75d0d3b2a06	2018-02-28 11:09:03.393341-06	2	[21055] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
44b6247b-a14b-493a-94fe-7acc49e51f4f	2018-02-28 11:09:30.258028-06	2	[21077] RM 304 16R MAC Driver	[4] DLarrabee	[21062] a	\N	\N
79e83123-0ed8-4a60-8c55-cb6024eaf109	2018-02-28 11:09:30.288031-06	2	[15783] R7C1-16R	[4] DLarrabee	[21062] a	\N	\N
593cbc8f-75ba-47ae-8f6d-8a7c79ab0599	2018-02-28 11:09:30.299032-06	2	[16103] R7C2-16R	[4] DLarrabee	[21062] a	\N	\N
05816f15-2c5e-4036-ae6d-232da8f110ec	2018-02-28 11:09:30.310033-06	2	[16423] R7C3-16R	[4] DLarrabee	[21062] a	\N	\N
1071680e-4474-496a-aafb-47eca45847f6	2018-02-28 11:09:30.320034-06	2	[16743] R7C4-16R	[4] DLarrabee	[21062] a	\N	\N
c71f1195-60ba-41bb-9c85-170489cf8ce2	2018-02-28 11:09:30.330035-06	2	[17063] R7C5-16R	[4] DLarrabee	[21062] a	\N	\N
728ed516-ab83-442c-892e-f8db638d1cff	2018-02-28 11:09:53.575359-06	2	[21059] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
8f1e67a5-aa3e-4bfa-bd26-2a26f0f8246e	2018-02-28 11:10:14.78248-06	2	[21076] RM 304 32i MAC Driver	[4] DLarrabee	[21062] a	\N	\N
5eb7e01e-07fc-442d-87d8-82f2e3759f4b	2018-02-28 11:10:33.103312-06	2	[21056] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
61c5dac8-bd71-4452-b7d9-ae3dfbf2a328	2018-02-28 11:11:25.751576-06	2	[21057] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
1543d51b-1370-480c-96b4-e78b1ac93f8a	2018-02-28 11:12:06.885689-06	2	[21060] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
fb142e82-5081-4f20-98bd-634f6fa9be6b	2018-02-28 11:12:32.147215-06	2	[21058] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
49195c16-a45f-43cf-aca0-30d6709577f8	2018-02-28 11:13:12.231223-06	2	[8220] RM 304 8iC MAC Driver	[4] DLarrabee	[21062] a	\N	\N
3d272ca1-d1fa-45f9-a3b0-94c33aa2b358	2018-02-28 11:13:29.593959-06	2	[8220] RM 304 8iC MAC Driver	[4] DLarrabee	[21062] a	\N	\N
d5a855c3-eccf-4198-a90f-bc38d1d8ea8c	2018-02-28 11:13:32.458245-06	1	[21078] New Poly Object	[21041] OSSI-DNOVAK	[293] master	\N	\N
975cda62-b2ac-4ece-a206-563ebb9b4f0d	2018-02-28 11:13:57.498749-06	1	[21079] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
8fb0a461-dc08-4378-8219-953f0961d90a	2018-02-28 11:14:30.504049-06	2	[21079] Lebel	[21041] OSSI-DNOVAK	[293] master	\N	\N
6125db87-f442-4865-978d-fd816d0f32ec	2018-02-28 11:14:58.135812-06	2	[21079] Lebel	[21041] OSSI-DNOVAK	[293] master	\N	\N
5a327e4b-5b66-4678-a734-8ea5d81f21c3	2018-02-28 11:15:32.635262-06	1	[21080] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
a87666fb-6b9b-4199-aab2-84ed0daaa0cd	2018-02-28 11:15:40.640062-06	1	[21081] New (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
ff7816cd-cd81-4b47-88fa-ee5ae0629b8a	2018-02-28 11:16:13.485346-06	2	[21081] B	[21041] OSSI-DNOVAK	[293] master	\N	\N
a1461e43-f9dd-45d4-a4eb-377529baf241	2018-02-28 11:16:31.296127-06	2	[21079] Lebel	[21041] OSSI-DNOVAK	[293] master	\N	\N
22604823-7da1-46e1-8981-ff35c9c42dd1	2018-02-28 11:16:50.445042-06	2	[21079] Lebel	[21041] OSSI-DNOVAK	[293] master	\N	\N
7591cecb-b4c9-4129-af48-486979454ae6	2018-02-28 11:17:06.477645-06	2	[21079] Lebel	[21041] OSSI-DNOVAK	[293] master	\N	\N
0641709e-1a5f-45ec-a1a5-23cbd49e2c0b	2018-02-28 11:17:25.218519-06	2	[21079] Lebel	[21041] OSSI-DNOVAK	[293] master	\N	\N
e09ddb11-2277-47dc-80bd-9e4555f411b3	2018-02-28 11:17:33.411338-06	3	[21079] Lebel	[21041] OSSI-DNOVAK	[293] master	\N	\N
546fb05d-57c9-4966-b3ca-1901e453add1	2018-02-28 11:17:50.33603-06	2	[21081] B	[21041] OSSI-DNOVAK	[293] master	\N	\N
61bc6749-dfbe-4a0a-a72c-477572ac3832	2018-02-28 11:18:05.777574-06	2	[21081] B	[21041] OSSI-DNOVAK	[293] master	\N	\N
9252157d-f96c-4253-8a60-1c2c8b8d8123	2018-02-28 11:18:09.195916-06	2	[14414] Not used NPUT 31 Call Button	[4] DLarrabee	[21062] a	\N	\N
77443ed8-bd4e-4392-804b-d5835a37081c	2018-02-28 11:18:09.199917-06	2	[14481] Not used NPUT 31 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
cca04f7f-0a23-4d87-9978-806baaaa2f20	2018-02-28 11:18:35.659562-06	2	[14414] Not used NPUT 31	[4] DLarrabee	[21062] a	\N	\N
cbe00e63-ae9c-4494-83d3-59fe3e0b8416	2018-02-28 11:18:35.675564-06	2	[14481] Not used NPUT 31 Supervision	[4] DLarrabee	[21062] a	\N	\N
0408b24e-d2ed-4235-87cf-759f1398f767	2018-02-28 11:18:40.253022-06	3	[21080] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
9f6e1b18-9af7-4ad7-8511-6c267e80f41a	2018-02-28 11:18:40.477044-06	2	[21081] B	[21041] OSSI-DNOVAK	[293] master	\N	\N
a3311863-78e9-436c-8f1e-5402f0a6dafd	2018-02-28 11:18:53.101306-06	1	[21079] B	[21041] OSSI-DNOVAK	[293] master	\N	\N
ce820d42-937f-4f60-ada5-5eaacb1d795b	2018-02-28 11:19:08.386835-06	2	[21079] B	[21041] OSSI-DNOVAK	[293] master	\N	\N
c68e0945-704b-4606-81c6-e3667be709c3	2018-02-28 11:19:43.561352-06	2	[21079] B	[21041] OSSI-DNOVAK	[293] master	\N	\N
2fea5dba-2052-4cd9-b531-f485c7152afb	2018-02-28 11:19:57.44374-06	2	[21079] B	[21041] OSSI-DNOVAK	[293] master	\N	\N
71808227-3795-4f6b-90ac-c0cf75c87fce	2018-02-28 11:20:06.636659-06	2	[21079] B	[21041] OSSI-DNOVAK	[293] master	\N	\N
74680e98-394e-4d52-9f9a-b2ec444bb3df	2018-02-28 11:20:32.208216-06	2	[21079] A	[21041] OSSI-DNOVAK	[293] master	\N	\N
2108fcca-f941-41df-88ce-e897f8bac462	2018-02-28 11:20:57.921787-06	2	[21079] A	[21041] OSSI-DNOVAK	[293] master	\N	\N
2284fcfc-5896-4dbb-8e9d-425442637e7e	2018-02-28 11:21:18.206815-06	2	[21079] A	[21041] OSSI-DNOVAK	[293] master	\N	\N
079c6d62-c491-4130-9b76-a74def9ef779	2018-02-28 11:21:39.85898-06	2	[21079] c	[21041] OSSI-DNOVAK	[293] master	\N	\N
501c3c89-7856-4b68-8b30-ddf22fad84ee	2018-02-28 11:21:59.492944-06	1	[21080] c Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
ee4b5d13-804c-4ea0-a112-7b6ba40593d7	2018-02-28 11:22:17.219716-06	2	[21080] D	[21041] OSSI-DNOVAK	[293] master	\N	\N
debd088e-1676-4a5b-bfbc-1ef3e50cb287	2018-02-28 11:22:21.940188-06	1	[21082] D Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
ee376b41-58f5-4968-8a43-40f9484664ed	2018-02-28 11:22:37.987793-06	2	[21082] E	[21041] OSSI-DNOVAK	[293] master	\N	\N
9600f519-e330-4e1e-a4f0-22952a3b4563	2018-02-28 11:22:57.244718-06	1	[21083] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
9e776524-1f3e-41e9-b3f0-c8498074a39c	2018-02-28 11:23:26.86168-06	2	[21083] A	[21041] OSSI-DNOVAK	[293] master	\N	\N
814a2a46-2221-4a2c-9455-429c9fa95d30	2018-02-28 11:23:38.749868-06	2	[21083] A	[21041] OSSI-DNOVAK	[293] master	\N	\N
fea402d3-d269-4845-869f-c9cda692e76d	2018-02-28 11:25:12.423235-06	2	[14384] DPIS-103	[4] DLarrabee	[21062] a	\N	\N
bf007bff-8db1-483c-8fec-d8ab0586b4fc	2018-02-28 11:25:12.459238-06	2	[14385] DPIS-104	[4] DLarrabee	[21062] a	\N	\N
c3689cb2-483d-40e8-aa00-ce2e04df6997	2018-02-28 11:25:12.465239-06	2	[14451] DPIS-103 Supervision	[4] DLarrabee	[21062] a	\N	\N
15d92fc1-2afd-4c99-ae29-b75483105004	2018-02-28 11:25:12.468239-06	2	[14452] DPIS-104 Supervision	[4] DLarrabee	[21062] a	\N	\N
fd2ba568-fcd5-42a8-a755-c75aaddacc8d	2018-02-28 11:26:21.58615-06	1	[21084] Demo	[4] DLarrabee	[21062] a	\N	\N
bbb44c9d-ea44-4c37-b187-da625f9a7bd3	2018-02-28 11:26:23.715363-06	2	[21084] Demo	[4] DLarrabee	[21062] a	\N	\N
4f5ef5b6-ea9f-40c5-bf58-cfb4ed47617c	2018-02-28 11:29:11.832173-06	1	[21085] Detention Hall.jpg	[4] DLarrabee	[21062] a	\N	\N
669c5903-eda8-4165-be78-d6329a27982e	2018-02-28 11:29:15.080498-06	2	[21085] Detention Hall.jpg	[4] DLarrabee	[21062] a	\N	\N
d06f6846-0cc0-4749-8ab4-384ea018e271	2018-02-28 11:30:16.50464-06	2	[21046] Tool 240x320.png	[4] DLarrabee	[21062] a	\N	\N
98974cff-3ab6-44f3-9fa5-587c59a8e659	2018-02-28 11:30:29.337923-06	1	[21086] Detention Hall.jpg	[4] DLarrabee	[21062] a	\N	\N
d7558972-d6a6-4265-93a5-ad3a905e12b4	2018-02-28 11:35:25.507537-06	1	[21087] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
a958cd53-46a4-4079-95d6-77612d638855	2018-02-28 11:35:50.869073-06	2	[21087] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
ec7a8ece-6b6b-4b0c-8818-5cd5da6c19f7	2018-02-28 11:36:14.286414-06	2	[14386] DPIS-105	[4] DLarrabee	[21062] a	\N	\N
56fc89d6-cc7c-4a0f-b14e-a8c5e3893e49	2018-02-28 11:36:14.324418-06	2	[14387] DPIS-107	[4] DLarrabee	[21062] a	\N	\N
3de44133-1a4f-46cb-8891-fa03137f347a	2018-02-28 11:36:14.33742-06	2	[14388] DPIS-108	[4] DLarrabee	[21062] a	\N	\N
c8dc26d3-588c-4c0c-aa88-5edb4b392f0b	2018-02-28 11:36:14.353421-06	2	[14389] DPIS-109	[4] DLarrabee	[21062] a	\N	\N
8b4401f0-9057-48ee-8117-c539b83703ff	2018-02-28 11:36:14.369423-06	2	[14390] DPIS-112	[4] DLarrabee	[21062] a	\N	\N
36ba9e8c-72c6-4d81-a6dc-32eb4920cd57	2018-02-28 11:36:14.384424-06	2	[14391] DPIS-113	[4] DLarrabee	[21062] a	\N	\N
2a0d9019-b93c-4ed2-9faa-39e0cc33752b	2018-02-28 11:36:14.402426-06	2	[14392] DPIS-114A	[4] DLarrabee	[21062] a	\N	\N
4a3914dc-de37-48a2-91b1-8263da79d039	2018-02-28 11:36:14.419428-06	2	[14393] DPIS-114B	[4] DLarrabee	[21062] a	\N	\N
ab1f8474-06b2-4731-85e8-fffbf2d6e0ac	2018-02-28 11:36:14.431429-06	2	[14394] DPIS-115	[4] DLarrabee	[21062] a	\N	\N
10a9b5aa-2b97-4cdf-a4d4-a956aaccb88d	2018-02-28 11:36:14.450431-06	2	[14395] DPIS-116	[4] DLarrabee	[21062] a	\N	\N
a373d895-b2e2-4321-9d44-93a9ef9ef998	2018-02-28 11:36:14.463432-06	2	[14396] DPIS-117	[4] DLarrabee	[21062] a	\N	\N
1fbe8ba9-52b2-45fb-962b-cdb823abd105	2018-02-28 11:36:14.477434-06	2	[14397] DPIS-119	[4] DLarrabee	[21062] a	\N	\N
fee2c816-90ca-4a70-983d-2e164e88922f	2018-02-28 11:36:14.489435-06	2	[14398] DPIS-121	[4] DLarrabee	[21062] a	\N	\N
3ca07747-a660-4473-a4a8-d336a8e3d37e	2018-02-28 11:36:14.500436-06	2	[14399] DPIS-122	[4] DLarrabee	[21062] a	\N	\N
329ee94f-f11f-4b16-92ba-ccde409a3d62	2018-02-28 11:36:14.512437-06	2	[14400] DPIS-123	[4] DLarrabee	[21062] a	\N	\N
0de1811d-5fc2-4f8d-9431-bd32c4622c46	2018-02-28 11:36:14.529439-06	2	[14401] DPIS-124	[4] DLarrabee	[21062] a	\N	\N
1f02d490-9171-4db4-b026-d4159904216c	2018-02-28 11:36:14.54244-06	2	[14402] DPIS-125	[4] DLarrabee	[21062] a	\N	\N
281696c0-7800-4434-9807-3013f652e772	2018-02-28 11:36:14.557442-06	2	[14403] DPIS-126	[4] DLarrabee	[21062] a	\N	\N
3f422d9a-74c0-4f89-a6d9-d156d2f5c2ee	2018-02-28 11:36:14.571443-06	2	[14404] DPIS-128	[4] DLarrabee	[21062] a	\N	\N
48e2745f-099f-4531-95e9-5170c47f2a98	2018-02-28 11:36:14.591445-06	2	[14405] DPIS-129	[4] DLarrabee	[21062] a	\N	\N
e66a141c-5ee6-4eaa-84a6-3db0aa5048a8	2018-02-28 11:36:14.611447-06	2	[14406] DPIS-131	[4] DLarrabee	[21062] a	\N	\N
7cd59b44-714f-4c0d-8e7c-21a693f445f8	2018-02-28 11:36:14.626448-06	2	[14407] DPIS-132	[4] DLarrabee	[21062] a	\N	\N
4c5b4399-3411-4cb2-9d34-a4a5781936a4	2018-02-28 11:36:14.64245-06	2	[14408] DPIS-133	[4] DLarrabee	[21062] a	\N	\N
d0d22bc9-cbb7-41fb-897a-5a32ff428b7a	2018-02-28 11:36:14.654451-06	2	[14409] DPIS-134A	[4] DLarrabee	[21062] a	\N	\N
b7981093-edfa-4785-ae4b-ecd8e12cb080	2018-02-28 11:36:14.667453-06	2	[14410] DPIS-134B	[4] DLarrabee	[21062] a	\N	\N
bc5b627d-90e5-4b94-bb32-505fec5ad916	2018-02-28 11:36:14.679454-06	2	[14411] DPIS-136	[4] DLarrabee	[21062] a	\N	\N
15d4f08c-2cbf-4ec6-bae1-d4d6a4bb087e	2018-02-28 11:36:14.697456-06	2	[14412] DPIS-137	[4] DLarrabee	[21062] a	\N	\N
e3c39715-ece0-4016-aa7e-707198a6890f	2018-02-28 11:36:14.711457-06	2	[14413] DPIS-138	[4] DLarrabee	[21062] a	\N	\N
b9717b28-d08c-4cde-8c95-27167be13ddd	2018-02-28 11:36:14.724458-06	2	[14415] DPIS-141	[4] DLarrabee	[21062] a	\N	\N
64b560b6-8d61-4cd2-b2ee-5c0cfdcb1a3a	2018-02-28 11:36:14.727459-06	2	[14453] DPIS-105 Supervision	[4] DLarrabee	[21062] a	\N	\N
3b25f03c-e0a3-4c91-b015-9dc30e3cf60d	2018-02-28 11:36:14.730459-06	2	[14454] DPIS-107 Supervision	[4] DLarrabee	[21062] a	\N	\N
9587bdde-e8a7-47fe-b36d-f4d83ed03fdb	2018-02-28 11:36:14.732459-06	2	[14455] DPIS-108 Supervision	[4] DLarrabee	[21062] a	\N	\N
f0e65cdb-c2f5-4fb8-9641-6b59929e604a	2018-02-28 11:36:14.736459-06	2	[14456] DPIS-109 Supervision	[4] DLarrabee	[21062] a	\N	\N
952e53f1-17b4-4ff4-a198-45b418a7f0fc	2018-02-28 11:36:14.73946-06	2	[14457] DPIS-112 Supervision	[4] DLarrabee	[21062] a	\N	\N
7cac6684-e8bc-41c2-8957-e2ce4f6ba032	2018-02-28 11:36:14.74246-06	2	[14458] DPIS-113 Supervision	[4] DLarrabee	[21062] a	\N	\N
f8bd805f-a46a-47cc-ab44-905144c828f3	2018-02-28 11:36:14.74546-06	2	[14459] DPIS-114A Supervision	[4] DLarrabee	[21062] a	\N	\N
1919cbbd-b637-4f8a-92af-d68d01587122	2018-02-28 11:36:14.749461-06	2	[14460] DPIS-114B Supervision	[4] DLarrabee	[21062] a	\N	\N
9f1da015-d2cf-4b46-b6f7-6494c7c4ee54	2018-02-28 11:36:14.751461-06	2	[14461] DPIS-115 Supervision	[4] DLarrabee	[21062] a	\N	\N
dc940099-f409-45e2-bea1-c3cba9607f3a	2018-02-28 11:36:14.754461-06	2	[14462] DPIS-116 Supervision	[4] DLarrabee	[21062] a	\N	\N
54046282-3efe-4897-b0ed-fe888bddf65b	2018-02-28 11:36:14.757462-06	2	[14463] DPIS-117 Supervision	[4] DLarrabee	[21062] a	\N	\N
00c04dac-c6e9-4c78-acf7-8c2ebc371944	2018-02-28 11:36:14.761462-06	2	[14464] DPIS-119 Supervision	[4] DLarrabee	[21062] a	\N	\N
dd9ddcd9-d12a-4bce-ad8a-dddd3a5ac285	2018-02-28 11:36:14.766462-06	2	[14465] DPIS-121 Supervision	[4] DLarrabee	[21062] a	\N	\N
5b0be395-3133-4836-af25-d4959ac3eb10	2018-02-28 11:36:14.769463-06	2	[14466] DPIS-122 Supervision	[4] DLarrabee	[21062] a	\N	\N
3cecc3f5-ab20-45fe-94a3-b58fd0c5b134	2018-02-28 11:36:14.773463-06	2	[14467] DPIS-123 Supervision	[4] DLarrabee	[21062] a	\N	\N
553e3375-7e1a-436a-a151-f07c2745b357	2018-02-28 11:36:14.777464-06	2	[14468] DPIS-124 Supervision	[4] DLarrabee	[21062] a	\N	\N
7b6c3f1c-1f50-4042-9ee2-70f1cb0bbd19	2018-02-28 11:36:14.781464-06	2	[14469] DPIS-125 Supervision	[4] DLarrabee	[21062] a	\N	\N
566a708c-270c-4ee2-aad7-ade6a9418387	2018-02-28 11:36:14.784464-06	2	[14470] DPIS-126 Supervision	[4] DLarrabee	[21062] a	\N	\N
35937e26-8cde-4bb4-89f9-a15e0148078d	2018-02-28 11:36:14.787465-06	2	[14471] DPIS-128 Supervision	[4] DLarrabee	[21062] a	\N	\N
702f9a38-806f-4f05-8ed7-12679396bcfa	2018-02-28 11:36:14.789465-06	2	[14472] DPIS-129 Supervision	[4] DLarrabee	[21062] a	\N	\N
e26b057b-288c-4c31-9c30-14d798b52fcc	2018-02-28 11:36:14.792465-06	2	[14473] DPIS-131 Supervision	[4] DLarrabee	[21062] a	\N	\N
47f0b6df-17fa-4484-b018-5b856b194264	2018-02-28 11:36:14.795465-06	2	[14474] DPIS-132 Supervision	[4] DLarrabee	[21062] a	\N	\N
3d4d921a-942d-4e42-bc4e-9daeb767b29e	2018-02-28 11:36:14.798466-06	2	[14475] DPIS-133 Supervision	[4] DLarrabee	[21062] a	\N	\N
9a85bf32-d169-4d53-b580-7bdd42c8e37c	2018-02-28 11:36:14.801466-06	2	[14476] DPIS-134A Supervision	[4] DLarrabee	[21062] a	\N	\N
eb5032a1-2064-4c79-ac4a-ffc443b8c490	2018-02-28 11:36:14.804466-06	2	[14477] DPIS-134B Supervision	[4] DLarrabee	[21062] a	\N	\N
e2f4577e-8b46-4bde-b488-d2f800540ca0	2018-02-28 11:36:14.808467-06	2	[14478] DPIS-136 Supervision	[4] DLarrabee	[21062] a	\N	\N
d4601887-e8ec-4c32-a92b-b69c3e59686d	2018-02-28 11:36:14.811467-06	2	[14479] DPIS-137 Supervision	[4] DLarrabee	[21062] a	\N	\N
8f32c562-050f-402f-b4df-d947591bc906	2018-02-28 11:36:14.814467-06	2	[14480] DPIS-138 Supervision	[4] DLarrabee	[21062] a	\N	\N
e996bab6-334a-45bb-9a86-a739f5987b2b	2018-02-28 11:36:14.818468-06	2	[14482] DPIS-141 Supervision	[4] DLarrabee	[21062] a	\N	\N
6c79deb2-cb6a-4b25-82a7-b0ded3e27e22	2018-02-28 11:36:18.806866-06	2	[21087] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
d27b1179-288d-4d97-814f-5215c494d715	2018-02-28 11:37:13.395325-06	2	[21087] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
0263ad74-9300-4c21-ab7a-53dd90a6bb83	2018-02-28 11:37:54.923477-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
0b21fd61-d141-4977-9c6e-a2b51b756bc8	2018-02-28 11:38:27.602745-06	2	[21087] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
13dc45cc-74f3-4aa3-9fd8-b8bb9cb88794	2018-02-28 11:38:42.55424-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
dc88b33d-c10f-4c1a-a576-23077c8c38ae	2018-02-28 11:39:48.097793-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
37012ab6-efec-434c-abda-bbe12c872075	2018-02-28 11:40:20.424026-06	2	[21087] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
2d5f0bc1-6dc5-4699-beea-c8fc7ba9a075	2018-02-28 11:40:32.084192-06	2	[14851] DPIS-142	[4] DLarrabee	[21062] a	\N	\N
6b38a1e0-4768-47f1-a43f-1d437ae6075d	2018-02-28 11:40:32.097193-06	2	[14852] DPIS-145	[4] DLarrabee	[21062] a	\N	\N
ce543672-6ef2-4640-9d96-8b662ce36cc6	2018-02-28 11:40:32.109194-06	2	[14853] DPIS-146	[4] DLarrabee	[21062] a	\N	\N
aad2cfb1-0a24-4136-9ada-f8087155fe5d	2018-02-28 11:40:32.121195-06	2	[14854] DPIS-201	[4] DLarrabee	[21062] a	\N	\N
67f3f16a-0ea1-4963-9a6c-809d16545867	2018-02-28 11:40:32.146198-06	2	[14855] DPIS-202	[4] DLarrabee	[21062] a	\N	\N
e734b979-1a79-47d7-8587-ff58b80bfe67	2018-02-28 11:40:32.162199-06	2	[14856] DPIS-203	[4] DLarrabee	[21062] a	\N	\N
60f00b5f-dd69-45d3-8de2-7a4f8b149cce	2018-02-28 11:40:32.180201-06	2	[14857] DPIS-205	[4] DLarrabee	[21062] a	\N	\N
384235a9-5454-4e19-b70b-9fd959597644	2018-02-28 11:40:32.196203-06	2	[14858] DPIS-206	[4] DLarrabee	[21062] a	\N	\N
f555a6ae-b2e6-46b1-9db2-506b1a3551c0	2018-02-28 11:40:32.215205-06	2	[14859] DPIS-207	[4] DLarrabee	[21062] a	\N	\N
e2f67afd-53e8-4cc4-adbf-c02a756f1f95	2018-02-28 11:40:32.235207-06	2	[14860] DPIS-209A	[4] DLarrabee	[21062] a	\N	\N
02db200c-c33b-41c4-aa83-adaa186fab73	2018-02-28 11:40:32.250208-06	2	[14861] DPIS-209B	[4] DLarrabee	[21062] a	\N	\N
da9b864b-fe81-463a-8170-9cf749864bbf	2018-02-28 11:40:32.26321-06	2	[14862] DPIS-211	[4] DLarrabee	[21062] a	\N	\N
9d55e1fb-e1fe-4bce-82f4-6b6a82816a5a	2018-02-28 11:40:32.278211-06	2	[14863] DPIS-213	[4] DLarrabee	[21062] a	\N	\N
40f180ef-e542-40a3-bdd8-e34faa1b8903	2018-02-28 11:40:32.296213-06	2	[14864] DPIS-214	[4] DLarrabee	[21062] a	\N	\N
8da233af-471a-4357-a86a-f8ad7e31c883	2018-02-28 11:40:32.309214-06	2	[14865] DPIS-215	[4] DLarrabee	[21062] a	\N	\N
f07beaeb-065d-4f0e-805d-9f0cb54da11d	2018-02-28 11:40:32.330216-06	2	[14866] DPIS-216	[4] DLarrabee	[21062] a	\N	\N
e6fba4f8-17d9-4590-a7bc-9645213cc092	2018-02-28 11:40:32.344218-06	2	[14867] DPIS-218	[4] DLarrabee	[21062] a	\N	\N
4446630a-df2f-4568-8512-96712faa2c6a	2018-02-28 11:40:32.357219-06	2	[14868] DPIS-219	[4] DLarrabee	[21062] a	\N	\N
cdc21186-37e3-442a-a3ce-42230b7a40d6	2018-02-28 11:40:32.37122-06	2	[14869] DPIS-221	[4] DLarrabee	[21062] a	\N	\N
03050ac2-a449-42a3-80c4-d468a55eed6f	2018-02-28 11:40:32.390222-06	2	[14870] DPIS-222	[4] DLarrabee	[21062] a	\N	\N
22bc0380-9df0-4290-8fd9-883d8ce0e832	2018-02-28 11:40:32.403224-06	2	[14871] DPIS-223	[4] DLarrabee	[21062] a	\N	\N
97b58e9f-4b9d-46dc-aa2e-7b27c6807a97	2018-02-28 11:40:32.417225-06	2	[14872] DPIS-224	[4] DLarrabee	[21062] a	\N	\N
1858bde9-c63d-4501-9847-8b8f3fad1559	2018-02-28 11:40:32.432226-06	2	[14873] DPIS-225	[4] DLarrabee	[21062] a	\N	\N
3ddd431f-412a-46cb-b617-69f67b315685	2018-02-28 11:40:32.447228-06	2	[14874] DPIS-226	[4] DLarrabee	[21062] a	\N	\N
7687630a-8273-4321-a49b-5b8454e3fd54	2018-02-28 11:40:32.462229-06	2	[14875] DPIS-227	[4] DLarrabee	[21062] a	\N	\N
c16a51fd-e5eb-47d1-8973-f193dec42428	2018-02-28 11:40:32.476231-06	2	[14876] DPIS-228	[4] DLarrabee	[21062] a	\N	\N
46aad979-35da-427f-9b1d-a85488c15dbd	2018-02-28 11:40:32.491232-06	2	[14877] DPIS-231	[4] DLarrabee	[21062] a	\N	\N
bbe52ef3-e571-4482-aead-fcf7c6d57311	2018-02-28 11:40:32.511234-06	2	[14878] DPIS-232	[4] DLarrabee	[21062] a	\N	\N
985cc4ab-4b3a-4398-a83f-c1f7ac677733	2018-02-28 11:40:32.524236-06	2	[14879] DPIS-233	[4] DLarrabee	[21062] a	\N	\N
7b2e9030-51ed-4409-b238-50ef0e5c8ff9	2018-02-28 11:40:32.544238-06	2	[14880] DPIS-235	[4] DLarrabee	[21062] a	\N	\N
78704c21-3bae-46a3-a222-bf7e5c143ef3	2018-02-28 11:40:32.556239-06	2	[14881] DPIS-236	[4] DLarrabee	[21062] a	\N	\N
7cd5a558-d10b-4255-b00f-7d225ba25b5d	2018-02-28 11:40:32.574241-06	2	[14882] DPIS-237A	[4] DLarrabee	[21062] a	\N	\N
96eb11aa-05be-4ad5-baee-ec4b10974c1f	2018-02-28 11:40:32.577241-06	2	[14918] DPIS-142 Supervision	[4] DLarrabee	[21062] a	\N	\N
eb822ade-e106-4717-bf1f-5561cca3bfd0	2018-02-28 11:40:32.582241-06	2	[14919] DPIS-145 Supervision	[4] DLarrabee	[21062] a	\N	\N
5abc8b4b-0675-4838-8523-55490bd83bec	2018-02-28 11:40:32.585242-06	2	[14920] DPIS-146 Supervision	[4] DLarrabee	[21062] a	\N	\N
882d9d00-e307-4e37-bc72-da57edfe8571	2018-02-28 11:40:32.588242-06	2	[14921] DPIS-201 Supervision	[4] DLarrabee	[21062] a	\N	\N
26cc22c3-91aa-449f-ab2a-f8c8b4b8d725	2018-02-28 11:40:32.592242-06	2	[14922] DPIS-202 Supervision	[4] DLarrabee	[21062] a	\N	\N
e0e27e4e-67be-4134-a374-315ad70dbfff	2018-02-28 11:40:32.596243-06	2	[14923] DPIS-203 Supervision	[4] DLarrabee	[21062] a	\N	\N
9e438c01-165c-4bda-8268-2e3f30a8c996	2018-02-28 11:40:32.599243-06	2	[14924] DPIS-205 Supervision	[4] DLarrabee	[21062] a	\N	\N
275d49b2-42da-49f9-b0b5-c329abfb7a0d	2018-02-28 11:40:32.603244-06	2	[14925] DPIS-206 Supervision	[4] DLarrabee	[21062] a	\N	\N
04377997-4cc4-41bc-8586-6a7ce654de56	2018-02-28 11:40:32.607244-06	2	[14926] DPIS-207 Supervision	[4] DLarrabee	[21062] a	\N	\N
acee5cd5-d77d-459d-828d-cb26b0978c19	2018-02-28 11:40:32.611244-06	2	[14927] DPIS-209A Supervision	[4] DLarrabee	[21062] a	\N	\N
082f99d4-ec97-4eb4-9fba-2472a22bec00	2018-02-28 11:40:32.614245-06	2	[14928] DPIS-209B Supervision	[4] DLarrabee	[21062] a	\N	\N
318de76a-3d77-47ee-96eb-c3108b521a9d	2018-02-28 11:40:32.618245-06	2	[14929] DPIS-211 Supervision	[4] DLarrabee	[21062] a	\N	\N
fc054089-01e2-4376-9701-0ee3eeb6a4cb	2018-02-28 11:40:32.621245-06	2	[14930] DPIS-213 Supervision	[4] DLarrabee	[21062] a	\N	\N
ea153f04-14c7-4e6b-8b8b-97f3cee05acf	2018-02-28 11:40:32.623246-06	2	[14931] DPIS-214 Supervision	[4] DLarrabee	[21062] a	\N	\N
e1780fac-ecf3-4a75-bfb1-4aac9901e9cd	2018-02-28 11:40:32.626246-06	2	[14932] DPIS-215 Supervision	[4] DLarrabee	[21062] a	\N	\N
d42edaa6-33eb-4b30-b5d5-ca5625b915c0	2018-02-28 11:40:32.629246-06	2	[14933] DPIS-216 Supervision	[4] DLarrabee	[21062] a	\N	\N
e873da56-a72c-4b18-bff3-5b463e5082fa	2018-02-28 11:40:32.631246-06	2	[14934] DPIS-218 Supervision	[4] DLarrabee	[21062] a	\N	\N
1002dc60-bfa7-40bd-be01-ad93da25cdc5	2018-02-28 11:40:32.635247-06	2	[14935] DPIS-219 Supervision	[4] DLarrabee	[21062] a	\N	\N
8e91b951-2895-47b2-9cde-9ad527a03a0a	2018-02-28 11:40:32.638247-06	2	[14936] DPIS-221 Supervision	[4] DLarrabee	[21062] a	\N	\N
b41fb8f2-0305-4eca-8057-a38a393d0971	2018-02-28 11:40:32.641247-06	2	[14937] DPIS-222 Supervision	[4] DLarrabee	[21062] a	\N	\N
2869c8e6-251f-4a8e-9e80-558992cb5c35	2018-02-28 11:40:32.643248-06	2	[14938] DPIS-223 Supervision	[4] DLarrabee	[21062] a	\N	\N
e8a77b8f-1636-4d59-a2f0-fa042f0a15d9	2018-02-28 11:40:32.648248-06	2	[14939] DPIS-224 Supervision	[4] DLarrabee	[21062] a	\N	\N
a0f13666-fe0b-4390-942a-45f22ffa65e6	2018-02-28 11:40:32.652248-06	2	[14940] DPIS-225 Supervision	[4] DLarrabee	[21062] a	\N	\N
f5916b7d-6e87-4224-b71f-e1ff5d86ce76	2018-02-28 11:40:32.656249-06	2	[14941] DPIS-226 Supervision	[4] DLarrabee	[21062] a	\N	\N
667fda6b-afc3-4e22-b766-5d078d6a03b5	2018-02-28 11:40:32.660249-06	2	[14942] DPIS-227 Supervision	[4] DLarrabee	[21062] a	\N	\N
07253c35-ae68-432b-b550-c9e539a44a89	2018-02-28 11:40:32.66425-06	2	[14943] DPIS-228 Supervision	[4] DLarrabee	[21062] a	\N	\N
3da61d08-aa64-4011-ab9f-b277b60dfcb9	2018-02-28 11:40:32.66725-06	2	[14944] DPIS-231 Supervision	[4] DLarrabee	[21062] a	\N	\N
7d9b7b7d-0517-43fa-a09c-2de75e15532f	2018-02-28 11:40:32.67125-06	2	[14945] DPIS-232 Supervision	[4] DLarrabee	[21062] a	\N	\N
c62fb8a4-461f-4cbf-ac05-941ca9ccf0bd	2018-02-28 11:40:32.675251-06	2	[14946] DPIS-233 Supervision	[4] DLarrabee	[21062] a	\N	\N
2a53a66a-8089-4150-bb43-e7d8596c880f	2018-02-28 11:40:32.679251-06	2	[14947] DPIS-235 Supervision	[4] DLarrabee	[21062] a	\N	\N
a2b599b0-a45d-4161-a6e6-c7afd3a9dd10	2018-02-28 11:40:32.683252-06	2	[14948] DPIS-236 Supervision	[4] DLarrabee	[21062] a	\N	\N
4f0ef647-edcd-4ff7-aacc-da81dd337188	2018-02-28 11:40:32.687252-06	2	[14949] DPIS-237A Supervision	[4] DLarrabee	[21062] a	\N	\N
11bec57e-2907-4176-962b-7449bdfb0727	2018-02-28 11:40:54.232406-06	2	[21087] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
8e7b19cc-9c6f-4802-a722-9fb2ebcb96a3	2018-02-28 11:41:25.325515-06	2	[21087] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
98ffd08a-abbb-4028-abf5-47c016bf6da7	2018-02-28 11:41:51.693152-06	2	[21087] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
5874e492-322e-4967-a58d-c5598ca7819e	2018-02-28 11:42:13.162298-06	2	[21087] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
e802b690-5073-41da-bf36-de0e20f8483f	2018-02-28 11:42:56.162598-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
d78c5284-c780-4ee8-9771-71ee5505b383	2018-02-28 11:43:54.169398-06	1	[21088] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
f257fc9f-9830-4089-8ba8-c6e940fd49c1	2018-02-28 11:44:26.321613-06	2	[15318] DPIS-237B	[4] DLarrabee	[21062] a	\N	\N
0e1e3b70-b6be-4d94-8338-e145025ef528	2018-02-28 11:44:26.336615-06	2	[15319] DPIS-239	[4] DLarrabee	[21062] a	\N	\N
a0b5ef4e-9083-45d5-a43e-f7c6bcad936c	2018-02-28 11:44:26.351616-06	2	[15320] DPIS-241	[4] DLarrabee	[21062] a	\N	\N
6ce093aa-8c24-4264-a6b5-3cebdf9c1f4b	2018-02-28 11:44:26.366618-06	2	[15321] DPIS-242	[4] DLarrabee	[21062] a	\N	\N
0f8c4362-4e18-40df-ab9a-3d40ca2602d1	2018-02-28 11:44:26.382619-06	2	[15322] DPIS-243	[4] DLarrabee	[21062] a	\N	\N
c6460ee1-e853-4113-9e3e-fed02633e021	2018-02-28 11:44:26.39562-06	2	[15323] DPIS-245	[4] DLarrabee	[21062] a	\N	\N
3628ab17-4057-4448-9aea-2d9b3d365f24	2018-02-28 11:44:26.408622-06	2	[15324] DPIS-246	[4] DLarrabee	[21062] a	\N	\N
033a6b85-1898-468f-a5ed-123850a5ee24	2018-02-28 11:44:26.420623-06	2	[15325] DPIS-247	[4] DLarrabee	[21062] a	\N	\N
2057f657-7803-437e-bddf-f1b0fe9487d6	2018-02-28 11:44:26.434624-06	2	[15326] DPIS-248	[4] DLarrabee	[21062] a	\N	\N
1846a220-5982-4f51-924a-21b886367a52	2018-02-28 11:44:26.446626-06	2	[15327] DPIS-252	[4] DLarrabee	[21062] a	\N	\N
6677a916-39f1-43e6-a76b-90f2d6e50297	2018-02-28 11:44:26.461627-06	2	[15328] DPIS-253	[4] DLarrabee	[21062] a	\N	\N
6c58f626-d5b0-4a6a-af1e-dbbd209d387b	2018-02-28 11:44:26.473628-06	2	[15329] DPIS-259	[4] DLarrabee	[21062] a	\N	\N
c1ac4e02-a20f-45b3-b1ae-15a113b4e383	2018-02-28 11:44:26.485629-06	2	[15330] DPIS-261	[4] DLarrabee	[21062] a	\N	\N
9d49f22b-025f-4578-8e17-d98f63814caa	2018-02-28 11:44:26.499631-06	2	[15331] DPIS-301A	[4] DLarrabee	[21062] a	\N	\N
e9c91f1b-cc0f-451b-babe-fa4c729581a6	2018-02-28 11:44:26.514632-06	2	[15332] DPIS-301B	[4] DLarrabee	[21062] a	\N	\N
02dcff23-a021-4d60-8708-f16e1104920f	2018-02-28 11:44:26.529634-06	2	[15333] DPIS-306	[4] DLarrabee	[21062] a	\N	\N
7d72eb64-4b3e-48ff-a691-a6c9673a963f	2018-02-28 11:44:26.545635-06	2	[15334] DPIS-102	[4] DLarrabee	[21062] a	\N	\N
96c18a50-7e57-426d-98b2-269519fe8253	2018-02-28 11:44:26.559637-06	2	[15335] DPIS-111	[4] DLarrabee	[21062] a	\N	\N
a9185e56-326d-4a2c-b33c-a1d5d4296e28	2018-02-28 11:44:26.580639-06	2	[15336] DPIS-135	[4] DLarrabee	[21062] a	\N	\N
3851489b-d970-4c63-9cac-dd5d41bff51a	2018-02-28 11:44:26.59364-06	2	[15337] DPIS-143	[4] DLarrabee	[21062] a	\N	\N
6e492227-a60f-46c8-a200-8b43221ac014	2018-02-28 11:44:26.607642-06	2	[15338] DPIS-208	[4] DLarrabee	[21062] a	\N	\N
db5e7272-d0a5-4b88-88b1-f0109c89d543	2018-02-28 11:44:26.620643-06	2	[15339] DPIS-212	[4] DLarrabee	[21062] a	\N	\N
5696e274-3fa4-457e-8103-2250e68a4773	2018-02-28 11:44:26.634644-06	2	[15340] DPIS-234	[4] DLarrabee	[21062] a	\N	\N
66ad08a5-2891-433b-82f5-7442bbe731f3	2018-02-28 11:44:26.649646-06	2	[15341] DPIS-238	[4] DLarrabee	[21062] a	\N	\N
7645a720-fef6-4a58-8325-7ca1b6c81ad8	2018-02-28 11:44:26.666648-06	2	[15342] DURESS-113	[4] DLarrabee	[21062] a	\N	\N
ef17bd21-9f29-4d21-b5b6-bbfcffa56286	2018-02-28 11:44:26.680649-06	2	[15343] DURESS-133	[4] DLarrabee	[21062] a	\N	\N
be4ddc8f-1a2b-45af-a970-443d3051d9bc	2018-02-28 11:44:26.69465-06	2	[15344] DURESS-211	[4] DLarrabee	[21062] a	\N	\N
a32c2430-52cd-4ffe-89c8-642c1d07a51f	2018-02-28 11:44:26.709652-06	2	[15345] DURESS-236	[4] DLarrabee	[21062] a	\N	\N
a488c9ad-31b7-45d7-9ab5-89b059311747	2018-02-28 11:44:26.722653-06	2	[15346] Not Used INPUT 32	[4] DLarrabee	[21062] a	\N	\N
c85d9531-421e-4e22-b449-1266d4b4b316	2018-02-28 11:44:26.725653-06	2	[15385] DPIS-237B Supervision	[4] DLarrabee	[21062] a	\N	\N
20f0882a-aace-424a-b178-06d539fa634d	2018-02-28 11:44:26.727654-06	2	[15386] DPIS-239 Supervision	[4] DLarrabee	[21062] a	\N	\N
fdb7abe5-556c-42f0-a454-72f976f54d19	2018-02-28 11:44:26.730654-06	2	[15387] DPIS-241 Supervision	[4] DLarrabee	[21062] a	\N	\N
86d0e1ac-5e46-4343-811b-bb5bf4b24414	2018-02-28 11:44:26.733654-06	2	[15388] DPIS-242 Supervision	[4] DLarrabee	[21062] a	\N	\N
c5095f71-c864-4a2f-bc88-a116b40918c9	2018-02-28 11:44:26.736655-06	2	[15389] DPIS-243 Supervision	[4] DLarrabee	[21062] a	\N	\N
c4cb301a-d492-4c09-a757-907cbe621971	2018-02-28 11:44:26.740655-06	2	[15390] DPIS-245 Supervision	[4] DLarrabee	[21062] a	\N	\N
c01ce94e-6d2a-4feb-92c7-65e538e20562	2018-02-28 11:44:26.743655-06	2	[15391] DPIS-246 Supervision	[4] DLarrabee	[21062] a	\N	\N
0a65b50a-f3c9-4db7-86a6-7f204525fbcd	2018-02-28 11:44:26.746656-06	2	[15392] DPIS-247 Supervision	[4] DLarrabee	[21062] a	\N	\N
a4f61969-e639-4687-891a-bd532a19b5a0	2018-02-28 11:44:26.750656-06	2	[15393] DPIS-248 Supervision	[4] DLarrabee	[21062] a	\N	\N
85cc0bcc-97c6-4329-ab77-e25333b08f9b	2018-02-28 11:44:26.753656-06	2	[15394] DPIS-252 Supervision	[4] DLarrabee	[21062] a	\N	\N
e04a87a5-73b9-4799-bbb8-bf631701f470	2018-02-28 11:44:26.757657-06	2	[15395] DPIS-253 Supervision	[4] DLarrabee	[21062] a	\N	\N
b7b6c928-ac0e-42a1-a24f-f15b798b22ee	2018-02-28 11:44:26.760657-06	2	[15396] DPIS-259 Supervision	[4] DLarrabee	[21062] a	\N	\N
8b5c61f5-2fb6-4c24-918b-1fdd24f7d7de	2018-02-28 11:44:26.764657-06	2	[15397] DPIS-261 Supervision	[4] DLarrabee	[21062] a	\N	\N
371b6700-f161-4173-a2f2-fdcdc2ade856	2018-02-28 11:44:26.768658-06	2	[15398] DPIS-301A Supervision	[4] DLarrabee	[21062] a	\N	\N
fef14ba7-fed3-4018-80b5-473d1ae5703d	2018-02-28 11:44:26.772658-06	2	[15399] DPIS-301B Supervision	[4] DLarrabee	[21062] a	\N	\N
0a61eec8-54ef-4207-9439-60b37a05d5af	2018-02-28 11:44:26.775658-06	2	[15400] DPIS-306 Supervision	[4] DLarrabee	[21062] a	\N	\N
e4f26d3c-6b2a-46d9-a123-5ddb53baaac6	2018-02-28 11:44:26.779659-06	2	[15401] DPIS-102 Supervision	[4] DLarrabee	[21062] a	\N	\N
26accc74-009f-49cd-9194-6dc91cd00846	2018-02-28 11:44:26.783659-06	2	[15402] DPIS-111 Supervision	[4] DLarrabee	[21062] a	\N	\N
993b2c53-0546-4b37-9eb4-a13b077550ac	2018-02-28 11:44:26.78666-06	2	[15403] DPIS-135 Supervision	[4] DLarrabee	[21062] a	\N	\N
89eb6404-1b38-44f2-ad03-73d1f3da4470	2018-02-28 11:44:26.78966-06	2	[15404] DPIS-143 Supervision	[4] DLarrabee	[21062] a	\N	\N
4e5f1c6a-4b00-487e-835d-a2c64891191b	2018-02-28 11:44:26.79266-06	2	[15405] DPIS-208 Supervision	[4] DLarrabee	[21062] a	\N	\N
5852f2cf-0172-42d8-9c3e-0e12f1059c01	2018-02-28 11:44:26.79566-06	2	[15406] DPIS-212 Supervision	[4] DLarrabee	[21062] a	\N	\N
c68a70ff-52ff-4dd0-acb8-83442401bc6f	2018-02-28 11:44:26.797661-06	2	[15407] DPIS-234 Supervision	[4] DLarrabee	[21062] a	\N	\N
19f248f9-1095-4e6b-b698-844588fd592d	2018-02-28 11:44:26.802661-06	2	[15408] DPIS-238 Supervision	[4] DLarrabee	[21062] a	\N	\N
7c96715f-2aa9-42ac-8567-52735fe255c6	2018-02-28 11:44:26.806662-06	2	[15409] DURESS-113 Supervision	[4] DLarrabee	[21062] a	\N	\N
2b4945ad-962b-4451-a641-d60ea8094123	2018-02-28 11:44:26.810662-06	2	[15410] DURESS-133 Supervision	[4] DLarrabee	[21062] a	\N	\N
759b9af4-e2eb-4490-897c-1f88da8fd187	2018-02-28 11:44:26.814662-06	2	[15411] DURESS-211 Supervision	[4] DLarrabee	[21062] a	\N	\N
39df7ebf-88a7-4e82-b248-1c3debcebfd7	2018-02-28 11:44:26.817663-06	2	[15412] DURESS-236 Supervision	[4] DLarrabee	[21062] a	\N	\N
39d3ce18-2007-4b88-b040-caeddd299ca9	2018-02-28 11:44:26.820663-06	2	[15413] Not Used INPUT 32 Supervision	[4] DLarrabee	[21062] a	\N	\N
e0709323-cad1-48ce-9d28-a1daa11f4882	2018-02-28 11:44:54.387419-06	2	[21088] Area Label	[21041] OSSI-DNOVAK	[293] master	\N	\N
9eb9ad3d-15f3-4f46-854c-e1b8686115eb	2018-02-28 11:45:39.635944-06	2	[21088] Area Label	[21041] OSSI-DNOVAK	[293] master	\N	\N
73bd63c0-d7ff-4d67-b8fd-53fb570746ac	2018-02-28 11:45:43.313311-06	2	[15346] Not Used INPUT 29	[4] DLarrabee	[21062] a	\N	\N
693e2d12-6381-489f-92e7-cea943c3f800	2018-02-28 11:45:43.325313-06	2	[15347] Not Used INPUT 30	[4] DLarrabee	[21062] a	\N	\N
c8c9c9ce-3ae8-439e-b20a-cf3c3522409f	2018-02-28 11:45:43.338314-06	2	[15348] Not Used INPUT 31	[4] DLarrabee	[21062] a	\N	\N
60dee00d-03b7-4a7e-aac2-563b6fb769f0	2018-02-28 11:45:43.351315-06	2	[15349] Not Used INPUT32	[4] DLarrabee	[21062] a	\N	\N
a36bca7a-95dd-4091-91b2-ad50dec95cd8	2018-02-28 11:45:43.354316-06	2	[15413] Not Used INPUT 29 Supervision	[4] DLarrabee	[21062] a	\N	\N
6082271a-3726-4d26-b328-af36d6c60bbe	2018-02-28 11:45:43.358316-06	2	[15414] Not Used INPUT 30 Supervision	[4] DLarrabee	[21062] a	\N	\N
1bac0485-a189-4011-a85f-8fdb8cc5f193	2018-02-28 11:45:43.361316-06	2	[15415] Not Used INPUT 31 Supervision	[4] DLarrabee	[21062] a	\N	\N
0b3cc412-c938-48ee-bfbf-2ad76b66cfd8	2018-02-28 11:45:43.365317-06	2	[15416] Not Used INPUT32 Supervision	[4] DLarrabee	[21062] a	\N	\N
23241c41-ad6c-4cc4-80aa-ba62a7e2af4b	2018-02-28 11:45:56.087589-06	2	[21088] Area Label	[21041] OSSI-DNOVAK	[293] master	\N	\N
d74d4281-2d96-4964-8e4e-9499b69091ac	2018-02-28 11:46:15.345514-06	2	[21088] Area Label	[21041] OSSI-DNOVAK	[293] master	\N	\N
786b9514-8cfa-41af-b4ce-0ca853101734	2018-02-28 11:46:41.938173-06	2	[21088] Area Label	[21041] OSSI-DNOVAK	[293] master	\N	\N
20cb4c59-1940-43b6-a236-2d85309b1085	2018-02-28 12:02:43.234293-06	2	[1047] DPIS-316B	[4] DLarrabee	[21062] a	\N	\N
b6ee07d8-7a64-4d95-9a52-fb6d7da0da59	2018-02-28 12:02:43.313301-06	2	[1048] DPIS-326A	[4] DLarrabee	[21062] a	\N	\N
c2762d73-dedd-454a-86b0-2a1d4ffe5bef	2018-02-28 12:02:43.330303-06	2	[1049] DPIS-327A	[4] DLarrabee	[21062] a	\N	\N
587058f7-1f58-4579-a82e-2cb993077ede	2018-02-28 12:02:43.346305-06	2	[1050] DPIS-329A	[4] DLarrabee	[21062] a	\N	\N
beca07b1-55de-48f9-a8b4-c2a40987c0fd	2018-02-28 12:02:43.363306-06	2	[1051] DPIS-329B	[4] DLarrabee	[21062] a	\N	\N
2126154f-d551-4a72-bb45-0ea3efc9a38b	2018-02-28 12:02:43.367307-06	2	[1114] DPIS-316B Supervision	[4] DLarrabee	[21062] a	\N	\N
0bc7e6b7-6f5d-4d2e-9388-bd36265d1b26	2018-02-28 12:02:43.370307-06	2	[1115] DPIS-326A Supervision	[4] DLarrabee	[21062] a	\N	\N
7570e627-13c5-44d3-9f83-ffa575f2dd98	2018-02-28 12:02:43.373307-06	2	[1116] DPIS-327A Supervision	[4] DLarrabee	[21062] a	\N	\N
f41a383c-628d-4daa-a9ef-f0d12cba3021	2018-02-28 12:02:43.378308-06	2	[1117] DPIS-329A Supervision	[4] DLarrabee	[21062] a	\N	\N
4c6aa478-13e4-4f9b-991a-f8266506a7b8	2018-02-28 12:02:43.382308-06	2	[1118] DPIS-329B Supervision	[4] DLarrabee	[21062] a	\N	\N
cfdf1ff3-5906-4e1e-b260-cdae4d646037	2018-02-28 12:17:48.377799-06	2	[1052] DPIS-334A	[4] DLarrabee	[21062] a	\N	\N
cb00471b-505a-47d0-9bc9-2baea9bde97f	2018-02-28 12:17:48.415802-06	2	[1053] DPIS-335A	[4] DLarrabee	[21062] a	\N	\N
614161b1-3018-48fc-8dae-4b0059f2ad1c	2018-02-28 12:17:48.427804-06	2	[1054] DPIS-336A	[4] DLarrabee	[21062] a	\N	\N
a464a5ae-9a3c-4226-81c0-faa9275c95c5	2018-02-28 12:17:48.441805-06	2	[1055] DPIS-337A	[4] DLarrabee	[21062] a	\N	\N
9f6844bd-68c9-455c-a61c-14335f8cdbc1	2018-02-28 12:17:48.461807-06	2	[1056] DPIS-338A	[4] DLarrabee	[21062] a	\N	\N
c3751a53-a3ad-4933-bc51-bf6388c7409c	2018-02-28 12:17:48.480809-06	2	[1057] DPIS-343A	[4] DLarrabee	[21062] a	\N	\N
6ae09cb4-5dcc-4a5c-a959-d12635fd8afe	2018-02-28 12:17:48.500811-06	2	[1058] DPIS-344A	[4] DLarrabee	[21062] a	\N	\N
bd5c2046-ab91-4787-8c99-c48641e5e28c	2018-02-28 12:17:48.519813-06	2	[1059] DPIS-346A	[4] DLarrabee	[21062] a	\N	\N
55a73d10-1774-4c0e-bedf-dc41ccc493ae	2018-02-28 12:17:48.532814-06	2	[1060] DPIS-347A	[4] DLarrabee	[21062] a	\N	\N
5ea09cce-520b-4018-873a-0f4e6888abad	2018-02-28 12:17:48.552816-06	2	[1061] DPIS-348A	[4] DLarrabee	[21062] a	\N	\N
2233cb61-1b7c-4c41-8342-aadf954454ad	2018-02-28 12:17:48.570818-06	2	[1062] DPIS-349A	[4] DLarrabee	[21062] a	\N	\N
5786494b-d0c0-4692-b17d-7ab21f3d6e19	2018-02-28 12:17:48.58682-06	2	[1063] DPIS-351A	[4] DLarrabee	[21062] a	\N	\N
0d9ec3dd-df8a-4bc2-a04d-5e17f386384e	2018-02-28 12:17:48.602821-06	2	[1064] DPIS-351B	[4] DLarrabee	[21062] a	\N	\N
f58c4580-92b7-4e76-862e-7da99db93722	2018-02-28 12:17:48.619823-06	2	[1065] DPIS-352A	[4] DLarrabee	[21062] a	\N	\N
059b4651-57b3-47ca-aa17-b435131cb35e	2018-02-28 12:17:48.638825-06	2	[1066] DPIS-405A	[4] DLarrabee	[21062] a	\N	\N
b4fc3ced-8649-4fc7-be74-753a5ea042a5	2018-02-28 12:17:48.657827-06	2	[1067] DPIS-414A	[4] DLarrabee	[21062] a	\N	\N
9dc3b19e-0297-47ba-9737-8919231e285c	2018-02-28 12:17:48.670828-06	2	[1068] DPIS-414B	[4] DLarrabee	[21062] a	\N	\N
f04c2956-de9f-4fc7-bbfa-84df3ef5a057	2018-02-28 12:17:48.68683-06	2	[1069] Not Used INPUT 23	[4] DLarrabee	[21062] a	\N	\N
cbbf8412-a939-436e-b789-1103bc30f461	2018-02-28 12:17:48.702831-06	2	[1070] Not Used INPUT 24	[4] DLarrabee	[21062] a	\N	\N
1d871576-b1a6-432d-9a0a-30c2b77a3905	2018-02-28 12:17:48.717833-06	2	[1071] DPIS-422A	[4] DLarrabee	[21062] a	\N	\N
6eb74972-e75d-4c50-a705-ab2c7c68b145	2018-02-28 12:17:48.730834-06	2	[1073] Not Used INPUT 27	[4] DLarrabee	[21062] a	\N	\N
0d6d07d1-dded-41e2-b572-503b13358014	2018-02-28 12:17:48.742835-06	2	[1074] Not Used INPUT 28	[4] DLarrabee	[21062] a	\N	\N
a8f6cabc-f1bb-461b-83e0-6f6f24f2ab7c	2018-02-28 12:17:48.758837-06	2	[1075] Not Used INPUT 29	[4] DLarrabee	[21062] a	\N	\N
8c295dc5-cd53-45f8-9a4c-c8080dd6bc81	2018-02-28 12:17:48.770838-06	2	[1076] Not Used INPUT 30	[4] DLarrabee	[21062] a	\N	\N
5e774ec2-7c13-40f2-b3da-d47aaa7a463c	2018-02-28 12:17:48.784839-06	2	[1077] Not Used INPUT 31	[4] DLarrabee	[21062] a	\N	\N
9c66749e-8732-412d-9538-dcc4a4ec3bcb	2018-02-28 12:17:48.803841-06	2	[1078] Not Used INPUT 32	[4] DLarrabee	[21062] a	\N	\N
2e5c7e35-e88d-405c-9aaa-8a95c1d6ef22	2018-02-28 12:17:48.808842-06	2	[1119] DPIS-334A Supervision	[4] DLarrabee	[21062] a	\N	\N
07807dd6-325a-42c9-98c3-c68d82facc70	2018-02-28 12:17:48.812842-06	2	[1120] DPIS-335A Supervision	[4] DLarrabee	[21062] a	\N	\N
dcce08c3-556c-48a2-8aee-d045d5f37da3	2018-02-28 12:17:48.816843-06	2	[1121] DPIS-336A Supervision	[4] DLarrabee	[21062] a	\N	\N
c92aad84-b2fb-4a6d-b228-cee6cf888975	2018-02-28 12:17:48.820843-06	2	[1122] DPIS-337A Supervision	[4] DLarrabee	[21062] a	\N	\N
a78cd3c5-7873-466f-9c59-df4a64228133	2018-02-28 12:17:48.823843-06	2	[1123] DPIS-338A Supervision	[4] DLarrabee	[21062] a	\N	\N
54d8b70b-0570-43b4-a068-7ad0d3054de9	2018-02-28 12:17:48.826844-06	2	[1124] DPIS-343A Supervision	[4] DLarrabee	[21062] a	\N	\N
9e8a8d41-fffb-4b0a-8ed7-46582dbb24c4	2018-02-28 12:17:48.829844-06	2	[1125] DPIS-344A Supervision	[4] DLarrabee	[21062] a	\N	\N
b6a52864-1f09-4667-bbea-30b585bbe171	2018-02-28 12:17:48.833844-06	2	[1126] DPIS-346A Supervision	[4] DLarrabee	[21062] a	\N	\N
2155ad59-3223-4c90-a78f-cbc536d85cb5	2018-02-28 12:17:48.836845-06	2	[1127] DPIS-347A Supervision	[4] DLarrabee	[21062] a	\N	\N
532fa903-6b4c-48c2-adaf-2a65d4fd0362	2018-02-28 12:17:48.839845-06	2	[1128] DPIS-348A Supervision	[4] DLarrabee	[21062] a	\N	\N
7aea8ac6-a723-48eb-bbe3-8dd8181fe58a	2018-02-28 12:17:48.842845-06	2	[1129] DPIS-349A Supervision	[4] DLarrabee	[21062] a	\N	\N
481a3b57-974b-48c0-9d08-ef762ca892de	2018-02-28 12:17:48.846846-06	2	[1130] DPIS-351A Supervision	[4] DLarrabee	[21062] a	\N	\N
fc9d0539-1137-4f30-a3ce-901d2f9d1844	2018-02-28 12:17:48.851846-06	2	[1131] DPIS-351B Supervision	[4] DLarrabee	[21062] a	\N	\N
3bea27ab-2f67-4ac1-8b37-249ff32aa756	2018-02-28 12:17:48.854846-06	2	[1132] DPIS-352A Supervision	[4] DLarrabee	[21062] a	\N	\N
384d4f3e-1a98-41a7-8a7d-8579cf59795b	2018-02-28 12:17:48.858847-06	2	[1133] DPIS-405A Supervision	[4] DLarrabee	[21062] a	\N	\N
f6d289e1-e9cf-4295-a5a0-2498401be32d	2018-02-28 12:17:48.862847-06	2	[1134] DPIS-414A Supervision	[4] DLarrabee	[21062] a	\N	\N
35236ff9-d105-4cdd-bf04-00ba49f57f31	2018-02-28 12:17:48.866848-06	2	[1135] DPIS-414B Supervision	[4] DLarrabee	[21062] a	\N	\N
1beee784-c1d7-448a-8500-e52ca61fa6a6	2018-02-28 12:17:48.869848-06	2	[1136] Not Used INPUT 23 Supervision	[4] DLarrabee	[21062] a	\N	\N
937342ac-b480-490f-9fdd-1eb9e56e0dcf	2018-02-28 12:17:48.874848-06	2	[1137] Not Used INPUT 24 Supervision	[4] DLarrabee	[21062] a	\N	\N
736771db-939d-4431-ad94-b35920806bce	2018-02-28 12:17:48.878849-06	2	[1138] DPIS-422A Supervision	[4] DLarrabee	[21062] a	\N	\N
b3a9d385-8ba7-43b5-8203-96a2c540c108	2018-02-28 12:17:48.881849-06	2	[1140] Not Used INPUT 27 Supervision	[4] DLarrabee	[21062] a	\N	\N
fc3f3b37-3ada-4814-bfab-ae0819be38ff	2018-02-28 12:17:48.885849-06	2	[1141] Not Used INPUT 28 Supervision	[4] DLarrabee	[21062] a	\N	\N
b9e642d7-acb7-4c5f-9c6a-efb3d6c9f4d3	2018-02-28 12:17:48.88885-06	2	[1142] Not Used INPUT 29 Supervision	[4] DLarrabee	[21062] a	\N	\N
ddc1fccd-89af-4e1e-9b39-7b10c9f44865	2018-02-28 12:17:48.89285-06	2	[1143] Not Used INPUT 30 Supervision	[4] DLarrabee	[21062] a	\N	\N
f7227c98-e18c-480a-9e6c-6f25302ec9e9	2018-02-28 12:17:48.896851-06	2	[1144] Not Used INPUT 31 Supervision	[4] DLarrabee	[21062] a	\N	\N
5f443da1-b3e1-4de1-8221-b33475557589	2018-02-28 12:17:48.899851-06	2	[1145] Not Used INPUT 32 Supervision	[4] DLarrabee	[21062] a	\N	\N
65f74eac-c4ec-48e6-aaec-27c8bf2dddc9	2018-02-28 12:22:57.273685-06	2	[1515] DPIS-438A	[4] DLarrabee	[21062] a	\N	\N
2014907d-ed18-4354-8561-ac6a40dc07b5	2018-02-28 12:22:57.348693-06	2	[1516] DPIS-439A	[4] DLarrabee	[21062] a	\N	\N
39bbb0ee-ceda-4690-b3a8-4083098d2c09	2018-02-28 12:22:57.368695-06	2	[1517] Not Used INPUT 3	[4] DLarrabee	[21062] a	\N	\N
d9e5ec65-55e6-4340-9781-35f93f36319c	2018-02-28 12:22:57.387697-06	2	[1518] DPIS-443A	[4] DLarrabee	[21062] a	\N	\N
2e16139e-bcca-4947-8b8c-2f57ce3daee5	2018-02-28 12:22:57.404698-06	2	[1519] DPIS-443B	[4] DLarrabee	[21062] a	\N	\N
b2af3f1e-6515-4243-909c-4a7b9c36b981	2018-02-28 12:22:57.4217-06	2	[1520] DPIS-444A	[4] DLarrabee	[21062] a	\N	\N
3c1897f1-ae12-47cf-a2fb-b2612d96b871	2018-02-28 12:22:57.452703-06	2	[1521] DPIS-444B 	[4] DLarrabee	[21062] a	\N	\N
e9e6226f-29a7-44a1-8a28-1e656e580384	2018-02-28 12:22:57.470705-06	2	[1522] Not Used INPUT 8	[4] DLarrabee	[21062] a	\N	\N
a4b3532c-fb54-4da7-9b0c-c2476512078d	2018-02-28 12:22:57.485706-06	2	[1523] DPIS-447A	[4] DLarrabee	[21062] a	\N	\N
22d51720-4872-46b2-92b1-368a6c91f577	2018-02-28 12:22:57.500708-06	2	[1524] DPIS-447B	[4] DLarrabee	[21062] a	\N	\N
10534d0f-b2e3-4ebd-8e63-c98bb6fac257	2018-02-28 12:22:57.51971-06	2	[1525] DPIS-448A	[4] DLarrabee	[21062] a	\N	\N
bee55e85-d497-443e-8833-6c0fac3a6eb2	2018-02-28 12:22:57.535711-06	2	[1526] DPIS-451A	[4] DLarrabee	[21062] a	\N	\N
673c5716-1291-49c6-abe9-1af6e1a6132d	2018-02-28 12:22:57.549713-06	2	[1527] DPIS-455A	[4] DLarrabee	[21062] a	\N	\N
d2b80a5e-a431-4de0-a923-87128fb9eb25	2018-02-28 12:22:57.565714-06	2	[1528] DPIS-455B	[4] DLarrabee	[21062] a	\N	\N
df5ed3c4-2d03-41c3-affd-b7d94d2ab20e	2018-02-28 12:22:57.586716-06	2	[1529] DPIS-455D	[4] DLarrabee	[21062] a	\N	\N
7a8d9d56-ed24-40f9-af1e-fc78031e64b4	2018-02-28 12:22:57.601718-06	2	[1530] DPIS-316B	[4] DLarrabee	[21062] a	\N	\N
f99d8ccb-2a31-464b-a5af-750b141a4d64	2018-02-28 12:22:57.616719-06	2	[1531] DPIS-326A	[4] DLarrabee	[21062] a	\N	\N
9397b6a4-5ede-435b-956d-a2dde9c80e2d	2018-02-28 12:22:57.631721-06	2	[1532] DPIS-327A	[4] DLarrabee	[21062] a	\N	\N
836d669e-004e-4d7f-ad39-825537af37a8	2018-02-28 12:22:57.648723-06	2	[1533] DPIS-329A	[4] DLarrabee	[21062] a	\N	\N
ca909a31-287d-4c32-8087-4e2c6649e32c	2018-02-28 12:22:57.660724-06	2	[1534] DPIS-329B	[4] DLarrabee	[21062] a	\N	\N
53795e88-b10d-4c2d-9c52-44114524de71	2018-02-28 12:22:57.674725-06	2	[1535] DPIS-334A	[4] DLarrabee	[21062] a	\N	\N
69110326-8b62-485b-8ece-692eabaacf87	2018-02-28 12:22:57.690727-06	2	[1536] Not Used INPUT 22	[4] DLarrabee	[21062] a	\N	\N
bafb56fc-5aee-4ed8-a676-089d859a85e2	2018-02-28 12:22:57.708729-06	2	[1537] Not Used INPUT 23	[4] DLarrabee	[21062] a	\N	\N
4e7b83a9-d7f5-4031-98fb-bce119e3ff87	2018-02-28 12:22:57.72473-06	2	[1538] Not Used INPUT 24	[4] DLarrabee	[21062] a	\N	\N
e9bd5638-d3ba-43f7-a546-3c594d8bfdf8	2018-02-28 12:22:57.739732-06	2	[1539] Not Used INPUT 25	[4] DLarrabee	[21062] a	\N	\N
9db2e168-2328-400d-9047-7f4208b5f854	2018-02-28 12:22:57.754733-06	2	[1540] Not Used INPUT 26	[4] DLarrabee	[21062] a	\N	\N
6adfd3f2-39e5-421d-9ed2-739c6edbc5bc	2018-02-28 12:22:57.771735-06	2	[1541] Not Used INPUT 27	[4] DLarrabee	[21062] a	\N	\N
b624b090-3b4e-4aeb-a013-a6d1d89120d8	2018-02-28 12:22:57.788737-06	2	[1542] Not Used INPUT 28	[4] DLarrabee	[21062] a	\N	\N
a4393c85-ab33-427a-b572-b871f59afdc8	2018-02-28 12:22:57.804738-06	2	[1543] Not Used INPUT 29	[4] DLarrabee	[21062] a	\N	\N
0c3bad96-4052-4cc5-ae83-2398b3007d9f	2018-02-28 12:22:57.82374-06	2	[1544] Not Used INPUT 30	[4] DLarrabee	[21062] a	\N	\N
139d5a4a-f4ec-4dc7-858c-a3a8efacbc18	2018-02-28 12:22:57.842742-06	2	[1545] Not Used INPUT 31	[4] DLarrabee	[21062] a	\N	\N
0ecbbb4c-cf85-413e-a694-576147b92531	2018-02-28 12:22:57.859744-06	2	[1546] Not Used INPUT 32	[4] DLarrabee	[21062] a	\N	\N
0a3a3bb0-3876-45c6-bb8a-738beeec6e3f	2018-02-28 12:22:57.863744-06	2	[1582] DPIS-438A Supervision	[4] DLarrabee	[21062] a	\N	\N
048c2f9f-3777-4bda-b1e6-0deaec107a32	2018-02-28 12:22:57.867745-06	2	[1583] DPIS-439A Supervision	[4] DLarrabee	[21062] a	\N	\N
a482c71d-dddf-457f-adae-55e4fbf773c8	2018-02-28 12:22:57.870745-06	2	[1584] Not Used INPUT 3 Supervision	[4] DLarrabee	[21062] a	\N	\N
b447ec63-3e52-4141-bfc2-4a0467b0f7eb	2018-02-28 12:22:57.874745-06	2	[1585] DPIS-443A Supervision	[4] DLarrabee	[21062] a	\N	\N
167e4dc3-1cba-452b-87fe-5f7ed45c6aa1	2018-02-28 12:22:57.878746-06	2	[1586] DPIS-443B Supervision	[4] DLarrabee	[21062] a	\N	\N
8d1a9b24-7719-4761-93ca-f07c4031cebf	2018-02-28 12:22:57.882746-06	2	[1587] DPIS-444A Supervision	[4] DLarrabee	[21062] a	\N	\N
5e8771f4-ec7c-47c2-a61a-dc2144800170	2018-02-28 12:22:57.885746-06	2	[1588] DPIS-444B  Supervision	[4] DLarrabee	[21062] a	\N	\N
5034c6b4-8caf-48a1-bc31-b6f808947cc8	2018-02-28 12:22:57.889747-06	2	[1589] Not Used INPUT 8 Supervision	[4] DLarrabee	[21062] a	\N	\N
51cd1974-e76d-43b1-b28a-fa7d498f878f	2018-02-28 12:22:57.892747-06	2	[1590] DPIS-447A Supervision	[4] DLarrabee	[21062] a	\N	\N
99cb70e3-1781-4773-8ec5-00de2ae3dd9d	2018-02-28 12:22:57.896747-06	2	[1591] DPIS-447B Supervision	[4] DLarrabee	[21062] a	\N	\N
de742ad9-2966-4f89-bd49-3e8024e4d16c	2018-02-28 12:22:57.899748-06	2	[1592] DPIS-448A Supervision	[4] DLarrabee	[21062] a	\N	\N
cda4b7a1-b47b-411f-8953-162d176d2eba	2018-02-28 12:22:57.903748-06	2	[1593] DPIS-451A Supervision	[4] DLarrabee	[21062] a	\N	\N
fd00bee8-d7fa-441d-826f-bd7cf8fd5be4	2018-02-28 12:22:57.907749-06	2	[1594] DPIS-455A Supervision	[4] DLarrabee	[21062] a	\N	\N
eaad49a9-ae9a-4844-a7b7-d1d251bcde30	2018-02-28 12:22:57.909749-06	2	[1595] DPIS-455B Supervision	[4] DLarrabee	[21062] a	\N	\N
84b70003-84e1-4472-9de8-d45b3fee3353	2018-02-28 12:22:57.913749-06	2	[1596] DPIS-455D Supervision	[4] DLarrabee	[21062] a	\N	\N
e5bdae01-b3e1-472f-8100-629635a75d30	2018-02-28 12:22:57.91975-06	2	[1597] DPIS-316B Supervision	[4] DLarrabee	[21062] a	\N	\N
1a158495-f12c-45f4-b1da-1a78bc2b7dc6	2018-02-28 12:22:57.92275-06	2	[1598] DPIS-326A Supervision	[4] DLarrabee	[21062] a	\N	\N
4c62ed7b-764f-4ed5-9e57-b2bdd47fdbca	2018-02-28 12:22:57.92675-06	2	[1599] DPIS-327A Supervision	[4] DLarrabee	[21062] a	\N	\N
f1e6a01c-1e3f-47eb-9822-1dd1526902aa	2018-02-28 12:22:57.929751-06	2	[1600] DPIS-329A Supervision	[4] DLarrabee	[21062] a	\N	\N
f36984ed-e295-454f-acfb-b47343746171	2018-02-28 12:22:57.933751-06	2	[1601] DPIS-329B Supervision	[4] DLarrabee	[21062] a	\N	\N
560deddf-66a9-4213-bce7-4f9add152d1a	2018-02-28 12:22:57.936751-06	2	[1602] DPIS-334A Supervision	[4] DLarrabee	[21062] a	\N	\N
464d1e56-389f-449d-9578-39cf497898f5	2018-02-28 12:22:57.940752-06	2	[1603] Not Used INPUT 22 Supervision	[4] DLarrabee	[21062] a	\N	\N
a8ce3807-1eb8-48f0-881e-0742de5d864a	2018-02-28 12:22:57.943752-06	2	[1604] Not Used INPUT 23 Supervision	[4] DLarrabee	[21062] a	\N	\N
eccdfb70-4120-4f19-8485-1ae28ad85e91	2018-02-28 12:22:57.948753-06	2	[1605] Not Used INPUT 24 Supervision	[4] DLarrabee	[21062] a	\N	\N
c615b4a3-a03a-46d2-add2-d60cc049a514	2018-02-28 12:22:57.951753-06	2	[1606] Not Used INPUT 25 Supervision	[4] DLarrabee	[21062] a	\N	\N
ed3c3e34-2ee4-4cf7-abb5-db83e2d2b9fb	2018-02-28 12:22:57.954753-06	2	[1607] Not Used INPUT 26 Supervision	[4] DLarrabee	[21062] a	\N	\N
eef2756b-eccc-4172-8425-9cbf686c6e58	2018-02-28 12:22:57.957754-06	2	[1608] Not Used INPUT 27 Supervision	[4] DLarrabee	[21062] a	\N	\N
ceb1a853-b412-4800-a303-113ff5fe0a0a	2018-02-28 12:22:57.961754-06	2	[1609] Not Used INPUT 28 Supervision	[4] DLarrabee	[21062] a	\N	\N
0370230c-5698-428e-802d-d44035c487a1	2018-02-28 12:22:57.965754-06	2	[1610] Not Used INPUT 29 Supervision	[4] DLarrabee	[21062] a	\N	\N
99777d61-d92d-47e7-8fb1-8df67d890f9b	2018-02-28 12:22:57.968755-06	2	[1611] Not Used INPUT 30 Supervision	[4] DLarrabee	[21062] a	\N	\N
6f3ce7d0-db12-446c-8bc9-8557ad33c68c	2018-02-28 12:22:57.970755-06	2	[1612] Not Used INPUT 31 Supervision	[4] DLarrabee	[21062] a	\N	\N
117601e2-95df-4291-9c92-9bc50eac077d	2018-02-28 12:22:57.976755-06	2	[1613] Not Used INPUT 32 Supervision	[4] DLarrabee	[21062] a	\N	\N
36835dd3-595a-4fff-af0e-83bf1b486d3e	2018-02-28 12:28:21.4571-06	2	[1983] LOCK DR-316B Relay	[4] DLarrabee	[21062] a	\N	\N
3e40405d-5cdc-42eb-9277-a21cbaa9bfb2	2018-02-28 12:28:21.520107-06	2	[1984] LOCK DR-326A Relay	[4] DLarrabee	[21062] a	\N	\N
f71a51a0-71dd-46b7-900a-ec38e2609261	2018-02-28 12:28:21.540109-06	2	[1985] LOCK DR-327A Relay	[4] DLarrabee	[21062] a	\N	\N
7e8e8029-50b8-45eb-b0a6-a2096b7294aa	2018-02-28 12:28:21.55411-06	2	[1986] LOCK DR329A Relay	[4] DLarrabee	[21062] a	\N	\N
0d412740-e8d9-45cc-8756-15fb9ff96588	2018-02-28 12:28:21.576112-06	2	[1987] LOCK DR-329B Relay	[4] DLarrabee	[21062] a	\N	\N
d69430b7-ce8a-4f84-b18d-4e4bc4919932	2018-02-28 12:28:21.593114-06	2	[1988] LOCK DR-334A Relay	[4] DLarrabee	[21062] a	\N	\N
fd488cdf-ff8c-416b-b6de-313d8cabb589	2018-02-28 12:28:21.611116-06	2	[1989] LOCK DR-335A Relay	[4] DLarrabee	[21062] a	\N	\N
070afd9c-a17d-48b7-841f-7f6a2d47e8a3	2018-02-28 12:28:21.629117-06	2	[1990] LOCK DR-336A Relay	[4] DLarrabee	[21062] a	\N	\N
7fdcbd51-c5d9-4234-93cd-41153c807b99	2018-02-28 12:28:21.648119-06	2	[1991] LOCK DR-337A Relay	[4] DLarrabee	[21062] a	\N	\N
7f779ef9-51e1-43e9-95d4-1b062ab8333d	2018-02-28 12:28:21.663121-06	2	[1992] LOCK DR-338A Relay	[4] DLarrabee	[21062] a	\N	\N
bba60cc5-f823-4b1a-99ac-baf57c2b0ba4	2018-02-28 12:28:21.679122-06	2	[1993] LOCK DR-343A Relay	[4] DLarrabee	[21062] a	\N	\N
ffa6b4c2-7032-401d-b01c-d0121dabba6a	2018-02-28 12:28:21.697124-06	2	[1994] LOCK DR-344A Relay	[4] DLarrabee	[21062] a	\N	\N
fc92a5eb-8888-4380-8ef0-4229a74b1560	2018-02-28 12:28:21.713126-06	2	[1995] LOCK DR-346A Relay	[4] DLarrabee	[21062] a	\N	\N
0f06142a-21c6-4856-95fb-0290ef553cad	2018-02-28 12:28:21.732128-06	2	[1996] LOCK DR-347A Relay	[4] DLarrabee	[21062] a	\N	\N
1afa166c-5300-4fc3-9e05-ab052595a81a	2018-02-28 12:28:21.746129-06	2	[1997] LOCK DR-348A Relay	[4] DLarrabee	[21062] a	\N	\N
b8c6a94f-df2e-4168-8290-2d2b33c831b6	2018-02-28 12:28:21.762131-06	2	[1998] LOCK DR-349A Relay	[4] DLarrabee	[21062] a	\N	\N
6523f5c0-1cae-4651-949b-b776afc05d5c	2018-02-28 12:30:11.552109-06	2	[2303] LOCK DR-351A Relay	[4] DLarrabee	[21062] a	\N	\N
3ce090bf-1f1e-4592-a09a-511197300eb0	2018-02-28 12:30:11.56611-06	2	[2304] LOCK DR-351B Relay	[4] DLarrabee	[21062] a	\N	\N
356d925a-f031-4820-8814-c96703a0eca8	2018-02-28 12:30:11.591113-06	2	[2305] LOCK DR-352A Relay	[4] DLarrabee	[21062] a	\N	\N
a1c86ab9-ca84-4c13-a347-7dd5694cc52e	2018-02-28 12:30:11.620115-06	2	[2306] LOCK DR-405A Relay	[4] DLarrabee	[21062] a	\N	\N
de05dc3c-67cf-43bf-a924-a76804cd56c3	2018-02-28 12:30:11.645118-06	2	[2307] LOCK DR-414A Relay	[4] DLarrabee	[21062] a	\N	\N
c721d70e-3ecb-4ad6-9bcd-bcd1fbeee927	2018-02-28 12:30:11.66312-06	2	[2308] LOCK DR-414B Relay	[4] DLarrabee	[21062] a	\N	\N
1c5cd24f-0283-45fa-aea7-eb1aa792e314	2018-02-28 12:30:11.678121-06	2	[2309] LOCK DR-422A Relay	[4] DLarrabee	[21062] a	\N	\N
dfa6e145-f831-4d10-900c-7c20f1af9f7f	2018-02-28 12:30:11.696123-06	2	[2310] LOCK DR-422B Relay	[4] DLarrabee	[21062] a	\N	\N
83d6456d-e972-413e-af18-98da7f48269a	2018-02-28 12:30:11.711125-06	2	[2311] LOCK DR-438A Relay	[4] DLarrabee	[21062] a	\N	\N
f497aadd-31e8-4969-aa73-2f7d42a59f11	2018-02-28 12:30:11.730126-06	2	[2312] LOCK DR-439A Relay	[4] DLarrabee	[21062] a	\N	\N
65004621-4a60-4c9c-8076-19075128fdc4	2018-02-28 12:30:11.748128-06	2	[2313] LOCK DR-443A Relay	[4] DLarrabee	[21062] a	\N	\N
1af4caf5-ee1d-4b1d-b0b8-9fb1da706780	2018-02-28 12:30:11.76313-06	2	[2314] LOCK DR-443B Relay	[4] DLarrabee	[21062] a	\N	\N
9427fa9f-ab1c-4411-b8e7-ff61bdf09854	2018-02-28 12:30:11.780131-06	2	[2315] LOCK DR-444A Relay	[4] DLarrabee	[21062] a	\N	\N
0d6f74d4-528d-4081-b96c-d7b775bca7a4	2018-02-28 12:30:11.795133-06	2	[2316] LOCK DR-444B Relay	[4] DLarrabee	[21062] a	\N	\N
c79c5488-2150-4ec5-a6d4-18442c4e5f25	2018-02-28 12:30:11.809134-06	2	[2317] LOCK DR-447A Relay	[4] DLarrabee	[21062] a	\N	\N
d90f6ac8-0284-4ccf-bdab-3a213ce242ef	2018-02-28 12:30:11.824136-06	2	[2318] LOCK DR-447B Relay	[4] DLarrabee	[21062] a	\N	\N
cb9962d1-a9b5-451a-95ef-e60db89b50b3	2018-02-28 12:34:32.419193-06	2	[2623] LOCK DR-448A Relay	[4] DLarrabee	[21062] a	\N	\N
63a54d2b-4a73-42a2-a503-512e281dc3b2	2018-02-28 12:34:32.434194-06	2	[2624] LOCK DR-455A Relay	[4] DLarrabee	[21062] a	\N	\N
2bd7e735-4c34-4d50-bcb3-3f7ce1349a2c	2018-02-28 12:34:32.461197-06	2	[2625] LOCK DR-455B Relay	[4] DLarrabee	[21062] a	\N	\N
1c07e275-9dca-44b3-ae4d-520f3a30cc2c	2018-02-28 12:34:32.4882-06	2	[2626] LOCK DR-455D Relay	[4] DLarrabee	[21062] a	\N	\N
c2843401-c720-4e9a-b7e6-b4b92ed041cd	2018-02-28 12:34:32.515202-06	2	[2627] LOCK DR-316B Relay	[4] DLarrabee	[21062] a	\N	\N
2559d995-a0b2-4af9-8bc8-ab2c9ad2ae3e	2018-02-28 12:34:32.533204-06	2	[2628] LOCK DR-326A Relay	[4] DLarrabee	[21062] a	\N	\N
980bb5bc-18cf-4a32-b52f-4f720922c912	2018-02-28 12:34:32.552206-06	2	[2629] LOCK DR-327A Relay	[4] DLarrabee	[21062] a	\N	\N
cd4264e9-99b9-46c2-bbb9-ea9f945f5a89	2018-02-28 12:34:32.569208-06	2	[2630] LOCK DR-329A Relay	[4] DLarrabee	[21062] a	\N	\N
5f44e550-67cd-4895-8cbe-d05ee090a9f5	2018-02-28 12:34:32.583209-06	2	[2631] LOCK DR-329B Relay	[4] DLarrabee	[21062] a	\N	\N
2906dc6b-6b67-42cb-9e83-91d8f83602eb	2018-02-28 12:34:32.598211-06	2	[2632] LOCK DR-334A Relay	[4] DLarrabee	[21062] a	\N	\N
e11aa020-0f81-4463-905b-0eec1e85c93a	2018-02-28 12:40:06.343582-06	2	[21076] RM 304 32i MAC Driver	[4] DLarrabee	[21062] a	\N	\N
a6fba57a-ed0e-442b-933b-ead2bb860bbc	2018-02-28 12:40:39.283876-06	2	[21077] RM 304 16R MAC Driver	[4] DLarrabee	[21062] a	\N	\N
85b24fb4-ed98-4129-8cdf-fd1fe49b53c2	2018-02-28 12:54:33.31127-06	2	[15786] Lock DR-103 Relay	[4] DLarrabee	[21062] a	\N	\N
05b88477-1d7d-4412-b20e-351fe2ef3724	2018-02-28 12:54:33.359275-06	2	[15787] Lock DR-104 Relay	[4] DLarrabee	[21062] a	\N	\N
84c5018d-3ee1-44f2-82c8-0dfb6fc4d3d7	2018-02-28 12:54:33.384277-06	2	[15788] Lock DR-105 Relay	[4] DLarrabee	[21062] a	\N	\N
dd66d940-c37d-4c1b-853b-5cb7115044c4	2018-02-28 12:54:33.404279-06	2	[15789] Lock DR-107 Relay	[4] DLarrabee	[21062] a	\N	\N
3d52b58a-0d2c-4c12-996a-ee9bdb3675bb	2018-02-28 12:54:33.430282-06	2	[15790] Lock DR-108 Relay	[4] DLarrabee	[21062] a	\N	\N
5e39dff7-c300-43a7-afe2-333cf285b4e1	2018-02-28 12:54:33.446283-06	2	[15791] Lock DR-109 Relay	[4] DLarrabee	[21062] a	\N	\N
4f4f7240-3436-4b3c-803f-c50cc570941b	2018-02-28 12:54:33.465285-06	2	[15792] Lock DR-112 Relay	[4] DLarrabee	[21062] a	\N	\N
fc3b7596-394e-41ad-b6c0-c70dc025e8fb	2018-02-28 12:54:33.486287-06	2	[15793] Lock DR-113 Relay	[4] DLarrabee	[21062] a	\N	\N
609dcbb2-76b6-46db-822b-2fdb66be3c2f	2018-02-28 12:54:33.505289-06	2	[15794] Lock DR-114A Relay	[4] DLarrabee	[21062] a	\N	\N
81938959-f5c9-4a17-91e0-bb2f81f0094c	2018-02-28 12:54:33.525291-06	2	[15795] Lock DR-114B Relay	[4] DLarrabee	[21062] a	\N	\N
9d96faed-c51b-439d-b1a0-7926ffefbb96	2018-02-28 12:54:33.540293-06	2	[15796] Lock DR-115 Relay	[4] DLarrabee	[21062] a	\N	\N
1b50b2ac-dc04-4f8e-9fbb-543520898b49	2018-02-28 12:54:33.557295-06	2	[15797] Lock DR-116 Relay	[4] DLarrabee	[21062] a	\N	\N
ca82d781-af3f-4a69-8648-6c613e5a972b	2018-02-28 12:54:33.575296-06	2	[15798] Lock DR-117 Relay	[4] DLarrabee	[21062] a	\N	\N
010104eb-ec5a-494f-b58f-05e640a58bda	2018-02-28 12:54:33.591298-06	2	[15799] Lock DR-119 Relay	[4] DLarrabee	[21062] a	\N	\N
6d722531-fb60-419a-9ef2-7ff334181d22	2018-02-28 12:54:33.6103-06	2	[15800] Lock DR-121 Relay	[4] DLarrabee	[21062] a	\N	\N
7661f152-d796-4e4f-a540-215563066d26	2018-02-28 12:54:33.627302-06	2	[15801] Lock DR-122 Relay	[4] DLarrabee	[21062] a	\N	\N
47070c1d-94ed-427e-a839-72da06203dba	2018-02-28 12:56:07.728711-06	2	[16106] Lock DR-123 Relay	[4] DLarrabee	[21062] a	\N	\N
9c25e31e-4abf-40e7-8ab9-5e3632b4c3af	2018-02-28 12:56:07.745712-06	2	[16107] Lock DR-124 Relay	[4] DLarrabee	[21062] a	\N	\N
b112aa83-9840-408e-898d-39810688fe2e	2018-02-28 12:56:07.760714-06	2	[16108] Lock DR-125 Relay	[4] DLarrabee	[21062] a	\N	\N
644d7a28-dd13-454b-bdce-109fb063773d	2018-02-28 12:56:07.785716-06	2	[16109] Lock DR-126 Relay	[4] DLarrabee	[21062] a	\N	\N
80c1aa57-96ca-4947-aab5-f0bfbcf60ab4	2018-02-28 12:56:07.801718-06	2	[16110] Lock DR-128 Relay	[4] DLarrabee	[21062] a	\N	\N
6751e45c-5577-421c-9e8f-b2247cfb4398	2018-02-28 12:56:07.81872-06	2	[16111] Lock DR-129 Relay	[4] DLarrabee	[21062] a	\N	\N
6bf56e7e-f4e1-4b1d-abf0-480cbfb3b6a1	2018-02-28 12:56:07.835721-06	2	[16112] Lock DR-131 Relay	[4] DLarrabee	[21062] a	\N	\N
7aa4e1df-e8ec-4b26-81b6-ab189a5c113c	2018-02-28 12:56:07.849723-06	2	[16113] Lock DR-132 Relay	[4] DLarrabee	[21062] a	\N	\N
9680e586-4018-4f6e-98c6-154c01aea5e6	2018-02-28 12:56:07.863724-06	2	[16114] Lock DR-133 Relay	[4] DLarrabee	[21062] a	\N	\N
11428422-15b3-4768-8826-4230eb063f8b	2018-02-28 12:56:07.876726-06	2	[16115] Lock DR-134A Relay	[4] DLarrabee	[21062] a	\N	\N
cd34ece7-2464-412b-9ce6-892dc2e7ea17	2018-02-28 12:56:07.892727-06	2	[16116] Lock DR-134B Relay	[4] DLarrabee	[21062] a	\N	\N
c3e91eb8-3895-4ced-b1fc-af2ca11e7006	2018-02-28 12:56:07.907729-06	2	[16117] Lock DR-136 Relay	[4] DLarrabee	[21062] a	\N	\N
631c5ce8-d234-4e97-ac1c-08b79eadf12a	2018-02-28 12:56:07.92273-06	2	[16118] Lock DR-137 Relay	[4] DLarrabee	[21062] a	\N	\N
27998375-fe3d-4078-a2e6-6064ac63d014	2018-02-28 12:56:07.940732-06	2	[16119] Lock DR-138 Relay	[4] DLarrabee	[21062] a	\N	\N
1c514bad-5bd6-4bc5-9df7-4529a0d8c6ae	2018-02-28 12:56:07.955733-06	2	[16120] Lock DR-141 Relay	[4] DLarrabee	[21062] a	\N	\N
13a9f3a8-9b0e-4b34-a4aa-1e130ca4d082	2018-02-28 12:56:07.971735-06	2	[16121] Lock DR-142 Relay	[4] DLarrabee	[21062] a	\N	\N
70b09842-f813-4710-8752-cdcfd263bc48	2018-02-28 12:57:00.42998-06	2	[16426] Lock DR-145 Relay	[4] DLarrabee	[21062] a	\N	\N
a24722d3-80a6-494a-ac5e-65bf8de6c311	2018-02-28 12:57:00.448982-06	2	[16427] Lock DR-146 Relay	[4] DLarrabee	[21062] a	\N	\N
e11f21c6-be76-46f8-bfe5-ec09fb5d860a	2018-02-28 12:57:00.464984-06	2	[16428] Lock DR-201 Relay	[4] DLarrabee	[21062] a	\N	\N
f2ab8900-3049-41f5-a114-c493a5abb658	2018-02-28 12:57:00.478985-06	2	[16429] Lock DR-202 Relay	[4] DLarrabee	[21062] a	\N	\N
0c37d9d3-078a-4c55-88d5-3da29d4a30af	2018-02-28 12:57:00.497987-06	2	[16430] Lock DR-203 Relay	[4] DLarrabee	[21062] a	\N	\N
69a905d8-2037-499d-bd71-8b086ea921bd	2018-02-28 13:00:19.815917-06	2	[16431] Lock DR-205 Relay	[4] DLarrabee	[21062] a	\N	\N
de6ee490-9278-40c3-b4c7-ada20394386e	2018-02-28 13:00:19.829918-06	2	[16432] Lock DR-206 Relay	[4] DLarrabee	[21062] a	\N	\N
997cffea-04fb-48e5-8728-c1e65a254b48	2018-02-28 13:00:19.84592-06	2	[16433] Lock DR-207 Relay	[4] DLarrabee	[21062] a	\N	\N
9f611b02-3e66-4274-af56-e7cfb760b589	2018-02-28 13:00:19.865922-06	2	[16434] Lock DR-209A Relay	[4] DLarrabee	[21062] a	\N	\N
a41b8541-98c7-40bb-8096-724a64196537	2018-02-28 13:00:19.877923-06	2	[16435] Lock DR-209B Relay	[4] DLarrabee	[21062] a	\N	\N
db37a5ae-37ce-43c3-befb-5024218e9592	2018-02-28 13:00:19.893925-06	2	[16436] Lock DR-211 Relay	[4] DLarrabee	[21062] a	\N	\N
836d2767-3360-4972-b830-fedac86a92ca	2018-02-28 13:00:19.910926-06	2	[16437] Lock DR-213 Relay	[4] DLarrabee	[21062] a	\N	\N
0b002fe7-72f3-45ea-8588-65bacf8b2b08	2018-02-28 13:00:19.927928-06	2	[16438] Lock DR-214 Relay	[4] DLarrabee	[21062] a	\N	\N
96e3b24c-3d0a-411d-be1d-e50d2d86fcfb	2018-02-28 13:00:19.94493-06	2	[16439] Lock DR-215 Relay	[4] DLarrabee	[21062] a	\N	\N
e2ca0ea7-0523-4b2e-b1aa-5a2a7e0c652b	2018-02-28 13:00:19.963932-06	2	[16440] Lock DR-216 Relay	[4] DLarrabee	[21062] a	\N	\N
0e22a5a2-434d-42d7-ba4c-90e52c65b883	2018-02-28 13:00:19.979933-06	2	[16441] Lock DR-218 Relay	[4] DLarrabee	[21062] a	\N	\N
35bb17a4-6009-4bbd-9f2c-2f22481e8556	2018-02-28 13:02:29.979932-06	2	[16746] Lock DR-219 Relay	[4] DLarrabee	[21062] a	\N	\N
bd8d1542-1a21-4239-a9db-4ae5c69c8104	2018-02-28 13:02:30.000934-06	2	[16747] Lock DR-221 Relay	[4] DLarrabee	[21062] a	\N	\N
d099ef8c-4733-4ab0-ac39-5657e9ae7b70	2018-02-28 13:02:30.023936-06	2	[16748] Lock DR-222 Relay	[4] DLarrabee	[21062] a	\N	\N
ef6a582a-10eb-483f-a75d-c4d89fb241bf	2018-02-28 13:02:30.042938-06	2	[16749] Lock DR-223 Relay	[4] DLarrabee	[21062] a	\N	\N
128f8852-2fb2-4303-9657-985a7be47883	2018-02-28 13:02:30.06094-06	2	[16750] Lock DR-224 Relay	[4] DLarrabee	[21062] a	\N	\N
732e1b6a-9e10-427a-80b7-948803cc533d	2018-02-28 13:02:30.076942-06	2	[16751] Lock DR-225 Relay	[4] DLarrabee	[21062] a	\N	\N
6752bb43-bc23-49c1-ab07-084077956b7d	2018-02-28 13:02:30.094944-06	2	[16752] Lock DR-226 Relay	[4] DLarrabee	[21062] a	\N	\N
553ff480-79d2-4ecd-bda0-e8fd83765b11	2018-02-28 13:02:30.114946-06	2	[16753] Lock DR-227 Relay	[4] DLarrabee	[21062] a	\N	\N
f932ab54-303e-4655-ad39-9b7eec710b45	2018-02-28 13:02:30.127947-06	2	[16754] Lock DR-228 Relay	[4] DLarrabee	[21062] a	\N	\N
efea9547-564f-4a4b-bd9f-002475e8287a	2018-02-28 13:02:30.144949-06	2	[16755] Lock DR-231 Relay	[4] DLarrabee	[21062] a	\N	\N
6c34b0b1-1b4d-4d0b-8eb6-3979196d9881	2018-02-28 13:02:30.15895-06	2	[16756] Lock DR-232 Relay	[4] DLarrabee	[21062] a	\N	\N
3fd098f0-0b79-46bb-a7a8-9892e7521677	2018-02-28 13:02:30.172951-06	2	[16757] Lock DR-233 Relay	[4] DLarrabee	[21062] a	\N	\N
d2dc152a-8946-4f21-b3d6-b9df2d633182	2018-02-28 13:02:30.184953-06	2	[16758] Lock DR-235 Relay	[4] DLarrabee	[21062] a	\N	\N
32c99805-f727-4e60-bbbd-45bc87722e5c	2018-02-28 13:02:30.198954-06	2	[16759] Lock DR-236 Relay	[4] DLarrabee	[21062] a	\N	\N
0f952815-66d5-47fa-b2fe-04d6cebae4ab	2018-02-28 13:02:30.211955-06	2	[16760] Lock DR-237A Relay	[4] DLarrabee	[21062] a	\N	\N
333b3c76-a5be-4a0b-85d5-a371a88a7c8c	2018-02-28 13:02:30.225957-06	2	[16761] Lock DR-237B Relay	[4] DLarrabee	[21062] a	\N	\N
866c3f7f-e757-48c8-a4a9-ff20b28adb5d	2018-02-28 13:02:54.270361-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
f034edcc-e618-402a-834c-d1a24c3d37c5	2018-02-28 13:03:17.099644-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
c4c50d57-5585-4ca9-acdd-2542ed9d5caa	2018-02-28 13:03:35.804514-06	2	[21055] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
f3071271-cdd2-461d-a326-9d2ee3df8f87	2018-02-28 13:03:56.840617-06	2	[17066] Lock DR-239 Relay	[4] DLarrabee	[21062] a	\N	\N
9612bc99-2bc7-41b2-82bd-b799dfe77616	2018-02-28 13:03:56.889622-06	2	[17067] Lock DR-241 Relay	[4] DLarrabee	[21062] a	\N	\N
0e35aff1-ff70-47d6-bd65-04d59b99fdad	2018-02-28 13:03:56.915625-06	2	[17068] Lock DR-242 Relay	[4] DLarrabee	[21062] a	\N	\N
e5ceb0d2-682c-4f17-817a-5a0e82ea8796	2018-02-28 13:03:56.929626-06	2	[17069] Lock DR-243 Relay	[4] DLarrabee	[21062] a	\N	\N
1ed22d99-2be7-46a7-b048-7c086c9f2f57	2018-02-28 13:03:56.945628-06	2	[17070] Lock DR-245 Relay	[4] DLarrabee	[21062] a	\N	\N
4927b8dd-318e-452b-ad65-068a6de41a7c	2018-02-28 13:03:56.96363-06	2	[17071] Lock DR-246 Relay	[4] DLarrabee	[21062] a	\N	\N
3e135418-0b2b-4167-bbcc-1b01eeaac2f9	2018-02-28 13:03:56.977631-06	2	[17072] Lock DR-247 Relay	[4] DLarrabee	[21062] a	\N	\N
4ad3b7a0-f0a7-4797-a515-6520c42855a0	2018-02-28 13:03:56.993633-06	2	[17073] Lock DR-248 Relay	[4] DLarrabee	[21062] a	\N	\N
7a5a0369-587b-4279-80ae-fc58bf667b3d	2018-02-28 13:03:57.013635-06	2	[17074] Lock DR-252 Relay	[4] DLarrabee	[21062] a	\N	\N
7da471c8-d95e-434a-b65b-f6fa0818dcf4	2018-02-28 13:03:57.028636-06	2	[17075] Lock DR-253 Relay	[4] DLarrabee	[21062] a	\N	\N
fce64dc2-a14a-49ed-984c-39e2b851aa24	2018-02-28 13:03:57.043638-06	2	[17076] Lock DR-259 Relay	[4] DLarrabee	[21062] a	\N	\N
0a42246a-b307-4104-b4b7-ae9286e1ca52	2018-02-28 13:03:57.060639-06	2	[17077] Lock DR-261 Relay	[4] DLarrabee	[21062] a	\N	\N
a7149557-4448-4396-9278-f4e6b5376b76	2018-02-28 13:03:57.073641-06	2	[17078] Lock DR-301A Relay	[4] DLarrabee	[21062] a	\N	\N
c2ad67b9-07b6-44d1-b6aa-6e32ed55dff4	2018-02-28 13:03:57.090642-06	2	[17079] Lock DR-301B Relay	[4] DLarrabee	[21062] a	\N	\N
73b4b4c1-16ce-4af2-9291-9122938082a9	2018-02-28 13:03:57.109644-06	2	[17080] Lock DR-306 Relay	[4] DLarrabee	[21062] a	\N	\N
37e3a90f-1b20-43b5-9b06-b8b10e7d8749	2018-02-28 13:04:06.311564-06	2	[21056] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
b4e0fd86-c77c-4506-9f02-e5dd3dc8987c	2018-02-28 13:04:19.833916-06	2	[21059] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
5d1b3625-34d2-43aa-b971-ac38fcced258	2018-02-28 13:09:11.239054-06	2	[21057] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
c9d23151-3b89-4a0c-a163-d2f93477fd3b	2018-02-28 13:09:23.429273-06	2	[21060] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
888c5b13-4f74-48ed-9766-b7d1258be6b6	2018-02-28 13:09:38.347765-06	2	[21058] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
fbd57bae-d2d4-49a3-b185-97d3def64031	2018-02-28 13:10:17.20965-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
a3f0d3a0-d128-4a1c-8574-83d3e79c32e8	2018-02-28 13:12:36.368565-06	2	[21088] Area Label	[21041] OSSI-DNOVAK	[293] master	\N	\N
cffd34a7-9ad2-41bb-894f-0c7bbb75f9da	2018-02-28 13:12:52.806208-06	2	[21088] Area Label	[21041] OSSI-DNOVAK	[293] master	\N	\N
3cdb7441-d83e-42a7-969f-6f0d144c54f9	2018-02-28 13:13:28.053733-06	2	[21088] Area Label	[21041] OSSI-DNOVAK	[293] master	\N	\N
ba37625e-9eed-445e-ae14-bc3a5e203145	2018-02-28 13:13:33.906318-06	1	[21089] Area Label Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
6e206072-968d-4c3c-966a-632fc2f62e8d	2018-02-28 13:13:53.952322-06	2	[21089] Area Label Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
260bb7bf-946f-4552-91a0-9f0d528257da	2018-02-28 13:13:58.037731-06	3	[21089] Area Label Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
d37db7a2-2dab-4489-abd3-dd08a1d66064	2018-02-28 13:14:18.141741-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
d4e7dcf8-d7fe-4f1a-a522-f32d82ba73b6	2018-02-28 13:14:56.420569-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
0df99022-30bd-4ce5-b619-44bcfbc40330	2018-02-28 13:15:16.653592-06	2	[21055] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
c435e4f8-0296-4337-9231-69396d3230df	2018-02-28 13:15:29.600886-06	2	[21055] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
42bf68d2-31e5-4a0f-99d3-6eb15bb41f91	2018-02-28 13:15:48.904817-06	2	[21056] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
882af62b-cee0-46e3-b08e-071f355f7a25	2018-02-28 13:16:00.448971-06	2	[21056] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
51b2c591-fe1a-4775-a58b-20372b670bf1	2018-02-28 13:16:21.458072-06	2	[21059] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
42fb1c64-5b68-442e-8ff6-83bf2b5f8e7e	2018-02-28 13:16:47.800706-06	2	[21057] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
f3f3602d-1986-44c6-8c1b-a369390b283c	2018-02-28 13:17:05.769502-06	2	[21060] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
12555e55-d82a-49c6-8a9e-f7e251c2b4d3	2018-02-28 13:17:19.654891-06	2	[21058] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
f6d5b2f6-dc3c-4243-8534-15cbbe0b91de	2018-02-28 13:17:48.862811-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
8b81a34f-d538-4de4-a8b5-3f43fe4954ef	2018-02-28 13:18:46.251549-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
1b78475f-409f-4276-ba53-54074e3601a0	2018-02-28 13:23:37.546676-06	2	[17383] RM 372 MAC Driver	[4] DLarrabee	[21062] a	\N	\N
272e07cc-d785-4a86-b3eb-5894d30f45a9	2018-02-28 13:36:30.753989-06	2	[18707] DPIS-307	[4] DLarrabee	[21062] a	\N	\N
1f290717-8ddb-4c2e-af90-dbbb30e1bccc	2018-02-28 13:36:30.826996-06	2	[18708] DPIS-309	[4] DLarrabee	[21062] a	\N	\N
bf71ad91-08b5-4a18-9299-84b552547bac	2018-02-28 13:36:30.845998-06	2	[18709] DPIS-314	[4] DLarrabee	[21062] a	\N	\N
995d7628-24cc-4c0e-aa80-e7bb3c96e981	2018-02-28 13:36:30.86-06	2	[18710] DPIS-322	[4] DLarrabee	[21062] a	\N	\N
89ba8d0e-4239-4339-b793-682f65b295a0	2018-02-28 13:36:30.874001-06	2	[18711] DPIS-324A	[4] DLarrabee	[21062] a	\N	\N
5ab8342e-2dd6-4a26-b3b6-41dda71cd08d	2018-02-28 13:36:30.887002-06	2	[18712] DPIS-324B 	[4] DLarrabee	[21062] a	\N	\N
c2707bb2-ab8a-466e-875e-fac9f47d4b89	2018-02-28 13:36:30.902004-06	2	[18713] DPIS-324C	[4] DLarrabee	[21062] a	\N	\N
4bcb4e30-89e9-4321-a368-c80771e7c792	2018-02-28 13:36:30.916005-06	2	[18714] DPIS-333	[4] DLarrabee	[21062] a	\N	\N
304807a6-649d-4316-baa1-49fc09604889	2018-02-28 13:36:30.930007-06	2	[18715] DPIS-330A	[4] DLarrabee	[21062] a	\N	\N
f89c0a97-7630-42d7-b0e6-3fba87d6f31f	2018-02-28 13:36:30.944008-06	2	[18716] DPIS-330B	[4] DLarrabee	[21062] a	\N	\N
3fd04ec0-eb87-4d1d-a0d4-98a8dc935b20	2018-02-28 13:36:30.96101-06	2	[18717] DPIS-378	[4] DLarrabee	[21062] a	\N	\N
d8962bab-a694-4af7-ba89-c9d550b1c3e1	2018-02-28 13:36:30.976011-06	2	[18718] DPIS-414A	[4] DLarrabee	[21062] a	\N	\N
59a3224f-a440-4944-a7ff-afabc974876b	2018-02-28 13:36:30.989013-06	2	[18719] DPIS-414B	[4] DLarrabee	[21062] a	\N	\N
0985aec3-2993-4cae-aaf1-0be97bfb015e	2018-02-28 13:36:31.003014-06	2	[18720] DPIS-323OHD	[4] DLarrabee	[21062] a	\N	\N
e62dc888-afad-4cf7-9246-2a27e4aa33cd	2018-02-28 13:36:31.020016-06	2	[18721] DPIS-324OHDE	[4] DLarrabee	[21062] a	\N	\N
ec6b15ff-6c08-4a03-bd70-d7d9b81e2ed1	2018-02-28 13:36:31.035017-06	2	[18722] DPIS-324OHDW	[4] DLarrabee	[21062] a	\N	\N
03d79853-0d1c-4538-9852-73975378ecc5	2018-02-28 13:36:31.052019-06	2	[18723] DPIS-342	[4] DLarrabee	[21062] a	\N	\N
e07d4c0e-5f1d-4424-ba10-6d1436415e53	2018-02-28 13:36:31.072021-06	2	[18724] DURESS-415	[4] DLarrabee	[21062] a	\N	\N
d9887a01-596d-4c59-8963-9e1139fbe78f	2018-02-28 13:36:31.088022-06	2	[18725] DURESS-418	[4] DLarrabee	[21062] a	\N	\N
77040940-0654-4868-9cb4-809449b5d67e	2018-02-28 13:36:31.103024-06	2	[18726] INPUT 20	[4] DLarrabee	[21062] a	\N	\N
b8cd9faa-9d0a-49bd-a51d-aa1024909dcc	2018-02-28 13:36:31.117025-06	2	[18727] INPUT 21	[4] DLarrabee	[21062] a	\N	\N
0cd4eacb-b0d0-487a-ab00-c85caec3126c	2018-02-28 13:36:31.132027-06	2	[18728] INPUT 22	[4] DLarrabee	[21062] a	\N	\N
b5740eb3-fd6e-4632-a5cd-708df2e88d4f	2018-02-28 13:36:31.146028-06	2	[18729] INPUT 23	[4] DLarrabee	[21062] a	\N	\N
c567b13c-d04c-471d-9eda-13296288de5d	2018-02-28 13:36:31.16203-06	2	[18730] INPUT 24	[4] DLarrabee	[21062] a	\N	\N
4b02965d-246f-4d1c-960b-06382017a80f	2018-02-28 13:36:31.180032-06	2	[18731] INPUT 25	[4] DLarrabee	[21062] a	\N	\N
bd097a9f-3c62-41a8-9427-d93e3f81b6ab	2018-02-28 13:36:31.199034-06	2	[18732] INPUT 26	[4] DLarrabee	[21062] a	\N	\N
824edc53-5836-4146-ad84-eab825037c44	2018-02-28 13:36:31.216035-06	2	[18733] INPUT 27	[4] DLarrabee	[21062] a	\N	\N
612156d9-7d85-4793-b8ae-879cb1d64f49	2018-02-28 13:36:31.231037-06	2	[18734] INPUT 28	[4] DLarrabee	[21062] a	\N	\N
ffa8a271-a942-4d88-b992-65492f4a940a	2018-02-28 13:36:31.246038-06	2	[18735] INPUT 29	[4] DLarrabee	[21062] a	\N	\N
01f843fd-1853-4a44-bd91-1290b9e35b06	2018-02-28 13:36:31.26504-06	2	[18736] INPUT 30	[4] DLarrabee	[21062] a	\N	\N
e8df9bc3-7ef4-44a9-a3b1-84352e0c48ba	2018-02-28 13:36:31.283042-06	2	[18737] INPUT 31	[4] DLarrabee	[21062] a	\N	\N
ce815c59-9cbb-4f36-ae7b-256b5d7ee9eb	2018-02-28 13:36:31.300044-06	2	[18738] INPUT 32	[4] DLarrabee	[21062] a	\N	\N
9afc1e4f-26c0-47e2-a4f0-627fa57f866d	2018-02-28 13:36:31.304044-06	2	[18774] DPIS-307 Supervision	[4] DLarrabee	[21062] a	\N	\N
93b9a8d3-9817-40bf-b5de-4c50416d0392	2018-02-28 13:36:31.309045-06	2	[18775] DPIS-309 Supervision	[4] DLarrabee	[21062] a	\N	\N
fb27f48d-b2a5-4c6a-b54a-8d7499b24bc5	2018-02-28 13:36:31.313045-06	2	[18776] DPIS-314 Supervision	[4] DLarrabee	[21062] a	\N	\N
bfcf270f-3f16-42f4-b6da-b069e3e91072	2018-02-28 13:36:31.316045-06	2	[18777] DPIS-322 Supervision	[4] DLarrabee	[21062] a	\N	\N
00b6456b-b9a9-45c0-a600-e6ce52a46b1c	2018-02-28 13:36:31.320046-06	2	[18778] DPIS-324A Supervision	[4] DLarrabee	[21062] a	\N	\N
978bedb5-45c0-4704-964a-42d622055a00	2018-02-28 13:36:31.323046-06	2	[18779] DPIS-324B  Supervision	[4] DLarrabee	[21062] a	\N	\N
2283ccae-ed75-4be4-a282-6155465492c9	2018-02-28 13:36:31.327046-06	2	[18780] DPIS-324C Supervision	[4] DLarrabee	[21062] a	\N	\N
adf383ba-d55a-4abb-9254-e0db5b07f04f	2018-02-28 13:36:31.331047-06	2	[18781] DPIS-333 Supervision	[4] DLarrabee	[21062] a	\N	\N
0b8dfd8c-a558-43c8-96db-8cf6e9de004a	2018-02-28 13:36:31.336047-06	2	[18782] DPIS-330A Supervision	[4] DLarrabee	[21062] a	\N	\N
1258efc2-c988-4d45-a919-78362b609531	2018-02-28 13:36:31.339048-06	2	[18783] DPIS-330B Supervision	[4] DLarrabee	[21062] a	\N	\N
34195740-309e-42e9-8c3c-e1887b8014b0	2018-02-28 13:36:31.342048-06	2	[18784] DPIS-378 Supervision	[4] DLarrabee	[21062] a	\N	\N
a1083527-fdce-4dce-bca0-cd0eec899979	2018-02-28 13:36:31.345048-06	2	[18785] DPIS-414A Supervision	[4] DLarrabee	[21062] a	\N	\N
1b86bc4a-1b89-45cd-b15d-67c6ae2f9f6e	2018-02-28 13:36:31.349049-06	2	[18786] DPIS-414B Supervision	[4] DLarrabee	[21062] a	\N	\N
335c8ad2-c2a7-4af4-bf49-124dd840b9da	2018-02-28 13:36:31.353049-06	2	[18787] DPIS-323OHD Supervision	[4] DLarrabee	[21062] a	\N	\N
3bbc9663-25f0-4195-ae46-31c71f2c7ae0	2018-02-28 13:36:31.357049-06	2	[18788] DPIS-324OHDE Supervision	[4] DLarrabee	[21062] a	\N	\N
90b05ce9-1cae-4d21-8702-abf5c1777d23	2018-02-28 13:36:31.36105-06	2	[18789] DPIS-324OHDW Supervision	[4] DLarrabee	[21062] a	\N	\N
32f927f6-e84f-46d0-9218-7e109649ed4d	2018-02-28 13:36:31.36505-06	2	[18790] DPIS-342 Supervision	[4] DLarrabee	[21062] a	\N	\N
f4dcd9ac-cbc6-4d7b-a31a-54abb11552f8	2018-02-28 13:36:31.369051-06	2	[18791] DURESS-415 Supervision	[4] DLarrabee	[21062] a	\N	\N
5410371f-f22a-466e-bfca-f656ac0f5eab	2018-02-28 13:36:31.372051-06	2	[18792] DURESS-418 Supervision	[4] DLarrabee	[21062] a	\N	\N
c26c21c2-45c4-4dcf-8adc-e507edf627dc	2018-02-28 13:36:31.375051-06	2	[18793] INPUT 20 Supervision	[4] DLarrabee	[21062] a	\N	\N
78d0703c-729f-4fac-9cd9-dd3d819442b4	2018-02-28 13:36:31.378051-06	2	[18794] INPUT 21 Supervision	[4] DLarrabee	[21062] a	\N	\N
cc70230b-ee61-41bb-808f-9dec18863627	2018-02-28 13:36:31.382052-06	2	[18795] INPUT 22 Supervision	[4] DLarrabee	[21062] a	\N	\N
6bb5316e-eddd-4e8f-9378-5a868e72feac	2018-02-28 13:36:31.384052-06	2	[18796] INPUT 23 Supervision	[4] DLarrabee	[21062] a	\N	\N
2c19bb69-6eaf-402b-a6eb-c62407672480	2018-02-28 13:36:31.389053-06	2	[18797] INPUT 24 Supervision	[4] DLarrabee	[21062] a	\N	\N
a444ba7c-0f9c-4aa4-97c6-b319e3ae2de5	2018-02-28 13:36:31.392053-06	2	[18798] INPUT 25 Supervision	[4] DLarrabee	[21062] a	\N	\N
5a7d3a26-7f63-4ed1-a2dc-55942548de89	2018-02-28 13:36:31.395053-06	2	[18799] INPUT 26 Supervision	[4] DLarrabee	[21062] a	\N	\N
eee92d73-085e-42d1-b969-a3edb84ee722	2018-02-28 13:36:31.399054-06	2	[18800] INPUT 27 Supervision	[4] DLarrabee	[21062] a	\N	\N
ebc5bb62-d092-410b-acfb-2e405faf2aa2	2018-02-28 13:36:31.403054-06	2	[18801] INPUT 28 Supervision	[4] DLarrabee	[21062] a	\N	\N
464c2400-de3d-4c25-9db3-ce2c4d7cfe9c	2018-02-28 13:36:31.407054-06	2	[18802] INPUT 29 Supervision	[4] DLarrabee	[21062] a	\N	\N
2e3bdb6f-ace8-4916-b843-6084b0028f3d	2018-02-28 13:36:31.411055-06	2	[18803] INPUT 30 Supervision	[4] DLarrabee	[21062] a	\N	\N
7cd0873a-71ca-4459-a905-039b5211ac85	2018-02-28 13:36:31.415055-06	2	[18804] INPUT 31 Supervision	[4] DLarrabee	[21062] a	\N	\N
fddd6af7-d40f-41cf-9e0a-c82fc40c037a	2018-02-28 13:36:31.418055-06	2	[18805] INPUT 32 Supervision	[4] DLarrabee	[21062] a	\N	\N
abcc76f6-ebe3-4f80-a7c1-8a2bf00305b0	2018-02-28 13:39:21.48106-06	2	[19175] Lock DR-307 Relay	[4] DLarrabee	[21062] a	\N	\N
5ed89e33-9754-4f80-95ba-163f0e12361d	2018-02-28 13:39:21.502062-06	2	[19176] Lock DR-309 Relay	[4] DLarrabee	[21062] a	\N	\N
4d5c80b3-5e5f-470c-a778-3c6d4dc2078a	2018-02-28 13:39:21.514063-06	2	[19177] Lock DR-314 Relay	[4] DLarrabee	[21062] a	\N	\N
157ca0a1-4609-4c5e-9650-1b8d9e4bc49f	2018-02-28 13:39:21.531065-06	2	[19178] Lock DR-322 Relay	[4] DLarrabee	[21062] a	\N	\N
86a24cd3-cd50-4c7a-9971-5a904265eb83	2018-02-28 13:39:21.552067-06	2	[19179] Lock DR-324A Relay	[4] DLarrabee	[21062] a	\N	\N
c85ebd14-b967-4a32-8ec0-d4fef10a0c0b	2018-02-28 13:39:21.568069-06	2	[19180] Lock DR-324B Relay	[4] DLarrabee	[21062] a	\N	\N
9e81f219-cf2b-4988-b536-eb90cb60a6b9	2018-02-28 13:39:21.58407-06	2	[19181] Lock DR-324C Relay	[4] DLarrabee	[21062] a	\N	\N
b5a91a3a-99fb-4553-941d-4d1b58c2b829	2018-02-28 13:39:21.601072-06	2	[19182] Lock DR-333 Relay	[4] DLarrabee	[21062] a	\N	\N
f3add258-6ead-4d70-888e-e19ae74bc256	2018-02-28 13:39:21.613073-06	2	[19183] Lock DR-330A Relay	[4] DLarrabee	[21062] a	\N	\N
5236b876-715e-46c8-8150-44ee2d216079	2018-02-28 13:39:21.630075-06	2	[19184] Lock DR-330B Relay	[4] DLarrabee	[21062] a	\N	\N
3a3b81ce-f680-4ff5-90f7-9c9b79b10417	2018-02-28 13:39:21.643076-06	2	[19185] Lock DR-378 Relay	[4] DLarrabee	[21062] a	\N	\N
542587bd-ec36-427f-81c5-6e4902f4c791	2018-02-28 13:39:21.657078-06	2	[19186] Lock DR-414A Relay	[4] DLarrabee	[21062] a	\N	\N
22a978bf-42e1-4656-9280-45b97a7be596	2018-02-28 13:39:21.67908-06	2	[19187] Lock DR-414B Relay	[4] DLarrabee	[21062] a	\N	\N
d4c57db8-5613-43cb-8086-f1675ad63fb3	2018-02-28 13:39:21.704082-06	2	[19188] OPEN DR-323OHD Relay	[4] DLarrabee	[21062] a	\N	\N
260a87f8-7b05-4c20-9e02-7d15ebc8bf7a	2018-02-28 13:39:21.724084-06	2	[19189] CLOSE DR-323OHD Relay	[4] DLarrabee	[21062] a	\N	\N
bf165fb5-c4d1-4377-b0cb-7a275fa3053b	2018-02-28 13:39:21.737086-06	2	[19190] OPEN DR-324OHDE Relay	[4] DLarrabee	[21062] a	\N	\N
3b7af2b2-100f-40bc-a136-6fbe4599d24e	2018-02-28 13:41:43.330244-06	2	[19495] CLOSE DR-324OHDE Relay	[4] DLarrabee	[21062] a	\N	\N
07250d7f-5acf-4e27-90d2-1d5856208882	2018-02-28 13:41:43.352246-06	2	[19496] OPEN DR-324OHDW Relay	[4] DLarrabee	[21062] a	\N	\N
92c47bcd-375a-4928-9875-2409f4a1368d	2018-02-28 13:41:43.369247-06	2	[19497] CLOSE DR-324OHDW Relay	[4] DLarrabee	[21062] a	\N	\N
77601267-d226-494c-9dda-66a58a365d0e	2018-02-28 13:43:30.796989-06	1	[21089] Default Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
ac65e77e-bfae-4d6c-9260-75a9598c01e9	2018-02-28 13:45:21.038012-06	2	[19188] OPEN-323OHD Relay	[4] DLarrabee	[21062] a	\N	\N
402aa8c9-b770-47b6-92fa-009dfa2a58da	2018-02-28 13:45:21.059014-06	2	[19189] CLOSE-323OHD Relay	[4] DLarrabee	[21062] a	\N	\N
43cd7965-179f-4997-89b0-c50c40b38d2a	2018-02-28 13:45:21.077016-06	2	[19190] OPEN-324OHDE Relay	[4] DLarrabee	[21062] a	\N	\N
407ebe03-5453-4ad4-a5be-fb9e97562851	2018-02-28 13:45:46.334542-06	2	[21089] Weber Valley	[21041] OSSI-DNOVAK	[293] master	\N	\N
a6d867ad-7464-4400-8a28-d1b8502d1ea0	2018-02-28 13:46:05.839492-06	2	[293] master	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef5ed1fb-5564-49bf-b762-3380c3c5a445	2018-02-28 13:46:52.305138-06	2	[19495] CLOSE-324OHDE Relay	[4] DLarrabee	[21062] a	\N	\N
b1610f6a-e604-429f-9876-d5ac8cd6799c	2018-02-28 13:46:52.339141-06	2	[19496] OPEN-324OHDW Relay	[4] DLarrabee	[21062] a	\N	\N
b9708add-74f7-4915-b011-47bba4c2b59a	2018-02-28 13:46:52.356143-06	2	[19497] CLOSE-324OHDW Relay	[4] DLarrabee	[21062] a	\N	\N
f3a7c176-c7b6-443d-bb8e-2247ae9a6cfa	2018-02-28 13:47:18.409748-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
1f1375b1-02df-4711-9d7b-1b8f8b1f0e39	2018-02-28 13:49:37.974703-06	2	[21089] Weber Valley	[21041] OSSI-DNOVAK	[293] master	\N	\N
602afdb8-ff40-45bf-aaf3-7da5dacb226f	2018-02-28 13:50:35.320437-06	2	[21089] Weber Valley	[21041] OSSI-DNOVAK	[293] master	\N	\N
763f525f-90f3-499b-80e9-01392a135244	2018-02-28 13:51:04.74738-06	2	[21089] Weber Valley	[21041] OSSI-DNOVAK	[293] master	\N	\N
95e3c0c1-9c44-4239-a293-9be184565dd0	2018-02-28 13:55:27.394642-06	2	[19815] DPIS-429A	[4] DLarrabee	[21062] a	\N	\N
9222fff0-8ba8-43a0-ae67-2f8f5d0b96cd	2018-02-28 13:55:27.411643-06	2	[19816] DPIS-429B	[4] DLarrabee	[21062] a	\N	\N
bc20fd7a-e3b8-4c57-98ce-5b088f7e48ab	2018-02-28 13:55:27.427645-06	2	[19817] DPIS-429C	[4] DLarrabee	[21062] a	\N	\N
8da890cb-916c-473e-9626-faadb63bf1e5	2018-02-28 13:55:27.442647-06	2	[19818] DPIS-456	[4] DLarrabee	[21062] a	\N	\N
65888cce-d29c-4c8f-931f-1119afbbe1ea	2018-02-28 13:55:27.458648-06	2	[19819] DPIS-461	[4] DLarrabee	[21062] a	\N	\N
58f2f0db-5e0e-47a5-976f-d89f968f2824	2018-02-28 13:55:27.47365-06	2	[19820] DPIS-514	[4] DLarrabee	[21062] a	\N	\N
6e912996-9a42-4e8e-84de-f4cd9267e240	2018-02-28 13:55:27.490651-06	2	[19821] DPIS-529	[4] DLarrabee	[21062] a	\N	\N
97b13496-9c43-4f3b-a44d-46845056cc27	2018-02-28 13:55:27.506653-06	2	[19822] DURESS-425	[4] DLarrabee	[21062] a	\N	\N
0d5b0b49-9051-4668-bc3a-bc6fe7515084	2018-02-28 13:55:27.522655-06	2	[19823] DURESS-428	[4] DLarrabee	[21062] a	\N	\N
59c22866-6800-4741-9be4-c040f627120b	2018-02-28 13:55:27.537656-06	2	[19824] DURESS-463	[4] DLarrabee	[21062] a	\N	\N
1a060f46-5b90-4a26-a5b7-7ca8daef35c6	2018-02-28 13:55:27.556658-06	2	[19825] DURESS-465	[4] DLarrabee	[21062] a	\N	\N
831d0138-ce02-4014-9e3b-31dc5594397e	2018-02-28 13:55:27.570659-06	2	[19826] DURESS-514	[4] DLarrabee	[21062] a	\N	\N
353a3280-1b69-43c9-acd5-3e2a35c62c2f	2018-02-28 13:55:27.585661-06	2	[19827] DURESS-529	[4] DLarrabee	[21062] a	\N	\N
811ca5a3-fbcb-4942-9752-1201c2ba55a5	2018-02-28 13:55:27.601662-06	2	[19828] INPUT 14	[4] DLarrabee	[21062] a	\N	\N
7e4a121a-d085-4504-a181-a917a56dafc5	2018-02-28 13:55:27.614664-06	2	[19829] INPUT 15	[4] DLarrabee	[21062] a	\N	\N
37dddcea-8e0f-4948-8dea-27972fa779fa	2018-02-28 13:55:27.627665-06	2	[19830] INPUT 16	[4] DLarrabee	[21062] a	\N	\N
c1ef897c-6e2f-4bca-b58b-7f1a60c27e3e	2018-02-28 13:55:27.640666-06	2	[19831] INPUT 17	[4] DLarrabee	[21062] a	\N	\N
8564ffb9-0196-4efb-9397-626a143da921	2018-02-28 13:55:27.653668-06	2	[19832] INPUT 18	[4] DLarrabee	[21062] a	\N	\N
a9033421-4261-48a6-93b9-c5ef45a3e261	2018-02-28 13:55:27.665669-06	2	[19833] INPUT 19	[4] DLarrabee	[21062] a	\N	\N
376e85b7-d3c8-440b-a655-e61e740a32e8	2018-02-28 13:55:27.67967-06	2	[19834] INPUT 20	[4] DLarrabee	[21062] a	\N	\N
da95b60d-459a-451e-8e51-5e3ed501666a	2018-02-28 13:55:27.691671-06	2	[19835] INPUT 21	[4] DLarrabee	[21062] a	\N	\N
d57b285b-5592-4f9f-b609-f011bd9304c0	2018-02-28 13:55:27.707673-06	2	[19836] INPUT 22	[4] DLarrabee	[21062] a	\N	\N
0215853e-dfd5-4248-a3d5-8092332a6a40	2018-02-28 13:55:27.720674-06	2	[19837] INPUT 23	[4] DLarrabee	[21062] a	\N	\N
50698f32-fdf0-444b-a50b-74e2e1884542	2018-02-28 13:55:27.735676-06	2	[19838] INPUT 24	[4] DLarrabee	[21062] a	\N	\N
4a264f01-40ca-4755-bbf0-dc9f7726fbf2	2018-02-28 13:55:27.754678-06	2	[19839] INPUT 25	[4] DLarrabee	[21062] a	\N	\N
55bbd156-ff41-4b24-9d8b-071e3e0598cf	2018-02-28 13:55:27.77468-06	2	[19840] INPUT 26	[4] DLarrabee	[21062] a	\N	\N
2e75d061-87cc-4e8b-8f98-7bcabcce94b6	2018-02-28 13:55:27.793682-06	2	[19841] INPUT 27	[4] DLarrabee	[21062] a	\N	\N
3bdf770e-4272-4978-aae6-3030fe2eba04	2018-02-28 13:55:27.806683-06	2	[19842] INPUT 28	[4] DLarrabee	[21062] a	\N	\N
5a624dd2-9065-4d16-ba10-273ab25d5b01	2018-02-28 13:55:27.819684-06	2	[19843] INPUT 29	[4] DLarrabee	[21062] a	\N	\N
b18ac2fe-a6fb-4c49-a8f9-b5862bb04703	2018-02-28 13:55:27.832686-06	2	[19844] INPUT 30	[4] DLarrabee	[21062] a	\N	\N
425e7328-c4df-466d-9917-43099164e07b	2018-02-28 13:55:27.844687-06	2	[19845] INPUT 31	[4] DLarrabee	[21062] a	\N	\N
b4e44ac4-0cb4-44ba-a80e-691078b99c4a	2018-02-28 13:55:27.860688-06	2	[19846] INPUT 32	[4] DLarrabee	[21062] a	\N	\N
8002e8c9-6f63-4ae3-bf60-71c1225aa420	2018-02-28 13:55:27.862689-06	2	[19882] DPIS-429A Supervision	[4] DLarrabee	[21062] a	\N	\N
07115cbf-4ba4-4f6c-9746-01230eeed53c	2018-02-28 13:55:27.865689-06	2	[19883] DPIS-429B Supervision	[4] DLarrabee	[21062] a	\N	\N
c6840368-ab41-404e-93b6-3575d98eb642	2018-02-28 13:55:27.869689-06	2	[19884] DPIS-429C Supervision	[4] DLarrabee	[21062] a	\N	\N
3f8a5207-38da-43b0-a252-2a1f838a14b7	2018-02-28 13:55:27.87369-06	2	[19885] DPIS-456 Supervision	[4] DLarrabee	[21062] a	\N	\N
068c9a10-a31b-418c-af58-f5bcc440cfc1	2018-02-28 13:55:27.87669-06	2	[19886] DPIS-461 Supervision	[4] DLarrabee	[21062] a	\N	\N
94b2506d-da21-4f21-bc7b-7ff83efa27f8	2018-02-28 13:55:27.87969-06	2	[19887] DPIS-514 Supervision	[4] DLarrabee	[21062] a	\N	\N
63a327c4-6678-4ae7-9721-ecfd1f9f966d	2018-02-28 13:55:27.883691-06	2	[19888] DPIS-529 Supervision	[4] DLarrabee	[21062] a	\N	\N
c6ff65ee-7498-4d97-be29-638b383fd1da	2018-02-28 13:55:27.886691-06	2	[19889] DURESS-425 Supervision	[4] DLarrabee	[21062] a	\N	\N
0c535e1d-9de0-4922-99ee-5f0516e27af3	2018-02-28 13:55:27.889691-06	2	[19890] DURESS-428 Supervision	[4] DLarrabee	[21062] a	\N	\N
db32514a-4c0b-4830-be6f-8ccfbac461f2	2018-02-28 13:55:27.891691-06	2	[19891] DURESS-463 Supervision	[4] DLarrabee	[21062] a	\N	\N
273ab20e-320c-4f85-8f3b-707a28292358	2018-02-28 13:55:27.894692-06	2	[19892] DURESS-465 Supervision	[4] DLarrabee	[21062] a	\N	\N
fe3b153f-8649-4b58-9e59-e72483b01b65	2018-02-28 13:55:27.897692-06	2	[19893] DURESS-514 Supervision	[4] DLarrabee	[21062] a	\N	\N
6c7cdad5-412c-49f3-a091-ef6f5b7dbd46	2018-02-28 13:55:27.902693-06	2	[19894] DURESS-529 Supervision	[4] DLarrabee	[21062] a	\N	\N
104eaeec-7c52-482d-ae0e-94c3e0592720	2018-02-28 13:55:27.906693-06	2	[19895] INPUT 14 Supervision	[4] DLarrabee	[21062] a	\N	\N
3787e4d3-d27b-4445-9d9c-fa81a803058c	2018-02-28 13:55:27.910693-06	2	[19896] INPUT 15 Supervision	[4] DLarrabee	[21062] a	\N	\N
9f715a4f-fad9-4041-8ef7-28904716e1c1	2018-02-28 13:55:27.914694-06	2	[19897] INPUT 16 Supervision	[4] DLarrabee	[21062] a	\N	\N
813958a2-39ee-4ee3-9ba7-e1becc7c82a5	2018-02-28 13:55:27.917694-06	2	[19898] INPUT 17 Supervision	[4] DLarrabee	[21062] a	\N	\N
dbe616ec-d607-4090-927b-adfb06eb6235	2018-02-28 13:55:27.920694-06	2	[19899] INPUT 18 Supervision	[4] DLarrabee	[21062] a	\N	\N
ab1c6b15-fc30-4ab6-8354-df708a3325fb	2018-02-28 13:55:27.923695-06	2	[19900] INPUT 19 Supervision	[4] DLarrabee	[21062] a	\N	\N
67f1e955-9763-4bdf-875b-2cc38ed5a113	2018-02-28 13:55:27.926695-06	2	[19901] INPUT 20 Supervision	[4] DLarrabee	[21062] a	\N	\N
dcd4dc2d-446e-4137-826a-06c2d76d42de	2018-02-28 13:55:27.930695-06	2	[19902] INPUT 21 Supervision	[4] DLarrabee	[21062] a	\N	\N
41e911e2-cf66-42e5-9157-94241ad9ed6c	2018-02-28 13:55:27.934696-06	2	[19903] INPUT 22 Supervision	[4] DLarrabee	[21062] a	\N	\N
9645621b-0d90-4d59-91f8-ed4afa56debf	2018-02-28 13:55:27.938696-06	2	[19904] INPUT 23 Supervision	[4] DLarrabee	[21062] a	\N	\N
1cc5158a-80ba-46d5-aa05-29d72dd1b800	2018-02-28 13:55:27.942697-06	2	[19905] INPUT 24 Supervision	[4] DLarrabee	[21062] a	\N	\N
2a5e0d36-97e2-45c3-a643-43474c0d9d2b	2018-02-28 13:55:27.946697-06	2	[19906] INPUT 25 Supervision	[4] DLarrabee	[21062] a	\N	\N
98b686d9-9f25-41c2-ade8-929f1d6e61a2	2018-02-28 13:55:27.950697-06	2	[19907] INPUT 26 Supervision	[4] DLarrabee	[21062] a	\N	\N
909d7ad5-2d28-482e-9130-99f128508e5b	2018-02-28 13:55:27.954698-06	2	[19908] INPUT 27 Supervision	[4] DLarrabee	[21062] a	\N	\N
f371995f-a022-4a7b-8bf9-b573a236b8d0	2018-02-28 13:55:27.957698-06	2	[19909] INPUT 28 Supervision	[4] DLarrabee	[21062] a	\N	\N
98613371-60b7-4d0d-b85f-1d32b6010375	2018-02-28 13:55:27.962699-06	2	[19910] INPUT 29 Supervision	[4] DLarrabee	[21062] a	\N	\N
42495e94-e7b7-4ca7-a6a2-c478dc6afd14	2018-02-28 13:55:27.966699-06	2	[19911] INPUT 30 Supervision	[4] DLarrabee	[21062] a	\N	\N
9d3ab5e9-e657-4d69-80b5-98c6289278cb	2018-02-28 13:55:27.968699-06	2	[19912] INPUT 31 Supervision	[4] DLarrabee	[21062] a	\N	\N
b3d23386-92e6-476a-b14a-fe40e0dd9527	2018-02-28 13:55:27.971699-06	2	[19913] INPUT 32 Supervision	[4] DLarrabee	[21062] a	\N	\N
4f4ea80c-48fb-4cef-be1b-82aeb1dfd0a7	2018-02-28 14:02:20.0189-06	2	[20291] OUTPUT 8	[4] DLarrabee	[21062] a	\N	\N
85a344b5-4a86-4a1f-b73f-30a346010837	2018-02-28 14:02:20.056904-06	2	[20292] OUTPUT 9	[4] DLarrabee	[21062] a	\N	\N
2bb43984-2a88-479a-bd9f-84e3263cbb21	2018-02-28 14:02:20.070905-06	2	[20293] OUTPUT 10	[4] DLarrabee	[21062] a	\N	\N
5e014977-2a9d-4138-91de-ec2de124d0f3	2018-02-28 14:02:20.083907-06	2	[20294] OUTPUT 11	[4] DLarrabee	[21062] a	\N	\N
26c98219-3f5f-4cf8-bb80-b9a61c312692	2018-02-28 14:02:20.096908-06	2	[20295] OUTPUT 12	[4] DLarrabee	[21062] a	\N	\N
2c6356f5-7cee-4dc3-b5d6-bd74b991759f	2018-02-28 14:02:20.108909-06	2	[20296] OUTPUT 13	[4] DLarrabee	[21062] a	\N	\N
130a99ac-c976-40f2-8a0e-8d28223bbff1	2018-02-28 14:02:20.127911-06	2	[20297] OUTPUT 14	[4] DLarrabee	[21062] a	\N	\N
8b5023b0-a9dc-4af4-83d0-d6d7e58dd5c8	2018-02-28 14:02:20.141912-06	2	[20298] OUTPUT 15	[4] DLarrabee	[21062] a	\N	\N
f529bda7-ac31-4ee0-a8db-88c11dad716c	2018-02-28 14:02:20.154914-06	2	[20299] OUTPUT 16	[4] DLarrabee	[21062] a	\N	\N
9f726f73-1d49-49b5-b36c-a32fe005575e	2018-02-28 14:05:06.389535-06	2	[20610] IC- 8 Call Button	[4] DLarrabee	[21062] a	\N	\N
b0773304-a623-46ed-ba6b-5e9956dd75eb	2018-02-28 14:05:06.395536-06	2	[20661] IC- 8 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9889587d-5452-43bd-bc8f-2c7e4acab8c7	2018-02-28 14:06:58.992795-06	2	[20619] IC-8 Relay	[4] DLarrabee	[21062] a	\N	\N
f24646a8-fc00-4724-b779-9c63a5ffa346	2018-02-28 14:06:58.996795-06	2	[20628] IC-8 Connect	[4] DLarrabee	[21062] a	\N	\N
efb9ef19-4eff-4fb3-89a0-7151d8237bd5	2018-02-28 14:06:59.000795-06	2	[20680] IC-8 Call	[4] DLarrabee	[21062] a	\N	\N
be2f248e-9f47-419b-b582-e2f175d58a91	2018-02-28 14:08:06.218517-06	2	[19812] RM 474 MAC Driver	[4] DLarrabee	[21062] a	\N	\N
c91438d7-d196-428f-aeff-a742a565be11	2018-02-28 14:11:07.150608-06	2	[21089] Weber Valley	[21041] OSSI-DNOVAK	[293] master	\N	\N
b2e16822-254d-4a29-8535-5e22844e663d	2018-02-28 14:11:15.947488-06	2	[19498] Output 4	[4] DLarrabee	[21062] a	\N	\N
b5a5e101-ecb7-4a31-801d-fa4c9854951c	2018-02-28 14:11:15.963489-06	2	[19499] Output 5	[4] DLarrabee	[21062] a	\N	\N
22cb6e51-4b46-4ca3-b9fa-9ba0d1b4df0a	2018-02-28 14:11:15.982491-06	2	[19500] Output 6	[4] DLarrabee	[21062] a	\N	\N
2e52b895-612e-4e51-9891-60f862cb2ea9	2018-02-28 14:11:15.994492-06	2	[19501] Output 7	[4] DLarrabee	[21062] a	\N	\N
db885d30-d5f9-4eec-965f-4675eda7d9fd	2018-02-28 14:11:16.015494-06	2	[19502] Output 8	[4] DLarrabee	[21062] a	\N	\N
1566e6ff-4e62-4bb1-b632-c81d24f460d1	2018-02-28 14:11:16.032496-06	2	[19503] Output 9	[4] DLarrabee	[21062] a	\N	\N
5143feb4-ca59-406f-b91b-2df742fa7ea1	2018-02-28 14:11:16.048498-06	2	[19504] Output 10	[4] DLarrabee	[21062] a	\N	\N
cef9f971-3e3d-45fc-92e1-2d9f5ef632ef	2018-02-28 14:11:16.064499-06	2	[19505] Output 11	[4] DLarrabee	[21062] a	\N	\N
926c4b59-d4d0-4b19-8ca6-cb4f8a8c9d4f	2018-02-28 14:11:16.081501-06	2	[19506] Output 12	[4] DLarrabee	[21062] a	\N	\N
b047f369-0543-4e9b-af24-8e84e99503a1	2018-02-28 14:11:16.093502-06	2	[19507] Output 13	[4] DLarrabee	[21062] a	\N	\N
7280bd8b-3b4f-465b-ba03-df17c7b65730	2018-02-28 14:11:16.108504-06	2	[19508] Output 14	[4] DLarrabee	[21062] a	\N	\N
0d3ef826-99f7-4d18-a489-7d6eb5a16b46	2018-02-28 14:11:16.127506-06	2	[19509] Output 15	[4] DLarrabee	[21062] a	\N	\N
e5d14210-0a9f-4289-8355-654ecf27857a	2018-02-28 14:11:16.147508-06	2	[19510] Output 16	[4] DLarrabee	[21062] a	\N	\N
d13fca68-c691-46ae-95a1-f9c531c7ffc5	2018-02-28 14:12:24.0813-06	2	[21089] Weber Valley	[21041] OSSI-DNOVAK	[293] master	\N	\N
b3dc4905-737f-4c11-808a-2cd420d80411	2018-02-28 14:12:39.625855-06	2	[20291] Output 8	[4] DLarrabee	[21062] a	\N	\N
cd3f6204-92e5-4f0a-963c-fae442951589	2018-02-28 14:12:39.642856-06	2	[20292] Output 9	[4] DLarrabee	[21062] a	\N	\N
f78fccb6-7803-4d5f-b730-1eef172117ba	2018-02-28 14:12:39.660858-06	2	[20293] Output 10	[4] DLarrabee	[21062] a	\N	\N
b3eb8715-9c75-49aa-bf9e-de33541f848e	2018-02-28 14:12:39.67586-06	2	[20294] Output 11	[4] DLarrabee	[21062] a	\N	\N
a44cce5e-d81a-44d0-b4f1-a8a21f1b468f	2018-02-28 14:12:39.693861-06	2	[20295] Output 12	[4] DLarrabee	[21062] a	\N	\N
cda6a16f-a699-4e55-9a2a-8a2dd6d63a7b	2018-02-28 14:12:39.708863-06	2	[20296] Output 13	[4] DLarrabee	[21062] a	\N	\N
c1585ae4-cd95-4b8e-8505-56f4f35de1ea	2018-02-28 14:12:39.723864-06	2	[20297] Output 14	[4] DLarrabee	[21062] a	\N	\N
797e7c24-893f-41f6-90d3-8a5fa01b6797	2018-02-28 14:12:39.744866-06	2	[20298] Output 15	[4] DLarrabee	[21062] a	\N	\N
618c94ab-bd7d-4e03-b7fa-88058a683c19	2018-02-28 14:12:39.763868-06	2	[20299] Output 16	[4] DLarrabee	[21062] a	\N	\N
8b6f9076-ae7a-4aaf-9d38-e3e06035ee4b	2018-02-28 14:15:20.628953-06	2	[19828] Input 14	[4] DLarrabee	[21062] a	\N	\N
fdc74d26-f740-44f7-b4e0-ec7ee0bcc9f1	2018-02-28 14:15:20.642955-06	2	[19829] Input 15	[4] DLarrabee	[21062] a	\N	\N
b5704a21-c22d-4ac6-bd10-309c3a61e685	2018-02-28 14:15:20.655956-06	2	[19830] Input 16	[4] DLarrabee	[21062] a	\N	\N
22360eed-9fb7-4b03-b51a-bfcd45923576	2018-02-28 14:15:20.668957-06	2	[19831] Input 17	[4] DLarrabee	[21062] a	\N	\N
78d4a7f9-a88f-4fab-ab84-cd2ae1934e2e	2018-02-28 14:15:20.686959-06	2	[19832] Input 18	[4] DLarrabee	[21062] a	\N	\N
2d0e0503-c382-4ef6-a23c-39be9ddf9228	2018-02-28 14:15:20.702961-06	2	[19833] Input 19	[4] DLarrabee	[21062] a	\N	\N
48160cd7-da0b-4361-b31a-a3cb430bb37c	2018-02-28 14:15:20.719962-06	2	[19834] Input 20	[4] DLarrabee	[21062] a	\N	\N
9d015a60-4069-4487-9477-11c972dbf137	2018-02-28 14:15:20.735964-06	2	[19835] Input 21	[4] DLarrabee	[21062] a	\N	\N
66308000-7a22-4d2c-a5ed-d598f4cd57a5	2018-02-28 14:15:20.748965-06	2	[19836] Input 22	[4] DLarrabee	[21062] a	\N	\N
d7c2e636-a511-4ed4-add3-6ad515c0bd91	2018-02-28 14:15:20.767967-06	2	[19837] Input 23	[4] DLarrabee	[21062] a	\N	\N
210aa2aa-c465-41e6-8639-e61edeb246ae	2018-02-28 14:15:20.786969-06	2	[19838] Input 24	[4] DLarrabee	[21062] a	\N	\N
d49822d4-8e96-43e9-b835-a082adcaca2b	2018-02-28 14:15:20.806971-06	2	[19839] Input 25	[4] DLarrabee	[21062] a	\N	\N
13f45879-b615-4878-a53a-b9fe68020d51	2018-02-28 14:15:20.825973-06	2	[19840] Input 26	[4] DLarrabee	[21062] a	\N	\N
86927454-5786-4a44-a23c-4cc008bad355	2018-02-28 14:15:20.838974-06	2	[19841] Input 27	[4] DLarrabee	[21062] a	\N	\N
d7a9376e-bc45-4f03-ba9e-fc496e6dabf5	2018-02-28 14:15:20.852976-06	2	[19842] Input 28	[4] DLarrabee	[21062] a	\N	\N
e98c3a59-df8a-4850-8778-fb099beb8f16	2018-02-28 14:15:20.867977-06	2	[19843] Input 29	[4] DLarrabee	[21062] a	\N	\N
e84a0470-7450-4e32-84ea-0bcf6847bc46	2018-02-28 14:15:20.880978-06	2	[19844] Input 30	[4] DLarrabee	[21062] a	\N	\N
88781870-96b7-4de7-9e8f-5664de5c1450	2018-02-28 14:15:20.89498-06	2	[19845] Input 31	[4] DLarrabee	[21062] a	\N	\N
f6aaecc4-d535-4d23-91c4-8642f22f6a67	2018-02-28 14:15:20.907981-06	2	[19846] Input 32	[4] DLarrabee	[21062] a	\N	\N
b8223988-14e5-4b06-9fe8-c2144b99d435	2018-02-28 14:15:20.911982-06	2	[19895] Input 14 Supervision	[4] DLarrabee	[21062] a	\N	\N
0fb0520d-60e4-4d9f-ab4d-971a16f99749	2018-02-28 14:15:20.914982-06	2	[19896] Input 15 Supervision	[4] DLarrabee	[21062] a	\N	\N
f241db72-933d-4dc8-b13a-892eb1b70d32	2018-02-28 14:15:20.918982-06	2	[19897] Input 16 Supervision	[4] DLarrabee	[21062] a	\N	\N
09ccf6de-8247-4caa-91eb-f07af20ca542	2018-02-28 14:15:20.921983-06	2	[19898] Input 17 Supervision	[4] DLarrabee	[21062] a	\N	\N
02a02ebf-3d30-4728-8af8-73c189b01330	2018-02-28 14:15:20.924983-06	2	[19899] Input 18 Supervision	[4] DLarrabee	[21062] a	\N	\N
9d752c52-cabe-458a-b3c7-215d41e59cb3	2018-02-28 14:15:20.927983-06	2	[19900] Input 19 Supervision	[4] DLarrabee	[21062] a	\N	\N
bc36d28b-10e1-4964-ab24-945a90e01581	2018-02-28 14:15:20.930983-06	2	[19901] Input 20 Supervision	[4] DLarrabee	[21062] a	\N	\N
399fb634-8b01-4539-9947-ec3f5b2e64a4	2018-02-28 14:15:20.933984-06	2	[19902] Input 21 Supervision	[4] DLarrabee	[21062] a	\N	\N
90b37539-3f05-42c7-8e1b-7cfb044dd763	2018-02-28 14:15:20.936984-06	2	[19903] Input 22 Supervision	[4] DLarrabee	[21062] a	\N	\N
86f3c692-2c11-48c6-8c12-681feb09ad35	2018-02-28 14:15:20.940984-06	2	[19904] Input 23 Supervision	[4] DLarrabee	[21062] a	\N	\N
6602b663-ade5-4141-a380-9e247f13eeb9	2018-02-28 14:15:20.944985-06	2	[19905] Input 24 Supervision	[4] DLarrabee	[21062] a	\N	\N
653249ca-02c8-46df-b0af-b4dfe2ea0a13	2018-02-28 14:15:20.948985-06	2	[19906] Input 25 Supervision	[4] DLarrabee	[21062] a	\N	\N
2d500ea3-47e4-4989-b098-d355912fb2a2	2018-02-28 14:15:20.952986-06	2	[19907] Input 26 Supervision	[4] DLarrabee	[21062] a	\N	\N
914d8613-daf0-4352-94ed-f16884fe7bfc	2018-02-28 14:15:20.956986-06	2	[19908] Input 27 Supervision	[4] DLarrabee	[21062] a	\N	\N
9849d6fb-fbfa-4d0e-8758-40d6c695fa4c	2018-02-28 14:15:20.960986-06	2	[19909] Input 28 Supervision	[4] DLarrabee	[21062] a	\N	\N
6bfdecc9-d431-4f26-8d09-b604e3a1fa11	2018-02-28 14:15:20.964987-06	2	[19910] Input 29 Supervision	[4] DLarrabee	[21062] a	\N	\N
242bb6a6-b5d1-4043-a75b-354955bcd0f5	2018-02-28 14:15:20.968987-06	2	[19911] Input 30 Supervision	[4] DLarrabee	[21062] a	\N	\N
3a4e6567-f67b-41d2-a353-b0b0d73cf903	2018-02-28 14:15:20.971988-06	2	[19912] Input 31 Supervision	[4] DLarrabee	[21062] a	\N	\N
d462231f-0c74-42e4-ad5b-99e0dc05f5a8	2018-02-28 14:15:20.975988-06	2	[19913] Input 32 Supervision	[4] DLarrabee	[21062] a	\N	\N
769b42a3-7e35-462c-a893-45e2da131cde	2018-02-28 14:15:22.99819-06	2	[21087] Alarm Box	[21041] OSSI-DNOVAK	[293] master	\N	\N
5c8c0c4b-7aea-4465-891f-edb6aeb1d817	2018-02-28 14:20:39.02679-06	2	[18726] Input 20	[4] DLarrabee	[21062] a	\N	\N
a86b8975-a539-431c-8b25-25b6cd837722	2018-02-28 14:20:39.169804-06	2	[18727] Input 21	[4] DLarrabee	[21062] a	\N	\N
e8781773-078e-4e2c-a8e7-7d01083ee1c0	2018-02-28 14:20:39.189806-06	2	[18728] Input 22	[4] DLarrabee	[21062] a	\N	\N
cbcc7a1b-d804-4d5b-8cca-fafe46e0be48	2018-02-28 14:20:39.203808-06	2	[18729] Input 23	[4] DLarrabee	[21062] a	\N	\N
7ab4f1ab-4fdf-4f55-b129-934e58bd1fb3	2018-02-28 14:20:39.219809-06	2	[18730] Input 24	[4] DLarrabee	[21062] a	\N	\N
662e317e-ff79-4068-9360-429020c56225	2018-02-28 14:20:39.233811-06	2	[18731] Input 25	[4] DLarrabee	[21062] a	\N	\N
1e001721-d8f4-40f2-9848-1a56dca206d2	2018-02-28 14:20:39.252812-06	2	[18732] Input 26	[4] DLarrabee	[21062] a	\N	\N
4237e73f-b0ab-4bdf-b276-240ce21105a1	2018-02-28 14:20:39.269814-06	2	[18733] Input 27	[4] DLarrabee	[21062] a	\N	\N
492881f2-4256-40d1-92ff-522aac2142be	2018-02-28 14:20:39.288816-06	2	[18734] Input 28	[4] DLarrabee	[21062] a	\N	\N
07c44b10-7d49-49cd-b9d2-b73fa4a1696a	2018-02-28 14:20:39.302817-06	2	[18735] Input 29	[4] DLarrabee	[21062] a	\N	\N
2adbdce1-1049-46b9-be89-5a8be2d7b79d	2018-02-28 14:20:39.317819-06	2	[18736] Input 30	[4] DLarrabee	[21062] a	\N	\N
0af73563-ff4a-422e-a988-2800266e05f0	2018-02-28 14:20:39.33282-06	2	[18737] Input 31	[4] DLarrabee	[21062] a	\N	\N
d0644732-b0f1-486a-8f16-dcb466c74313	2018-02-28 14:20:39.344822-06	2	[18738] Input 32	[4] DLarrabee	[21062] a	\N	\N
4d5a05b0-8c9f-4995-ad14-778f1c22f3e2	2018-02-28 14:20:39.348822-06	2	[18793] Input 20 Supervision	[4] DLarrabee	[21062] a	\N	\N
98cf39f2-a56b-4ce9-8947-a661f7885696	2018-02-28 14:20:39.352822-06	2	[18794] Input 21 Supervision	[4] DLarrabee	[21062] a	\N	\N
3fd2dbb0-c29e-4c8f-a80a-f36664769abe	2018-02-28 14:20:39.357823-06	2	[18795] Input 22 Supervision	[4] DLarrabee	[21062] a	\N	\N
95a4e334-218f-4770-8f69-bbdec4f2b6a4	2018-02-28 14:20:39.361823-06	2	[18796] Input 23 Supervision	[4] DLarrabee	[21062] a	\N	\N
0c04e2d2-6dea-4a0e-afaf-d42805ca59a4	2018-02-28 14:20:39.364824-06	2	[18797] Input 24 Supervision	[4] DLarrabee	[21062] a	\N	\N
c7abc486-c118-4840-8137-ff3b8db5fae3	2018-02-28 14:20:39.367824-06	2	[18798] Input 25 Supervision	[4] DLarrabee	[21062] a	\N	\N
5d322e86-5910-48a4-b153-056c95795b4f	2018-02-28 14:20:39.371824-06	2	[18799] Input 26 Supervision	[4] DLarrabee	[21062] a	\N	\N
7bf56ecf-9d9a-4b9d-8700-37b4a7d38223	2018-02-28 14:20:39.374825-06	2	[18800] Input 27 Supervision	[4] DLarrabee	[21062] a	\N	\N
812c2f39-3d2a-4f19-846e-35bdeb2028d3	2018-02-28 14:20:39.378825-06	2	[18801] Input 28 Supervision	[4] DLarrabee	[21062] a	\N	\N
83256ea5-d134-4c46-9f98-a0522db52208	2018-02-28 14:20:39.381825-06	2	[18802] Input 29 Supervision	[4] DLarrabee	[21062] a	\N	\N
a8114afd-fce4-457b-b136-8c888c9e83eb	2018-02-28 14:20:39.384826-06	2	[18803] Input 30 Supervision	[4] DLarrabee	[21062] a	\N	\N
4855fe1e-040f-4003-a6ee-e939b9a3fbba	2018-02-28 14:20:39.387826-06	2	[18804] Input 31 Supervision	[4] DLarrabee	[21062] a	\N	\N
5b8faee6-b7a7-44f8-9d46-b87fab2c09de	2018-02-28 14:20:39.391826-06	2	[18805] Input 32 Supervision	[4] DLarrabee	[21062] a	\N	\N
2b2e48e7-63b3-4fe7-af7f-a3d00a6e16ac	2018-02-28 14:21:36.992586-06	2	[18274] IC-8 Call Button	[4] DLarrabee	[21062] a	\N	\N
df1db268-ebbd-4ba8-95ac-ec010df7a427	2018-02-28 14:21:36.998586-06	2	[18325] IC-8 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
9eb316e8-a478-43ad-ad51-afe57b1c93a8	2018-02-28 14:22:40.925979-06	2	[18283] IC-8 Relay	[4] DLarrabee	[21062] a	\N	\N
4c87798c-6153-4b7d-b984-1d1e10026770	2018-02-28 14:22:40.931979-06	2	[18292] IC-8 Connect	[4] DLarrabee	[21062] a	\N	\N
ec67377c-169e-45f6-b718-2686f2d59f26	2018-02-28 14:22:40.93898-06	2	[18344] IC-8 Call	[4] DLarrabee	[21062] a	\N	\N
78b1b5f7-97d8-43e7-911e-ea21a38cca08	2018-02-28 14:24:06.117497-06	2	[17081] Output 16	[4] DLarrabee	[21062] a	\N	\N
f70001b2-a0ab-4eea-a659-a69941fa226f	2018-02-28 14:25:43.866353-06	2	[15346] Input 29	[4] DLarrabee	[21062] a	\N	\N
c9257328-a391-49c9-b210-2d6351ac36c8	2018-02-28 14:25:43.883341-06	2	[15347] Input 30	[4] DLarrabee	[21062] a	\N	\N
c68229ec-d264-49d3-8117-8bee6e9f803b	2018-02-28 14:25:43.900329-06	2	[15348] Input 31	[4] DLarrabee	[21062] a	\N	\N
2b19cc73-3bb4-4594-9828-6328ac4f53f0	2018-02-28 14:25:43.916318-06	2	[15349] Input 32	[4] DLarrabee	[21062] a	\N	\N
9dd0d0c2-444a-40be-af6c-452a47638362	2018-02-28 14:25:43.920315-06	2	[15413] Input 29 Supervision	[4] DLarrabee	[21062] a	\N	\N
3eaf3310-db3f-4574-bd04-97f7fe78186d	2018-02-28 14:25:43.926311-06	2	[15414] Input 30 Supervision	[4] DLarrabee	[21062] a	\N	\N
b1fc0acc-8b5f-4c97-8d18-72cab8bf2312	2018-02-28 14:25:43.931308-06	2	[15415] Input 31 Supervision	[4] DLarrabee	[21062] a	\N	\N
9a2dde54-45ab-4fdd-a67a-2b430a775c80	2018-02-28 14:25:43.935305-06	2	[15416] Input 32 Supervision	[4] DLarrabee	[21062] a	\N	\N
7266c964-19c0-410a-bc45-e7087a6c6e70	2018-02-28 14:26:27.451822-06	2	[14414] Input 31	[4] DLarrabee	[21062] a	\N	\N
f298e48a-26ed-43cc-9fd4-b0bb5def8305	2018-02-28 14:26:27.455819-06	2	[14481] Input 31 Supervision	[4] DLarrabee	[21062] a	\N	\N
583bfaac-7fd6-4703-86ad-b802ce80aaf0	2018-02-28 14:29:53.625399-06	2	[13950] IC-7 Call Button	[4] DLarrabee	[21062] a	\N	\N
e85d30c5-3b6c-40c7-832c-5f6adab311c3	2018-02-28 14:29:53.641388-06	2	[13951] IC-8Call Button	[4] DLarrabee	[21062] a	\N	\N
a66e229f-95c9-4f57-b4c7-891e2db2019f	2018-02-28 14:29:53.658376-06	2	[13959] IC-7 Relay	[4] DLarrabee	[21062] a	\N	\N
7ebb01cb-2c24-4c40-bd5d-40f054ec52e7	2018-02-28 14:29:53.670368-06	2	[13960] IC-8 Relay	[4] DLarrabee	[21062] a	\N	\N
b028734b-1a53-43eb-b605-e8a32a7bf4f7	2018-02-28 14:29:53.673366-06	2	[13968] IC-7 Connect	[4] DLarrabee	[21062] a	\N	\N
508ada13-5717-477e-97fe-f6479a73419e	2018-02-28 14:29:53.677363-06	2	[13969] IC-8 Connect	[4] DLarrabee	[21062] a	\N	\N
c1ac5d95-af98-42dd-9afe-a02c1e46cb9f	2018-02-28 14:29:53.682359-06	2	[14001] IC-7 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
c164e0c7-db83-4ce4-b841-2d19cc94a7e8	2018-02-28 14:29:53.686357-06	2	[14002] IC-8 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
f05bfdf0-43ab-4c20-8d7e-f9767c87eb6e	2018-02-28 14:29:53.690354-06	2	[14020] IC-7 Call	[4] DLarrabee	[21062] a	\N	\N
fad7b519-1bcc-407e-835e-45bd3cce5b5c	2018-02-28 14:29:53.693352-06	2	[14021] IC-8 Call	[4] DLarrabee	[21062] a	\N	\N
052159cf-212c-425b-b9f2-68bfd4d6b845	2018-02-28 14:32:20.755888-06	2	[10871] IC-8 Call Button	[4] DLarrabee	[21062] a	\N	\N
1976280c-e687-4b5c-b31c-08e68f8c7249	2018-02-28 14:32:20.797879-06	2	[10880] IC-8 Relay	[4] DLarrabee	[21062] a	\N	\N
bff8bb0f-6114-4ec0-a80c-6ed134b17443	2018-02-28 14:32:20.800879-06	2	[10889] IC-8 Connect	[4] DLarrabee	[21062] a	\N	\N
b50adb0c-c22b-4e90-8782-0c0dbd5fa7a7	2018-02-28 14:32:20.805878-06	2	[10922] IC-8 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
a34f9835-6209-4108-a7f4-829c854a73da	2018-02-28 14:32:20.808877-06	2	[10941] IC-8 Call	[4] DLarrabee	[21062] a	\N	\N
c5e3cfab-1080-4839-b7f1-db6eba179263	2018-02-28 14:38:45.282297-06	2	[7784] IC-3 Call Button	[4] DLarrabee	[21062] a	\N	\N
c8bd5d1c-f69f-4d3b-9eb7-e212acb1444b	2018-02-28 14:38:45.371297-06	2	[7785] IC-4 Call Button	[4] DLarrabee	[21062] a	\N	\N
227eaf79-5e3b-45e5-90b4-f0a4ef54f87a	2018-02-28 14:38:45.387297-06	2	[7786] IC-5 Call Button	[4] DLarrabee	[21062] a	\N	\N
cf478134-952f-46dc-b95c-40f9f633a135	2018-02-28 14:38:45.402297-06	2	[7787] IC-6 Call Button	[4] DLarrabee	[21062] a	\N	\N
0d0cc81d-d03a-4f79-8b1d-c7eb0a11bfe9	2018-02-28 14:38:45.419297-06	2	[7788] IC-7 Call Button	[4] DLarrabee	[21062] a	\N	\N
0612e5d3-8ff7-4535-b128-ffd634fa2e84	2018-02-28 14:38:45.440297-06	2	[7789] IC-8 Call Button	[4] DLarrabee	[21062] a	\N	\N
4c2d5761-a53a-41d8-ac45-26088d7b0b3e	2018-02-28 14:38:45.459297-06	2	[7793] IC-3 Relay	[4] DLarrabee	[21062] a	\N	\N
c76e6aaf-e772-4577-af4d-254310a4a95a	2018-02-28 14:38:45.474297-06	2	[7794] IC-4 Relay	[4] DLarrabee	[21062] a	\N	\N
13116e75-5220-4513-b934-137f2e38534a	2018-02-28 14:38:45.488297-06	2	[7795] IC-5 Relay	[4] DLarrabee	[21062] a	\N	\N
bd578ae2-fb4b-4d80-adc4-c3d50510483b	2018-02-28 14:38:45.502297-06	2	[7796] IC-6 Relay	[4] DLarrabee	[21062] a	\N	\N
76f6aa6f-93eb-4dce-b443-9972c87d6126	2018-02-28 14:38:45.516297-06	2	[7797] IC-7 Relay	[4] DLarrabee	[21062] a	\N	\N
2b496b92-edab-456c-b138-ed1cf047f94a	2018-02-28 14:38:45.531297-06	2	[7798] IC-8 Relay	[4] DLarrabee	[21062] a	\N	\N
4f79f61f-0327-4cf5-9ff2-e2e7f5a403f6	2018-02-28 14:38:45.535297-06	2	[7802] IC-3 Connect	[4] DLarrabee	[21062] a	\N	\N
ea4e6e9d-b19c-42e3-94cf-71527780a51a	2018-02-28 14:38:45.539297-06	2	[7803] IC-4 Connect	[4] DLarrabee	[21062] a	\N	\N
74495c31-5211-4946-b76c-0e9223ea2269	2018-02-28 14:38:45.542297-06	2	[7804] IC-5 Connect	[4] DLarrabee	[21062] a	\N	\N
d7fea337-3f02-4c1d-aa43-36d08d0c3c06	2018-02-28 14:38:45.547297-06	2	[7805] IC-6 Connect	[4] DLarrabee	[21062] a	\N	\N
2e3af397-6aa8-4351-9d00-6614781323ae	2018-02-28 14:38:45.551297-06	2	[7806] IC-7 Connect	[4] DLarrabee	[21062] a	\N	\N
febcabda-996b-49ca-825b-2d960ed83f58	2018-02-28 14:38:45.554297-06	2	[7807] IC-8 Connect	[4] DLarrabee	[21062] a	\N	\N
16c04b1b-ec89-43b8-8dfe-61c50951593f	2018-02-28 14:38:45.557297-06	2	[7854] IC-3 Call	[4] DLarrabee	[21062] a	\N	\N
e996723c-56b0-4066-a2e4-ee1c3cf466b0	2018-02-28 14:38:45.561297-06	2	[7855] IC-4 Call	[4] DLarrabee	[21062] a	\N	\N
96434515-2156-4dd9-b273-e0f2dccaff9f	2018-02-28 14:38:45.565297-06	2	[7856] IC-5 Call	[4] DLarrabee	[21062] a	\N	\N
6ea9008a-1cd0-4456-bbcf-2527cfed6491	2018-02-28 14:38:45.569297-06	2	[7857] IC-6 Call	[4] DLarrabee	[21062] a	\N	\N
06bbf2d7-b494-4a94-89b8-4cf3eb4fedf4	2018-02-28 14:38:45.572297-06	2	[7858] IC-7 Call	[4] DLarrabee	[21062] a	\N	\N
a9422fa6-ab4c-4479-b6e6-413488f5a509	2018-02-28 14:38:45.575297-06	2	[7859] IC-8	[4] DLarrabee	[21062] a	\N	\N
27a8f6c7-8a79-48bb-bc17-39d14355bc37	2018-02-28 14:48:47.162648-06	2	[5589] IC-8 Call Button	[4] DLarrabee	[21062] a	\N	\N
54449200-2428-4200-8193-39962556c360	2018-02-28 14:48:47.199651-06	2	[5598] IC-8 Relay	[4] DLarrabee	[21062] a	\N	\N
6452feef-9412-4860-90c5-6e05cc3402c1	2018-02-28 14:48:47.218653-06	2	[5607] IC-8 Connect	[4] DLarrabee	[21062] a	\N	\N
8db76cc0-446a-44a5-9caf-e58e2e3bc84c	2018-02-28 14:48:47.222654-06	2	[5640] IC-8 Call Button Supervision	[4] DLarrabee	[21062] a	\N	\N
ace39743-f9d9-4b53-9425-76abe016a4f6	2018-02-28 14:48:47.226654-06	2	[5659] IC-8 Call	[4] DLarrabee	[21062] a	\N	\N
5e60d238-4400-4e24-a344-5646d1985608	2018-02-28 14:50:49.948925-06	2	[2633] Output 11	[4] DLarrabee	[21062] a	\N	\N
efa9d084-118b-406d-943c-f3cf5cb5da9e	2018-02-28 14:50:49.99393-06	2	[2634] Output 12	[4] DLarrabee	[21062] a	\N	\N
73f7e961-4000-4384-9a8f-015706ed09ea	2018-02-28 14:50:50.007931-06	2	[2635] Output 13	[4] DLarrabee	[21062] a	\N	\N
cd7afcf5-833f-47ea-8357-0eb0cc752aa7	2018-02-28 14:50:50.027933-06	2	[2636] Output 14	[4] DLarrabee	[21062] a	\N	\N
a691a8d6-7187-4fe5-9248-dca575c577d4	2018-02-28 14:50:50.043935-06	2	[2637] Output 15	[4] DLarrabee	[21062] a	\N	\N
094f70de-b56d-4831-b235-792fe17d1e5b	2018-02-28 14:50:50.059936-06	2	[2638] Output 16	[4] DLarrabee	[21062] a	\N	\N
ff137a6f-5328-4810-83d8-c7eac0c124c2	2018-02-28 14:58:20.793005-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
1716809d-7dbf-4af0-b353-041039ec1a85	2018-02-28 14:58:46.280553-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
c5b635f0-28e4-4ce4-9b56-9ea62360fc53	2018-02-28 14:59:12.278153-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
2b4ecd09-091d-4e01-82b5-d51995ceb9cf	2018-02-28 14:59:44.645389-06	2	[21047] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
dc907df1-a0a7-4ff8-94bf-92d6e12be52f	2018-02-28 15:00:05.246449-06	2	[21047] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
14f8abe5-d6b8-41bd-94a0-d32e567437b3	2018-02-28 15:00:15.790504-06	2	[1517] Input 3	[4] DLarrabee	[21062] a	\N	\N
4fc41793-412d-44d2-9a29-206c92e69075	2018-02-28 15:00:15.803505-06	2	[1522] Input 8	[4] DLarrabee	[21062] a	\N	\N
79f23d7c-f528-4755-8f44-c2e81139fca4	2018-02-28 15:00:15.815506-06	2	[1536] Input 22	[4] DLarrabee	[21062] a	\N	\N
c173d44d-ab35-443f-b644-49ad5e8d0e17	2018-02-28 15:00:15.828507-06	2	[1537] Input 23	[4] DLarrabee	[21062] a	\N	\N
144e3454-4e91-4465-99f3-05ff482017f3	2018-02-28 15:00:15.840509-06	2	[1538] Input 24	[4] DLarrabee	[21062] a	\N	\N
4f622139-49e5-4d6e-8b27-cc20221009cb	2018-02-28 15:00:15.85551-06	2	[1539] Input 25	[4] DLarrabee	[21062] a	\N	\N
2de2c306-e0be-42fc-a2cc-32d22aa41f65	2018-02-28 15:00:15.867511-06	2	[1540] Input 26	[4] DLarrabee	[21062] a	\N	\N
11384956-0c6f-472b-9e03-8d0b81c93125	2018-02-28 15:00:15.885513-06	2	[1541] Input 27	[4] DLarrabee	[21062] a	\N	\N
7f8f02e9-c7fc-41f6-b2ab-10836ae804ad	2018-02-28 15:00:15.900515-06	2	[1542] Input 28	[4] DLarrabee	[21062] a	\N	\N
a90228ff-d235-484a-a894-bd9ec19e7733	2018-02-28 15:00:15.915516-06	2	[1543] Input 29	[4] DLarrabee	[21062] a	\N	\N
49f53043-22c5-44d3-a828-78223c2cd3b9	2018-02-28 15:00:15.931518-06	2	[1544] Input 30	[4] DLarrabee	[21062] a	\N	\N
66c3de58-ce88-4937-a708-306d65d99f12	2018-02-28 15:00:15.943519-06	2	[1545] Input 31	[4] DLarrabee	[21062] a	\N	\N
0a0017a8-b36d-4aa6-ae12-3d41a365d513	2018-02-28 15:00:15.95752-06	2	[1546] Input 32	[4] DLarrabee	[21062] a	\N	\N
1353e47d-351b-4649-89c4-ac5a021a8f0a	2018-02-28 15:00:15.961521-06	2	[1584] Input 3 Supervision	[4] DLarrabee	[21062] a	\N	\N
79e60611-0dba-40f0-ac7e-cd1c6537a697	2018-02-28 15:00:15.964521-06	2	[1589] Input 8 Supervision	[4] DLarrabee	[21062] a	\N	\N
51064172-5e5c-4515-a272-5a1de184ab6e	2018-02-28 15:00:15.968521-06	2	[1603] Input 22 Supervision	[4] DLarrabee	[21062] a	\N	\N
4fb996a6-09b6-4078-9cf3-b95b576d68a9	2018-02-28 15:00:15.971522-06	2	[1604] Input 23 Supervision	[4] DLarrabee	[21062] a	\N	\N
1e4d7410-7e57-4ca7-83bf-29b9eb88956d	2018-02-28 15:00:15.974522-06	2	[1605] Input 24 Supervision	[4] DLarrabee	[21062] a	\N	\N
681afecf-a69a-4f8a-80de-391dc485f29f	2018-02-28 15:00:15.976522-06	2	[1606] Input 25 Supervision	[4] DLarrabee	[21062] a	\N	\N
5f1dcdcd-1d8d-4760-9102-ee4ba29bccde	2018-02-28 15:00:15.979522-06	2	[1607] Input 26 Supervision	[4] DLarrabee	[21062] a	\N	\N
24529e94-9928-4dda-8812-024e26733862	2018-02-28 15:00:15.983523-06	2	[1608] Input 27 Supervision	[4] DLarrabee	[21062] a	\N	\N
9b537574-2f6c-4f2b-be4a-351e1e5c2b11	2018-02-28 15:00:15.986523-06	2	[1609] Input 28 Supervision	[4] DLarrabee	[21062] a	\N	\N
f3692066-b183-47cb-b0c5-672e0c3b6b72	2018-02-28 15:00:15.989523-06	2	[1610] Input 29 Supervision	[4] DLarrabee	[21062] a	\N	\N
44d5e198-5df5-47cb-b49f-382f7b7a0e7e	2018-02-28 15:00:15.991524-06	2	[1611] Input 30 Supervision	[4] DLarrabee	[21062] a	\N	\N
5924af97-e408-430b-905a-df9737fdda15	2018-02-28 15:00:15.995524-06	2	[1612] Input 31 Supervision	[4] DLarrabee	[21062] a	\N	\N
1414f348-103a-48c3-9786-39bd798b64d8	2018-02-28 15:00:15.998524-06	2	[1613] Input 32 Supervision	[4] DLarrabee	[21062] a	\N	\N
07951f1c-ffda-4b3f-b4f0-ffc396d71495	2018-02-28 15:01:30.996023-06	2	[21087] Alarm Box	[21041] OSSI-DNOVAK	[293] master	\N	\N
bc93dea3-33d2-492f-ac62-0c449708d729	2018-02-28 15:02:13.153239-06	2	[21087] Alarm Box	[21041] OSSI-DNOVAK	[293] master	\N	\N
57dada6b-2d1d-4df6-8ef2-a9650408d931	2018-02-28 15:03:42.110133-06	2	[21087] Alarm Box	[21041] OSSI-DNOVAK	[293] master	\N	\N
dafd3484-6d41-41ce-ae10-95a72f7cf41f	2018-02-28 15:03:57.362659-06	3	[21088] Area Label	[21041] OSSI-DNOVAK	[293] master	\N	\N
206b94a1-3a02-4f6b-beea-b74028904b92	2018-02-28 15:04:16.405563-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
615038d2-2fb6-4219-84d6-1258adc5b83a	2018-02-28 15:05:19.616883-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
d4726da7-7777-4b01-8e41-2cf5384fbbe2	2018-02-28 15:05:48.459767-06	2	[21083] A	[21041] OSSI-DNOVAK	[293] master	\N	\N
43a5df9d-ff1d-40fe-81ec-d211e9d5944a	2018-02-28 15:06:31.861107-06	1	[21088] New Shared Screen Objects Group	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef9f81b5-cc63-48fe-bc96-7340e563ebeb	2018-02-28 15:06:36.053526-06	2	[21088] New Shared Screen Objects Group	[21041] OSSI-DNOVAK	[293] master	\N	\N
6b190153-15fc-4429-8f5f-c82c943d747a	2018-02-28 15:07:01.574078-06	2	[1069] Input 23	[4] DLarrabee	[21062] a	\N	\N
ff008170-ab87-4bb9-87f5-bc7cf196a46d	2018-02-28 15:07:01.59408-06	2	[1070] Input 24	[4] DLarrabee	[21062] a	\N	\N
fd13bbab-90cf-47ad-bd94-125e57e041b0	2018-02-28 15:07:01.611082-06	2	[1073] Input 27	[4] DLarrabee	[21062] a	\N	\N
28a3f369-21e5-4d3b-9b9c-add61b60a8f2	2018-02-28 15:07:01.628083-06	2	[1074] Input 28	[4] DLarrabee	[21062] a	\N	\N
95762190-a3fc-4e22-9bac-b16478fbe1c0	2018-02-28 15:07:01.643085-06	2	[1075] Input 29	[4] DLarrabee	[21062] a	\N	\N
44a808e5-ec76-46dc-922e-399a68c4ee5d	2018-02-28 15:07:01.654086-06	2	[1076] Input 30	[4] DLarrabee	[21062] a	\N	\N
0195b4d7-8816-4ba7-8c54-30080312afbc	2018-02-28 15:07:01.672088-06	2	[1077] Input 31	[4] DLarrabee	[21062] a	\N	\N
66a2921a-40d5-4b4c-bc97-25f48544f192	2018-02-28 15:07:01.686089-06	2	[1078] Input 32	[4] DLarrabee	[21062] a	\N	\N
afd2972a-5cff-4d00-8163-fac48f353be8	2018-02-28 15:07:01.689089-06	2	[1136] Input 23 Supervision	[4] DLarrabee	[21062] a	\N	\N
5870e49b-5def-451e-b841-1ac4283a8a47	2018-02-28 15:07:01.69309-06	2	[1137] Input 24 Supervision	[4] DLarrabee	[21062] a	\N	\N
ce308afd-d1df-4415-9873-72e45fc2ad53	2018-02-28 15:07:01.69609-06	2	[1140] Input 27 Supervision	[4] DLarrabee	[21062] a	\N	\N
c41c7bd7-6f9b-4d7d-b784-6458c5a9398c	2018-02-28 15:07:01.69909-06	2	[1141] Input 28 Supervision	[4] DLarrabee	[21062] a	\N	\N
54e989ed-297f-4162-bc24-69c4e4fc1a40	2018-02-28 15:07:01.703091-06	2	[1142] Input 29 Supervision	[4] DLarrabee	[21062] a	\N	\N
9393ff26-88db-48df-8987-0b2e1b4f8e0a	2018-02-28 15:07:01.706091-06	2	[1143] Input 30 Supervision	[4] DLarrabee	[21062] a	\N	\N
7ce140d4-fb24-4404-a50d-89e4f12a6786	2018-02-28 15:07:01.709091-06	2	[1144] Input 31 Supervision	[4] DLarrabee	[21062] a	\N	\N
d5f5c8a6-3424-45cf-94d4-d2b154535d33	2018-02-28 15:07:01.713092-06	2	[1145] Input 32 Supervision	[4] DLarrabee	[21062] a	\N	\N
bb5bf4dc-0fa6-4d9f-826a-3836ed72400d	2018-02-28 15:08:31.496069-06	2	[21088] New Shared Screen Objects Group	[21041] OSSI-DNOVAK	[293] master	\N	\N
e49122a6-cf2d-4219-9e19-0728a2c97ba7	2018-02-28 15:09:25.838503-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
d67863ea-7e3c-43ce-8be1-3e57fd48d46e	2018-02-28 15:11:32.182136-06	2	[21047] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
1ed915fc-ffb5-4b23-8a1b-25cfee0d6fb1	2018-02-28 15:11:56.511569-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
7802a0ca-a87b-47e8-a8d9-781aa7974915	2018-02-28 15:12:47.072624-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
23dda680-b7c2-4b57-94fc-4c01f9bee7d9	2018-02-28 15:12:59.513868-06	2	[21047] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
60c41797-3e0a-4d3b-ac83-bbd7e88cf9fe	2018-02-28 15:19:25.289442-06	1	[21090] New Shared Screen Object	[21041] OSSI-DNOVAK	[293] master	\N	\N
3eef3056-d81f-4022-968b-1b213ab77f5e	2018-02-28 15:19:39.36885-06	2	[21090] New Shared Screen Object	[21041] OSSI-DNOVAK	[293] master	\N	\N
d2d971a3-fac1-4882-af11-d49eafdce6bd	2018-02-28 15:19:54.346347-06	2	[21090] New Shared Screen Object	[21041] OSSI-DNOVAK	[293] master	\N	\N
55b509c6-f804-4f66-84b7-17e7d96964eb	2018-02-28 15:20:02.221135-06	2	[21090] New Shared Screen Object	[21041] OSSI-DNOVAK	[293] master	\N	\N
a8466518-4b76-4d01-baa7-cfb5b5e0bba4	2018-02-28 15:20:06.495562-06	1	[21091] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
57b29eb7-2662-43bd-919e-0bc0d07b6a88	2018-02-28 15:20:45.391451-06	2	[21091] Frame	[21041] OSSI-DNOVAK	[293] master	\N	\N
dd55da11-91ff-4b6e-94f7-f5f12d531e86	2018-02-28 15:21:22.436155-06	2	[21091] Frame	[21041] OSSI-DNOVAK	[293] master	\N	\N
93ae5d10-22ba-4475-8a1d-77317a799009	2018-02-28 15:21:51.564068-06	2	[21091] Frame	[21041] OSSI-DNOVAK	[293] master	\N	\N
0e103566-929e-4198-9a16-5c60c3c3c579	2018-02-28 15:22:20.517963-06	1	[21092] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
1200d702-1758-44f6-9f3c-f11a7b8720a4	2018-02-28 15:23:14.756386-06	2	[21092] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
bf1db717-529c-495e-8c4c-da4a88ea041c	2018-02-28 15:23:36.461557-06	2	[21092] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
e48806fc-48c1-484e-be08-e8fceeefe583	2018-02-28 16:43:28.948757-06	1	[21093] New Screens Group	[4] DLarrabee	[293] master	\N	\N
6ca820d0-2bc6-4beb-b4a6-708c67585cd6	2018-02-28 16:43:45.931456-06	2	[21093] Main Screen	[4] DLarrabee	[293] master	\N	\N
b9fc37a2-38e9-490d-a065-434add5656e3	2018-02-28 16:44:00.227885-06	1	[21094] New Screen	[4] DLarrabee	[293] master	\N	\N
7435cf57-5c73-485a-b689-769f2fffbb02	2018-02-28 16:44:31.88005-06	2	[290] LeadIn	[4] DLarrabee	[293] master	\N	\N
56e93d86-33ca-4aab-ac9f-643cf22c1347	2018-02-28 16:45:49.094771-06	2	[21094] Main Screen	[4] DLarrabee	[293] master	\N	\N
f839b666-e610-43af-8c9f-46bc5dd64273	2018-02-28 16:50:00.369896-06	2	[21094] Main Screen	[4] DLarrabee	[293] master	\N	\N
8f8c4589-a8f8-459f-b6e5-0179d4b2a2ce	2018-02-28 16:50:30.907949-06	2	[21094] Main Screen	[4] DLarrabee	[293] master	\N	\N
6fc9652a-5f66-47c9-940d-d658b8295e54	2018-02-28 16:52:18.743732-06	1	[21095] New	[4] DLarrabee	[293] master	\N	\N
d8f2a014-85d6-47bf-8193-62f3f5e7dace	2018-02-28 16:53:05.658423-06	2	[21095] New	[4] DLarrabee	[293] master	\N	\N
cdd36fb7-a6aa-40f1-8fc2-5cdd7355e99d	2018-02-28 16:53:23.775234-06	2	[21095] New	[4] DLarrabee	[293] master	\N	\N
09d4494e-46de-4685-b707-737616738c8b	2018-02-28 16:53:37.83864-06	2	[21095] New	[4] DLarrabee	[293] master	\N	\N
43a4ed0d-c366-49df-b101-897c1a710646	2018-02-28 16:53:51.279984-06	2	[21095] New	[4] DLarrabee	[293] master	\N	\N
8b794a62-e875-40c5-9da2-10e16e52a49d	2018-02-28 16:53:57.724629-06	2	[21095] New	[4] DLarrabee	[293] master	\N	\N
b245d0fb-0c32-47a6-bfbe-c2bbe70c6d62	2018-02-28 16:54:12.772133-06	2	[21094] Main Screen	[4] DLarrabee	[293] master	\N	\N
ab1e2d89-c446-43ac-8dac-a28f2b5ff91b	2018-02-28 16:54:42.383094-06	2	[21095] New	[4] DLarrabee	[293] master	\N	\N
5a44347a-b866-452b-8bd2-e7e9c80ae236	2018-02-28 16:55:57.4496-06	2	[21095] New	[4] DLarrabee	[293] master	\N	\N
775bd0f1-5ead-4526-b342-6022c3904002	2018-02-28 17:00:20.066859-06	1	[21096] New	[4] DLarrabee	[293] master	\N	\N
c5aa0597-40e0-4d04-9e83-c75501bf97d7	2018-02-28 17:00:49.119764-06	2	[21096] New	[4] DLarrabee	[293] master	\N	\N
3437b8e1-4120-4ca2-a5d2-d9e64186ae4a	2018-02-28 17:01:01.113963-06	2	[21096] New	[4] DLarrabee	[293] master	\N	\N
ed38a290-f16e-4639-824b-61e57d39703c	2018-02-28 17:02:43.933244-06	2	[21095] Background	[4] DLarrabee	[293] master	\N	\N
9bc6e377-b093-4bd1-a965-fb9837b4e2f2	2018-02-28 17:03:42.738124-06	2	[21095] Baclground Frame	[4] DLarrabee	[293] master	\N	\N
8a7b5fe5-fc31-499b-94c8-cac36e27a573	2018-02-28 17:03:51.272978-06	2	[21094] Main Screen	[4] DLarrabee	[293] master	\N	\N
2d246466-95df-4f90-b8d4-0b1c40e94016	2018-02-28 17:08:37.495597-06	2	[21096] Door 316B	[4] DLarrabee	[293] master	\N	\N
3ac098cb-58ae-4acd-9dd5-5b04df9e7d5d	2018-02-28 17:09:26.051452-06	2	[21096] Door 316B	[4] DLarrabee	[293] master	\N	\N
9643cd1b-6cbd-4546-b18c-f70ee46ae699	2018-02-28 17:10:22.655112-06	1	[21097] Door 316B Copy	[4] DLarrabee	[293] master	\N	\N
095904e4-0a96-4780-bd99-44625e02106c	2018-02-28 17:11:03.5382-06	2	[21097] Door 326A	[4] DLarrabee	[293] master	\N	\N
381d6e8a-9220-4065-89be-9e978de7664c	2018-02-28 17:11:48.015647-06	1	[21098] Door 326A Copy	[4] DLarrabee	[293] master	\N	\N
9c93ef51-c02b-415b-ac76-31f2bf1db5e0	2018-02-28 17:12:27.836629-06	2	[21098] Door 327A 	[4] DLarrabee	[293] master	\N	\N
80e605b8-d62c-4ef2-a002-d9b8b8df83e5	2018-02-28 17:13:02.44709-06	1	[21099] Door 327A  Copy	[4] DLarrabee	[293] master	\N	\N
035aaf62-6f2a-4e95-aa80-a541aced7ba5	2018-02-28 17:13:52.684113-06	2	[21099] Door 329A	[4] DLarrabee	[293] master	\N	\N
57bc0a5f-48c6-4ff7-ad12-9bf8a55a7b95	2018-02-28 17:14:49.5668-06	1	[21100] Door 329A Copy	[4] DLarrabee	[293] master	\N	\N
6a9a1f51-1118-41f3-aed2-0dc42e31facf	2018-02-28 17:15:37.16556-06	2	[21100] Door 329B	[4] DLarrabee	[293] master	\N	\N
64082fcf-f2a6-433b-ae1b-22ce946b63e7	2018-02-28 17:15:55.07335-06	1	[21101] Door 329B Copy	[4] DLarrabee	[293] master	\N	\N
9beb02a9-3c21-454f-b8b9-f27e2d30889e	2018-02-28 17:16:25.432386-06	2	[21101] Door 334A	[4] DLarrabee	[293] master	\N	\N
48921001-b467-4e35-80de-5a271b876d9e	2018-02-28 17:16:36.713514-06	1	[21102] Door 334A Copy	[4] DLarrabee	[293] master	\N	\N
b2880310-96c1-4848-be68-c5d85fbb4dc9	2018-02-28 17:17:10.682911-06	2	[21102] Door 335A	[4] DLarrabee	[293] master	\N	\N
8308c087-8ec2-4cea-b920-5a9a9e413117	2018-02-28 17:17:27.541596-06	2	[21102] Door 335A	[4] DLarrabee	[293] master	\N	\N
bb64149f-1db1-45dd-a474-f72d8a7c5b60	2018-02-28 17:17:38.908733-06	1	[21103] Door 335A Copy	[4] DLarrabee	[293] master	\N	\N
66c88496-0795-4543-b8a2-ce92ede94590	2018-02-28 17:18:09.187761-06	2	[21103] Door 336A	[4] DLarrabee	[293] master	\N	\N
612a8bae-7694-4e24-bd6d-d7b79b357116	2018-02-28 17:18:20.68491-06	1	[21104] Door 336A Copy	[4] DLarrabee	[293] master	\N	\N
ef408920-34f7-403c-a7bb-8ad2acac875d	2018-02-28 17:18:57.18756-06	2	[21104] Door 337A	[4] DLarrabee	[293] master	\N	\N
9ef190b5-27ac-46c8-b920-d3956dd6003e	2018-02-28 17:19:10.606902-06	1	[21105] Door 337A Copy	[4] DLarrabee	[293] master	\N	\N
21ee68e3-fb5d-48e7-b806-1c9820600b7c	2018-02-28 17:19:54.498291-06	2	[21105] Door 338A	[4] DLarrabee	[293] master	\N	\N
6aeed6ef-0560-459d-a801-c796102fbbb6	2018-02-28 17:20:29.153756-06	1	[21106] Door 338A Copy	[4] DLarrabee	[293] master	\N	\N
00ebbd03-9efc-4f7c-947e-748f22f9d612	2018-02-28 17:21:33.394179-06	2	[21106] Door 343A	[4] DLarrabee	[293] master	\N	\N
cbd78884-a52c-439b-a108-9c41d8552773	2018-02-28 18:49:58.846671-06	2	[21106] Door 343A	[4] DLarrabee	[293] master	\N	\N
a60838ee-d586-4418-9272-fbed3f4b083c	2018-02-28 18:50:05.120299-06	1	[21107] Door 343A Copy	[4] DLarrabee	[293] master	\N	\N
44140b84-0f83-4881-8dc7-9d5bc08ce4ba	2018-02-28 18:51:40.919878-06	2	[21107] Door 344A	[4] DLarrabee	[293] master	\N	\N
d97f1b1d-db52-40cb-ae02-52dfc422f085	2018-02-28 18:51:53.222108-06	2	[21107] Door 344A	[4] DLarrabee	[293] master	\N	\N
155dc492-ecdb-4cb9-82c9-9e6e2c2293fa	2018-02-28 18:52:04.859271-06	1	[21108] Door 344A Copy	[4] DLarrabee	[293] master	\N	\N
e1c238ad-24f8-4b45-9d6d-d4b52ad180d3	2018-02-28 18:53:01.969982-06	2	[21108] Door 346A	[4] DLarrabee	[293] master	\N	\N
ae4f014b-9fa5-4d54-8625-507607ff01d2	2018-02-28 18:53:06.030388-06	1	[21109] Door 346A Copy	[4] DLarrabee	[293] master	\N	\N
de08668f-1e05-4769-af99-e527b2696f13	2018-02-28 18:56:12.936077-06	2	[21109] Door 347A	[4] DLarrabee	[293] master	\N	\N
0ec2c992-e597-49c7-a83c-9f479c52e15d	2018-02-28 18:56:18.812664-06	1	[21110] Door 347A Copy	[4] DLarrabee	[293] master	\N	\N
0e6549c4-53ea-405c-9da9-3a4cbef3e329	2018-02-28 18:56:49.735756-06	2	[21110] Door 348A	[4] DLarrabee	[293] master	\N	\N
098fdbab-0367-4ddf-83e8-1c0372cd61f3	2018-02-28 18:57:00.215804-06	1	[21111] Door 348A Copy	[4] DLarrabee	[293] master	\N	\N
6c3d8eb8-b6b8-40c8-817b-343037a20122	2018-02-28 18:57:42.404022-06	2	[21111] Door 349A	[4] DLarrabee	[293] master	\N	\N
9f69c48b-1823-464b-b531-2726a36138d2	2018-02-28 18:59:51.119893-06	1	[21112] Door 349A Copy	[4] DLarrabee	[293] master	\N	\N
b0cc2b33-8c94-4326-a9f0-6c2d671c39ba	2018-02-28 19:00:58.232603-06	2	[21112] Door 351A	[4] DLarrabee	[293] master	\N	\N
2e2271c6-e7e0-4469-99e4-0bf51f8c2007	2018-02-28 19:06:13.474124-06	1	[21113] Door 351A Copy	[4] DLarrabee	[293] master	\N	\N
291d94f1-51a9-411b-bd27-a0c13838d6e5	2018-02-28 19:06:43.13709-06	2	[21113] Door 351B	[4] DLarrabee	[293] master	\N	\N
b66de67d-dec2-4d30-aefe-7633cfc1c316	2018-02-28 19:06:47.789556-06	1	[21114] Door 351B Copy	[4] DLarrabee	[293] master	\N	\N
2359128e-ee65-46ca-bbfd-9ee219285e4b	2018-02-28 19:07:17.223499-06	2	[21114] Door 352A	[4] DLarrabee	[293] master	\N	\N
2bbb4b82-a481-492d-864f-79a2b82b90d5	2018-02-28 19:07:25.108287-06	1	[21115] Door 352A Copy	[4] DLarrabee	[293] master	\N	\N
c3d0d5e3-6c24-42ee-8d45-bc5850df778b	2018-02-28 19:07:58.799656-06	2	[21115] Door 405A	[4] DLarrabee	[293] master	\N	\N
72757ed5-4b1f-419a-beb4-6bafba10474b	2018-02-28 19:08:04.465222-06	1	[21116] Door 405A Copy	[4] DLarrabee	[293] master	\N	\N
ea5c946e-4bf9-4173-9bb1-38ee7abd5f4a	2018-02-28 19:09:53.409116-06	2	[21116] Door 414A	[4] DLarrabee	[293] master	\N	\N
ffe23b20-17f6-45c7-9ec3-ff2e3d26915f	2018-02-28 19:10:06.266401-06	1	[21117] Door 414A Copy	[4] DLarrabee	[293] master	\N	\N
31f4b8d7-63b2-4b63-8b72-dd97fd104573	2018-02-28 19:10:31.445919-06	2	[21117] Door 414B	[4] DLarrabee	[293] master	\N	\N
a47e191f-0781-48d7-b93b-749af204a014	2018-02-28 19:10:37.340508-06	1	[21118] Door 414B Copy	[4] DLarrabee	[293] master	\N	\N
c6eb1960-1735-44f3-a400-8a34a5aade33	2018-02-28 19:12:35.213294-06	2	[21118] Door 422A	[4] DLarrabee	[293] master	\N	\N
d971d663-61e5-4d43-a921-40f8b7fd905f	2018-02-28 19:12:39.031676-06	1	[21119] Door 422A Copy	[4] DLarrabee	[293] master	\N	\N
9b0d65aa-4b24-461f-963e-41684a53c77c	2018-02-28 19:32:52.542015-06	2	[21119] Door 422B	[4] DLarrabee	[293] master	\N	\N
3f9b8077-908f-482d-82c1-efa719ca690f	2018-02-28 19:33:07.99456-06	1	[21120] Door 422B Copy	[4] DLarrabee	[293] master	\N	\N
6c4e329a-23be-4852-9613-7f5e9ca272df	2018-02-28 19:34:12.258986-06	2	[21120] Door 438A	[4] DLarrabee	[293] master	\N	\N
d81af5a7-63ac-4156-8372-c4875874917d	2018-02-28 19:34:16.906451-06	1	[21121] Door 438A Copy	[4] DLarrabee	[293] master	\N	\N
4e320b96-ed1f-483f-8a69-199af99ddbe9	2018-02-28 19:34:52.089969-06	2	[21121] Door 439A	[4] DLarrabee	[293] master	\N	\N
daec3334-1573-498f-a9ba-317e12373edf	2018-02-28 19:34:58.485608-06	1	[21122] Door 439A Copy	[4] DLarrabee	[293] master	\N	\N
c2819a97-d981-47a5-a11b-0eef7411f447	2018-02-28 19:36:07.160475-06	2	[21122] Door 443A	[4] DLarrabee	[293] master	\N	\N
fdeece7a-bfd9-4788-a7ff-f3ffc35d120c	2018-02-28 19:36:12.994058-06	1	[21123] Door 443A Copy	[4] DLarrabee	[293] master	\N	\N
d2708ac9-1afe-4f77-88a0-e2ea515d296a	2018-02-28 19:36:42.271986-06	2	[21123] Door 443B	[4] DLarrabee	[293] master	\N	\N
e1b5efed-aeac-4ba6-ac1c-67eca1895939	2018-02-28 19:36:50.438802-06	1	[21124] Door 443B Copy	[4] DLarrabee	[293] master	\N	\N
f185eff8-364c-484c-8d6a-ef26b5611a77	2018-02-28 19:40:31.409897-06	2	[21124] Door 444A Copy	[4] DLarrabee	[293] master	\N	\N
81c9fb55-d77b-4180-bec1-2f4176b19bc1	2018-02-28 19:40:37.277484-06	1	[21125] Door 444A Copy Copy	[4] DLarrabee	[293] master	\N	\N
2332d65e-c6a5-48f8-84e8-c9f03d01ff88	2018-02-28 19:40:53.191075-06	2	[21125] Door 444B	[4] DLarrabee	[293] master	\N	\N
982a198e-33d9-41ad-b622-ba44090f6292	2018-02-28 19:41:23.304086-06	2	[21124] Door 444A	[4] DLarrabee	[293] master	\N	\N
d782d0fc-ecfb-402c-9539-52229690e85e	2018-02-28 19:41:49.223678-06	2	[21125] Door 444B	[4] DLarrabee	[293] master	\N	\N
90f72d21-cc87-44e8-89e4-ae8490342351	2018-02-28 19:41:53.634119-06	1	[21126] Door 444B Copy	[4] DLarrabee	[293] master	\N	\N
18895a42-440b-4ac7-ae65-e505421a4801	2018-02-28 19:43:27.792534-06	2	[21126] Door 447A	[4] DLarrabee	[293] master	\N	\N
d5426abb-78f9-46f2-90ca-e29b0bf5d7f5	2018-02-28 19:43:33.722127-06	1	[21127] Door 447A Copy	[4] DLarrabee	[293] master	\N	\N
1375cedc-5a93-491e-86de-971ff9250b0b	2018-02-28 19:44:49.406694-06	2	[21127] Door 447B	[4] DLarrabee	[293] master	\N	\N
3418b19f-4cd9-4df0-b901-ab98a5c01729	2018-02-28 19:45:24.390192-06	1	[21128] Door 447B Copy	[4] DLarrabee	[293] master	\N	\N
d1db590f-6e06-4b83-8df0-db64d1172549	2018-02-28 19:46:20.847838-06	2	[21128] Door 448A	[4] DLarrabee	[293] master	\N	\N
82525de3-4680-4e88-8387-ab49aad36e36	2018-02-28 19:46:25.992352-06	1	[21129] Door 448A Copy	[4] DLarrabee	[293] master	\N	\N
c8129b49-a901-40e5-8b5b-95f593125821	2018-02-28 19:46:59.37269-06	2	[21129] Door 455A	[4] DLarrabee	[293] master	\N	\N
7d9d523b-7594-4f25-8896-da893b9fa675	2018-02-28 19:47:03.618114-06	1	[21130] Door 455A Copy	[4] DLarrabee	[293] master	\N	\N
b8800009-0660-4fd8-8e0e-c1e6f954e35d	2018-02-28 19:48:17.503502-06	2	[21130] Door 455B	[4] DLarrabee	[293] master	\N	\N
7258d86f-f629-4a0b-989e-b4c180bd28f6	2018-02-28 19:48:22.88804-06	1	[21131] Door 455B Copy	[4] DLarrabee	[293] master	\N	\N
45033939-5740-46a6-b7d4-5da10c2a8833	2018-02-28 19:49:16.88844-06	2	[21131] Door 455D	[4] DLarrabee	[293] master	\N	\N
ed670ee6-ce18-48b3-9f15-4e397597f093	2018-02-28 19:49:26.98745-06	1	[21132] Door 455D Copy	[4] DLarrabee	[293] master	\N	\N
fa52c600-ace1-472f-9d28-eefa8841f5db	2018-02-28 20:20:27.203453-06	2	[21132] Door 455D Copy	[4] DLarrabee	[293] master	\N	\N
224270ff-fb91-46e8-85f6-9b77ae341f16	2018-03-01 07:51:14.237798-06	1	[21133] Key.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
def0a9b5-c28a-4cee-8a1a-3ad38a8bcc45	2018-03-01 07:51:17.068081-06	2	[21133] Key.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
e5006777-f15d-41e0-aa8d-2aa17e781850	2018-03-01 07:51:36.401014-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
a35a1bf7-e2fc-4189-a09a-399947c333f0	2018-03-01 07:52:59.356309-06	2	[21092] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
2841452d-dfc6-4bb0-9b57-1c66faf1c5fd	2018-03-01 08:06:59.882353-06	1	[21134] New Screens Group	[4] DLarrabee	[293] master	\N	\N
fecd81bf-5d3c-476b-9432-e359aaece247	2018-03-01 08:07:30.463411-06	2	[21134] 2ND Screen Group	[4] DLarrabee	[293] master	\N	\N
6e294c4f-7280-49ec-87b5-c5f6483fe2ad	2018-03-01 08:07:37.706135-06	1	[21135] New Screen	[4] DLarrabee	[293] master	\N	\N
edbdf5b8-a7b9-4a15-9eb6-7c1760555091	2018-03-01 08:09:21.844548-06	2	[21135] 2ND Screen	[4] DLarrabee	[293] master	\N	\N
7d760ff6-9824-444e-b7a1-efbb3ae2eaa0	2018-03-01 08:09:22.980662-06	2	[21094] Main Screen	[4] DLarrabee	[293] master	\N	\N
c713c332-63a5-49f5-b6d0-79f4389b328e	2018-03-01 08:10:46.923055-06	2	[21135] 2ND Screen	[4] DLarrabee	[293] master	\N	\N
77be0e7d-2ba9-40d2-9f52-4da583b2570b	2018-03-01 08:10:58.820245-06	1	[21136] New	[4] DLarrabee	[293] master	\N	\N
ae73ad10-0c7b-4262-9a0b-3a72a0ff6794	2018-03-01 08:11:47.745137-06	1	[21137] Navigation Key	[21041] OSSI-DNOVAK	[293] master	\N	\N
2a2c000d-703a-4df1-8119-3a11e592deb8	2018-03-01 08:11:50.18138-06	2	[21137] Navigation Key	[21041] OSSI-DNOVAK	[293] master	\N	\N
cc99f1bf-606e-4c09-8fff-91c3075a151f	2018-03-01 08:12:08.593221-06	1	[21138] Key-A.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
bbb4f48a-b500-4cc1-9c28-e047c3372333	2018-03-01 08:12:10.448407-06	2	[21138] Key-A.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
5d20b95d-5842-4033-9964-4cbd3f55828b	2018-03-01 08:12:16.498012-06	1	[21139] Key-B.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
91ad6730-15b5-4915-a76c-04ad9e6ecc5f	2018-03-01 08:12:17.644126-06	2	[21136] 2nd Screen Background and Frame	[4] DLarrabee	[293] master	\N	\N
0272e21c-cc03-4655-b5a7-de791eae648c	2018-03-01 08:12:17.956157-06	2	[21139] Key-B.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
5f793760-bc70-49d8-8366-614f7c04c2cd	2018-03-01 08:12:24.734835-06	2	[21136] 2nd Screen Background and Frame	[4] DLarrabee	[293] master	\N	\N
06bc44f0-cc79-4396-be47-4bf36d443787	2018-03-01 08:12:26.514013-06	1	[21140] Key-C.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
bd485c39-174a-4b66-b36d-1ee90a1f671f	2018-03-01 08:12:28.744236-06	2	[21140] Key-C.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
0971c96c-fd0f-450c-bfad-abb68d0fc960	2018-03-01 08:12:35.475909-06	1	[21141] Key-D.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
e1f22be7-d4e7-4ddc-a907-f9a53ad8d131	2018-03-01 08:12:35.695931-06	2	[21141] Key-D.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
3b77f97d-0a5c-4b47-b65d-cf34ee3656f8	2018-03-01 08:12:42.718633-06	1	[21142] Key-E.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
a9bfbffa-2125-4884-a2b5-6c1f16f73655	2018-03-01 08:12:42.943656-06	2	[21142] Key-E.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
78d6947f-82c7-456e-9a70-6ba161be334d	2018-03-01 08:12:53.515713-06	2	[21136] 2nd Screen Background and Frame	[4] DLarrabee	[293] master	\N	\N
5487f33b-1063-41c6-b487-a7d36c630d09	2018-03-01 08:13:21.102471-06	1	[21143] New Area	[21041] OSSI-DNOVAK	[293] master	\N	\N
5a1734c9-b2a5-4264-8253-3b80b9cb184a	2018-03-01 08:13:38.722233-06	2	[21143] System	[21041] OSSI-DNOVAK	[293] master	\N	\N
d40bc218-94e9-437b-a1ca-abd635b1077c	2018-03-01 08:13:55.041865-06	1	[21144] Counters	[21041] OSSI-DNOVAK	[293] master	\N	\N
b36c5bdb-2c05-488b-bd76-b7b4c8b56851	2018-03-01 08:13:55.044865-06	1	[21145] New Counter Group	[21041] OSSI-DNOVAK	[293] master	\N	\N
4a6138eb-d8d6-4faf-86f5-731846bfd351	2018-03-01 08:13:55.059867-06	1	[21146] New Counter	[21041] OSSI-DNOVAK	[293] master	\N	\N
e00a98f6-e9d8-4b7f-b926-cc989ccdd162	2018-03-01 08:13:57.542115-06	2	[21144] Counters	[21041] OSSI-DNOVAK	[293] master	\N	\N
365db4e6-e52b-4f8f-998f-f458ad634fef	2018-03-01 08:14:30.614422-06	2	[21145] Navigation Counter	[21041] OSSI-DNOVAK	[293] master	\N	\N
456db12d-388b-4cdc-992a-98037dfbaba0	2018-03-01 08:14:45.810941-06	1	[21147] 1	[21041] OSSI-DNOVAK	[293] master	\N	\N
2fd0ad7d-76e1-4db5-96ad-e4dfdc881f78	2018-03-01 08:15:22.013561-06	1	[21148] New Counter (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
db64f2f5-2c22-4201-8556-d358caa79430	2018-03-01 08:15:22.019562-06	1	[21149] New Counter (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
0d28ec91-524d-410b-a03b-4410e2fcacce	2018-03-01 08:15:22.028563-06	1	[21150] New Counter (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
4074c52f-64be-4e3c-84d3-bfd3c3b4ef69	2018-03-01 08:15:22.031563-06	1	[21151] New Counter (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
3003bd89-54eb-4ed2-b078-bd337c692daa	2018-03-01 08:15:33.320692-06	3	[21148] New Counter (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
d23f12f5-64ae-4109-87a2-f862d5edddf5	2018-03-01 08:15:33.561716-06	2	[21149] New Counter (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
da443260-e5f3-4469-a199-ab9415f47b49	2018-03-01 08:15:33.564716-06	2	[21150] New Counter (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
7f358c6f-9eea-4af5-ac62-2fd2d8750e62	2018-03-01 08:15:33.568717-06	2	[21151] New Counter (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
5b60e644-b5db-4427-a892-cd165d8dea3b	2018-03-01 08:15:37.083068-06	3	[21149] New Counter (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
c920a249-4d9b-4669-b87d-f6ebc43f052f	2018-03-01 08:15:37.30209-06	2	[21150] New Counter (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
618924dd-e06c-4241-8818-184cbf2062b6	2018-03-01 08:15:37.30509-06	2	[21151] New Counter (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
60323a51-0611-4cdc-b01e-21b089a70f70	2018-03-01 08:15:41.271487-06	3	[21150] New Counter (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
76b275aa-e6e7-4112-af4d-60de5356e4e3	2018-03-01 08:15:41.490509-06	2	[21151] New Counter (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
3ae39160-8129-4abc-88cc-33a0608e2646	2018-03-01 08:15:45.491909-06	3	[21151] New Counter (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
f5c0ecd4-042e-4f9a-a9d6-c1417b16486a	2018-03-01 08:15:55.116871-06	1	[21148] 2	[21041] OSSI-DNOVAK	[293] master	\N	\N
d498f97a-cf6e-400a-8050-93e173b28246	2018-03-01 08:15:55.121872-06	1	[21149] 3	[21041] OSSI-DNOVAK	[293] master	\N	\N
f49ca178-600b-43f3-b3eb-431d019ce2f8	2018-03-01 08:15:55.126872-06	1	[21150] 4	[21041] OSSI-DNOVAK	[293] master	\N	\N
cc0f57b6-5c7a-49ce-aca6-7014f8d0315e	2018-03-01 08:15:55.129873-06	1	[21151] 5	[21041] OSSI-DNOVAK	[293] master	\N	\N
58ab9282-d582-4b2a-a8da-9cdbcfad2ab7	2018-03-01 08:16:02.571617-06	2	[21147] A	[21041] OSSI-DNOVAK	[293] master	\N	\N
4b0c7d0b-299b-4e44-84db-f61bb026ee50	2018-03-01 08:16:09.494309-06	2	[21148] B	[21041] OSSI-DNOVAK	[293] master	\N	\N
d440f890-fd4e-4b15-8d88-be29a7a830d5	2018-03-01 08:16:17.869146-06	2	[21149] C	[21041] OSSI-DNOVAK	[293] master	\N	\N
d8cbc464-1113-4524-be74-988d90055cb5	2018-03-01 08:16:24.626822-06	2	[21150] D	[21041] OSSI-DNOVAK	[293] master	\N	\N
2ff57d7f-f5aa-4d99-ab05-ecf17210381a	2018-03-01 08:16:32.782637-06	2	[21151] E	[21041] OSSI-DNOVAK	[293] master	\N	\N
c6ce5488-f584-49b2-ae00-31c7128bd0ea	2018-03-01 08:18:40.903448-06	2	[21092] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
5345e717-1c08-4257-8de1-4dc86ffe4f3c	2018-03-01 08:20:05.418899-06	1	[21152] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
e6845bfb-fc7f-4411-a370-e8821fd84643	2018-03-01 08:21:03.706727-06	2	[21152] Area A Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
a6d1b677-9e01-4d8a-8699-35965cf8f42a	2018-03-01 08:21:57.587115-06	2	[21152] Area A Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
97c5b454-a8ed-4c41-90d5-7b4359870e25	2018-03-01 08:22:05.94395-06	1	[21153] Area A Target Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
ea6355c4-9ead-4b2a-b0e8-c73e777328ec	2018-03-01 08:22:38.421198-06	2	[21153] Area B Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
90de7fd5-9df4-4851-82b1-05fc606df738	2018-03-01 08:22:45.654921-06	1	[21154] Area B Target Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
53668549-fb7d-4c66-8db4-aa46ceb779ea	2018-03-01 08:23:30.594414-06	2	[21154] Area C Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
bec2ac79-69fb-4c9a-b8ce-b52375c029e4	2018-03-01 08:23:41.215476-06	1	[21155] Area C Target Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
f5383e6b-6137-40fd-9b65-a5d08400762b	2018-03-01 08:24:13.924747-06	2	[21155] Area D Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
7bbd40cc-c201-4684-a0dd-76d09f8e2744	2018-03-01 08:24:18.85524-06	1	[21156] Area D Target Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
e5259402-b4c5-44a8-8e6b-650172668b3c	2018-03-01 08:24:57.876142-06	1	[21157] Door 316B	[4] DLarrabee	[293] master	\N	\N
97e9791b-f477-4428-8752-b1d561f9319c	2018-03-01 08:24:59.215276-06	2	[21156] Area E Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
3bee0994-94a4-4e42-ab85-08caa24596c8	2018-03-01 08:26:26.395993-06	2	[21157] Door 103	[4] DLarrabee	[293] master	\N	\N
81422a1d-7a9e-4056-aeda-9694cb138063	2018-03-01 08:26:32.944648-06	1	[21158] Door 103 Copy	[4] DLarrabee	[293] master	\N	\N
a0201245-2c7f-4944-a89b-766a76197bb1	2018-03-01 08:26:52.988652-06	2	[21152] Area A Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
191cb432-feac-4f5a-b302-5965b0b6c2f6	2018-03-01 08:27:08.284181-06	2	[21158] Door 104	[4] DLarrabee	[293] master	\N	\N
3d2ff327-925e-4b30-80ae-05f7e4f2342c	2018-03-01 08:27:14.866839-06	1	[21159] Door 104 Copy	[4] DLarrabee	[293] master	\N	\N
38246b74-e56f-48ac-9e89-d3a96321139d	2018-03-01 08:27:25.658919-06	2	[21153] Area B Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
5407edb2-158a-4e48-8929-4df8d66ba37f	2018-03-01 08:27:59.412294-06	2	[21154] Area C Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
a382fef5-2cb9-4439-aef4-34e03401ac45	2018-03-01 08:28:22.77963-06	2	[21159] Door 105	[4] DLarrabee	[293] master	\N	\N
427dda0e-1cdf-448e-a165-eca88b9470af	2018-03-01 08:28:30.566409-06	1	[21160] Door 105 Copy	[4] DLarrabee	[293] master	\N	\N
6d6cf643-b853-40f6-9868-70134b2503bb	2018-03-01 08:28:38.953247-06	2	[21155] Area D Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
adcc20bf-45fa-438d-ad56-5c079bd09305	2018-03-01 08:28:51.269479-06	2	[21160] Door 107	[4] DLarrabee	[293] master	\N	\N
881146ca-2845-489e-befd-8a24f99e0b5f	2018-03-01 08:28:57.766128-06	1	[21161] Door 107 Copy	[4] DLarrabee	[293] master	\N	\N
771998fa-87c9-4a80-99d7-e150617a3c70	2018-03-01 08:29:06.521004-06	2	[21156] Area E Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
34dcdca1-5c50-4391-98c8-02beb001a57b	2018-03-01 08:29:48.153167-06	1	[21162] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
c917bbc6-37e2-48a8-be8f-aa3c2bc1227a	2018-03-01 08:30:06.950046-06	2	[21161] Door 108	[4] DLarrabee	[293] master	\N	\N
33537fb7-c791-428c-ab97-747ae3bc8eeb	2018-03-01 08:30:35.049856-06	1	[21163] Door 108 Copy	[4] DLarrabee	[293] master	\N	\N
b8dc7cd2-116f-4281-aeb7-eb13f5e39c07	2018-03-01 08:30:55.504901-06	2	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
1fa9cec2-ab99-4d32-b391-55cb658a2c00	2018-03-01 08:31:02.09856-06	3	[21053] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
b6cad0a9-75d2-476f-bd71-d3b1b76bd702	2018-03-01 08:31:15.539904-06	2	[21163] Door 109	[4] DLarrabee	[293] master	\N	\N
b11fd437-e2df-455e-a6d4-f91745820d30	2018-03-01 08:31:25.425893-06	1	[21053] Door 109 Copy	[4] DLarrabee	[293] master	\N	\N
bb196669-9d9a-4679-80b1-c4a86b63a346	2018-03-01 08:32:26.973047-06	2	[21053] Door 112	[4] DLarrabee	[293] master	\N	\N
b2ce3e54-f1ef-4cdd-87a1-99a3cc807c54	2018-03-01 08:32:31.583508-06	1	[21078] Door 112 Copy	[4] DLarrabee	[293] master	\N	\N
80faca86-0b38-42ed-b7b6-537c9039d3bd	2018-03-01 08:33:05.675917-06	2	[21091] Frame	[21041] OSSI-DNOVAK	[293] master	\N	\N
49a97535-9de3-4411-b626-91b0ae36e582	2018-03-01 08:33:37.322081-06	2	[21091] Frame	[21041] OSSI-DNOVAK	[293] master	\N	\N
e0752e03-10d9-4748-86a4-d1e6f38c8dd1	2018-03-01 08:33:45.997949-06	2	[21078] Door 114A	[4] DLarrabee	[293] master	\N	\N
8d57352b-3dd3-48a3-b80e-2d18f206e306	2018-03-01 08:33:50.176366-06	1	[21079] Door 114A Copy	[4] DLarrabee	[293] master	\N	\N
88dc1408-71e8-4c95-9884-f58dec7d407d	2018-03-01 08:33:55.541903-06	2	[21090] New Shared Screen Object	[21041] OSSI-DNOVAK	[293] master	\N	\N
dd57945b-5e78-46d9-b5d3-96ac93ed5c23	2018-03-01 08:34:26.276976-06	2	[21091] Frame	[21041] OSSI-DNOVAK	[293] master	\N	\N
f32b2d08-cd15-4fa0-a472-814e3cadfd46	2018-03-01 08:34:39.783327-06	2	[21090] New Shared Screen Object	[21041] OSSI-DNOVAK	[293] master	\N	\N
2889a49d-92cf-47a6-a026-abd353f47ff0	2018-03-01 08:34:49.476296-06	2	[21090] New Shared Screen Object	[21041] OSSI-DNOVAK	[293] master	\N	\N
674581b6-49ee-497b-b8f5-5b66d0bf0794	2018-03-01 08:35:51.167464-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
f1ad94f7-2c21-41a6-8f49-dec7babf62b9	2018-03-01 08:36:16.303978-06	2	[21047] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
3fe819ae-7ce2-4536-852f-4a4d57eb0556	2018-03-01 08:36:19.781325-06	2	[21079] Door 115	[4] DLarrabee	[293] master	\N	\N
392688d0-72f8-4d7c-a237-e5ce9ea5ccec	2018-03-01 08:36:22.902638-06	1	[21080] Door 115 Copy	[4] DLarrabee	[293] master	\N	\N
a1c09274-1a7f-415f-9df5-2fdcd223094c	2018-03-01 08:36:48.607208-06	2	[21080] Door 116	[4] DLarrabee	[293] master	\N	\N
12fa4b38-afc8-4fe3-adfb-092a1f132dae	2018-03-01 08:36:51.702517-06	1	[21081] Door 115 Copy	[4] DLarrabee	[293] master	\N	\N
ceb21447-471d-4e7c-b0be-f8079fb03a55	2018-03-01 08:37:16.194966-06	2	[21079] Door 115	[4] DLarrabee	[293] master	\N	\N
48a02b20-ee6c-429f-9f47-65a5f94a3c44	2018-03-01 08:37:40.192366-06	2	[21081] Door 116	[4] DLarrabee	[293] master	\N	\N
ebc97b26-2065-42c6-828f-2c6885f1ec9c	2018-03-01 08:37:44.585805-06	1	[21082] Door 115 Copy	[4] DLarrabee	[293] master	\N	\N
1205f538-13e0-49af-a7b2-fdbb18ca4afb	2018-03-01 08:38:05.372018-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
cd5b05c9-b9ad-4a45-a104-0fce6187fd40	2018-03-01 08:38:11.631006-06	2	[21082] Door 116	[4] DLarrabee	[293] master	\N	\N
820fb1b3-b541-4eea-98d1-3dadd6a83f7f	2018-03-01 08:38:14.89939-06	1	[21083] Door 116 Copy	[4] DLarrabee	[293] master	\N	\N
e8bfdd3a-8c18-4fb6-a75d-c5e3a0e72361	2018-03-01 08:38:17.075647-06	3	[21061] Tool Bar Name	[21041] OSSI-DNOVAK	[293] master	\N	\N
76b47bab-8227-4ab0-a903-af65718d8b97	2018-03-01 08:38:33.693342-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
84539f68-6068-49d4-bbde-410dbfb79338	2018-03-01 08:38:41.330228-06	2	[21083] Door 117	[4] DLarrabee	[293] master	\N	\N
bcd04fc0-7712-4636-8c14-67b526c5fdbf	2018-03-01 08:38:45.19913-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
d449c508-f377-4815-9a4c-67faba5a1a72	2018-03-01 08:38:47.637178-06	2	[21083] Door 117	[4] DLarrabee	[293] master	\N	\N
fa86279e-45cf-4ff8-a61b-9d3ec11a6c2f	2018-03-01 08:38:50.788655-06	1	[21061] Door 117 Copy	[4] DLarrabee	[293] master	\N	\N
70ef480f-accc-4001-95a5-9b42d5840c0b	2018-03-01 08:39:12.585204-06	2	[21061] Door 119	[4] DLarrabee	[293] master	\N	\N
059c42e7-6646-4091-97af-46ab83486528	2018-03-01 08:39:15.95051-06	1	[21164] Door 119 Copy	[4] DLarrabee	[293] master	\N	\N
c2a1ab00-246b-42eb-8321-78dbaf3b5bf7	2018-03-01 08:39:18.954105-06	2	[21046] Tool 240x320.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
44d9ed07-95dc-4bba-890d-220cfc1fc833	2018-03-01 08:39:40.991461-06	2	[21164] Door 121	[4] DLarrabee	[293] master	\N	\N
abf29865-4fd3-4eee-b0ae-1e9928e9a938	2018-03-01 08:39:41.781828-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
88180f65-56b4-41e3-82a5-ad00640e1dae	2018-03-01 08:39:44.38974-06	1	[21165] Door 121 Copy	[4] DLarrabee	[293] master	\N	\N
c4ddb367-e4fa-4d8b-b430-85c0827957a9	2018-03-01 08:39:52.48326-06	2	[21055] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
c78baedd-d656-40fa-b9bc-552d361ccd8f	2018-03-01 08:39:59.101961-06	2	[21056] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
3542f00e-eae1-4fb5-a10b-9dec01c0bc46	2018-03-01 08:40:03.648321-06	2	[21057] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
90f08d7d-9235-4e13-af16-e173022f396e	2018-03-01 08:40:06.03441-06	2	[21059] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
b5288373-d18c-4b2a-ab34-3ec301889cbe	2018-03-01 08:40:10.251034-06	2	[21057] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
dbdcd6eb-cbea-4520-a8b3-833a86559d40	2018-03-01 08:40:10.258029-06	2	[21165] Door 122	[4] DLarrabee	[293] master	\N	\N
40f74d92-627b-4c16-b4ff-cfcaf0478005	2018-03-01 08:40:14.651511-06	2	[21060] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
5332c285-6645-47fa-96ef-c0ed13c9c57e	2018-03-01 08:40:20.020213-06	2	[21058] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
300dce86-bc37-4b32-8e7b-56f5ae79e336	2018-03-01 08:40:47.010603-06	2	[21059] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
27af06cf-aa54-42e5-98d3-bbced42deeac	2018-03-01 08:41:06.070343-06	1	[21166] Door 122 Copy	[4] DLarrabee	[293] master	\N	\N
21fc90f0-e8f9-4992-a399-a6814325d5ed	2018-03-01 08:41:29.410656-06	3	[21086] Detention Hall.jpg	[21041] OSSI-DNOVAK	[293] master	\N	\N
4cce7db6-2d69-441a-baa0-d0974dda34f5	2018-03-01 08:41:29.635476-06	2	[21162] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
770f4d36-01ce-499a-9f84-9c33db4ee885	2018-03-01 08:41:32.351302-06	2	[21166] Door 123	[4] DLarrabee	[293] master	\N	\N
5abca5c1-6711-4b9a-8c80-d59f659fe099	2018-03-01 08:41:36.235192-06	1	[21086] Door 123 Copy	[4] DLarrabee	[293] master	\N	\N
b723a0a6-d982-456d-8feb-64f0f5d4db88	2018-03-01 08:41:56.315115-06	2	[21087] Alarm Box	[21041] OSSI-DNOVAK	[293] master	\N	\N
8ea643e6-9a99-439d-a4e0-4bc07ff8aa48	2018-03-01 08:42:09.459591-06	2	[21086] Door 124	[4] DLarrabee	[293] master	\N	\N
edf9c48a-e7ba-483b-b1bc-630c9926f6e2	2018-03-01 08:42:33.549304-06	2	[21081] Door 116	[4] DLarrabee	[293] master	\N	\N
b20c9d5d-1b22-41b5-8402-f0f11a077307	2018-03-01 08:43:10.311238-06	2	[21082] Door 125	[4] DLarrabee	[293] master	\N	\N
6bfc1b9e-a68f-4778-9413-381fc9f6907f	2018-03-01 08:45:13.195657-06	2	[21081] Door 126	[4] DLarrabee	[293] master	\N	\N
046678ae-33ee-465e-938f-2f91591230b4	2018-03-01 08:46:31.134066-06	1	[21167] Door 126 Copy	[4] DLarrabee	[293] master	\N	\N
973f5bfd-5885-40fc-b100-82489bf05667	2018-03-01 08:46:58.384615-06	2	[21167] Door 128	[4] DLarrabee	[293] master	\N	\N
1798a1fb-ca2a-40e5-bc6d-700cb71e559d	2018-03-01 08:47:01.162059-06	1	[21168] Door 128 Copy	[4] DLarrabee	[293] master	\N	\N
d425b4a0-eaa2-40c5-b4dd-d6b9d95371b0	2018-03-01 08:47:35.362218-06	2	[21168] Door 129	[4] DLarrabee	[293] master	\N	\N
d124a040-052d-4078-a397-c107297028ff	2018-03-01 08:47:47.494791-06	1	[21169] Door 129 Copy	[4] DLarrabee	[293] master	\N	\N
1ec06e3c-f1e1-4006-a6b3-dfb8c58af03d	2018-03-01 08:48:19.071361-06	2	[21169] Door 131	[4] DLarrabee	[293] master	\N	\N
2e2c3c98-54d6-4f3d-aaf1-30dc28847838	2018-03-01 08:53:01.792361-06	2	[21087] Alarm Box	[4] DLarrabee	[293] master	\N	\N
8700822b-2680-466e-a693-1f1bf054564e	2018-03-01 08:55:45.010361-06	2	[21087] Alarm Box	[4] DLarrabee	[293] master	\N	\N
b47613c3-efa7-4c13-adc6-13f2792cc553	2018-03-01 08:56:14.036361-06	2	[21087] Alarm Box	[4] DLarrabee	[293] master	\N	\N
0b7495d4-ec10-4c0d-b2fc-a4973a8f30c2	2018-03-01 08:56:37.678361-06	2	[21087] Alarm Box	[4] DLarrabee	[293] master	\N	\N
1543af3a-f624-4a37-8e35-cc3590cbee93	2018-03-01 08:57:19.207361-06	2	[21087] Alarm Box	[4] DLarrabee	[293] master	\N	\N
5a0a8854-c1b1-466a-accf-f90c5c49c08a	2018-03-01 08:57:56.425043-06	2	[21087] Alarm Box	[4] DLarrabee	[293] master	\N	\N
7f8b8e01-6c24-4d64-b178-5818fb1ca575	2018-03-01 08:58:39.314331-06	2	[21087] Alarm Box	[4] DLarrabee	[293] master	\N	\N
15d8c619-2620-40ab-a407-b4390fe61589	2018-03-01 09:02:30.635461-06	2	[21090] New Shared Screen Object	[4] DLarrabee	[293] master	\N	\N
0ad1edf4-b0a2-44d0-9274-3251f3227efc	2018-03-01 09:03:14.780875-06	2	[21090] New Shared Screen Object	[4] DLarrabee	[293] master	\N	\N
5cc8cf2e-a6d2-4124-a82b-8eb9b33a20d5	2018-03-01 09:03:51.316528-06	2	[21090] New Shared Screen Object	[4] DLarrabee	[293] master	\N	\N
2b50ed4d-a07f-45ac-abd3-a9cbd1472547	2018-03-01 09:07:24.15481-06	2	[21152] Area A Target	[4] DLarrabee	[293] master	\N	\N
746948b5-280a-49db-a41f-93f826cf32e9	2018-03-01 09:07:42.603655-06	2	[21153] Area B Target	[4] DLarrabee	[293] master	\N	\N
35e9b721-e3d2-4f74-b50f-573fc8138083	2018-03-01 09:07:57.720166-06	2	[21154] Area C Target	[4] DLarrabee	[293] master	\N	\N
2f9b8b9b-9c3d-4a8b-92d4-8503bc650621	2018-03-01 09:08:12.210615-06	2	[21155] Area D Target	[4] DLarrabee	[293] master	\N	\N
30b68977-674b-456f-a10e-c952ead99e09	2018-03-01 09:08:24.716866-06	2	[21156] Area E Target	[4] DLarrabee	[293] master	\N	\N
19d2db48-3b5f-4db5-9ccb-1fe5e228dd92	2018-03-01 09:15:39.830373-06	1	[21170] Door 131 Copy	[4] DLarrabee	[293] master	\N	\N
3b684064-f4b6-4895-a4e9-fe2fb34a5413	2018-03-01 09:16:21.115501-06	2	[21170] Door 132	[4] DLarrabee	[293] master	\N	\N
2a73130a-4acb-4ca9-8028-f4fbff82c388	2018-03-01 09:16:26.231012-06	1	[21171] Door 132 Copy	[4] DLarrabee	[293] master	\N	\N
4296afa7-8573-4b6d-b5ed-617b17429483	2018-03-01 09:17:29.451334-06	2	[21171] Door 133	[4] DLarrabee	[293] master	\N	\N
c8fa0798-b35d-4359-a027-5bceed95a2ed	2018-03-01 09:17:35.993988-06	1	[21172] Door 133 Copy	[4] DLarrabee	[293] master	\N	\N
47d8d792-b798-4b75-9f01-59d08fb6aab7	2018-03-01 09:18:06.339022-06	2	[21172] Door 134A	[4] DLarrabee	[293] master	\N	\N
a1e12d97-5245-4482-b300-f215c427375e	2018-03-01 09:18:10.428431-06	1	[21173] Door 134A Copy	[4] DLarrabee	[293] master	\N	\N
e3c0c381-1b36-44bd-9cf9-a347a77eb2fa	2018-03-01 09:18:43.875775-06	2	[21173] Door 134B	[4] DLarrabee	[293] master	\N	\N
4246650c-f23d-46fd-bcc3-5b98c7b64ab3	2018-03-01 09:18:48.1252-06	1	[21174] Door 134B Copy	[4] DLarrabee	[293] master	\N	\N
e6ec51fe-9504-48d1-af21-85aedb062f9a	2018-03-01 09:19:16.82307-06	2	[21174] Door 136	[4] DLarrabee	[293] master	\N	\N
243a6fb8-4aca-45a7-aad4-cba2a2ef73cc	2018-03-01 09:19:20.82947-06	1	[21175] Door 136 Copy	[4] DLarrabee	[293] master	\N	\N
7f739b9e-15b3-4806-b1c9-16d082ee67b8	2018-03-01 09:19:51.83357-06	2	[21175] Door 137	[4] DLarrabee	[293] master	\N	\N
ddf8adbe-254f-4930-ba99-0a92aba97e06	2018-03-01 09:19:55.614948-06	1	[21176] Door 137 Copy	[4] DLarrabee	[293] master	\N	\N
efbe3763-f399-4396-b9bc-8b0d0c4ea5dd	2018-03-01 09:20:17.93018-06	2	[21176] Door 138	[4] DLarrabee	[293] master	\N	\N
e056266d-df0a-42a0-bc6e-2afafcf1fd7f	2018-03-01 09:20:21.487535-06	1	[21177] Door 138 Copy	[4] DLarrabee	[293] master	\N	\N
e9da9e7d-ea36-453b-8c9c-45b5a02b9d65	2018-03-01 09:20:52.595646-06	2	[21177] Door 141	[4] DLarrabee	[293] master	\N	\N
74649c89-3985-412a-a643-3215326a38f9	2018-03-01 09:20:56.73806-06	1	[21178] Door 141 Copy	[4] DLarrabee	[293] master	\N	\N
260cfc15-ebc4-4ce1-b761-b85a021c0886	2018-03-01 09:21:18.564243-06	2	[21178] Door 142	[4] DLarrabee	[293] master	\N	\N
b62b9fde-36d4-497c-a6a0-b811c386c8ad	2018-03-01 09:21:45.346921-06	1	[21179] Door 142 Copy	[4] DLarrabee	[293] master	\N	\N
d5ac5715-5410-4643-b0cf-8ee19d777aee	2018-03-01 09:22:34.428828-06	2	[21179] Door 145	[4] DLarrabee	[293] master	\N	\N
d391f6cb-923d-4c9e-8367-18f7b51d9939	2018-03-01 09:22:36.613047-06	1	[21180] Door 145 Copy	[4] DLarrabee	[293] master	\N	\N
ab70744a-b327-460d-8938-21167a9f0749	2018-03-01 09:23:03.069692-06	2	[21180] Door 146	[4] DLarrabee	[293] master	\N	\N
dc97b128-863e-4277-8fdc-5b4fbc7fd0ce	2018-03-01 09:23:06.775063-06	1	[21181] Door 146 Copy	[4] DLarrabee	[293] master	\N	\N
620e786f-1f55-4038-9a10-005c1b0e4eb5	2018-03-01 09:23:41.294514-06	2	[21181] Door 201	[4] DLarrabee	[293] master	\N	\N
b4bffcdb-d13e-4616-b7f7-219532a5c8cb	2018-03-01 09:23:44.55184-06	1	[21182] Door 201 Copy	[4] DLarrabee	[293] master	\N	\N
92cfe36a-c9df-4741-9b17-ee620b3da74a	2018-03-01 09:24:06.964081-06	2	[21182] Door 202	[4] DLarrabee	[293] master	\N	\N
e5b6f743-cd0b-48ab-900c-82bb74f1d7d3	2018-03-01 09:24:10.840468-06	1	[21183] Door 202 Copy	[4] DLarrabee	[293] master	\N	\N
49022538-b2b3-4dc4-bb56-39f28e69db4d	2018-03-01 09:24:36.85607-06	2	[21183] Door 203	[4] DLarrabee	[293] master	\N	\N
b49c75c6-4400-4652-b002-a5fcf2348c7a	2018-03-01 09:24:40.345419-06	1	[21184] Door 203 Copy	[4] DLarrabee	[293] master	\N	\N
8b6dc1c5-70c4-4bf8-9adc-593c1de76cc5	2018-03-01 09:25:07.591143-06	2	[21184] Door 205	[4] DLarrabee	[293] master	\N	\N
420080ab-0cc3-4e98-bf0e-fc8b51088cc6	2018-03-01 09:25:11.274511-06	1	[21185] Door 205 Copy	[4] DLarrabee	[293] master	\N	\N
bcaa598f-ad3d-4987-ac68-3be223b68900	2018-03-01 09:25:35.076891-06	2	[21185] Door 206	[4] DLarrabee	[293] master	\N	\N
e93b55a4-a2af-4235-9336-01e9ba22266a	2018-03-01 09:25:39.133297-06	1	[21186] Door 206 Copy	[4] DLarrabee	[293] master	\N	\N
b2a269dc-bed5-48c4-8c9d-17badf4307cf	2018-03-01 09:26:02.537637-06	2	[21186] Door 207	[4] DLarrabee	[293] master	\N	\N
30be0884-0946-428d-9f0f-6c2170779aa3	2018-03-01 09:26:05.051888-06	1	[21187] Door 207 Copy	[4] DLarrabee	[293] master	\N	\N
ff2e7d9a-55d8-4a6c-b503-f50d5d15e35f	2018-03-01 09:26:35.012884-06	2	[21187] Door 209A	[4] DLarrabee	[293] master	\N	\N
7d8c96ab-879d-4648-b5a0-667fc5735f3d	2018-03-01 09:26:41.085491-06	1	[21188] Door 209A Copy	[4] DLarrabee	[293] master	\N	\N
c292b250-7735-46e9-bbc0-a53eeb7a3a0e	2018-03-01 09:27:21.207503-06	2	[21188] Door 209B	[4] DLarrabee	[293] master	\N	\N
1b93d609-778f-4cd4-bb79-e00a8661ad76	2018-03-01 09:27:24.350818-06	1	[21189] Door 209B Copy	[4] DLarrabee	[293] master	\N	\N
e41564b0-f0a8-42e3-89a4-6c2ba6f0814a	2018-03-01 09:27:45.852968-06	2	[21189] Door 211	[4] DLarrabee	[293] master	\N	\N
f1005d80-ba38-4f81-b5f4-a118f0e9560e	2018-03-01 09:27:49.696352-06	1	[21190] Door 211 Copy	[4] DLarrabee	[293] master	\N	\N
6cf79254-e0e0-4e92-a8bd-c3aff3be86e7	2018-03-01 09:28:24.350817-06	2	[21190] Door 213	[4] DLarrabee	[293] master	\N	\N
96566201-8a27-49c2-8a83-58a6668d58b6	2018-03-01 09:28:28.465228-06	1	[21191] Door 213 Copy	[4] DLarrabee	[293] master	\N	\N
98a36e59-edb1-4b07-8f2d-19d820465e48	2018-03-01 09:29:06.116993-06	2	[21191] Door 214	[4] DLarrabee	[293] master	\N	\N
f386ae12-1cbf-4abd-8468-b6f25563b47e	2018-03-01 09:29:09.875369-06	1	[21192] Door 214 Copy	[4] DLarrabee	[293] master	\N	\N
87995c58-e0d2-4b9d-83dd-15ccf810b966	2018-03-01 09:29:31.177499-06	2	[21192] Door 215	[4] DLarrabee	[293] master	\N	\N
b1950c70-3314-4dc9-8cf3-df12916e973c	2018-03-01 09:29:34.611842-06	1	[21193] Door 215 Copy	[4] DLarrabee	[293] master	\N	\N
d1eeaa03-8e3c-4bfe-942f-f6df0665abcf	2018-03-01 09:29:54.842865-06	2	[21193] Door 216	[4] DLarrabee	[293] master	\N	\N
3646ab8d-893c-4d05-b147-ac3264d4d932	2018-03-01 09:29:58.676249-06	1	[21194] Door 216 Copy	[4] DLarrabee	[293] master	\N	\N
b160159c-13fd-46a2-931d-6848b158a889	2018-03-01 09:30:21.08849-06	2	[21194] Door 218	[4] DLarrabee	[293] master	\N	\N
75f4fe0a-43ae-479e-bebf-dd513f94d95b	2018-03-01 09:31:24.647845-06	1	[21195] Door 103 Copy	[4] DLarrabee	[293] master	\N	\N
1a1b39f0-53b6-4697-a974-cdb3a212d192	2018-03-01 09:31:24.660846-06	1	[21196] Door 104 Copy	[4] DLarrabee	[293] master	\N	\N
ac2ca316-79f8-4289-b435-9d643acab1bc	2018-03-01 09:31:24.679848-06	1	[21197] Door 105 Copy	[4] DLarrabee	[293] master	\N	\N
a299f126-7b1a-46be-ae84-67169da6673f	2018-03-01 09:31:24.693849-06	1	[21198] Door 107 Copy	[4] DLarrabee	[293] master	\N	\N
d648183f-7623-4907-b572-d4d4a85a3781	2018-03-01 09:31:24.706851-06	1	[21199] Door 108 Copy	[4] DLarrabee	[293] master	\N	\N
bdc7fe69-918e-4667-a3bc-12169ad3e3a9	2018-03-01 09:31:24.721852-06	1	[21200] Door 109 Copy	[4] DLarrabee	[293] master	\N	\N
2df8c294-0802-440c-aa2a-c970ee8e505f	2018-03-01 09:31:24.735854-06	1	[21201] Door 112 Copy	[4] DLarrabee	[293] master	\N	\N
764c7205-5976-4c0e-a836-a85f05502a3e	2018-03-01 09:31:24.749855-06	1	[21202] Door 114A Copy	[4] DLarrabee	[293] master	\N	\N
5338c82e-6fc3-4e92-bc70-f748470ccc5c	2018-03-01 09:31:24.769857-06	1	[21203] Door 115 Copy	[4] DLarrabee	[293] master	\N	\N
8870452a-388a-4b10-9093-539184d80fb3	2018-03-01 09:31:24.785859-06	1	[21204] Door 116 Copy	[4] DLarrabee	[293] master	\N	\N
fa9696a3-e11b-4454-9178-1f438ea365f3	2018-03-01 09:31:24.79886-06	1	[21205] Door 117 Copy	[4] DLarrabee	[293] master	\N	\N
c8bcd7ac-a75f-4c5e-bcb9-0c831a37d8bc	2018-03-01 09:31:24.810861-06	1	[21206] Door 119 Copy	[4] DLarrabee	[293] master	\N	\N
eb35086d-a9e6-460d-b9a0-396e008b2afe	2018-03-01 09:31:24.823862-06	1	[21207] Door 121 Copy	[4] DLarrabee	[293] master	\N	\N
1e74873b-d170-478f-83fd-6c20ead53423	2018-03-01 09:31:24.838864-06	1	[21208] Door 122 Copy	[4] DLarrabee	[293] master	\N	\N
f3bca003-e2b2-440b-96fc-6428c0a01738	2018-03-01 09:34:20.442423-06	2	[21195] Door 219	[4] DLarrabee	[293] master	\N	\N
fa6afb1a-0fb9-4a57-88bb-2d663594bd74	2018-03-01 09:34:43.395718-06	2	[21196] Door 221	[4] DLarrabee	[293] master	\N	\N
9fc1e872-0204-4854-aff0-14055dab9c7a	2018-03-01 09:35:10.079386-06	2	[21197] Door 222	[4] DLarrabee	[293] master	\N	\N
ad927762-d48f-4090-98b6-1cc8cec4c379	2018-03-01 10:38:36.255965-06	2	[21198] Door 223	[4] DLarrabee	[293] master	\N	\N
2cd04553-ad61-498e-b17f-f53d2f99c9db	2018-03-01 10:38:59.599299-06	2	[21199] Door 224	[4] DLarrabee	[293] master	\N	\N
83d7e116-ac0a-439a-8397-a79f58e59343	2018-03-01 10:39:47.446084-06	2	[21200] Door 225	[4] DLarrabee	[293] master	\N	\N
f0126779-bf1a-45ec-a166-6e3dde32916b	2018-03-01 10:40:14.356774-06	2	[21201] Door 226	[4] DLarrabee	[293] master	\N	\N
1ad20edb-b3e9-436f-adc9-8a81131a0195	2018-03-01 10:40:52.397578-06	2	[21202] Door 227	[4] DLarrabee	[293] master	\N	\N
fbffbd3d-60b9-4ce9-9d82-c9a71338e351	2018-03-01 10:41:15.282866-06	2	[21203] Door 228	[4] DLarrabee	[293] master	\N	\N
0253f370-4609-4701-927f-6d9fca2a5b60	2018-03-01 10:41:41.881526-06	2	[21204] Door 231	[4] DLarrabee	[293] master	\N	\N
d8584172-ee52-4139-bed2-1bf7c9a4fd61	2018-03-01 10:42:08.692207-06	2	[21205] Door 232	[4] DLarrabee	[293] master	\N	\N
9783ac92-e67a-46dc-9bfb-ee8570e90959	2018-03-01 10:42:40.359373-06	2	[21206] Door 233	[4] DLarrabee	[293] master	\N	\N
9929de8b-9c70-4f00-bd60-932e95f73a1b	2018-03-01 10:44:08.196156-06	2	[21207] Door 235	[4] DLarrabee	[293] master	\N	\N
a203bb97-851b-4f8c-9af8-eb89be898fce	2018-03-01 10:44:34.945831-06	2	[21208] Door 236	[4] DLarrabee	[293] master	\N	\N
a8517b8e-828a-4d63-9e27-a77f4b55e082	2018-03-01 10:45:22.94663-06	1	[21209] Temp Area A.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
37ae78fb-40e6-4a11-b41b-ba96e6bf8f53	2018-03-01 10:45:24.997835-06	2	[21209] Temp Area A.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
38aaf942-a9b2-4241-9f26-dc2672ed0eaa	2018-03-01 10:45:34.071743-06	1	[21210] Temp Area B.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
f1ee6378-008e-4cf2-bfa0-ac14e554bb21	2018-03-01 10:45:35.572893-06	2	[21210] Temp Area B.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
c2f350cc-74f6-4db3-bda7-dea3144b3364	2018-03-01 10:45:45.591895-06	1	[21211] Temp Area C.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
4fbd2573-cb12-4a85-b634-1b90d0d43d53	2018-03-01 10:45:47.252061-06	2	[21211] Temp Area C.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
1b748017-7326-41a8-a773-f0ade3b96ef6	2018-03-01 10:46:01.932529-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
99f17325-8b42-4ca2-b87a-c876b88a084f	2018-03-01 10:46:12.029538-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
05f7fbd8-e313-488b-a9d0-fc0aadb0ce12	2018-03-01 10:46:41.365471-06	1	[21212] Door 112 Copy	[4] DLarrabee	[293] master	\N	\N
70687b48-f9d3-4b13-a503-1c456405f601	2018-03-01 10:47:07.211056-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
8b5aff90-6c62-4f00-83e9-83e3e556b6aa	2018-03-01 10:47:11.839519-06	2	[21212] Door 113	[4] DLarrabee	[293] master	\N	\N
cf92446a-9c05-47ef-9742-ceb0514e3a40	2018-03-01 10:47:37.778112-06	2	[290] Area A	[21041] OSSI-DNOVAK	[293] master	\N	\N
8adf7b43-ea30-476b-b2fa-91699ead3f19	2018-03-01 10:48:44.170751-06	1	[21213] Area A Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
5fb826ec-6ffa-4f11-a337-449a5317c49b	2018-03-01 10:48:54.937827-06	2	[21213] Area B	[21041] OSSI-DNOVAK	[293] master	\N	\N
5256d19d-74da-40b8-bc7d-594e4caa2429	2018-03-01 10:49:05.742908-06	1	[21227] Door 114A Copy	[4] DLarrabee	[293] master	\N	\N
af634e89-edc0-4137-a281-8f1ae57ee4f3	2018-03-01 10:49:14.001734-06	2	[21216] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
97cdacf5-597e-4e23-912b-43b96fef6652	2018-03-01 10:49:29.658299-06	2	[21216] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
e4093d2e-c198-4a3e-88cc-bf34bab19f5c	2018-03-01 10:49:30.47038-06	2	[21227] Door 114B	[4] DLarrabee	[293] master	\N	\N
3da1e545-a91b-431b-bf3c-965b95e94c7f	2018-03-01 10:49:39.100243-06	2	[21216] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
dda75cba-e9f8-4bab-ad43-77179b4d57e6	2018-03-01 10:49:48.050138-06	1	[21228] Area B Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
423ff978-2116-46f3-82ba-e378e255ab09	2018-03-01 10:50:00.141347-06	2	[21228] Area C	[21041] OSSI-DNOVAK	[293] master	\N	\N
1ed3c52a-318c-4ae1-a0a3-08b98db30513	2018-03-01 10:50:25.616894-06	2	[21231] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
6a0b8d04-50a2-44a4-90d1-6b7639b987e3	2018-03-01 10:50:33.428675-06	2	[21231] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
dced6d4c-5c1c-4858-ba21-d5918d5c68f7	2018-03-01 10:50:48.320164-06	2	[21231] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
d1346cf3-9716-448a-acf0-5d677c504bbc	2018-03-01 10:51:41.891521-06	1	[21242] Area C Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
8878088c-e7d1-436a-9a6c-d7628a3ebfb8	2018-03-01 10:51:55.966928-06	2	[21242] Area D	[21041] OSSI-DNOVAK	[293] master	\N	\N
8afd9304-39a4-49fc-9d8b-441919e1a8c4	2018-03-01 10:52:07.525084-06	1	[21256] Door 236 Copy	[4] DLarrabee	[293] master	\N	\N
726d0ded-4643-4989-a6a1-7f8c8b189066	2018-03-01 10:52:28.801212-06	1	[21257] Area D Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
2c3391b5-89a0-476f-8e55-970bd936f8d7	2018-03-01 10:52:38.522184-06	2	[21256] Door 237A	[4] DLarrabee	[293] master	\N	\N
3f945cdc-e968-41ef-8361-e840702e0432	2018-03-01 10:52:39.959327-06	2	[21257] Area E	[21041] OSSI-DNOVAK	[293] master	\N	\N
284afe07-c3e1-43ea-8a96-c5a65bf50540	2018-03-01 10:52:43.893721-06	1	[21271] Door 237A Copy	[4] DLarrabee	[293] master	\N	\N
4ac7efe6-ecae-41f0-83c0-a1d46efd4fa8	2018-03-01 10:53:07.769108-06	2	[21271] Door 237B	[4] DLarrabee	[293] master	\N	\N
df57041a-a5b7-4777-aed9-5ab725812702	2018-03-01 10:55:03.867717-06	1	[21272] Door 237B Copy	[4] DLarrabee	[293] master	\N	\N
9133797c-fabc-4d05-9e30-82284a19cbfb	2018-03-01 10:55:55.953925-06	2	[21272] Door 239	[4] DLarrabee	[293] master	\N	\N
0f9ac067-dc68-4f8b-b157-e202d94bfce7	2018-03-01 10:55:59.90232-06	1	[21273] Door 239 Copy	[4] DLarrabee	[293] master	\N	\N
50038a0c-896a-46f4-adb2-a4a1dc575723	2018-03-01 10:56:21.11144-06	2	[21273] Door 241	[4] DLarrabee	[293] master	\N	\N
84a96fd9-6bd2-49ec-9b76-bd366b44ea63	2018-03-01 10:56:24.173746-06	1	[21274] Door 241 Copy	[4] DLarrabee	[293] master	\N	\N
e5e1b1c7-5b42-40da-9eac-01978ec8dd01	2018-03-01 11:03:31.302455-06	2	[21274] Door 242	[4] DLarrabee	[293] master	\N	\N
01e6c942-d8c7-4369-b5ed-b9acb3f786ce	2018-03-01 11:03:36.430968-06	1	[21275] Door 242 Copy	[4] DLarrabee	[293] master	\N	\N
40114157-df70-422d-9da8-d4ad5322e4d3	2018-03-01 11:05:31.607484-06	2	[21275] Door 243	[4] DLarrabee	[293] master	\N	\N
65daf7dc-217d-4c77-8706-fcd5746150d2	2018-03-01 11:05:37.507074-06	1	[21276] Door 243 Copy	[4] DLarrabee	[293] master	\N	\N
578b95c8-7252-4349-8b8b-24311f732a70	2018-03-01 11:06:56.554978-06	2	[21276] Door 245	[4] DLarrabee	[293] master	\N	\N
bcfcb340-a919-4ce3-839a-99b9ebff9bef	2018-03-01 11:14:49.41726-06	2	[21245] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
7fcd1f82-2d18-417c-a237-81349ee002d0	2018-03-01 11:16:01.242442-06	1	[21277] Door 245 Copy	[4] DLarrabee	[293] master	\N	\N
704b4400-171e-4783-970a-0caa8909596c	2018-03-01 11:17:17.094026-06	1	[21278] Lock DR-239 Relay	[4] DLarrabee	[293] master	\N	\N
2a68835b-e372-45f1-82e4-8c2afbcec621	2018-03-01 11:18:15.072823-06	1	[21279] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
75a48f46-bd80-459e-968c-8ad094200b8b	2018-03-01 11:18:39.168233-06	2	[21279] Label	[21041] OSSI-DNOVAK	[293] master	\N	\N
0ee888ed-a79e-446b-9fea-c1afd6aa6280	2018-03-01 11:18:55.549871-06	1	[21280] Lock DR-241 Relay	[4] DLarrabee	[293] master	\N	\N
ac377976-18cd-4a17-937a-5078f375d52a	2018-03-01 11:18:55.567872-06	1	[21281] Lock DR-242 Relay	[4] DLarrabee	[293] master	\N	\N
41a063bb-ff73-4cac-b15e-eb52154846ea	2018-03-01 11:18:55.585874-06	1	[21282] Lock DR-243 Relay	[4] DLarrabee	[293] master	\N	\N
39ff7e4d-9958-445c-9823-95e2e971c933	2018-03-01 11:18:55.600876-06	1	[21283] Lock DR-245 Relay	[4] DLarrabee	[293] master	\N	\N
c854caa5-ada9-49dc-a2df-fcf1badac7b7	2018-03-01 11:18:55.615877-06	1	[21284] Lock DR-246 Relay	[4] DLarrabee	[293] master	\N	\N
f8219d19-89eb-4ac6-bd8d-5d8bbbaa8621	2018-03-01 11:18:55.630879-06	1	[21285] Lock DR-247 Relay	[4] DLarrabee	[293] master	\N	\N
9ae58a55-0bfd-43a4-ba46-113742683dcf	2018-03-01 11:18:55.64588-06	1	[21286] Lock DR-248 Relay	[4] DLarrabee	[293] master	\N	\N
5e4e49a1-8ffd-42ee-9434-0a5f82268264	2018-03-01 11:18:55.664882-06	1	[21287] Lock DR-252 Relay	[4] DLarrabee	[293] master	\N	\N
55d6f5a7-1e85-4f33-8e5d-506c3e2704dc	2018-03-01 11:18:55.687884-06	1	[21288] Lock DR-253 Relay	[4] DLarrabee	[293] master	\N	\N
917aec10-e2e4-4e12-8ec7-e083de35dc65	2018-03-01 11:18:55.705886-06	1	[21289] Lock DR-259 Relay	[4] DLarrabee	[293] master	\N	\N
e3249857-93df-493d-b50c-c7ec8dd2e456	2018-03-01 11:18:55.726888-06	1	[21290] Lock DR-261 Relay	[4] DLarrabee	[293] master	\N	\N
35cab2d0-bc1c-4f54-b527-e164eab1f3dc	2018-03-01 11:18:55.749891-06	1	[21291] Lock DR-301A Relay	[4] DLarrabee	[293] master	\N	\N
92291682-8dba-4c1a-b1a0-c1da39719264	2018-03-01 11:18:55.767892-06	1	[21292] Lock DR-301B Relay	[4] DLarrabee	[293] master	\N	\N
ead7ac8c-37d5-46de-943d-992e032a6ebe	2018-03-01 11:18:55.786894-06	1	[21293] Lock DR-306 Relay	[4] DLarrabee	[293] master	\N	\N
689c7431-5ea5-4e24-a966-d73b194b889a	2018-03-01 11:18:55.814897-06	1	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
12186b9e-1550-4627-b801-0a1a60faee76	2018-03-01 11:19:05.081824-06	2	[21260] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
ccbffbf2-5603-4fae-afda-fb8e2ad54d5f	2018-03-01 11:19:15.689884-06	3	[21278] Lock DR-239 Relay	[4] DLarrabee	[293] master	\N	\N
b8c5ac0c-f90e-447a-80a5-b068a016601e	2018-03-01 11:19:15.955911-06	2	[21280] Lock DR-241 Relay	[4] DLarrabee	[293] master	\N	\N
be3c6013-9fe2-4a90-a3d3-ee794f3aa9b0	2018-03-01 11:19:15.969912-06	2	[21281] Lock DR-242 Relay	[4] DLarrabee	[293] master	\N	\N
b53f67d7-3544-4798-8ade-80a372f92aed	2018-03-01 11:19:15.982914-06	2	[21282] Lock DR-243 Relay	[4] DLarrabee	[293] master	\N	\N
90eb4680-1768-408a-8283-4baa050416be	2018-03-01 11:19:15.997915-06	2	[21283] Lock DR-245 Relay	[4] DLarrabee	[293] master	\N	\N
a118b43c-b002-43fb-897e-ad3472b87976	2018-03-01 11:19:16.009916-06	2	[21284] Lock DR-246 Relay	[4] DLarrabee	[293] master	\N	\N
2333ee90-1e11-4474-8219-9591ab8b8e89	2018-03-01 11:19:16.021918-06	2	[21285] Lock DR-247 Relay	[4] DLarrabee	[293] master	\N	\N
787e4e39-9bcf-4a5d-b7d6-2b4194f7eaaf	2018-03-01 11:19:16.033919-06	2	[21286] Lock DR-248 Relay	[4] DLarrabee	[293] master	\N	\N
05a57f4f-bb4d-4a84-830f-b6264b77c197	2018-03-01 11:19:16.04392-06	2	[21287] Lock DR-252 Relay	[4] DLarrabee	[293] master	\N	\N
442a45ad-ed80-4139-8355-45f3ab9145a3	2018-03-01 11:19:16.058921-06	2	[21288] Lock DR-253 Relay	[4] DLarrabee	[293] master	\N	\N
2cd3e7e6-7d14-4b6d-b0ba-7147abe141d7	2018-03-01 11:19:16.072923-06	2	[21289] Lock DR-259 Relay	[4] DLarrabee	[293] master	\N	\N
3b6b32ed-0ad2-41bc-bf6f-761a3e707af2	2018-03-01 11:19:16.086924-06	2	[21290] Lock DR-261 Relay	[4] DLarrabee	[293] master	\N	\N
20c90b47-7dcd-4805-9975-1ccc723f0459	2018-03-01 11:19:16.098925-06	2	[21291] Lock DR-301A Relay	[4] DLarrabee	[293] master	\N	\N
074f1d00-bef7-4e57-8c49-34725a829327	2018-03-01 11:19:16.111927-06	2	[21292] Lock DR-301B Relay	[4] DLarrabee	[293] master	\N	\N
f35df572-1600-42ba-8a88-00ee1d63d725	2018-03-01 11:19:16.122928-06	2	[21293] Lock DR-306 Relay	[4] DLarrabee	[293] master	\N	\N
d0477dbc-4e1f-4737-bc8b-d5511f0f4608	2018-03-01 11:19:16.133929-06	2	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
be4c3b53-0608-460b-a815-ce78a758cfc6	2018-03-01 11:19:16.135929-06	3	[21280] Lock DR-241 Relay	[4] DLarrabee	[293] master	\N	\N
4f504de8-c1d1-4e29-af1d-c8ebdf5f51f1	2018-03-01 11:19:16.411957-06	2	[21281] Lock DR-242 Relay	[4] DLarrabee	[293] master	\N	\N
eeec9623-7956-454c-8996-2f3bd1afb850	2018-03-01 11:19:16.423958-06	2	[21282] Lock DR-243 Relay	[4] DLarrabee	[293] master	\N	\N
197910b6-3283-45b9-a42c-911489ff2905	2018-03-01 11:19:16.436959-06	2	[21283] Lock DR-245 Relay	[4] DLarrabee	[293] master	\N	\N
fc91d51e-ea4a-4ada-98a6-120b8bd97ede	2018-03-01 11:19:16.44696-06	2	[21284] Lock DR-246 Relay	[4] DLarrabee	[293] master	\N	\N
74c2acb1-1a7f-48d7-a98d-6900258f4078	2018-03-01 11:19:16.459961-06	2	[21285] Lock DR-247 Relay	[4] DLarrabee	[293] master	\N	\N
af75a0cc-fd03-46c9-8b9b-9aae479a32a2	2018-03-01 11:19:16.469962-06	2	[21286] Lock DR-248 Relay	[4] DLarrabee	[293] master	\N	\N
1b445ba5-5fbe-40cb-a959-de5792c6fb99	2018-03-01 11:19:16.483964-06	2	[21287] Lock DR-252 Relay	[4] DLarrabee	[293] master	\N	\N
b6620414-6eda-4674-b57a-304cfe38deac	2018-03-01 11:19:16.497965-06	2	[21288] Lock DR-253 Relay	[4] DLarrabee	[293] master	\N	\N
da304e17-caa8-4f0b-8d25-bc8ba86d07c6	2018-03-01 11:19:16.510966-06	2	[21289] Lock DR-259 Relay	[4] DLarrabee	[293] master	\N	\N
eb327373-5e36-425d-b48b-6ce9df783bee	2018-03-01 11:19:16.522968-06	2	[21290] Lock DR-261 Relay	[4] DLarrabee	[293] master	\N	\N
368c9268-f999-424f-ac71-ac83fae25f6d	2018-03-01 11:19:16.537969-06	2	[21291] Lock DR-301A Relay	[4] DLarrabee	[293] master	\N	\N
3656fe26-8fad-4b78-97da-5a2c2b628be0	2018-03-01 11:19:16.54997-06	2	[21292] Lock DR-301B Relay	[4] DLarrabee	[293] master	\N	\N
38a22bb1-c9ae-46e5-9ac7-f1334a126ccd	2018-03-01 11:19:16.563972-06	2	[21293] Lock DR-306 Relay	[4] DLarrabee	[293] master	\N	\N
e4c37837-8128-4579-9483-099305bcb92a	2018-03-01 11:19:16.576973-06	2	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
c2419bca-ff56-4228-bdc4-3e9bd0185cf6	2018-03-01 11:19:16.579973-06	3	[21281] Lock DR-242 Relay	[4] DLarrabee	[293] master	\N	\N
b22e9c2c-56f0-4a0d-b92e-fcecbf417fa7	2018-03-01 11:19:16.876003-06	2	[21282] Lock DR-243 Relay	[4] DLarrabee	[293] master	\N	\N
d875cd4c-ebb7-4afe-ac36-a6a84dce520a	2018-03-01 11:19:16.890004-06	2	[21283] Lock DR-245 Relay	[4] DLarrabee	[293] master	\N	\N
2ca37de5-9e82-4d50-b569-7e3ba3cd80ed	2018-03-01 11:19:16.900005-06	2	[21284] Lock DR-246 Relay	[4] DLarrabee	[293] master	\N	\N
5e35ab54-30c7-4f99-b3ef-830a1ffd2281	2018-03-01 11:19:16.914007-06	2	[21285] Lock DR-247 Relay	[4] DLarrabee	[293] master	\N	\N
23bfbd24-47d6-48c5-89c4-860571d3b354	2018-03-01 11:19:16.925008-06	2	[21286] Lock DR-248 Relay	[4] DLarrabee	[293] master	\N	\N
2404b566-4b20-46f3-9236-a1ec2bb632c4	2018-03-01 11:19:16.938009-06	2	[21287] Lock DR-252 Relay	[4] DLarrabee	[293] master	\N	\N
8d5fcc4f-534c-4c40-b0eb-1f454aa8ca31	2018-03-01 11:19:16.94901-06	2	[21288] Lock DR-253 Relay	[4] DLarrabee	[293] master	\N	\N
0fbba644-e358-41de-bd09-e1b1f4a8c9e1	2018-03-01 11:19:16.960011-06	2	[21289] Lock DR-259 Relay	[4] DLarrabee	[293] master	\N	\N
1f9c62c3-3167-4eac-9df4-43e89e687411	2018-03-01 11:19:16.973013-06	2	[21290] Lock DR-261 Relay	[4] DLarrabee	[293] master	\N	\N
95dc95df-420d-4deb-b2c6-8199c373671e	2018-03-01 11:19:16.987014-06	2	[21291] Lock DR-301A Relay	[4] DLarrabee	[293] master	\N	\N
ccc04cd6-5aa8-40db-a25c-81a34ec2264f	2018-03-01 11:19:17.000015-06	2	[21292] Lock DR-301B Relay	[4] DLarrabee	[293] master	\N	\N
1b639987-6a81-440e-aeb7-4a4d15686c92	2018-03-01 11:19:17.013017-06	2	[21293] Lock DR-306 Relay	[4] DLarrabee	[293] master	\N	\N
d7398ce5-12fb-4e2a-895c-258eb2d6cf19	2018-03-01 11:19:17.023018-06	2	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
84d4181f-c1c2-45cc-81d7-a5fddbf41fcd	2018-03-01 11:19:17.026018-06	3	[21282] Lock DR-243 Relay	[4] DLarrabee	[293] master	\N	\N
14a89116-bb9d-48b7-bb27-ce9c2ce45bd6	2018-03-01 11:19:17.314047-06	2	[21283] Lock DR-245 Relay	[4] DLarrabee	[293] master	\N	\N
ffa859a9-ffd1-4002-a9c2-c143fd5870ad	2018-03-01 11:19:17.327048-06	2	[21284] Lock DR-246 Relay	[4] DLarrabee	[293] master	\N	\N
21df362d-cb1b-4aa9-b810-0e3dfc49094c	2018-03-01 11:19:17.338049-06	2	[21285] Lock DR-247 Relay	[4] DLarrabee	[293] master	\N	\N
dd716519-3ce7-4c72-bee3-75533cd3e568	2018-03-01 11:19:17.35005-06	2	[21286] Lock DR-248 Relay	[4] DLarrabee	[293] master	\N	\N
267b4cfc-338f-4109-bdd1-aba905e309d3	2018-03-01 11:19:17.362052-06	2	[21287] Lock DR-252 Relay	[4] DLarrabee	[293] master	\N	\N
292058b7-cc6f-4dca-b111-3ca2a2f1587c	2018-03-01 11:19:17.373053-06	2	[21288] Lock DR-253 Relay	[4] DLarrabee	[293] master	\N	\N
cebe9692-7e40-4796-8935-3a611292bb6b	2018-03-01 11:19:17.384054-06	2	[21289] Lock DR-259 Relay	[4] DLarrabee	[293] master	\N	\N
bee87e8b-2bef-4f2b-8aaa-d78683aae7cf	2018-03-01 11:19:17.396055-06	2	[21290] Lock DR-261 Relay	[4] DLarrabee	[293] master	\N	\N
511316c4-ffe5-4e79-b9e6-9afe6a0aff62	2018-03-01 11:19:17.411056-06	2	[21291] Lock DR-301A Relay	[4] DLarrabee	[293] master	\N	\N
46c76d20-86fb-4fbd-abd8-f4b059041070	2018-03-01 11:19:17.424058-06	2	[21292] Lock DR-301B Relay	[4] DLarrabee	[293] master	\N	\N
30340e52-9f11-4f4f-b5c0-9f072a42a1de	2018-03-01 11:19:17.436059-06	2	[21293] Lock DR-306 Relay	[4] DLarrabee	[293] master	\N	\N
672f0e0e-ef90-4c01-8dff-ce2cc3b5bc57	2018-03-01 11:19:17.44906-06	2	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
996de006-b024-42a5-b59c-78e50a16187c	2018-03-01 11:19:17.45106-06	3	[21283] Lock DR-245 Relay	[4] DLarrabee	[293] master	\N	\N
07b8580f-dce9-4ce5-8cb9-679ca684b36b	2018-03-01 11:19:17.714087-06	2	[21284] Lock DR-246 Relay	[4] DLarrabee	[293] master	\N	\N
82932c03-e9a7-4042-a08c-38f379a7d6eb	2018-03-01 11:19:17.728088-06	2	[21285] Lock DR-247 Relay	[4] DLarrabee	[293] master	\N	\N
082f0478-0d53-43ba-ade4-79f7aa9f7cce	2018-03-01 11:19:17.741089-06	2	[21286] Lock DR-248 Relay	[4] DLarrabee	[293] master	\N	\N
960744e3-8e67-48f8-a376-92796cd2e5cb	2018-03-01 11:19:17.754091-06	2	[21287] Lock DR-252 Relay	[4] DLarrabee	[293] master	\N	\N
348f4ebd-5ede-485f-9019-d1f9402b0e1a	2018-03-01 11:19:17.764092-06	2	[21288] Lock DR-253 Relay	[4] DLarrabee	[293] master	\N	\N
6bf9e66f-99f0-4f86-aa44-389e4d642c84	2018-03-01 11:19:17.775093-06	2	[21289] Lock DR-259 Relay	[4] DLarrabee	[293] master	\N	\N
80ed9f63-86a8-4168-97f1-2618ce0e4325	2018-03-01 11:19:17.788094-06	2	[21290] Lock DR-261 Relay	[4] DLarrabee	[293] master	\N	\N
550bf1c0-50cb-4184-8222-ba1b506b9ead	2018-03-01 11:57:37.952088-06	2	[21276] Door 245	[4] DLarrabee	[293] master	\N	\N
6e29f071-ea35-4ffc-b493-fa667469c0b3	2018-03-01 11:19:17.798095-06	2	[21291] Lock DR-301A Relay	[4] DLarrabee	[293] master	\N	\N
b99ac4fc-6984-4a43-9de4-e5a4996bb9b0	2018-03-01 11:19:17.812097-06	2	[21292] Lock DR-301B Relay	[4] DLarrabee	[293] master	\N	\N
c257d544-4eb7-4529-8f09-146372eba7d1	2018-03-01 11:19:17.825098-06	2	[21293] Lock DR-306 Relay	[4] DLarrabee	[293] master	\N	\N
ad6e7325-21ae-43fe-a3c9-6292aaa1bd17	2018-03-01 11:19:17.836099-06	2	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
67a57721-699f-4e31-96e2-e5a8cc763d97	2018-03-01 11:19:17.838099-06	3	[21284] Lock DR-246 Relay	[4] DLarrabee	[293] master	\N	\N
6af97d09-8ae4-4c8b-9886-ecffa7aeecfc	2018-03-01 11:19:18.14413-06	2	[21285] Lock DR-247 Relay	[4] DLarrabee	[293] master	\N	\N
414f0ca7-438f-428a-adc4-d5f7c0fe95f6	2018-03-01 11:19:18.159131-06	2	[21286] Lock DR-248 Relay	[4] DLarrabee	[293] master	\N	\N
892c8d38-3b3f-45e1-9a26-77e173821761	2018-03-01 11:19:18.172133-06	2	[21287] Lock DR-252 Relay	[4] DLarrabee	[293] master	\N	\N
7120ca1f-bf28-4f71-9c52-16355839e8e2	2018-03-01 11:19:18.187134-06	2	[21288] Lock DR-253 Relay	[4] DLarrabee	[293] master	\N	\N
a212d07a-681b-4000-a8a8-77d0b2b15f29	2018-03-01 11:19:18.202136-06	2	[21289] Lock DR-259 Relay	[4] DLarrabee	[293] master	\N	\N
defc2cec-1850-4a00-8219-c18cb96fbe96	2018-03-01 11:19:18.216137-06	2	[21290] Lock DR-261 Relay	[4] DLarrabee	[293] master	\N	\N
0fa5478b-1cad-4339-86a6-3757fb47ab03	2018-03-01 11:19:18.229138-06	2	[21291] Lock DR-301A Relay	[4] DLarrabee	[293] master	\N	\N
ad532d99-5004-4905-a6e4-555b864add0a	2018-03-01 11:19:18.241139-06	2	[21292] Lock DR-301B Relay	[4] DLarrabee	[293] master	\N	\N
96ad1000-a807-4131-b00c-b7096c7534cf	2018-03-01 11:19:18.255141-06	2	[21293] Lock DR-306 Relay	[4] DLarrabee	[293] master	\N	\N
4e78eb7e-366d-4a81-8acf-de32a498a82d	2018-03-01 11:19:18.268142-06	2	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
a50a1c75-aefe-454d-aacf-fee51c9b178e	2018-03-01 11:19:18.271142-06	3	[21285] Lock DR-247 Relay	[4] DLarrabee	[293] master	\N	\N
cc6c17e9-c1d7-4768-a9d4-da8f0ed92e8c	2018-03-01 11:19:18.557171-06	2	[21286] Lock DR-248 Relay	[4] DLarrabee	[293] master	\N	\N
926bf8ff-349c-4230-b00f-fb8cf377aae8	2018-03-01 11:19:18.572173-06	2	[21287] Lock DR-252 Relay	[4] DLarrabee	[293] master	\N	\N
36d19c27-2d9f-40fd-9281-c5ebf4f1ffdf	2018-03-01 11:19:18.586174-06	2	[21288] Lock DR-253 Relay	[4] DLarrabee	[293] master	\N	\N
cc94235c-8dea-492e-a799-35728a92ca3c	2018-03-01 11:19:18.601175-06	2	[21289] Lock DR-259 Relay	[4] DLarrabee	[293] master	\N	\N
f5b172bc-260b-4ed9-a843-3e3f53679973	2018-03-01 11:19:18.619177-06	2	[21290] Lock DR-261 Relay	[4] DLarrabee	[293] master	\N	\N
17a661a2-a3d1-4dff-a0dd-9900885e607c	2018-03-01 11:19:18.635179-06	2	[21291] Lock DR-301A Relay	[4] DLarrabee	[293] master	\N	\N
c40d5235-93a6-4fcf-b81d-bb047f00a7d8	2018-03-01 11:19:18.65018-06	2	[21292] Lock DR-301B Relay	[4] DLarrabee	[293] master	\N	\N
699c5dab-d8c7-4615-90d9-f1017760528c	2018-03-01 11:19:18.664182-06	2	[21293] Lock DR-306 Relay	[4] DLarrabee	[293] master	\N	\N
d8678bb8-17bc-4123-99a8-e6afef37f6a0	2018-03-01 11:19:18.679183-06	2	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
e533e740-afb5-4e72-8b0d-190d967b4b07	2018-03-01 11:19:18.682184-06	3	[21286] Lock DR-248 Relay	[4] DLarrabee	[293] master	\N	\N
e5b8e4ef-dbb2-45fe-a1fc-e17301edfd7e	2018-03-01 11:19:18.978213-06	2	[21287] Lock DR-252 Relay	[4] DLarrabee	[293] master	\N	\N
998de9f4-b23c-47ad-bbdd-6571900327cd	2018-03-01 11:19:18.993215-06	2	[21288] Lock DR-253 Relay	[4] DLarrabee	[293] master	\N	\N
caa203a1-8058-490e-8979-4a97bf592628	2018-03-01 11:19:19.005216-06	2	[21289] Lock DR-259 Relay	[4] DLarrabee	[293] master	\N	\N
41cd1b0f-1e7d-402b-8951-389b8a6e0f5d	2018-03-01 11:19:19.020217-06	2	[21290] Lock DR-261 Relay	[4] DLarrabee	[293] master	\N	\N
f6cc2633-2876-42e2-9ab9-12e8f737cb74	2018-03-01 11:19:19.031218-06	2	[21291] Lock DR-301A Relay	[4] DLarrabee	[293] master	\N	\N
503eea9b-3704-4aae-9b4c-09ec5fc153b5	2018-03-01 11:19:19.04522-06	2	[21292] Lock DR-301B Relay	[4] DLarrabee	[293] master	\N	\N
3dae886b-a456-4e22-86ce-4c1fe99a567f	2018-03-01 11:19:19.057221-06	2	[21293] Lock DR-306 Relay	[4] DLarrabee	[293] master	\N	\N
191f0b23-7794-406f-b66e-5bf9ca09c8a1	2018-03-01 11:19:19.070222-06	2	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
be66aa2d-28c1-42c6-9d6f-1eac2a961996	2018-03-01 11:19:19.073223-06	3	[21287] Lock DR-252 Relay	[4] DLarrabee	[293] master	\N	\N
09ea0cb0-4c99-4cf0-9558-44e000285c6c	2018-03-01 11:19:19.371252-06	2	[21288] Lock DR-253 Relay	[4] DLarrabee	[293] master	\N	\N
dbe94af1-8c25-42d1-93b0-f00edca1eeba	2018-03-01 11:19:19.385254-06	2	[21289] Lock DR-259 Relay	[4] DLarrabee	[293] master	\N	\N
a3bec3ce-acb8-466a-96b8-ea4209af757f	2018-03-01 11:19:19.397255-06	2	[21290] Lock DR-261 Relay	[4] DLarrabee	[293] master	\N	\N
1d9f43f0-77d7-4093-87e4-50181b069ac1	2018-03-01 11:19:19.410256-06	2	[21291] Lock DR-301A Relay	[4] DLarrabee	[293] master	\N	\N
cc7d8964-3a67-465a-a03c-62ccc601cd1c	2018-03-01 11:19:19.423258-06	2	[21292] Lock DR-301B Relay	[4] DLarrabee	[293] master	\N	\N
b42dff72-5d4f-4679-a882-e840c97ef18e	2018-03-01 11:19:19.435259-06	2	[21293] Lock DR-306 Relay	[4] DLarrabee	[293] master	\N	\N
b6bdb28e-a5fb-41e9-b212-53bafd4ddd39	2018-03-01 11:19:19.44826-06	2	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
92e112df-54e1-47e7-ad1d-9e629f39e724	2018-03-01 11:19:19.45126-06	3	[21288] Lock DR-253 Relay	[4] DLarrabee	[293] master	\N	\N
30d1d518-6246-48bb-ae9c-f72badfbb932	2018-03-01 11:19:19.783294-06	2	[21289] Lock DR-259 Relay	[4] DLarrabee	[293] master	\N	\N
c48c59e2-4a76-47fe-90b8-27c6a8b1909b	2018-03-01 11:19:19.797295-06	2	[21290] Lock DR-261 Relay	[4] DLarrabee	[293] master	\N	\N
4021c442-1ceb-4265-8d0d-24ae0f8955ca	2018-03-01 11:19:19.809296-06	2	[21291] Lock DR-301A Relay	[4] DLarrabee	[293] master	\N	\N
c75fef03-efe8-4b33-bc06-ec794cb4fee2	2018-03-01 11:19:19.821297-06	2	[21292] Lock DR-301B Relay	[4] DLarrabee	[293] master	\N	\N
1386388e-b1d9-4e1e-9e7e-824bde3004aa	2018-03-01 11:19:19.834299-06	2	[21293] Lock DR-306 Relay	[4] DLarrabee	[293] master	\N	\N
4024dbb8-680e-4388-9b31-478c4be5d852	2018-03-01 11:19:19.8483-06	2	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
6ea7468e-a5e3-4db5-9adf-0ae15d9c49bc	2018-03-01 11:19:19.8513-06	3	[21289] Lock DR-259 Relay	[4] DLarrabee	[293] master	\N	\N
02b3a40c-4924-4a00-8989-924a628f6f60	2018-03-01 11:19:20.135329-06	2	[21290] Lock DR-261 Relay	[4] DLarrabee	[293] master	\N	\N
928c3aff-e212-4ec9-8efd-4b9c1af6034b	2018-03-01 11:19:20.14833-06	2	[21291] Lock DR-301A Relay	[4] DLarrabee	[293] master	\N	\N
5355ec0f-9584-4f77-a3c8-484c7d211a89	2018-03-01 11:19:20.164332-06	2	[21292] Lock DR-301B Relay	[4] DLarrabee	[293] master	\N	\N
4d9435f5-b9ae-4caf-9602-c85fc8e7783b	2018-03-01 11:19:20.176333-06	2	[21293] Lock DR-306 Relay	[4] DLarrabee	[293] master	\N	\N
60bccc0c-ac63-4ee8-9c03-0ad2f6275f4c	2018-03-01 11:19:20.190334-06	2	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
9fba37d8-5d2b-4187-89df-142d2378d524	2018-03-01 11:19:20.194335-06	3	[21290] Lock DR-261 Relay	[4] DLarrabee	[293] master	\N	\N
d2c38181-5950-481d-8052-a2306ad1dc29	2018-03-01 11:19:20.491364-06	2	[21291] Lock DR-301A Relay	[4] DLarrabee	[293] master	\N	\N
84994d6f-be4d-4b84-a91c-1f5e1024c41a	2018-03-01 11:19:20.505366-06	2	[21292] Lock DR-301B Relay	[4] DLarrabee	[293] master	\N	\N
6d7acd34-0a4b-4a39-ad4c-ebc3524b7c31	2018-03-01 11:19:20.515367-06	2	[21293] Lock DR-306 Relay	[4] DLarrabee	[293] master	\N	\N
dfc7feda-397e-4eb4-80bb-2c2c470b53fe	2018-03-01 11:19:20.527368-06	2	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
53cd41e5-9e0e-4f39-a6cc-b3afb82cb9e0	2018-03-01 11:19:20.530368-06	3	[21291] Lock DR-301A Relay	[4] DLarrabee	[293] master	\N	\N
dbf58133-5079-481d-ab1c-883cfad02c8a	2018-03-01 11:19:20.834399-06	2	[21292] Lock DR-301B Relay	[4] DLarrabee	[293] master	\N	\N
fc37c9bf-6386-4013-b34a-6a0a74240622	2018-03-01 11:19:20.8454-06	2	[21293] Lock DR-306 Relay	[4] DLarrabee	[293] master	\N	\N
5ee531b8-f9d8-4553-a74b-439d3534eccf	2018-03-01 11:19:20.859401-06	2	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
9cfd4499-c1c2-464f-9b0c-9881c5f764e2	2018-03-01 11:19:20.861401-06	3	[21292] Lock DR-301B Relay	[4] DLarrabee	[293] master	\N	\N
13399928-b8f0-4ed2-a91b-ac20c97dbbdb	2018-03-01 11:19:21.184434-06	2	[21293] Lock DR-306 Relay	[4] DLarrabee	[293] master	\N	\N
906ca8bd-418b-442c-ac40-f495be0b0440	2018-03-01 11:19:21.200435-06	2	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
22119acc-164e-44b0-a3f2-dcde73767185	2018-03-01 11:19:21.205436-06	3	[21293] Lock DR-306 Relay	[4] DLarrabee	[293] master	\N	\N
8460673a-ae75-40bf-a4dd-135b870f065a	2018-03-01 11:19:21.510466-06	2	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
bba9dbcc-50db-460d-85a8-7f86a80bb567	2018-03-01 11:19:21.513467-06	3	[21294] Output 16	[4] DLarrabee	[293] master	\N	\N
fd7b32d4-1e55-4a90-85f9-391bf181ea78	2018-03-01 11:19:34.423758-06	1	[21278] Label	[21041] OSSI-DNOVAK	[293] master	\N	\N
002dd11b-29ea-4414-8a5f-191602da4b24	2018-03-01 11:19:46.74799-06	2	[21278] Label	[21041] OSSI-DNOVAK	[293] master	\N	\N
c4f689a6-57fa-410e-8ed3-54396bd76190	2018-03-01 11:19:53.209636-06	1	[21280] Door 103 (1)	[4] DLarrabee	[293] master	\N	\N
67736a88-54fa-43c4-9cc9-27e201113d86	2018-03-01 11:19:53.234638-06	1	[21281] Door 103 (2)	[4] DLarrabee	[293] master	\N	\N
f71f0ee0-747f-4e09-9ef3-1d49bd0fdfb8	2018-03-01 11:19:53.256641-06	1	[21282] Door 103 (3)	[4] DLarrabee	[293] master	\N	\N
a313c469-6e42-4544-80da-23adf146cfb0	2018-03-01 11:19:53.276643-06	1	[21283] Door 103 (4)	[4] DLarrabee	[293] master	\N	\N
fb2b36bb-9d36-448b-86a1-ec9d67a795a6	2018-03-01 11:19:53.294644-06	1	[21284] Door 103 (5)	[4] DLarrabee	[293] master	\N	\N
998e8e95-ee03-46dd-871b-1bfbf5d196df	2018-03-01 11:19:53.313646-06	1	[21285] Door 103 (6)	[4] DLarrabee	[293] master	\N	\N
1af0058b-074e-4460-8c64-af9e19f18c77	2018-03-01 11:19:53.333648-06	1	[21286] Door 103 (7)	[4] DLarrabee	[293] master	\N	\N
cb6fb429-ec96-4a8c-968a-9de8d4ea0fea	2018-03-01 11:19:53.357651-06	1	[21287] Door 103 (8)	[4] DLarrabee	[293] master	\N	\N
59bbe032-c1a1-4149-bb7c-4ee8288a3ed6	2018-03-01 11:19:53.378653-06	1	[21288] Door 103 (9)	[4] DLarrabee	[293] master	\N	\N
814f7228-9c5f-41e3-a04b-7e01d35c8f62	2018-03-01 11:19:53.396655-06	1	[21289] Door 103 (10)	[4] DLarrabee	[293] master	\N	\N
3f74037d-b3d0-49d1-809e-5ab0fa890dbe	2018-03-01 11:19:53.415657-06	1	[21290] Door 103 (11)	[4] DLarrabee	[293] master	\N	\N
efc6e7fe-b809-4a2e-a6f6-8916d97b819e	2018-03-01 11:19:53.437659-06	1	[21291] Door 103 (12)	[4] DLarrabee	[293] master	\N	\N
d2ce39e8-c94b-401c-a97d-ceae7f1f393d	2018-03-01 11:19:53.45466-06	1	[21292] Door 103 (13)	[4] DLarrabee	[293] master	\N	\N
5dec149f-345e-4e27-aadc-053d6ade478b	2018-03-01 11:19:53.475663-06	1	[21293] Door 103 (14)	[4] DLarrabee	[293] master	\N	\N
a39ed238-2c7f-4b1f-a084-6555fdbd4486	2018-03-01 11:19:53.494664-06	1	[21294] Door 103 (15)	[4] DLarrabee	[293] master	\N	\N
dbaa6e98-98f4-4008-9b63-c110e2deb7bb	2018-03-01 11:20:22.258541-06	3	[21281] Door 103 (2)	[4] DLarrabee	[293] master	\N	\N
b9112c75-2c74-497c-8749-208f2c7d8874	2018-03-01 11:20:22.506565-06	2	[21282] Door 103 (3)	[4] DLarrabee	[293] master	\N	\N
ea429bf6-f5c7-48f2-bf61-81fe8ac1dd1b	2018-03-01 11:20:22.517566-06	2	[21283] Door 103 (4)	[4] DLarrabee	[293] master	\N	\N
8232839c-b4a4-4dd0-91bb-66e05403bd36	2018-03-01 11:20:22.528568-06	2	[21284] Door 103 (5)	[4] DLarrabee	[293] master	\N	\N
17e99af1-6c59-401f-994b-eca290f0415c	2018-03-01 11:20:22.539569-06	2	[21285] Door 103 (6)	[4] DLarrabee	[293] master	\N	\N
35ce7d24-0075-413d-9f93-cd6bb350bb6d	2018-03-01 11:20:22.55457-06	2	[21286] Door 103 (7)	[4] DLarrabee	[293] master	\N	\N
c57651ea-15ca-4e39-b64b-febbc436d50c	2018-03-01 11:20:22.569572-06	2	[21287] Door 103 (8)	[4] DLarrabee	[293] master	\N	\N
3e506327-140b-47cb-8161-26e82a17d3a3	2018-03-01 11:20:22.583573-06	2	[21288] Door 103 (9)	[4] DLarrabee	[293] master	\N	\N
2e635e91-8a7d-4f3d-853b-10c673af5970	2018-03-01 11:20:22.595574-06	2	[21289] Door 103 (10)	[4] DLarrabee	[293] master	\N	\N
d965d0ce-1bf2-4510-b806-b4f82a1c900a	2018-03-01 11:20:22.609576-06	2	[21290] Door 103 (11)	[4] DLarrabee	[293] master	\N	\N
627ca496-601c-4eea-82a9-ff07e985792b	2018-03-01 11:20:22.624577-06	2	[21291] Door 103 (12)	[4] DLarrabee	[293] master	\N	\N
d3f7afe5-c2c5-4c9a-8177-a18f49c56675	2018-03-01 11:20:22.646579-06	2	[21292] Door 103 (13)	[4] DLarrabee	[293] master	\N	\N
136074c9-92fe-44c3-8939-6a10d03a8f23	2018-03-01 11:20:22.659581-06	2	[21293] Door 103 (14)	[4] DLarrabee	[293] master	\N	\N
6b163096-2aa5-4bd5-986d-9264fe82e0ba	2018-03-01 11:20:22.671582-06	2	[21294] Door 103 (15)	[4] DLarrabee	[293] master	\N	\N
e682448f-7978-4185-8639-ca56d43ca8d7	2018-03-01 11:20:22.674582-06	3	[21282] Door 103 (3)	[4] DLarrabee	[293] master	\N	\N
30a8a0cb-bd7c-456c-876f-dde2412b4497	2018-03-01 11:20:22.986613-06	2	[21283] Door 103 (4)	[4] DLarrabee	[293] master	\N	\N
93f5eeb2-57e5-4ba5-9f68-b71636cc346d	2018-03-01 11:20:23.001615-06	2	[21284] Door 103 (5)	[4] DLarrabee	[293] master	\N	\N
9adb6c36-83f7-46f2-9336-67c35a17b05b	2018-03-01 11:20:23.011616-06	2	[21285] Door 103 (6)	[4] DLarrabee	[293] master	\N	\N
0a5cc870-9d04-4ef6-a67d-909d7a9f70a2	2018-03-01 11:20:23.021617-06	2	[21286] Door 103 (7)	[4] DLarrabee	[293] master	\N	\N
0035ecf1-8a39-44d8-8a4f-4dd8322e661c	2018-03-01 11:20:23.033618-06	2	[21287] Door 103 (8)	[4] DLarrabee	[293] master	\N	\N
a070826c-6d42-4c81-be75-2632088f8f31	2018-03-01 11:20:23.047619-06	2	[21288] Door 103 (9)	[4] DLarrabee	[293] master	\N	\N
f818d8a7-072e-4fdf-8383-27b0d6f14ae0	2018-03-01 11:20:23.062621-06	2	[21289] Door 103 (10)	[4] DLarrabee	[293] master	\N	\N
8c97c1b8-c4c7-4cdb-b45d-3f00205ad2c6	2018-03-01 11:20:23.075622-06	2	[21290] Door 103 (11)	[4] DLarrabee	[293] master	\N	\N
0f8103ab-7b9f-49ae-8009-f475e1eeb70c	2018-03-01 11:20:23.088624-06	2	[21291] Door 103 (12)	[4] DLarrabee	[293] master	\N	\N
3e4f3da3-fb94-4310-a080-352df5faf62f	2018-03-01 11:20:23.100625-06	2	[21292] Door 103 (13)	[4] DLarrabee	[293] master	\N	\N
ea8d615e-a986-4893-b9b8-558c4fac10ef	2018-03-01 11:20:23.114626-06	2	[21293] Door 103 (14)	[4] DLarrabee	[293] master	\N	\N
b1ae796c-5ea3-4c66-8b7c-4fdff84b4f14	2018-03-01 11:20:23.125627-06	2	[21294] Door 103 (15)	[4] DLarrabee	[293] master	\N	\N
9dff1722-4d9b-4222-ab8f-ba0ac81c8d3e	2018-03-01 11:20:23.128628-06	3	[21283] Door 103 (4)	[4] DLarrabee	[293] master	\N	\N
558e94de-6a09-43a5-9e6f-852187ba5ef5	2018-03-01 11:20:23.434658-06	2	[21284] Door 103 (5)	[4] DLarrabee	[293] master	\N	\N
0b39f0c5-c301-47a8-8999-be4e2dd146cf	2018-03-01 11:20:23.44866-06	2	[21285] Door 103 (6)	[4] DLarrabee	[293] master	\N	\N
b18c863d-554b-4097-b39b-a025487736cb	2018-03-01 11:20:23.462661-06	2	[21286] Door 103 (7)	[4] DLarrabee	[293] master	\N	\N
d73f670d-8fce-4d30-82b9-9e3bffcc1af3	2018-03-01 11:20:23.472662-06	2	[21287] Door 103 (8)	[4] DLarrabee	[293] master	\N	\N
13096e96-9605-4524-aadd-7c2ad4130b65	2018-03-01 11:20:23.487663-06	2	[21288] Door 103 (9)	[4] DLarrabee	[293] master	\N	\N
145285e4-a2ec-49ff-a375-22130a32a42e	2018-03-01 11:20:23.499665-06	2	[21289] Door 103 (10)	[4] DLarrabee	[293] master	\N	\N
3eeed273-179c-412f-b1c0-bba40d203209	2018-03-01 11:20:23.511666-06	2	[21290] Door 103 (11)	[4] DLarrabee	[293] master	\N	\N
37c9a0b2-886e-4560-a9e9-15111a285e8c	2018-03-01 11:20:23.522667-06	2	[21291] Door 103 (12)	[4] DLarrabee	[293] master	\N	\N
c6342ec7-8ae4-4474-b836-8493de3a7c1b	2018-03-01 11:20:23.533668-06	2	[21292] Door 103 (13)	[4] DLarrabee	[293] master	\N	\N
26b24266-4700-45a4-9206-ea5d92ae6976	2018-03-01 11:20:23.543669-06	2	[21293] Door 103 (14)	[4] DLarrabee	[293] master	\N	\N
fbb5952a-7e63-4156-9664-a0bc3b33adec	2018-03-01 11:20:23.55767-06	2	[21294] Door 103 (15)	[4] DLarrabee	[293] master	\N	\N
df4b9ca0-cb05-44ef-acb9-e89ebfe6efbc	2018-03-01 11:20:23.560671-06	3	[21284] Door 103 (5)	[4] DLarrabee	[293] master	\N	\N
91e5af16-a877-4472-acff-021dcbcebc35	2018-03-01 11:20:23.843699-06	2	[21285] Door 103 (6)	[4] DLarrabee	[293] master	\N	\N
2bc71761-11d7-4449-a451-96a4114cafc1	2018-03-01 11:20:23.8557-06	2	[21286] Door 103 (7)	[4] DLarrabee	[293] master	\N	\N
77f8f15a-a0aa-4acf-ad50-4752c76961ca	2018-03-01 11:20:23.866701-06	2	[21287] Door 103 (8)	[4] DLarrabee	[293] master	\N	\N
78b17f93-2599-4c1e-a01a-7fef857e9bf0	2018-03-01 11:20:23.876702-06	2	[21288] Door 103 (9)	[4] DLarrabee	[293] master	\N	\N
58ed803f-14d9-437e-8f1a-2750ab8d0a2c	2018-03-01 11:20:23.887703-06	2	[21289] Door 103 (10)	[4] DLarrabee	[293] master	\N	\N
e8a95025-3a61-4a1d-871e-6802879f926a	2018-03-01 11:20:23.898705-06	2	[21290] Door 103 (11)	[4] DLarrabee	[293] master	\N	\N
2bf1c529-34b5-47f5-ac59-c50100035873	2018-03-01 11:20:23.912706-06	2	[21291] Door 103 (12)	[4] DLarrabee	[293] master	\N	\N
57b3e9fd-ff3d-425c-84f9-1682536771b6	2018-03-01 11:20:23.924707-06	2	[21292] Door 103 (13)	[4] DLarrabee	[293] master	\N	\N
ae2fa5bb-23eb-48c1-b880-27e50c14870c	2018-03-01 11:20:23.938709-06	2	[21293] Door 103 (14)	[4] DLarrabee	[293] master	\N	\N
4616e5af-4698-41fd-bb91-2bd6eb2824c0	2018-03-01 11:20:23.94871-06	2	[21294] Door 103 (15)	[4] DLarrabee	[293] master	\N	\N
c49dfb9d-28ec-410e-8832-d168a12103d2	2018-03-01 11:20:23.95171-06	3	[21285] Door 103 (6)	[4] DLarrabee	[293] master	\N	\N
7776d222-b5ff-4d3a-a3d6-8968e60db8d5	2018-03-01 11:20:24.239739-06	2	[21286] Door 103 (7)	[4] DLarrabee	[293] master	\N	\N
9c6d8c38-267d-4cce-bfda-9da1520f7a1c	2018-03-01 11:20:24.25074-06	2	[21287] Door 103 (8)	[4] DLarrabee	[293] master	\N	\N
6318ef08-d68f-4a19-be2e-70c7fb8f77f0	2018-03-01 11:20:24.264741-06	2	[21288] Door 103 (9)	[4] DLarrabee	[293] master	\N	\N
38a78a09-3e93-4857-bdef-bd6a214dcbc7	2018-03-01 11:20:24.277742-06	2	[21289] Door 103 (10)	[4] DLarrabee	[293] master	\N	\N
fca8a934-b50e-483d-a575-3c48c2983a8d	2018-03-01 11:20:24.290744-06	2	[21290] Door 103 (11)	[4] DLarrabee	[293] master	\N	\N
cf5522c4-f4c7-4e9a-962d-d26a087cd219	2018-03-01 11:20:24.302745-06	2	[21291] Door 103 (12)	[4] DLarrabee	[293] master	\N	\N
93b8dcfc-27f9-48dc-9d2a-b7901fd5d722	2018-03-01 11:20:24.312746-06	2	[21292] Door 103 (13)	[4] DLarrabee	[293] master	\N	\N
7b6c2eea-113c-4f23-af38-54d9c10c2d3c	2018-03-01 11:20:24.324747-06	2	[21293] Door 103 (14)	[4] DLarrabee	[293] master	\N	\N
89b906e3-e5ef-4367-a54a-d54438349ced	2018-03-01 11:20:24.335748-06	2	[21294] Door 103 (15)	[4] DLarrabee	[293] master	\N	\N
19b35a1e-cede-441d-814b-bc5071597b8d	2018-03-01 11:20:24.338749-06	3	[21286] Door 103 (7)	[4] DLarrabee	[293] master	\N	\N
ef2456ec-89fc-42a7-8c49-d8d2c604a893	2018-03-01 11:20:24.625777-06	2	[21287] Door 103 (8)	[4] DLarrabee	[293] master	\N	\N
a6c36c2b-0ab8-47cc-af4d-366effc990f3	2018-03-01 11:20:24.637778-06	2	[21288] Door 103 (9)	[4] DLarrabee	[293] master	\N	\N
29eb90cc-b32b-498a-94f6-042683472228	2018-03-01 11:20:24.65078-06	2	[21289] Door 103 (10)	[4] DLarrabee	[293] master	\N	\N
ebe8323b-5732-4e0f-8717-6bacd434b337	2018-03-01 11:20:24.664781-06	2	[21290] Door 103 (11)	[4] DLarrabee	[293] master	\N	\N
3aa3dc36-bbfb-4f50-b9e7-6233a956fd5f	2018-03-01 11:20:24.676782-06	2	[21291] Door 103 (12)	[4] DLarrabee	[293] master	\N	\N
9cc0a4da-a8aa-4d4d-8b23-1dae92bdc818	2018-03-01 11:20:24.688784-06	2	[21292] Door 103 (13)	[4] DLarrabee	[293] master	\N	\N
e90161ea-b824-4661-8f4b-5f71e09cc26d	2018-03-01 11:20:24.700785-06	2	[21293] Door 103 (14)	[4] DLarrabee	[293] master	\N	\N
89eafa66-5954-4477-81be-b1e4e83c2c1c	2018-03-01 11:20:24.712786-06	2	[21294] Door 103 (15)	[4] DLarrabee	[293] master	\N	\N
d28edd67-db1f-4f9b-bc37-9e5b96990c7e	2018-03-01 11:20:24.715786-06	3	[21287] Door 103 (8)	[4] DLarrabee	[293] master	\N	\N
cedacd3b-218e-4be6-ab83-c0cbede2bef0	2018-03-01 11:20:25.032818-06	2	[21288] Door 103 (9)	[4] DLarrabee	[293] master	\N	\N
ddd6b0fe-5fc9-47e1-af07-04a0b9e7b868	2018-03-01 11:20:25.047819-06	2	[21289] Door 103 (10)	[4] DLarrabee	[293] master	\N	\N
58529283-b81a-4c7a-9653-37960c8882dc	2018-03-01 11:20:25.059821-06	2	[21290] Door 103 (11)	[4] DLarrabee	[293] master	\N	\N
4c07b9e7-307e-4f6c-9d72-b06c978c9034	2018-03-01 11:20:25.076822-06	2	[21291] Door 103 (12)	[4] DLarrabee	[293] master	\N	\N
423b0b5c-7efc-4f1c-83cb-7071619fd3fd	2018-03-01 11:20:25.089824-06	2	[21292] Door 103 (13)	[4] DLarrabee	[293] master	\N	\N
abf8e142-ecfe-4ffd-9f0b-0f5963d3b764	2018-03-01 11:20:25.103825-06	2	[21293] Door 103 (14)	[4] DLarrabee	[293] master	\N	\N
d687045d-af62-45a4-a583-1ce71f87b5bf	2018-03-01 11:20:25.116826-06	2	[21294] Door 103 (15)	[4] DLarrabee	[293] master	\N	\N
3ec5ece7-7eaa-4513-bd58-eef48db8de61	2018-03-01 11:20:25.119827-06	3	[21288] Door 103 (9)	[4] DLarrabee	[293] master	\N	\N
e9543608-7266-4be3-b054-a812e0b12c6f	2018-03-01 11:20:25.430858-06	2	[21289] Door 103 (10)	[4] DLarrabee	[293] master	\N	\N
50568d04-840e-4c1d-8082-b9e40fa7cfb8	2018-03-01 11:20:25.443859-06	2	[21290] Door 103 (11)	[4] DLarrabee	[293] master	\N	\N
21489a96-da33-4a85-89ca-f5a2d6385643	2018-03-01 11:20:25.45386-06	2	[21291] Door 103 (12)	[4] DLarrabee	[293] master	\N	\N
a7b69242-0958-4fe4-84e4-6d2973a2cde6	2018-03-01 11:20:25.464861-06	2	[21292] Door 103 (13)	[4] DLarrabee	[293] master	\N	\N
70cacd2b-fde4-4b6b-9aa4-e55a85453146	2018-03-01 11:20:25.476862-06	2	[21293] Door 103 (14)	[4] DLarrabee	[293] master	\N	\N
8df16061-0ebc-4f5d-812b-4682d8744e06	2018-03-01 11:20:25.487863-06	2	[21294] Door 103 (15)	[4] DLarrabee	[293] master	\N	\N
dcdb2a44-8036-490e-b2e4-838ab5d09e26	2018-03-01 11:20:25.489864-06	3	[21289] Door 103 (10)	[4] DLarrabee	[293] master	\N	\N
0fdcc3dc-73c2-49da-8e4c-4dba3ea8dc27	2018-03-01 11:20:25.780893-06	2	[21290] Door 103 (11)	[4] DLarrabee	[293] master	\N	\N
76906fc3-9ea1-4aa9-88c3-3aeea8b1d0cb	2018-03-01 11:20:25.791894-06	2	[21291] Door 103 (12)	[4] DLarrabee	[293] master	\N	\N
c050fc15-62ab-4faa-8728-6a45aebe7928	2018-03-01 11:20:25.803895-06	2	[21292] Door 103 (13)	[4] DLarrabee	[293] master	\N	\N
c1b3b0d8-353c-41c3-a24c-eeb269d37e61	2018-03-01 11:20:25.815896-06	2	[21293] Door 103 (14)	[4] DLarrabee	[293] master	\N	\N
ba4da88d-5054-4faa-9f54-4315ba78a5b5	2018-03-01 11:20:25.826897-06	2	[21294] Door 103 (15)	[4] DLarrabee	[293] master	\N	\N
fdaff8ec-0e69-4e19-9a0d-2bfbf3cde0f3	2018-03-01 11:20:25.828898-06	3	[21290] Door 103 (11)	[4] DLarrabee	[293] master	\N	\N
31fd36c0-0afa-419c-b676-706cf1dcd096	2018-03-01 11:20:26.145929-06	2	[21291] Door 103 (12)	[4] DLarrabee	[293] master	\N	\N
e1d86e4b-0ae6-4c42-afd3-56e69cff7a04	2018-03-01 11:20:26.15793-06	2	[21292] Door 103 (13)	[4] DLarrabee	[293] master	\N	\N
0c0914c4-616f-4ddc-a13b-90148b4c481e	2018-03-01 11:20:26.167931-06	2	[21293] Door 103 (14)	[4] DLarrabee	[293] master	\N	\N
0b4e1a51-2429-448d-b82a-6294298525f2	2018-03-01 11:20:26.179933-06	2	[21294] Door 103 (15)	[4] DLarrabee	[293] master	\N	\N
eda65780-1b45-4aba-a3ae-8a2550a0938f	2018-03-01 11:20:26.181933-06	3	[21291] Door 103 (12)	[4] DLarrabee	[293] master	\N	\N
c3fc4971-5e56-4546-b1c8-7e2dcaa81071	2018-03-01 11:20:26.474962-06	2	[21292] Door 103 (13)	[4] DLarrabee	[293] master	\N	\N
705b48fb-a45a-4c0a-9a57-394988d4a7ed	2018-03-01 11:20:26.484963-06	2	[21293] Door 103 (14)	[4] DLarrabee	[293] master	\N	\N
9e138b1a-c387-4a39-9fc9-a97c212bf555	2018-03-01 11:20:26.495964-06	2	[21294] Door 103 (15)	[4] DLarrabee	[293] master	\N	\N
b5a4061d-da27-4108-bfff-dd30259df156	2018-03-01 11:20:26.498965-06	3	[21292] Door 103 (13)	[4] DLarrabee	[293] master	\N	\N
85db62ed-5444-46a5-ad1a-08370e4e31da	2018-03-01 11:20:26.769992-06	2	[21293] Door 103 (14)	[4] DLarrabee	[293] master	\N	\N
3f9537a0-d5e7-4990-bf09-a9c0ebf26b72	2018-03-01 11:20:26.781993-06	2	[21294] Door 103 (15)	[4] DLarrabee	[293] master	\N	\N
04222038-d402-4966-8617-ee623def8ae1	2018-03-01 11:20:26.784993-06	3	[21293] Door 103 (14)	[4] DLarrabee	[293] master	\N	\N
b3725744-2d2e-464c-9267-886c0887ee21	2018-03-01 11:20:27.085023-06	2	[21294] Door 103 (15)	[4] DLarrabee	[293] master	\N	\N
947ffa0b-cdf7-4dc6-b599-9843a3f37b2a	2018-03-01 11:20:27.088023-06	3	[21294] Door 103 (15)	[4] DLarrabee	[293] master	\N	\N
e150839c-41a4-49e2-8876-b1b2fb352c6a	2018-03-01 11:20:31.330448-06	2	[21152] Area A Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
62107f03-c359-4f92-add9-d3d6791dcd9d	2018-03-01 11:20:33.930708-06	2	[21280] Door 103 (1)	[4] DLarrabee	[293] master	\N	\N
fe9a7761-2f5f-4171-827e-915e066ee34d	2018-03-01 11:20:39.416256-06	3	[21280] Door 103 (1)	[4] DLarrabee	[293] master	\N	\N
9680596f-c659-4bd3-87be-32b2938926aa	2018-03-01 11:20:47.15703-06	2	[21153] Area B Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
dad48472-8d96-42b2-8d59-65d9528cdc8b	2018-03-01 11:20:59.719286-06	2	[21154] Area C Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
65ec32fe-8345-45ea-9343-7fbca22375b5	2018-03-01 11:21:12.139528-06	1	[21280] Lock DR-239 Relay	[4] DLarrabee	[293] master	\N	\N
922b7fb9-f8af-4260-9031-c789e2f8e8f7	2018-03-01 11:21:14.55777-06	2	[21155] Area D Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
2b7dc151-ff23-460a-b52b-04490994adbe	2018-03-01 11:21:28.880202-06	2	[21156] Area E Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
be596045-694b-4d98-b104-ec3e3d7e41f2	2018-03-01 11:21:38.639178-06	2	[21280] Door 239 Relay	[4] DLarrabee	[293] master	\N	\N
4dc01d9a-9541-4a29-a924-d93154e7f87b	2018-03-01 11:22:07.56107-06	3	[21280] Door 239 Relay	[4] DLarrabee	[293] master	\N	\N
ee1a017f-f469-44e1-a97d-c3e11d82f4f0	2018-03-01 11:22:57.580071-06	3	[21277] Door 245 Copy	[4] DLarrabee	[293] master	\N	\N
bd35dd3f-0c99-46c9-acae-bfc54fa489c5	2018-03-01 11:23:40.838397-06	1	[21277] Door 239 (1)	[4] DLarrabee	[293] master	\N	\N
1f1eaa27-3a06-4067-af8d-ea600898515a	2018-03-01 11:23:40.856398-06	1	[21280] Door 239 (2)	[4] DLarrabee	[293] master	\N	\N
2fe89056-86d4-4aa7-8ed8-ee0aefc7455f	2018-03-01 11:23:40.8744-06	1	[21281] Door 239 (3)	[4] DLarrabee	[293] master	\N	\N
15e9b85a-629d-4390-98f0-4ca4c325e60e	2018-03-01 11:23:40.886401-06	1	[21282] Door 239 (4)	[4] DLarrabee	[293] master	\N	\N
4695e1af-4998-40eb-b941-4d943b687d16	2018-03-01 11:23:40.916404-06	1	[21283] Door 239 (5)	[4] DLarrabee	[293] master	\N	\N
a326fa69-84e6-4732-b051-266c39642948	2018-03-01 11:23:40.934406-06	1	[21284] Door 239 (6)	[4] DLarrabee	[293] master	\N	\N
40427f7b-a9fd-45d9-b443-0a5d504a68e8	2018-03-01 11:23:40.948408-06	1	[21285] Door 239 (7)	[4] DLarrabee	[293] master	\N	\N
82c8f9ff-6419-4e76-bb3f-9fffe9aa0e9b	2018-03-01 11:23:40.963409-06	1	[21286] Door 239 (8)	[4] DLarrabee	[293] master	\N	\N
88a5ae90-4b93-409c-a278-b7bfbf3e1a2f	2018-03-01 11:23:40.981411-06	1	[21287] Door 239 (9)	[4] DLarrabee	[293] master	\N	\N
690ac9f8-c42a-45c4-b52f-7507a56b1231	2018-03-01 11:23:41.001413-06	1	[21288] Door 239 (10)	[4] DLarrabee	[293] master	\N	\N
d2dc3cd2-5248-4a4d-ab04-004929fa603b	2018-03-01 11:23:41.018415-06	1	[21289] Door 239 (11)	[4] DLarrabee	[293] master	\N	\N
faaa5ca4-7ab8-447d-8176-d70d7f7d6491	2018-03-01 11:23:41.035416-06	1	[21290] Door 239 (12)	[4] DLarrabee	[293] master	\N	\N
ef7a7270-23a8-43aa-8b65-24f0db088fd0	2018-03-01 11:23:41.053418-06	1	[21291] Door 239 (13)	[4] DLarrabee	[293] master	\N	\N
cb29375d-a994-428b-af66-04db099fefcc	2018-03-01 11:23:41.07142-06	1	[21292] Door 239 (14)	[4] DLarrabee	[293] master	\N	\N
bb7b6178-f6d0-4fb2-83ac-d2c3b396d5cf	2018-03-01 11:23:41.089422-06	1	[21293] Door 239 (15)	[4] DLarrabee	[293] master	\N	\N
c99f4640-014f-4f59-9101-a67ff3d3f9bd	2018-03-01 11:24:10.901403-06	3	[21293] Door 239 (15)	[4] DLarrabee	[293] master	\N	\N
990cbde0-b5fe-44cc-8ea0-de4768e172ba	2018-03-01 11:24:46.196932-06	3	[21280] Door 239 (2)	[4] DLarrabee	[293] master	\N	\N
fc4ad4a0-15fb-433f-a07f-b0016f2b4c89	2018-03-01 11:24:46.486961-06	2	[21281] Door 239 (3)	[4] DLarrabee	[293] master	\N	\N
c95f5252-8fa1-41b6-8058-7d143289fd98	2018-03-01 11:24:46.501962-06	2	[21282] Door 239 (4)	[4] DLarrabee	[293] master	\N	\N
68dd27f5-f0c8-409c-ae01-d3b259353926	2018-03-01 11:24:46.514964-06	2	[21283] Door 239 (5)	[4] DLarrabee	[293] master	\N	\N
9b13a74b-7208-4574-949d-d0b9cec3e003	2018-03-01 11:24:46.529965-06	2	[21284] Door 239 (6)	[4] DLarrabee	[293] master	\N	\N
64476849-3efa-4628-af2e-85df3d3547bd	2018-03-01 11:24:46.541966-06	2	[21285] Door 239 (7)	[4] DLarrabee	[293] master	\N	\N
d92dc3b0-4c30-45d7-92fa-8fd265689ffe	2018-03-01 11:24:46.555968-06	2	[21286] Door 239 (8)	[4] DLarrabee	[293] master	\N	\N
57e3fa72-ba65-4f07-95ae-95134aaf87df	2018-03-01 11:24:46.568969-06	2	[21287] Door 239 (9)	[4] DLarrabee	[293] master	\N	\N
fee80577-0798-4631-a953-2d10a0a48a7f	2018-03-01 11:24:46.58397-06	2	[21288] Door 239 (10)	[4] DLarrabee	[293] master	\N	\N
16cb9b1f-3556-4f56-8a88-052ba2b21e59	2018-03-01 11:24:46.598972-06	2	[21289] Door 239 (11)	[4] DLarrabee	[293] master	\N	\N
405e2ec8-b8fe-4b2f-99f6-36cbd9c2fa6c	2018-03-01 11:24:46.611973-06	2	[21290] Door 239 (12)	[4] DLarrabee	[293] master	\N	\N
f7cd8c65-7e6c-4dd3-b8af-473231c12332	2018-03-01 11:24:46.621974-06	2	[21291] Door 239 (13)	[4] DLarrabee	[293] master	\N	\N
2b17c55e-e643-4cf7-a14e-84d30d26b29c	2018-03-01 11:24:46.634976-06	2	[21292] Door 239 (14)	[4] DLarrabee	[293] master	\N	\N
3d689be2-046b-4a5a-8e8e-5672ea52a931	2018-03-01 11:24:46.636976-06	3	[21281] Door 239 (3)	[4] DLarrabee	[293] master	\N	\N
1cb52128-b73b-43b7-9a3e-a3b1fa48aa39	2018-03-01 11:24:46.944006-06	2	[21282] Door 239 (4)	[4] DLarrabee	[293] master	\N	\N
20c1d46b-e02b-45e0-8276-feb253f543b2	2018-03-01 11:24:46.956008-06	2	[21283] Door 239 (5)	[4] DLarrabee	[293] master	\N	\N
34421688-2890-4a11-847d-cc3f4fbd5fbb	2018-03-01 11:24:46.968009-06	2	[21284] Door 239 (6)	[4] DLarrabee	[293] master	\N	\N
8ea82961-6895-4f7a-937e-b98b1ad5709e	2018-03-01 11:24:46.97801-06	2	[21285] Door 239 (7)	[4] DLarrabee	[293] master	\N	\N
d12c5720-8e92-4295-a33b-c9043662b8d5	2018-03-01 11:24:46.990011-06	2	[21286] Door 239 (8)	[4] DLarrabee	[293] master	\N	\N
4b5af6b7-5813-454b-ab80-c8c55b4029eb	2018-03-01 11:24:47.001012-06	2	[21287] Door 239 (9)	[4] DLarrabee	[293] master	\N	\N
6ccb7a89-0ffc-405b-abfb-4cf487f951f5	2018-03-01 11:24:47.016014-06	2	[21288] Door 239 (10)	[4] DLarrabee	[293] master	\N	\N
603194fc-8672-4028-b524-268ff14fb1f3	2018-03-01 11:24:47.031015-06	2	[21289] Door 239 (11)	[4] DLarrabee	[293] master	\N	\N
9009030e-cbe8-4122-aa9b-1e7dc94a3811	2018-03-01 11:24:47.044016-06	2	[21290] Door 239 (12)	[4] DLarrabee	[293] master	\N	\N
be5578c4-71b0-4dc4-84ff-34b6618909ef	2018-03-01 11:24:47.059018-06	2	[21291] Door 239 (13)	[4] DLarrabee	[293] master	\N	\N
4ce199d2-61b8-4302-ad93-6783c7a2c88d	2018-03-01 11:24:47.071019-06	2	[21292] Door 239 (14)	[4] DLarrabee	[293] master	\N	\N
b9d1b6db-f73b-481a-9971-fe5e235631d5	2018-03-01 11:24:47.074019-06	3	[21282] Door 239 (4)	[4] DLarrabee	[293] master	\N	\N
5aee1a54-f342-441a-86ba-4761d252f510	2018-03-01 11:24:47.395052-06	2	[21283] Door 239 (5)	[4] DLarrabee	[293] master	\N	\N
25004197-5ac6-423e-9f5b-c684428ee86d	2018-03-01 11:24:47.405053-06	2	[21284] Door 239 (6)	[4] DLarrabee	[293] master	\N	\N
be73457a-70aa-4b20-ab36-b827b28cf518	2018-03-01 11:24:47.418054-06	2	[21285] Door 239 (7)	[4] DLarrabee	[293] master	\N	\N
b8470c2a-06e6-4279-802d-ee4cd301da0d	2018-03-01 11:24:47.428055-06	2	[21286] Door 239 (8)	[4] DLarrabee	[293] master	\N	\N
fc88b8e0-a4d4-44a1-acf9-9d921bfe406e	2018-03-01 11:24:47.441056-06	2	[21287] Door 239 (9)	[4] DLarrabee	[293] master	\N	\N
1a00b407-cd89-4fcd-8d47-ae09806110c9	2018-03-01 11:24:47.452057-06	2	[21288] Door 239 (10)	[4] DLarrabee	[293] master	\N	\N
6b99b647-47f5-4db5-8993-1009df3f11bd	2018-03-01 11:24:47.462058-06	2	[21289] Door 239 (11)	[4] DLarrabee	[293] master	\N	\N
e3e9078f-6efa-488d-ae27-1925be8de727	2018-03-01 11:24:47.47506-06	2	[21290] Door 239 (12)	[4] DLarrabee	[293] master	\N	\N
27608004-541e-4c32-820e-7cce41adba37	2018-03-01 11:24:47.487061-06	2	[21291] Door 239 (13)	[4] DLarrabee	[293] master	\N	\N
f5659c1b-435c-4483-adcc-c295753205ad	2018-03-01 11:24:47.496062-06	2	[21292] Door 239 (14)	[4] DLarrabee	[293] master	\N	\N
1acae949-a3a3-4db5-8cfb-55d4f607e667	2018-03-01 11:24:51.396452-06	3	[21277] Door 239 (1)	[4] DLarrabee	[293] master	\N	\N
8c1489f2-728a-4c03-8691-59afc95cfac6	2018-03-01 11:24:51.644476-06	2	[21283] Door 239 (5)	[4] DLarrabee	[293] master	\N	\N
23a35869-dc33-422a-b4a3-8de25621a62b	2018-03-01 11:24:51.657478-06	2	[21284] Door 239 (6)	[4] DLarrabee	[293] master	\N	\N
46045301-9618-421f-bdbb-bf16f6b18c52	2018-03-01 11:24:51.669479-06	2	[21285] Door 239 (7)	[4] DLarrabee	[293] master	\N	\N
93ba0247-86df-44d0-985c-3b0f7f0d111f	2018-03-01 11:24:51.68148-06	2	[21286] Door 239 (8)	[4] DLarrabee	[293] master	\N	\N
8d1ad036-bf14-4ee6-ad5c-c00f5f591f4e	2018-03-01 11:24:51.695482-06	2	[21287] Door 239 (9)	[4] DLarrabee	[293] master	\N	\N
8afcaf6d-c596-44a4-9853-03535b8ebdd5	2018-03-01 11:24:51.706483-06	2	[21288] Door 239 (10)	[4] DLarrabee	[293] master	\N	\N
0fee71fc-3727-4c38-adc6-206f3a1b8ff7	2018-03-01 11:24:51.716484-06	2	[21289] Door 239 (11)	[4] DLarrabee	[293] master	\N	\N
8715a79d-4031-491f-867a-158c3c152219	2018-03-01 11:24:51.727485-06	2	[21290] Door 239 (12)	[4] DLarrabee	[293] master	\N	\N
063d89bd-8915-4df6-9246-165e620c1d09	2018-03-01 11:24:51.739486-06	2	[21291] Door 239 (13)	[4] DLarrabee	[293] master	\N	\N
02172449-fd3b-4124-a055-730ef84a56d0	2018-03-01 11:24:51.753487-06	2	[21292] Door 239 (14)	[4] DLarrabee	[293] master	\N	\N
d15e2a57-a7ab-4ac9-bf51-62c5695ee45d	2018-03-01 11:45:40.745374-06	2	[21055] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
42723caa-3017-40d9-bafc-705ddd2e9b02	2018-03-01 11:46:04.766776-06	2	[21055] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
ffdcb228-1231-43d7-8566-33e5016c9004	2018-03-01 11:46:30.188318-06	2	[21055] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
0ea3fecb-5eb1-4e6a-b398-7f5135e54575	2018-03-01 11:46:41.11441-06	2	[21055] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
9a778556-ed7a-482b-a90f-d2f6fd2a0dda	2018-03-01 11:47:07.995098-06	2	[21056] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
03159c27-b48c-4ce6-9948-5d850a2a850c	2018-03-01 11:47:38.980196-06	2	[21055] View IC Control	[21041] OSSI-DNOVAK	[293] master	\N	\N
afced1d2-a429-4289-bc5a-d956fb907d26	2018-03-01 11:48:15.393837-06	2	[21056] Interlock Control	[21041] OSSI-DNOVAK	[293] master	\N	\N
23b3692e-e98b-4009-aeca-17ceea590801	2018-03-01 11:48:48.986196-06	2	[21059] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
8351e4fc-161d-4da9-b552-005240d24a78	2018-03-01 11:49:15.515849-06	2	[21056] Interlock Control	[21041] OSSI-DNOVAK	[293] master	\N	\N
c7a90178-dbde-432d-b50d-f7afd41a1d7c	2018-03-01 11:49:37.549052-06	2	[21055] View IC Control	[21041] OSSI-DNOVAK	[293] master	\N	\N
02c38724-8417-4cb7-bbf3-4bdff1b44fab	2018-03-01 11:49:59.296227-06	2	[21057] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
dc7bd2f5-51d0-4886-bc43-d8350a9648f3	2018-03-01 11:51:21.379434-06	3	[21058] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
2318b962-0123-4222-b5b5-9c0469d47af5	2018-03-01 11:51:21.625459-06	2	[21059] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
f2fff7ce-e1c1-4f07-92ce-a19148a883f2	2018-03-01 11:51:21.629459-06	2	[21060] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
81aa3045-a264-45c8-8cd6-fda6ac47b707	2018-03-01 11:51:21.633459-06	2	[21047] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
4de79863-aba2-45aa-a98c-6b781b371acb	2018-03-01 11:51:21.63646-06	2	[21162] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
34110238-f86e-41c1-8b1a-7077bb78ab9b	2018-03-01 11:51:24.878784-06	3	[21060] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
e98882c2-7976-4127-b8be-d6ef4b0a677a	2018-03-01 11:51:25.111807-06	2	[21047] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
121296c5-ce30-4187-b9e7-66ba4d863832	2018-03-01 11:51:25.115808-06	2	[21162] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
931dfd3f-1ea2-4251-b9fc-24006f69f339	2018-03-01 11:51:32.896586-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
82fbf15f-1024-4fd4-ab81-c39c09b68070	2018-03-01 11:51:55.934889-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
40117b5a-9f8d-46e5-b11e-fa8ed2babaf6	2018-03-01 11:52:47.971092-06	2	[21045] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
f197ab92-63bc-48fc-bb10-f655ed5e7740	2018-03-01 11:53:25.757871-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
6f093173-821c-433a-bb6a-efe57ad8ef2c	2018-03-01 11:53:33.35663-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
6e4735d0-7924-4898-b0de-92c00c00cb4e	2018-03-01 11:54:23.734668-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
0d219ff0-bc9c-45ce-ba5f-26720fbb350f	2018-03-01 11:55:43.815675-06	2	[21087] Alarm Box	[21041] OSSI-DNOVAK	[293] master	\N	\N
589e8868-d84b-4d8b-832d-faff59de94f2	2018-03-01 11:56:07.991092-06	2	[21049] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
039177f4-16c2-4039-a69a-a350a73acb5d	2018-03-01 11:56:43.685661-06	2	[21055] View IC Control	[21041] OSSI-DNOVAK	[293] master	\N	\N
e0b35531-4e96-4cdc-87d2-e66b51e3f8e2	2018-03-01 11:56:49.725265-06	2	[21056] Interlock Control	[21041] OSSI-DNOVAK	[293] master	\N	\N
2945cc4e-b694-4008-a307-b489bed062fa	2018-03-01 11:56:56.300923-06	2	[21059] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
3674d09a-65c1-4725-9874-20318a584e4c	2018-03-01 11:57:01.561449-06	2	[21276] Door 245	[4] DLarrabee	[293] master	\N	\N
b407b38a-d2a9-4ddb-adc2-daa006b3f9f1	2018-03-01 11:57:02.17051-06	2	[21057] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
496b848a-a11f-4526-b3bc-91547f695539	2018-03-01 11:58:00.055298-06	2	[21283] Door 246	[4] DLarrabee	[293] master	\N	\N
e1362f87-e0d7-45e7-a4df-14114d98f6c3	2018-03-01 11:58:15.043796-06	2	[21284] Door 247	[4] DLarrabee	[293] master	\N	\N
8790b730-4505-41cf-959a-84fe85a7dc5a	2018-03-01 11:58:27.204012-06	2	[21285] Door 248	[4] DLarrabee	[293] master	\N	\N
26aa5fac-958d-4944-ba47-d38e9eb7ab9b	2018-03-01 11:58:42.305522-06	2	[21286] Door 252	[4] DLarrabee	[293] master	\N	\N
86909f05-f869-43b5-ba0a-dfa28c5e0036	2018-03-01 11:58:42.624554-06	2	[21059] Group Release	[21041] OSSI-DNOVAK	[293] master	\N	\N
143235d8-e9b0-4a7e-9745-dc71ced56f56	2018-03-01 11:59:00.411333-06	2	[21287] Door 253	[4] DLarrabee	[293] master	\N	\N
b747f324-0e66-45f8-a09f-69d42d568564	2018-03-01 11:59:06.722964-06	2	[21057] Reports	[21041] OSSI-DNOVAK	[293] master	\N	\N
4d8e32f1-6c80-4c3b-bd2a-0ff00d6e432c	2018-03-01 11:59:12.711563-06	2	[21288] Door 259	[4] DLarrabee	[293] master	\N	\N
e32092fe-33ca-4e21-b32e-759fada8ac8c	2018-03-01 11:59:29.407232-06	2	[21289] Door 261	[4] DLarrabee	[293] master	\N	\N
a58d80f4-abd3-4300-a664-2e5cc72fd55b	2018-03-01 11:59:52.607552-06	2	[21290] Door 301	[4] DLarrabee	[293] master	\N	\N
c2732eaf-ab0d-4ea0-86af-058642ceb21f	2018-03-01 12:00:12.265517-06	2	[21291] Door 301B	[4] DLarrabee	[293] master	\N	\N
5ee4d489-f7ab-4a09-a379-457663dea43c	2018-03-01 12:00:25.816872-06	2	[21290] Door 301A	[4] DLarrabee	[293] master	\N	\N
1486f91f-3a7a-4c65-8bff-a9a9e26cfd00	2018-03-01 12:00:40.453336-06	2	[21291] Door 301B	[4] DLarrabee	[293] master	\N	\N
8bfb5837-0861-426b-b42d-4f785cd8a3d9	2018-03-01 12:00:58.655156-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
ccac8163-d72b-4a65-9a17-250621d72dc8	2018-03-01 12:01:01.024393-06	2	[21292] Door 306	[4] DLarrabee	[293] master	\N	\N
e4daf934-4d96-41e3-abd2-20097028cf3d	2018-03-01 12:02:06.159906-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
2b4ca971-cd71-46a7-977d-840d616f7f57	2018-03-01 12:03:16.632952-06	1	[21058] New Screens Group	[4] DLarrabee	[293] master	\N	\N
5fb2fdc0-b74f-415d-b49d-1e34c8d95d8c	2018-03-01 12:03:18.905179-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
58d74545-ef4f-40b8-a810-0e2bcb6dcbc5	2018-03-01 12:03:34.719761-06	2	[21058] 3RD Screen Group	[4] DLarrabee	[293] master	\N	\N
f2840987-6739-4c92-baf9-800569f98a02	2018-03-01 12:03:36.921981-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
953e54d6-3e84-48b1-86ae-945fe4812ad0	2018-03-01 12:05:04.306719-06	2	[21048] New Popup Queue	[21041] OSSI-DNOVAK	[293] master	\N	\N
2bf8b2c5-a1f7-45f7-aea3-27b76e140894	2018-03-01 12:05:39.673255-06	2	[21058] 3RD Screen Group	[4] DLarrabee	[293] master	\N	\N
2ada79be-23c0-48f7-af05-432cde992414	2018-03-01 12:05:43.748662-06	1	[21060] New Screen	[4] DLarrabee	[293] master	\N	\N
e83da409-e0b8-4525-96d1-8b5d37d5ff49	2018-03-01 12:06:28.663153-06	2	[21060] Background Frame	[4] DLarrabee	[293] master	\N	\N
eb78e681-dea2-482b-86a8-3179e07ef1a6	2018-03-01 12:06:57.453032-06	2	[21095] Baclground Frame	[4] DLarrabee	[293] master	\N	\N
efe9406b-3d67-4453-ab2e-ccf31f8ef9fe	2018-03-01 12:14:04.020685-06	2	[21060] Background Frame	[4] DLarrabee	[293] master	\N	\N
3cc806a3-d5cf-46f5-b1e5-f83f845d8587	2018-03-01 12:15:36.339916-06	3	[21058] 3RD Screen Group	[4] DLarrabee	[293] master	\N	\N
d5791ac5-015c-426b-8cd2-286682a713f0	2018-03-01 12:22:25.618839-06	1	[21058] New	[4] DLarrabee	[293] master	\N	\N
8293e8ac-d297-4dc1-9f6f-aa95eec476e8	2018-03-01 12:24:53.408617-06	3	[21224] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
2368d587-0f37-4bf4-9380-3a40951439af	2018-03-01 12:24:53.651641-06	2	[21225] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
9d3fe77f-a3c7-44ab-9b85-93ce7ca22be0	2018-03-01 12:24:56.863962-06	3	[21223] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
f57e6cf8-f41e-465f-9bec-a4d0452df877	2018-03-01 12:24:57.094985-06	2	[21225] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
13bbe466-e308-49bd-959b-34208ff94c8e	2018-03-01 12:24:59.588235-06	3	[21222] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
e5e69b78-c44a-4b65-a305-a1752560621d	2018-03-01 12:24:59.815257-06	2	[21225] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
f6e05fc4-d309-40e0-b381-4a128ae9b491	2018-03-01 12:25:02.696546-06	3	[21221] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
3f76a9fd-fb15-4531-9f08-f7cd9609fb32	2018-03-01 12:25:02.918568-06	2	[21225] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
c968e842-4300-4346-8e86-799aa6283751	2018-03-01 12:25:06.298906-06	3	[21219] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
508390d1-8770-4a11-942a-eb7d5b9e1046	2018-03-01 12:25:06.527929-06	2	[21220] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
5b9a5016-42be-4515-a92f-88950c12ebae	2018-03-01 12:25:06.531929-06	2	[21225] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
59fb8e99-c4d6-4fcc-8462-6c8555dd3b56	2018-03-01 12:25:10.813357-06	3	[21220] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
3a7dda24-d37e-4be8-bd4c-c368853f3871	2018-03-01 12:25:11.036379-06	2	[21225] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
f6478f24-acb5-49ca-a69b-7834a6fc5481	2018-03-01 12:25:15.173793-06	2	[21058] New	[4] DLarrabee	[293] master	\N	\N
92720ab4-a3cf-4cc2-b757-b2455826d3d1	2018-03-01 12:25:16.280904-06	3	[21218] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
f8313c68-3ebf-430f-9ef5-3f27994ff210	2018-03-01 12:25:16.520928-06	2	[21225] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
b9e27ab0-3176-4551-90bf-31e30adb1bd1	2018-03-01 12:25:26.050881-06	3	[21058] New	[4] DLarrabee	[293] master	\N	\N
6b3fc820-bf75-4296-b187-e866bb5fa8a2	2018-03-01 12:27:34.994774-06	1	[21058] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
f6a6a504-367e-4844-82fc-63b18ec8a20d	2018-03-01 12:28:34.928767-06	3	[21233] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
1d50c16a-0156-45bb-9746-9f1e2fda1831	2018-03-01 12:28:35.177792-06	2	[21234] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
4776de3d-d91a-4d20-b2f6-5dfaba4e47d0	2018-03-01 12:28:35.180792-06	2	[21235] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
cd2a35a2-8acf-427d-a5e0-4b256842bc16	2018-03-01 12:28:35.183792-06	2	[21236] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
fc10d05d-2d58-498a-9181-d98d3a34251e	2018-03-01 12:28:35.188793-06	2	[21237] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
4420c534-57bb-4912-9e56-f7b8ae9c257f	2018-03-01 12:28:35.208795-06	2	[21238] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
3d723c3b-3352-4c71-999e-dc089c109d2e	2018-03-01 12:28:35.211795-06	2	[21239] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
f52ce9f6-a39f-4e7c-b2bc-270e4bc9c367	2018-03-01 12:28:35.215795-06	2	[21240] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
7b66f976-56f1-419b-9aba-bddf4efbf5c3	2018-03-01 12:28:35.218796-06	2	[21241] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
2063fed6-431c-4989-b59f-ee95173496fb	2018-03-01 12:28:41.432417-06	3	[21234] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
77bfe688-0371-4dd6-81ca-ba583a21ecd5	2018-03-01 12:28:41.656439-06	2	[21235] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
fa892ec4-becd-42ec-9372-51aa2e1c6c02	2018-03-01 12:28:41.65944-06	2	[21236] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
56e0ef21-7f4a-486a-a0f8-2635f5a8ed87	2018-03-01 12:28:41.66244-06	2	[21237] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
54402b5f-2207-4e6a-b177-1af638a9e7db	2018-03-01 12:28:41.66544-06	2	[21238] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
23d9513f-ce98-4f01-9e58-c83cc15c9718	2018-03-01 12:28:41.671441-06	2	[21239] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
f69f59dd-dee7-4310-9d9f-7a9e8375bb81	2018-03-01 12:28:41.674441-06	2	[21240] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
84e1db72-722b-4bf2-82ac-4ebdb1da72ff	2018-03-01 12:28:41.677441-06	2	[21241] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
328bd1c5-bd51-41e7-ab1d-3f455542df0c	2018-03-01 12:28:45.384812-06	3	[21235] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
214e6936-b7cc-4348-b53f-e0b7d900ec69	2018-03-01 12:28:45.612835-06	2	[21236] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
af2b260b-a5e3-41d1-818d-1affc220d2a0	2018-03-01 12:28:45.616835-06	2	[21237] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
3964ca5e-c422-494a-a5c5-2b461f08d6a2	2018-03-01 12:28:45.620836-06	2	[21238] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
99197100-585c-4956-b907-cca130f5d05a	2018-03-01 12:28:45.624836-06	2	[21239] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
5f3b6d88-ffb8-44dc-9dd2-b2f5b1e0720f	2018-03-01 12:28:45.628837-06	2	[21240] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
fb21723e-67a6-4b65-aadc-f1cfe63c596a	2018-03-01 12:28:45.632837-06	2	[21241] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
644372db-9890-4fd2-b842-f343a9859e09	2018-03-01 12:28:46.823956-06	3	[21236] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
21022e9f-dffa-44b8-a5da-277db705a463	2018-03-01 12:28:47.089983-06	2	[21237] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
7fae8d5a-b213-4552-8d0a-55e21cc72840	2018-03-01 12:28:47.092983-06	2	[21238] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef6e4796-51ec-40fc-827a-23676b41aea3	2018-03-01 12:28:47.098984-06	2	[21239] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
9c87baf0-82d0-4676-af9c-ee7a2a562902	2018-03-01 12:28:47.101984-06	2	[21240] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
ed47cfe5-ff91-41fa-9174-90e4d20f2066	2018-03-01 12:28:47.105984-06	2	[21241] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
a45188fc-925e-4f54-9b5e-97bd74336fe4	2018-03-01 12:28:48.125086-06	3	[21237] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
413f919e-ca6c-4dfb-874e-f32096a0879a	2018-03-01 12:28:48.352109-06	2	[21238] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
527c79f2-c4d7-493e-ad7d-8468450c446b	2018-03-01 12:28:48.356109-06	2	[21239] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
dbb5e5da-0d2e-4570-a6e9-f74bcb208f9f	2018-03-01 12:28:48.36111-06	2	[21240] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
20ff0890-7bf7-4227-a867-1016c657846b	2018-03-01 12:28:48.36511-06	2	[21241] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
226d8bc4-0309-4354-90a8-1bcb4bcb0edb	2018-03-01 12:28:49.304204-06	3	[21238] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
025e1d78-d2f5-4754-938b-55e464081228	2018-03-01 12:28:49.527226-06	2	[21239] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
8d72a3a7-cdce-4b4d-86c7-b45b9dc508d8	2018-03-01 12:28:49.531227-06	2	[21240] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
ccd265cb-964f-4a86-842d-3b6bc583f1a0	2018-03-01 12:28:49.535227-06	2	[21241] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
dda98f48-df81-4bd0-9f36-b394bbd395aa	2018-03-01 12:28:50.76635-06	3	[21239] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
c4df8db6-dcf2-4738-b015-70618230d78c	2018-03-01 12:28:51.015375-06	2	[21240] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
26cbe1fa-e95e-45da-9a0a-3929c659db8e	2018-03-01 12:28:51.020376-06	2	[21241] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
cd752cad-f956-4077-bcb3-0b25234ce63e	2018-03-01 12:30:07.708044-06	1	[21221] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
0ad73a71-b938-405e-b2dc-d2ab14161e3d	2018-03-01 12:30:25.817854-06	3	[21247] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
b2af81df-5a3d-4967-adc7-1402dc1cfdb7	2018-03-01 12:30:26.056878-06	2	[21248] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
e434a66b-c347-4345-ad67-95e501fb81bb	2018-03-01 12:30:26.059879-06	2	[21249] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
222bc399-7db0-4e0a-81a3-63d3e37407a4	2018-03-01 12:30:26.063879-06	2	[21250] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
80d4d015-8946-4de4-b1e6-304f14e072a7	2018-03-01 12:30:26.067879-06	2	[21251] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
2ce595fd-1bf7-4e31-a927-8eddbd653c26	2018-03-01 12:30:26.07088-06	2	[21252] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
69b98df1-aac0-4ae2-8216-9228a69a6a4c	2018-03-01 12:30:26.07488-06	2	[21253] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
c4ad1656-425d-49f9-874f-4637995a9ff2	2018-03-01 12:30:26.078881-06	2	[21254] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
d586b47a-101b-4b0f-a665-d400eac9e3ec	2018-03-01 12:30:26.081881-06	2	[21255] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
e6fada57-10aa-4b02-ad0c-e6f4267198bf	2018-03-01 12:30:27.623035-06	3	[21248] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
32fd0e99-6e96-4f2f-b835-6e09cd8c399b	2018-03-01 12:30:27.850058-06	2	[21249] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
41ccd973-8bb5-41ca-8900-521570eb2531	2018-03-01 12:30:27.854058-06	2	[21250] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
21275fbf-5115-4aa8-a572-cb76ac26f2d8	2018-03-01 12:30:27.858058-06	2	[21251] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
e69a4cf7-6af6-4436-b5f3-97779ec4ff57	2018-03-01 12:30:27.864059-06	2	[21252] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
a3618f42-e29d-4387-aa9c-a91922c530de	2018-03-01 12:30:27.867059-06	2	[21253] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
83df5f0d-ba85-445e-9324-b4a01fa75d41	2018-03-01 12:30:27.87106-06	2	[21254] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
81792432-45af-4bda-8e15-df64e00ad687	2018-03-01 12:30:27.87406-06	2	[21255] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
6ad00bd3-0bc9-43ad-9553-b0203e2d6fce	2018-03-01 12:30:28.508123-06	2	[21160] Door 107	[4] DLarrabee	[21062] a	\N	\N
c53ba175-7494-4e41-8cd8-90599ad1ab5c	2018-03-01 12:30:29.448217-06	3	[21249] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
731a9acb-a719-4bf2-a1d4-edfad2a669ff	2018-03-01 12:30:29.67524-06	2	[21250] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
83d75b1b-3dc3-4eee-b62d-85f898dd46c9	2018-03-01 12:30:29.67824-06	2	[21251] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
5c986fc4-2007-4348-b75c-15b9f94c675c	2018-03-01 12:30:29.684241-06	2	[21252] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
09d54b52-871a-453e-b981-4be52429e260	2018-03-01 12:30:29.687241-06	2	[21253] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
0ea8f3f4-2533-4d3e-af03-9c161f1c1743	2018-03-01 12:30:29.690242-06	2	[21254] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
832e9b9d-aa8d-45f1-909d-841ce18780c9	2018-03-01 12:30:29.692242-06	2	[21255] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
a050e0be-62ec-4491-a150-623921bc593c	2018-03-01 12:30:31.015374-06	3	[21250] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
ecd1b826-bd3f-41b4-a352-df367f991204	2018-03-01 12:30:31.239397-06	2	[21251] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
74769a8f-af9e-475d-a971-74fca548e2b3	2018-03-01 12:30:31.242397-06	2	[21252] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
c1a130e2-0488-4351-9460-7fd5bdefbc3b	2018-03-01 12:30:31.247397-06	2	[21253] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
706c7e81-7642-4277-bb19-35ab302ea861	2018-03-01 12:30:31.253398-06	2	[21254] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
3f3f896d-b7af-4760-be74-49e980501024	2018-03-01 12:30:31.256398-06	2	[21255] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
29489124-4ef9-4d29-8b86-5c9b47f6ab30	2018-03-01 12:30:32.416514-06	3	[21251] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
4a8bd7ab-2298-4ec1-8c12-17ecc9f2447e	2018-03-01 12:30:32.67454-06	2	[21252] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
ddc7d0e2-140e-4002-b2fa-88ceb43e0e1c	2018-03-01 12:30:32.681541-06	2	[21253] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
3cf11ea3-8ba2-4f01-bd90-cebb538c6b62	2018-03-01 12:30:32.685541-06	2	[21254] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
b70b4db8-7cf2-4918-b9ca-7e8848401fc6	2018-03-01 12:30:32.689542-06	2	[21255] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
7a82c36a-54e3-4ca2-9237-0a663a14bdb3	2018-03-01 12:30:33.815654-06	3	[21252] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
67a60bfd-be46-41e1-afb5-e1fa7d986c22	2018-03-01 12:30:34.042677-06	2	[21253] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
d1793b1b-7eea-4ccd-a5e6-7b92934b8cd7	2018-03-01 12:30:34.046677-06	2	[21254] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
cf1a5b0e-ec84-48fb-a2b6-cb4c77d81185	2018-03-01 12:30:34.050678-06	2	[21255] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
575b0045-abaa-470f-9035-ec43d12e3b65	2018-03-01 12:30:35.36981-06	3	[21253] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
a90c5571-8ecd-4e97-9586-75e16869f588	2018-03-01 12:30:35.617834-06	2	[21254] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
cbb98630-45fa-4dcd-ba8c-ff701a1ab1fe	2018-03-01 12:30:35.620835-06	2	[21255] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
53b700d1-7d33-4284-b2e3-a333b325698d	2018-03-01 12:30:58.843157-06	1	[21234] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
7d1e4b94-4a8d-4149-a66d-136426f403e6	2018-03-01 12:31:34.040676-06	3	[21262] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
8d54d1e4-7f65-4b61-936a-42fbe26fcc43	2018-03-01 12:31:34.286701-06	2	[21263] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
6fa921f4-cdc7-40d3-a9a8-3bbc8c8910af	2018-03-01 12:31:34.291701-06	2	[21264] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
99375107-36cc-434e-81a6-ce2456912fbd	2018-03-01 12:31:34.296702-06	2	[21265] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
e266ed79-c267-499b-a0c2-af75b4ea6e7a	2018-03-01 12:31:34.299702-06	2	[21266] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
db352691-3c33-4dd6-b50e-fbeb0d899658	2018-03-01 12:31:34.303702-06	2	[21267] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
114f8d85-2941-454b-910d-082a64da94d2	2018-03-01 12:31:34.306703-06	2	[21268] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
fb57b450-81ec-4cb3-9e6e-7dcd04cb1109	2018-03-01 12:31:34.310703-06	2	[21269] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
c864bff8-d9a9-478b-b693-0f22c9f16cbe	2018-03-01 12:31:34.313703-06	2	[21270] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
a1a017d2-ee95-43f7-ad8f-6d04b989348e	2018-03-01 12:31:35.144786-06	3	[21263] Rectangle 3 Button.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
6c74b66b-d3bc-42e7-aff5-4ec5f8828e04	2018-03-01 12:31:35.370809-06	2	[21264] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
2d1e0ef4-8162-4002-a1f2-30d5069c2c31	2018-03-01 12:31:35.374809-06	2	[21265] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
5c33ab53-5888-49a6-ba3c-5f5c32ab5720	2018-03-01 12:31:35.37881-06	2	[21266] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
3279548b-c54e-4e5e-8d2f-ce3c12c4431f	2018-03-01 12:31:35.38281-06	2	[21267] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
e9ec01f7-6fa7-40c9-940d-544bf19466a9	2018-03-01 12:31:35.386811-06	2	[21268] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
736722eb-b1a6-4029-ba8f-415b23688d6c	2018-03-01 12:31:35.390811-06	2	[21269] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
0315bd70-f576-4ae6-8d08-7881729037af	2018-03-01 12:31:35.393811-06	2	[21270] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
33cf36f8-9190-4843-b6ab-f6cef357977f	2018-03-01 12:31:36.104882-06	3	[21264] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
709acba8-b142-4417-9e21-ed89e22840ee	2018-03-01 12:31:36.333905-06	2	[21265] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
071037c7-de36-4d1f-b02a-1b990347403f	2018-03-01 12:31:36.336906-06	2	[21266] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
40b125c3-fa14-4209-be1c-896ca63fe5cd	2018-03-01 12:31:36.341906-06	2	[21267] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
20bf606e-d708-4911-ac07-d46d46f2ae82	2018-03-01 12:31:36.345907-06	2	[21268] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
57bc8a4b-4ab4-4c94-bf46-94028e9ff235	2018-03-01 12:31:36.348907-06	2	[21269] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
c8dce4c4-2d7d-4b91-b0a9-851867bf1a42	2018-03-01 12:31:36.352907-06	2	[21270] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
a97609ba-151c-4210-b1f3-4556df9d0ec3	2018-03-01 12:31:37.097982-06	3	[21265] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
06723495-3df0-4880-8ac3-30be108ae9ba	2018-03-01 12:31:37.325004-06	2	[21266] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
dd5f3569-1c34-4dec-b774-1ce1188483c1	2018-03-01 12:31:37.329005-06	2	[21267] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
d34016fd-e469-45ba-89c4-af938ed6be0a	2018-03-01 12:31:37.333005-06	2	[21268] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
6ebda6d5-8941-4431-942e-55736b271c17	2018-03-01 12:31:37.336006-06	2	[21269] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
437daf4a-cb83-485a-ad88-469e8ec658e5	2018-03-01 12:31:37.340006-06	2	[21270] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
22e90c5a-6f17-47d8-b80d-32b7056e4d78	2018-03-01 12:31:38.033075-06	3	[21266] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
e2e88454-b10a-4e62-843e-b2109dbb21af	2018-03-01 12:31:38.257098-06	2	[21267] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
c14b8c23-967f-4291-a05e-ebf3ea490d69	2018-03-01 12:31:38.261098-06	2	[21268] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
12a8da8d-5dd8-4c46-b2d6-6b5a8612e327	2018-03-01 12:31:38.266099-06	2	[21269] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
b285952c-b8d4-4579-a490-978af2768deb	2018-03-01 12:31:38.274099-06	2	[21270] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
d573518e-a409-4e8b-a0f7-0ec8b0f6b8a9	2018-03-01 12:31:39.098182-06	3	[21267] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
1d256860-e37d-454d-80cb-116d77865d96	2018-03-01 12:31:39.328205-06	2	[21268] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
44c97383-4200-47f6-8811-ede1d743d96a	2018-03-01 12:31:39.333205-06	2	[21269] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
42d2aedb-0e4a-4a2f-a34a-ac2a5c65f465	2018-03-01 12:31:39.339206-06	2	[21270] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
f7cf347f-9856-4e07-8d26-071426b8b070	2018-03-01 12:31:40.256298-06	3	[21268] Rectangle 3 Button.png Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
1bf15101-80f0-44fa-b604-1442bf6099c7	2018-03-01 12:31:40.500322-06	2	[21269] Nav Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
2562d3a4-b432-4dc9-a44c-0caa6e9d8888	2018-03-01 12:31:40.503322-06	2	[21270] New Shared Screen Object (link)	[21041] OSSI-DNOVAK	[293] master	\N	\N
69b7b15f-24a1-4358-b6c6-599ba139b56f	2018-03-01 12:31:53.342606-06	1	[21239] Main Button Tool	[21041] OSSI-DNOVAK	[293] master	\N	\N
c8c9d6b6-83e5-4964-8cd5-19f729922247	2018-03-01 12:32:35.305802-06	2	[21161] Door 108	[4] DLarrabee	[21062] a	\N	\N
6a9de75a-2f45-417a-91bf-a40de6ebeede	2018-03-01 12:33:20.575328-06	2	[21163] Door 109	[4] DLarrabee	[21062] a	\N	\N
c9e51bb8-a0e1-47c8-ab09-68285d3c3b1d	2018-03-01 12:34:29.565227-06	2	[21053] Door 112	[4] DLarrabee	[21062] a	\N	\N
232536e4-ba69-43f4-a1e5-077fc0f5d94c	2018-03-01 12:37:25.261795-06	2	[21078] Door 114A	[4] DLarrabee	[21062] a	\N	\N
966fce15-f5bc-4d82-9b4d-0444a9130540	2018-03-01 12:40:06.623929-06	2	[21078] Door 114A	[4] DLarrabee	[21062] a	\N	\N
16d50ce6-0cd3-4f63-bc35-38b66808796a	2018-03-01 12:40:20.656332-06	2	[21053] Door 112	[4] DLarrabee	[21062] a	\N	\N
225893e6-b3a7-445f-9763-1bdfa3d84f43	2018-03-01 12:40:31.412408-06	2	[21163] Door 109	[4] DLarrabee	[21062] a	\N	\N
1fa455d2-c76a-44d2-b5f8-adc92838d253	2018-03-01 12:40:43.972664-06	2	[21161] Door 108	[4] DLarrabee	[21062] a	\N	\N
fe64083b-c6e9-4160-8674-0a8a625a14d9	2018-03-01 12:40:54.001667-06	2	[21160] Door 107	[4] DLarrabee	[21062] a	\N	\N
6b788ae8-80bd-4847-81ca-c0a01fdba16b	2018-03-01 12:41:30.246291-06	2	[21045] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
dcb0bebd-937d-4ad0-8d54-bf5a67319d1d	2018-03-01 12:42:01.885454-06	2	[21045] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
7c022033-6f3f-40c4-a1ac-41c95e9186a3	2018-03-01 12:43:01.612426-06	2	[21045] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
1de5e668-966b-43e5-bbdb-68f73b8b948d	2018-03-01 13:29:37.450982-06	2	[21076] RM 304 32i MAC Driver	[4] DLarrabee	[21062] a	\N	\N
39470f83-c507-49a1-8928-5cdeb27a7516	2018-03-01 13:30:08.874124-06	2	[21077] RM 304 16R MAC Driver	[4] DLarrabee	[21062] a	\N	\N
d516f38a-da9d-4dea-abb4-69a49492217a	2018-03-01 13:30:58.878124-06	2	[21076] RM 304 32i MAC Driver	[4] DLarrabee	[21062] a	\N	\N
f740ec24-ab85-495b-84cf-b1db282fce07	2018-03-01 13:30:58.892126-06	2	[15783] R7C1-16R	[4] DLarrabee	[21062] a	\N	\N
6c6f3a65-5ce2-4c9c-b9d1-085a9ca4e85b	2018-03-01 13:30:58.929129-06	2	[16103] R7C2-16R	[4] DLarrabee	[21062] a	\N	\N
afef8970-4c09-4722-9eb1-3d0c2dcc1c73	2018-03-01 13:32:46.715907-06	2	[21077] RM 304 16R MAC Driver	[4] DLarrabee	[21062] a	\N	\N
3103aae6-3d3a-4616-b232-b5cb3049da82	2018-03-01 13:32:46.731908-06	2	[14849] R6C2-32I	[4] DLarrabee	[21062] a	\N	\N
b157c0fb-3e53-411d-b4ff-1f7de1030d06	2018-03-01 13:32:46.74891-06	2	[15316] R6C3-32I	[4] DLarrabee	[21062] a	\N	\N
e115c4a7-7a2b-41d2-8603-d0481e563099	2018-03-01 13:37:07.290962-06	2	[21077] RM 304 16R MAC Driver	[4] DLarrabee	[21062] a	\N	\N
ee5879e8-b536-4873-af5f-861d3f3f379c	2018-03-01 13:38:24.57669-06	2	[21077] RM 304 16R MAC Driver	[4] DLarrabee	[21062] a	\N	\N
7714ec50-92c1-4628-9e23-2138fab4e0c4	2018-03-01 13:53:17.625986-06	2	[21076] RM 304 32i MAC Driver	[4] DLarrabee	[21062] a	\N	\N
47d43f6f-4c99-4e68-b3e3-0865f4e4eebc	2018-03-01 13:54:05.831806-06	2	[21076] RM 304 I/O MAC Driver	[4] DLarrabee	[21062] a	\N	\N
753e33f5-9d24-4563-b860-8564fe0aedcd	2018-03-01 13:55:15.655787-06	2	[21077] RM 304 16R MAC Driver	[4] DLarrabee	[21062] a	\N	\N
85c75253-1e6e-4bda-9aed-125da6740803	2018-03-01 13:55:22.350457-06	3	[21077] RM 304 16R MAC Driver	[4] DLarrabee	[21062] a	\N	\N
d1fceb54-4553-4ade-84f4-008e8353453c	2018-03-01 13:57:11.039325-06	2	[21076] RM 304 I/O MAC Driver	[4] DLarrabee	[21062] a	\N	\N
bdc88f20-1871-45de-b7cf-cad296ffa361	2018-03-01 13:57:11.053326-06	2	[14849] R6C2-32I	[4] DLarrabee	[21062] a	\N	\N
2b037854-5345-40df-bf43-beb112d03616	2018-03-01 13:57:11.067327-06	2	[15316] R6C3-32I	[4] DLarrabee	[21062] a	\N	\N
b37aafd4-8148-4cad-a02d-45334707bccf	2018-03-01 13:57:11.083329-06	2	[16423] R7C3-16R	[4] DLarrabee	[21062] a	\N	\N
6e8d0d8e-641f-45ca-a19f-fd3615c702a0	2018-03-01 13:57:11.09533-06	2	[16743] R7C4-16R	[4] DLarrabee	[21062] a	\N	\N
293a4739-1d5a-4e8c-8c36-e63fcbb50c7a	2018-03-01 13:57:11.107331-06	2	[17063] R7C5-16R	[4] DLarrabee	[21062] a	\N	\N
2235bbde-3cf7-43c8-84fc-19c6e3f8a054	2018-03-01 14:31:43.724572-06	1	[21077] Door 211 Copy	[4] DLarrabee	[21062] a	\N	\N
eb8a4eb4-604c-49bb-978a-13f9f31ed843	2018-03-01 14:38:37.599956-06	2	[21216] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
3a2c5ad1-5cda-489a-90b1-65467d69e4e2	2018-03-01 14:43:50.325225-06	1	[21251] intercom_gry.jpg	[21041] OSSI-DNOVAK	[293] master	\N	\N
ce3bea26-f4db-4c15-a73c-68cdd3c91448	2018-03-01 14:46:37.745966-06	1	[21252] New Counter Group	[21041] OSSI-DNOVAK	[293] master	\N	\N
9eb585aa-7e00-4b93-91df-46c30a276edd	2018-03-01 14:46:58.611052-06	2	[21252] Intercom Visable	[21041] OSSI-DNOVAK	[293] master	\N	\N
8e55fbca-8cef-4a0d-af3a-b10c5af6bc1f	2018-03-01 14:47:11.49134-06	1	[21253] New Counter	[21041] OSSI-DNOVAK	[293] master	\N	\N
4f8d7ff7-45ab-4b24-8479-aae79fe5fa63	2018-03-01 14:48:10.885279-06	1	[21262] 1	[21041] OSSI-DNOVAK	[293] master	\N	\N
57d484d7-535b-4afe-a5d6-2844ab53e065	2018-03-01 14:48:25.014691-06	1	[21263] 2	[21041] OSSI-DNOVAK	[293] master	\N	\N
8754d61e-96c5-49d0-a72a-55b0f940121a	2018-03-01 14:48:25.036694-06	1	[21264] 3	[21041] OSSI-DNOVAK	[293] master	\N	\N
6d9f48df-b2ac-402c-abaf-c118367de55d	2018-03-01 14:48:25.040694-06	1	[21265] 4	[21041] OSSI-DNOVAK	[293] master	\N	\N
c4a31dfc-5ece-4ab7-937d-cb3691ef4488	2018-03-01 14:48:25.046695-06	1	[21266] 5	[21041] OSSI-DNOVAK	[293] master	\N	\N
6bbcda63-f570-450f-a277-1137c4bc46dd	2018-03-01 14:48:25.064696-06	1	[21267] 6	[21041] OSSI-DNOVAK	[293] master	\N	\N
2b892266-47e3-4d21-8e74-2c67baa4fcbb	2018-03-01 14:48:35.164706-06	2	[21262] A	[21041] OSSI-DNOVAK	[293] master	\N	\N
cdedd06a-2a0b-45cc-bbe7-132fc9c27699	2018-03-01 14:48:43.009491-06	2	[21263] B	[21041] OSSI-DNOVAK	[293] master	\N	\N
f7f02a0b-8269-4764-80eb-9d57ca01e5d8	2018-03-01 14:49:23.30452-06	2	[21262] Vewable	[21041] OSSI-DNOVAK	[293] master	\N	\N
8292d65f-9f33-4859-8388-858b3b0dba19	2018-03-01 14:49:38.664056-06	2	[21263] Not Viewable	[21041] OSSI-DNOVAK	[293] master	\N	\N
1a85fe5f-3ea5-43f6-b08f-a07d5b9a9741	2018-03-01 14:51:18.890077-06	2	[21251] intercom_gry.jpg	[21041] OSSI-DNOVAK	[293] master	\N	\N
0603703a-b935-42fa-a6a7-64c250767248	2018-03-01 14:52:11.502338-06	2	[21251] IC 316B-in B	[21041] OSSI-DNOVAK	[293] master	\N	\N
cfbf86dd-7530-4c71-9cf4-33ff14e00474	2018-03-01 14:58:04.080592-06	1	[21268] Door 306	[4] DLarrabee	[21062] a	\N	\N
3fe07218-ddef-4c56-88b9-a79072fb6dc4	2018-03-01 14:58:46.998884-06	1	[21277] IC 316B-in B Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
e9ac4c1d-0329-4696-b53f-6645b5b4912a	2018-03-01 15:01:37.392921-06	2	[21277] IC 316B-OUT B	[21041] OSSI-DNOVAK	[293] master	\N	\N
1298139b-3771-44fb-abc7-0966624bcf44	2018-03-01 15:01:47.820964-06	1	[21280] IC 316B-OUT B Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
e924daff-959b-4b94-9af5-36c1d7320478	2018-03-01 15:05:04.542634-06	2	[21280] IC 326B-A	[21041] OSSI-DNOVAK	[293] master	\N	\N
4721b49d-a6dd-4f6a-87c8-2e6728c3883f	2018-03-01 15:13:02.521427-06	2	[21262] Viewable	[21041] OSSI-DNOVAK	[293] master	\N	\N
817e6dc2-f34a-43b5-9df3-89d3ba15e342	2018-03-01 15:14:06.762851-06	3	[21077] Door 211 Copy	[4] DLarrabee	[21062] a	\N	\N
6f24b173-dfe9-4458-a78c-eab2874c7b59	2018-03-01 15:18:22.2834-06	2	[21280] IC 326B-A	[21041] OSSI-DNOVAK	[293] master	\N	\N
81d438b6-7940-4f07-8c6e-32d134e5af74	2018-03-01 15:20:39.072078-06	3	[21134] 2ND Screen Group	[4] DLarrabee	[21062] a	\N	\N
87e43c23-ea54-40bb-8795-f69662ace97f	2018-03-01 15:25:23.299498-06	2	[21277] IC 316B-OUT B	[21041] OSSI-DNOVAK	[293] master	\N	\N
2a6b33f6-ce24-4933-964a-84247c627199	2018-03-01 15:25:46.275795-06	2	[21251] IC 316B-in B	[21041] OSSI-DNOVAK	[293] master	\N	\N
a8f16151-3c28-4170-8ca3-a526d03a4a58	2018-03-01 15:26:23.904558-06	1	[21077] IC 326B-A Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
acb156a5-45df-43cf-9cc1-57b0f35dfbbb	2018-03-01 15:27:50.121178-06	2	[21077] IC 326A-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
4f910595-3e23-4b79-b044-baaa439762a9	2018-03-01 15:28:12.868453-06	1	[21134] IC 326A-OutB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
85efa5a0-9f6d-4bf5-8f82-05c8ba58eb73	2018-03-01 15:29:29.172082-06	2	[21134] IC 327A	[21041] OSSI-DNOVAK	[293] master	\N	\N
5110287a-5312-4a8b-b802-8985b0b79ab1	2018-03-01 15:29:38.236989-06	1	[21135] IC 327A Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
c8d58b55-ac04-4b00-ae09-f728e916f37e	2018-03-01 15:29:59.224087-06	2	[21280] IC 326A	[21041] OSSI-DNOVAK	[293] master	\N	\N
de3e19da-d2dc-40f7-9a7b-7c6967bed36e	2018-03-01 15:31:00.034168-06	2	[21135] IC 327A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
60412742-2d28-40a7-ae41-bb0d88781ade	2018-03-01 15:31:11.102274-06	1	[21136] IC 327A-outB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
09f233cc-ce69-45a7-84c0-92c23a08d03e	2018-03-01 15:32:20.750239-06	2	[21136] IC 329A	[21041] OSSI-DNOVAK	[293] master	\N	\N
bcb2c033-c955-41dd-9c1d-25901cb6cf71	2018-03-01 15:32:31.615325-06	1	[21281] IC 329A Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
5cda9e68-0012-43c5-8953-7652c9136f36	2018-03-01 15:33:46.306793-06	1	[21282] IC-329A-outB Connect	[21041] OSSI-DNOVAK	[293] master	\N	\N
8f19786d-31c6-41bd-8795-d8c11f29b509	2018-03-01 15:33:56.17578-06	2	[21281] IC 329A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
f2e546a4-81d7-44a6-accf-6ab816dcbb3b	2018-03-01 15:39:21.30429-06	1	[21293] IC 329A-outB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
1d18d481-7145-4bea-bea1-9a6e26d7d25c	2018-03-01 15:40:31.81034-06	2	[21293] IC 329A-outB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
06b3ea24-2e7a-4b00-8967-57f5cbd5cc51	2018-03-01 15:41:14.546613-06	2	[21293] IC 329B	[21041] OSSI-DNOVAK	[293] master	\N	\N
50db4d52-3811-4e16-8d58-c105658d6f2e	2018-03-01 15:42:10.186176-06	1	[21294] IC 329B (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
3d8ffa38-c240-4479-958a-f68a45aa9d04	2018-03-01 15:42:10.210179-06	1	[21295] IC 329B (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
ee92a4d5-3677-4e7a-8018-d12cfc97f6e0	2018-03-01 15:42:10.214179-06	1	[21296] IC 329B (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
873a7142-ff15-4f9e-aa4f-a472d648b5a0	2018-03-01 15:42:10.22118-06	1	[21297] IC 329B (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
e79422db-d717-43ec-b1c9-f30a26f07728	2018-03-01 15:42:10.22618-06	1	[21298] IC 329B (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
05177ad3-4c3d-4570-a172-8db5b263515f	2018-03-01 15:42:10.231181-06	1	[21299] IC 329B (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
45516c12-3221-40f8-85f7-6917029d1c3b	2018-03-01 15:42:10.238181-06	1	[21300] IC 329B (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
e8a6041f-b64f-4457-aa32-800254e8bbe3	2018-03-01 15:44:42.247381-06	1	[21301] IC 329B (7) Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
80a98122-5257-4f4f-b06d-399e10ccf4bc	2018-03-01 15:45:41.489304-06	2	[21301] IC 337A	[21041] OSSI-DNOVAK	[293] master	\N	\N
9a33307a-bc95-4281-ade1-37713c7b9a7a	2018-03-01 15:46:17.04886-06	2	[21300] IC 329B (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
81a55fed-f9e2-41e0-b479-3fd8540f85ff	2018-03-01 15:46:42.460401-06	2	[21294] IC 329B-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
c825c8ac-5661-454b-a5d0-8d5c7755cec5	2018-03-01 15:46:58.281983-06	2	[21295] IC 334A	[21041] OSSI-DNOVAK	[293] master	\N	\N
72a611dd-279e-4638-8bf7-0ba032206f1b	2018-03-01 15:47:19.796134-06	2	[21296] IC 334A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
fa3330f4-1391-4b59-b2dc-195904b2c054	2018-03-01 15:47:33.018456-06	2	[21297] IC 335A	[21041] OSSI-DNOVAK	[293] master	\N	\N
37728c74-c280-4daa-9750-1fef00f1a01a	2018-03-01 15:47:50.063161-06	2	[21298] IC 335A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
f1b28faa-4fbf-4a3a-b1d1-dd168202213f	2018-03-01 15:48:02.590413-06	2	[21299] IC 336A	[21041] OSSI-DNOVAK	[293] master	\N	\N
d21bdf21-0dbd-4e0c-84a1-36b812178805	2018-03-01 15:48:17.86494-06	2	[21300] IC 336A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
9ec08d87-aca8-4dea-bc73-aef66410aaa3	2018-03-01 15:49:12.586412-06	1	[21302] IC 337A (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
a504ac4d-0dc1-41cc-97cd-b652e648677c	2018-03-01 15:49:12.591413-06	1	[21303] IC 337A (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
2945bc16-f65f-4cd9-93ee-03b92d01bb19	2018-03-01 15:49:12.599413-06	1	[21304] IC 337A (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
1cfd140c-b772-4db5-b943-ba64039ec872	2018-03-01 15:49:12.605414-06	1	[21305] IC 337A (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
ceed2b47-71b9-4e69-831d-c1780cf9f67c	2018-03-01 15:49:12.612415-06	1	[21306] IC 337A (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
0576e413-b950-48a1-90b6-9a73c8cf7c29	2018-03-01 15:49:12.619415-06	1	[21307] IC 337A (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
c865afeb-898e-4d52-95ff-56ad165bd736	2018-03-01 15:49:40.810234-06	2	[21302] IC 337A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
20e75f32-7565-4b8f-bf68-8254dcd49f86	2018-03-01 15:49:52.553408-06	2	[21303] IC 338A	[21041] OSSI-DNOVAK	[293] master	\N	\N
aac8b861-8f2b-4fad-8dc5-59a39827b267	2018-03-01 15:50:05.16967-06	2	[21304] IC 338A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
ff36e6b9-a0ed-40c6-a32a-ebee3cd89353	2018-03-01 15:50:20.739227-06	2	[21305] IC 343A	[21041] OSSI-DNOVAK	[293] master	\N	\N
19982f1e-f2a6-4d43-9003-69c6a34517c8	2018-03-01 15:50:35.698722-06	2	[21306] IC 343A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
b8f0ac65-6076-49d4-b69a-6ccf042816d6	2018-03-01 15:50:47.043857-06	2	[21307] IC 344A	[21041] OSSI-DNOVAK	[293] master	\N	\N
e6f5099f-2ec9-4ac2-93d3-8f200216723c	2018-03-01 15:50:51.916344-06	1	[21308] IC 344A Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
2248a4a2-5fa2-4431-80c1-a3f9d0aeb071	2018-03-01 15:51:59.615113-06	3	[21308] IC 344A Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
7717e53c-3f5d-415f-a54a-0953ae0fbb65	2018-03-01 15:52:02.38039-06	3	[21307] IC 344A	[21041] OSSI-DNOVAK	[293] master	\N	\N
bd579f30-fa44-426e-ae07-531ac714df93	2018-03-01 15:52:44.195571-06	3	[21306] IC 343A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
daee301e-c02e-4ee0-8b00-2a7ba4b27417	2018-03-01 15:52:44.418593-06	3	[21305] IC 343A	[21041] OSSI-DNOVAK	[293] master	\N	\N
d8a3de45-5b93-4d5e-839c-c9b1102c0855	2018-03-01 15:52:44.661617-06	3	[21303] IC 338A	[21041] OSSI-DNOVAK	[293] master	\N	\N
51e9ceba-f6f7-404d-b793-19b9dd8055cd	2018-03-01 15:52:44.893641-06	2	[21304] IC 338A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
7cb444a3-cc13-409a-a905-7174f90b86da	2018-03-01 15:52:44.897641-06	3	[21304] IC 338A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
88b35af7-b129-4a5a-9ae8-36976bec1f4a	2018-03-01 15:52:45.143666-06	3	[21302] IC 337A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
f8bc28bc-77db-45d9-8ed3-fb1fa8316f4d	2018-03-01 15:54:26.791829-06	2	[21301] IC 337A	[21041] OSSI-DNOVAK	[293] master	\N	\N
9abfa2e1-f605-44a7-9cfa-d5d320fd8376	2018-03-01 15:55:03.99855-06	1	[21302] IC 337A (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
84d67bed-4d02-472e-8c3f-25f376db5a3c	2018-03-01 15:55:04.006551-06	1	[21303] IC 337A (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
6ba6023b-4558-4836-ac0b-a552e2e39170	2018-03-01 15:55:04.012551-06	1	[21304] IC 337A (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
4a6558df-1105-47de-aca5-91cb77916540	2018-03-01 15:55:04.017552-06	1	[21305] IC 337A (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
f2be103a-2f9f-40ba-93e6-13d3336af3c5	2018-03-01 15:55:04.023552-06	1	[21306] IC 337A (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
9561bb38-f4b3-46a6-a162-f40773fa4b52	2018-03-01 15:55:04.028553-06	1	[21307] IC 337A (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
7dbc7c7b-8917-4a03-bd9a-dd958830bf68	2018-03-01 15:55:04.032553-06	1	[21308] IC 337A (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
7b426285-ded1-4baa-8a35-dea56c0f64a0	2018-03-01 15:55:21.314281-06	2	[21131] Door 455D	[4] DLarrabee	[21062] a	\N	\N
99bf1686-633f-4408-b31d-ca85e1048217	2018-03-01 15:55:36.246774-06	3	[21132] Door 455D Copy	[4] DLarrabee	[21062] a	\N	\N
35a3b939-7e20-43e7-8312-75f5c6611346	2018-03-01 15:55:36.362786-06	2	[21302] IC 337A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
3d475da3-db7a-4544-93ce-93f01de8d068	2018-03-01 15:55:47.363886-06	2	[21303] IC 338A	[21041] OSSI-DNOVAK	[293] master	\N	\N
fc252dcd-92b1-44af-98be-3e8792a7b228	2018-03-01 15:56:03.033453-06	2	[21304] IC 338A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
f587e52b-ab79-4bd7-8c73-6b77f13e30dd	2018-03-01 15:56:15.596709-06	2	[21305] IC 343A	[21041] OSSI-DNOVAK	[293] master	\N	\N
5e230332-95ac-4131-9fa3-26a579be3894	2018-03-01 15:56:29.689118-06	2	[21306] IC 343A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
b1f5e898-9839-4553-a4b3-f64468525547	2018-03-01 15:56:44.016551-06	2	[21307] IC 344A	[21041] OSSI-DNOVAK	[293] master	\N	\N
b4cb80be-c1cb-46c5-b4b2-ba5eec5a524e	2018-03-01 15:56:58.085957-06	2	[21308] IC 344A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
db2c04df-0f6d-413d-8579-5f85be9fd801	2018-03-01 15:57:12.158364-06	2	[21308] IC 344A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
eefca94a-e90e-4e79-9dd9-ee6be7ea2d27	2018-03-01 15:58:59.049052-06	3	[21093] Main Screen	[4] DLarrabee	[21062] a	\N	\N
5fce0391-60e2-43cc-a139-84777e730fc1	2018-03-01 15:59:40.075155-06	3	[21282] IC-329A-outB Connect	[4] DLarrabee	[21062] a	\N	\N
a7ada5f9-1f67-499b-a6df-2fc5c61b9184	2018-03-01 15:59:40.305178-06	2	[21293] IC 329B	[4] DLarrabee	[21062] a	\N	\N
7264c17a-88b1-48e9-833a-e7515178db01	2018-03-01 15:59:40.309178-06	2	[21294] IC 329B-outB	[4] DLarrabee	[21062] a	\N	\N
425540b9-2809-4277-9780-ee34fc93654e	2018-03-01 15:59:40.316179-06	2	[21295] IC 334A	[4] DLarrabee	[21062] a	\N	\N
4794ed4f-5f51-4420-a32a-9401f70c7dad	2018-03-01 15:59:40.322179-06	2	[21296] IC 334A-outB	[4] DLarrabee	[21062] a	\N	\N
4b3903bc-1e1e-40ae-80c9-6ad94e01f416	2018-03-01 15:59:40.32818-06	2	[21297] IC 335A	[4] DLarrabee	[21062] a	\N	\N
688d20cd-25d3-4dd5-86f5-dc54a49c0716	2018-03-01 15:59:40.33318-06	2	[21298] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
2645bcc7-a968-43c8-bf9c-56754881de52	2018-03-01 15:59:40.338181-06	2	[21299] IC 336A	[4] DLarrabee	[21062] a	\N	\N
8c03693d-4e8d-4926-bb4c-196d901cfb57	2018-03-01 15:59:40.341181-06	2	[21300] IC 336A-outB	[4] DLarrabee	[21062] a	\N	\N
d63d40a0-cbe5-4406-9f6b-144f7a1d35cd	2018-03-01 15:59:40.346182-06	2	[21301] IC 337A	[4] DLarrabee	[21062] a	\N	\N
8286bc0f-f43f-4aea-b6bf-347bd055b970	2018-03-01 15:59:40.350182-06	2	[21302] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
c0b8a88c-2ea1-4054-9750-0473454fef29	2018-03-01 15:59:40.353182-06	2	[21303] IC 338A	[4] DLarrabee	[21062] a	\N	\N
3e912e23-1733-4541-a42a-f954ac594e9a	2018-03-01 15:59:40.358183-06	2	[21304] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
aae33f11-3d47-4c1d-97e7-44dc9feb43b5	2018-03-01 15:59:40.363183-06	2	[21305] IC 343A	[4] DLarrabee	[21062] a	\N	\N
79fd365d-a8ae-4bc9-b533-3fb1dc9d3599	2018-03-01 15:59:40.367184-06	2	[21306] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
88c5cd18-2ddb-421c-9dfc-9d9981f84172	2018-03-01 15:59:40.371184-06	2	[21307] IC 344A	[4] DLarrabee	[21062] a	\N	\N
4a3b2a63-24cd-49f7-82bc-4c29719ca3ba	2018-03-01 15:59:40.377185-06	2	[21308] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
ebeb3074-cfd4-4a07-b7cf-90c647bb5a6c	2018-03-01 15:59:55.42669-06	1	[21093] IC 344A-outB Copy	[4] DLarrabee	[21062] a	\N	\N
9be207cc-5f4f-4fa1-a75b-eeadfd8efdd0	2018-03-01 16:07:58.952037-06	2	[21093] IC 346A	[4] DLarrabee	[21062] a	\N	\N
52d18123-bc3b-4095-acb3-4bab81db747e	2018-03-01 16:08:55.098651-06	1	[21094] IC 346A (1)	[4] DLarrabee	[21062] a	\N	\N
c43b23b6-c28b-4a50-89b2-15c2fa05c4cb	2018-03-01 16:08:55.112653-06	1	[21095] IC 346A (2)	[4] DLarrabee	[21062] a	\N	\N
3ea8728b-4d41-42a3-9223-7fe592a6386a	2018-03-01 16:08:55.116653-06	1	[21132] IC 346A (3)	[4] DLarrabee	[21062] a	\N	\N
adb31701-1d70-4de5-b9b0-94d427c9a77d	2018-03-01 16:08:55.121654-06	1	[21282] IC 346A (4)	[4] DLarrabee	[21062] a	\N	\N
e44a6227-c790-4786-8dc0-d03e8b088fdb	2018-03-01 16:08:55.125654-06	1	[21309] IC 346A (5)	[4] DLarrabee	[21062] a	\N	\N
74f1a585-4e91-4333-9612-2e35c10a0e76	2018-03-01 16:08:55.130655-06	1	[21310] IC 346A (6)	[4] DLarrabee	[21062] a	\N	\N
66fac735-414f-4136-b6b7-47dfdc57af27	2018-03-01 16:08:55.135655-06	1	[21311] IC 346A (7)	[4] DLarrabee	[21062] a	\N	\N
52cb2be7-cdcb-40bd-b0c4-6ae33e18413e	2018-03-01 16:09:28.473989-06	2	[21094] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
d9c501be-5061-40e1-a012-3ff34492b536	2018-03-01 16:09:44.132554-06	2	[21095] IC 347A	[4] DLarrabee	[21062] a	\N	\N
eca72684-888c-4387-869e-8e7b722b5633	2018-03-01 16:10:00.302171-06	2	[21132] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
4de3c1cd-ab8b-4231-9ff0-936f699e2616	2018-03-01 16:10:14.840625-06	2	[21282] IC 348A	[4] DLarrabee	[21062] a	\N	\N
90cd9776-390f-4737-8afb-7da932124554	2018-03-01 16:10:29.044045-06	2	[21309] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
b4d021ab-4ac1-45ff-953d-419009c5ddaf	2018-03-01 16:10:46.29577-06	2	[21310] IC 349A	[4] DLarrabee	[21062] a	\N	\N
0c588316-4ac9-4d5b-99e6-24a95dd38b77	2018-03-01 16:11:02.402381-06	2	[21311] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
889eb4df-ab8b-4344-8488-48d7c3ec99d0	2018-03-01 16:16:49.263063-06	1	[21312] Door 103	[4] DLarrabee	[21062] a	\N	\N
e4427bad-c049-4221-a27f-29e54e610f35	2018-03-01 16:18:04.33757-06	2	[21312] Door 307	[4] DLarrabee	[21062] a	\N	\N
56c9a68e-3244-4dd7-961e-2cd5845cdc3f	2018-03-01 16:19:20.475183-06	1	[21313] Door 307 (1)	[4] DLarrabee	[21062] a	\N	\N
78a5b45d-046a-4ad3-a932-c4f6afbc0c75	2018-03-01 16:19:20.490184-06	1	[21314] Door 307 (2)	[4] DLarrabee	[21062] a	\N	\N
524a7d81-479e-4d26-bada-48f863d51688	2018-03-01 16:19:20.523188-06	1	[21315] Door 307 (3)	[4] DLarrabee	[21062] a	\N	\N
b578899e-d31f-4ed0-95c2-d3649a87ef10	2018-03-01 16:19:20.54719-06	1	[21316] Door 307 (4)	[4] DLarrabee	[21062] a	\N	\N
f6f94219-e854-4e5a-8c45-6dcf4e719799	2018-03-01 16:19:20.563192-06	1	[21317] Door 307 (5)	[4] DLarrabee	[21062] a	\N	\N
36449bfe-69ad-41c8-b487-98b9a0677325	2018-03-01 16:19:20.582194-06	1	[21318] Door 307 (6)	[4] DLarrabee	[21062] a	\N	\N
313b1546-1005-4c7f-8224-449d613edb57	2018-03-01 16:19:20.596195-06	1	[21319] Door 307 (7)	[4] DLarrabee	[21062] a	\N	\N
335da394-6fcd-4e1b-b849-ab28c089e785	2018-03-01 16:19:20.611196-06	1	[21320] Door 307 (8)	[4] DLarrabee	[21062] a	\N	\N
7fd3d4d9-29fa-4c66-aaaf-f0010e36d4ab	2018-03-01 16:19:20.628198-06	1	[21321] Door 307 (9)	[4] DLarrabee	[21062] a	\N	\N
07a2467a-eb1d-484a-b6a3-39715b72f294	2018-03-01 16:19:20.6432-06	1	[21322] Door 307 (10)	[4] DLarrabee	[21062] a	\N	\N
efba8a2f-5e1e-4036-a8cd-f8e9bf6f0a33	2018-03-01 16:19:20.657201-06	1	[21323] Door 307 (11)	[4] DLarrabee	[21062] a	\N	\N
dbb689bc-5858-4626-ad90-d3c2e4865775	2018-03-01 16:19:20.673203-06	1	[21324] Door 307 (12)	[4] DLarrabee	[21062] a	\N	\N
8eaa7476-ba9c-4f48-8eb0-70330a3d4033	2018-03-01 16:19:20.688204-06	1	[21325] Door 307 (13)	[4] DLarrabee	[21062] a	\N	\N
29647a1c-af60-4e94-acb2-659fcc8e5e8c	2018-03-01 16:19:20.701205-06	1	[21326] Door 307 (14)	[4] DLarrabee	[21062] a	\N	\N
e08ef488-0fa3-4c57-bae0-51fb792f40d6	2018-03-01 16:19:20.717207-06	1	[21327] Door 307 (15)	[4] DLarrabee	[21062] a	\N	\N
c34a01e3-3ee3-4ca5-a4d3-c5cf3b4558d1	2018-03-01 16:19:42.092344-06	2	[21313] Door 309	[4] DLarrabee	[21062] a	\N	\N
f6e95300-c001-441b-add5-e26d36a08c20	2018-03-01 16:19:55.54769-06	2	[21314] Door 314	[4] DLarrabee	[21062] a	\N	\N
c7c02c49-ead8-4bb5-ad7a-5f805a7447ae	2018-03-01 16:20:08.313966-06	2	[21315] Door 322	[4] DLarrabee	[21062] a	\N	\N
ec6b596f-616c-4112-bdb0-0ad5b10388f6	2018-03-01 16:20:27.485883-06	2	[21316] Door 324A	[4] DLarrabee	[21062] a	\N	\N
93e1f169-f9d3-4816-b563-28dda618ad29	2018-03-01 16:20:44.492584-06	2	[21317] Door 324B	[4] DLarrabee	[21062] a	\N	\N
97c00ab3-7517-4b8d-b0f7-ca844d3a0a95	2018-03-01 16:21:14.605595-06	2	[21318] Door 324C	[4] DLarrabee	[21062] a	\N	\N
8395687e-df77-482c-b76e-c2bcc448d9ad	2018-03-01 16:21:29.196054-06	2	[21319] Door 333	[4] DLarrabee	[21062] a	\N	\N
9277887a-141f-4403-98ed-a0da5d420230	2018-03-01 16:21:45.273661-06	2	[21320] Door 330A	[4] DLarrabee	[21062] a	\N	\N
016fe126-09ce-4194-86f4-4f8aed5eef4a	2018-03-01 16:22:05.970731-06	2	[21321] Door 330B	[4] DLarrabee	[21062] a	\N	\N
3e2928f3-5604-4ff0-b90e-dbb7874ae6e1	2018-03-01 16:22:24.393573-06	2	[21322] Door 378	[4] DLarrabee	[21062] a	\N	\N
4b6b0cb5-6aa0-4d24-baf9-c207f523ccf1	2018-03-01 16:22:37.188852-06	2	[21323] Door 414A	[4] DLarrabee	[21062] a	\N	\N
79a8274a-cc40-4d65-bcb0-35738efe043f	2018-03-01 16:22:55.059639-06	2	[21324] Door 414B	[4] DLarrabee	[21062] a	\N	\N
50ad576d-5a2e-4ea1-b524-26a20a4de640	2018-03-01 16:23:19.039037-06	2	[21325] Door 323OHD	[4] DLarrabee	[21062] a	\N	\N
dcdc96f0-b4e3-4281-b062-b59948dd7a8f	2018-03-01 16:23:50.437176-06	2	[21325] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
fc981c0e-0a36-429d-b2bd-7b095544f6e0	2018-03-01 16:24:20.77921-06	2	[21326] Door 333OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
248c174f-2c5b-4e88-9582-68e93256dc7a	2018-03-01 16:25:13.875519-06	2	[21327] Door 333OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
026c1134-470a-4ab0-8382-43e2f3339457	2018-03-01 16:26:10.211152-06	1	[21328] Door 333OHDE OPEN Copy	[4] DLarrabee	[21062] a	\N	\N
8ab58f12-da87-47a7-99ad-ef91f1d3e205	2018-03-01 16:26:15.329664-06	1	[21329] Door 333OHDE OPEN Copy Copy	[4] DLarrabee	[21062] a	\N	\N
a8ed6bb4-8c68-4de4-8bed-fdfd97182dcc	2018-03-01 16:26:29.602091-06	1	[21330] Door 333OHDE OPEN Copy Copy Copy	[4] DLarrabee	[21062] a	\N	\N
40231e38-8a94-462d-85d4-ae4310df3a60	2018-03-01 16:27:13.871518-06	2	[21328] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
24983116-978f-435c-938c-e8bf2dd53839	2018-03-01 16:28:14.359566-06	2	[21328] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
9e649b15-a28d-4988-8f15-d36549007ac3	2018-03-01 16:29:35.777707-06	2	[21329] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
f19654c8-eb8f-4932-93a5-618e048f3836	2018-03-01 16:29:49.280057-06	2	[21328] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
37784d5f-fe50-4993-9a1e-51d238cf0de3	2018-03-01 16:30:09.967126-06	2	[21330] Door 333OHDW OPEN Copy Copy Copy	[4] DLarrabee	[21062] a	\N	\N
9546f74d-8be0-4382-aed3-eb847909708b	2018-03-01 16:31:11.305259-06	2	[21330] Door 333OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
bfc29d0c-1727-4e4d-acf9-93894d64c8ae	2018-03-01 16:37:25.674692-06	1	[21331] Door 455D Copy	[4] DLarrabee	[21062] a	\N	\N
13932d1d-a21e-404a-a6da-184973cc20c1	2018-03-01 16:38:00.234148-06	2	[21331] Door 429A	[4] DLarrabee	[21062] a	\N	\N
e70208b5-47a3-459c-bd32-445ce8c2ed88	2018-03-01 16:38:38.186942-06	1	[21332] Door 429A (1)	[4] DLarrabee	[21062] a	\N	\N
554c927c-717b-4760-a138-46a68867160a	2018-03-01 16:38:38.212945-06	1	[21333] Door 429A (2)	[4] DLarrabee	[21062] a	\N	\N
09281dac-31f6-49a7-a465-0342d82c53ef	2018-03-01 16:38:38.237948-06	1	[21334] Door 429A (3)	[4] DLarrabee	[21062] a	\N	\N
5518ed58-1bf8-484b-a139-81be0a832fb1	2018-03-01 16:38:38.25995-06	1	[21335] Door 429A (4)	[4] DLarrabee	[21062] a	\N	\N
9c156e1a-dac3-4dec-a7cb-db682f448700	2018-03-01 16:38:38.276951-06	1	[21336] Door 429A (5)	[4] DLarrabee	[21062] a	\N	\N
3b3d25cf-de9f-4caa-83dc-9a56514819e2	2018-03-01 16:39:06.959819-06	2	[21332] Door 429B	[4] DLarrabee	[21062] a	\N	\N
bc714659-0be3-4ab0-ac02-91683215c6db	2018-03-01 16:39:23.202444-06	2	[21333] Door 429C	[4] DLarrabee	[21062] a	\N	\N
9683d347-489b-475b-a30e-ced7aec45794	2018-03-01 16:39:56.113734-06	2	[21334] Door 456	[4] DLarrabee	[21062] a	\N	\N
3f1de1b1-312a-4c58-a128-dcd16dba62d4	2018-03-01 16:40:08.504973-06	2	[21335] Door 461	[4] DLarrabee	[21062] a	\N	\N
adf505fb-164e-498e-89d0-bd81748be5e9	2018-03-01 16:40:37.739897-06	2	[21336] Door 514	[4] DLarrabee	[21062] a	\N	\N
0b0cfe64-11a4-47c4-bdce-c087b9dace10	2018-03-01 16:40:54.609583-06	1	[21337] Door 514 (1)	[4] DLarrabee	[21062] a	\N	\N
d12c1380-a636-471e-8023-abaa2f4cb00a	2018-03-01 16:41:15.627685-06	2	[21337] Door 529	[4] DLarrabee	[21062] a	\N	\N
6d4e22a2-e595-4565-9d86-7ea96376be68	2018-03-01 16:57:21.290242-06	2	[21326] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
fb81268f-e9a7-474d-a08a-96ccaacd8575	2018-03-01 16:58:05.424655-06	2	[21327] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
88e11e99-c82a-492d-8b1e-eabb823ce409	2018-03-01 16:58:24.555567-06	2	[21330] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
c7a09578-cd49-479f-ba4c-8fba03385306	2018-03-01 19:20:55.502638-06	1	[21338] IC 349A-outB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
28f905f6-9669-4d1b-9aa4-6b104f9bed50	2018-03-01 19:22:54.611547-06	1	[21339] IC-351A Call	[21041] OSSI-DNOVAK	[293] master	\N	\N
7b21ac61-997a-4be3-b6f8-f26f16257376	2018-03-01 19:23:10.218108-06	2	[21338] IC 351A	[21041] OSSI-DNOVAK	[293] master	\N	\N
43d1d4c0-99b4-4558-b9d6-a08e4075abfc	2018-03-01 19:23:15.152601-06	3	[21339] IC-351A Call	[21041] OSSI-DNOVAK	[293] master	\N	\N
f1daa1d6-e274-4b26-8723-952d07facb81	2018-03-01 19:24:10.131099-06	1	[21339] IC 351A (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
a23f2a41-39db-45bb-b044-8515e9182bdd	2018-03-01 19:24:10.137099-06	1	[21340] IC 351A (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
ffda726f-47e6-4cc5-87f2-2d3c0bcbbc24	2018-03-01 19:24:10.1461-06	1	[21341] IC 351A (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
5e84eb75-617d-4cf8-85ae-f42fb16ca179	2018-03-01 19:24:10.150101-06	1	[21342] IC 351A (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
221f29a2-5e37-41e9-a166-dc4f6426cf8f	2018-03-01 19:24:10.154101-06	1	[21343] IC 351A (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
7e6f4a05-3cb8-454f-aab3-68157a774cd3	2018-03-01 19:24:10.161102-06	1	[21344] IC 351A (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
ca655307-0278-4722-bf5e-c7bbb210824d	2018-03-01 19:24:10.165102-06	1	[21345] IC 351A (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
ce8bc36b-e014-484a-9561-c6dde43033bb	2018-03-01 19:24:41.715257-06	2	[21339] IC 351A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
fd449819-0793-4021-8c1b-4ddac83fc6ff	2018-03-01 19:24:58.168902-06	2	[21340] IC 351B	[21041] OSSI-DNOVAK	[293] master	\N	\N
77205df9-399f-4660-8678-59c2f41ba62c	2018-03-01 19:25:18.068892-06	2	[21341] IC 351B-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
14a3773e-deb7-43dd-ade5-e416d24837b0	2018-03-01 19:25:34.374522-06	2	[21342] IC 352A	[21041] OSSI-DNOVAK	[293] master	\N	\N
cf469d60-2eac-484b-9e36-592c78411cd7	2018-03-01 19:25:54.130498-06	2	[21343] IC 352A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef39c1db-875c-405e-b8f7-1f0cd6530433	2018-03-01 19:26:12.044289-06	2	[21344] IC 405A	[21041] OSSI-DNOVAK	[293] master	\N	\N
d576341c-fc80-467d-ab56-02bedcb4482a	2018-03-01 19:26:31.679252-06	2	[21345] IC 405A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
57d0592b-236c-476d-8177-4f36618ac6f3	2018-03-01 19:26:45.921676-06	1	[21346] IC 405A-outB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
c42d59b3-2bc0-411c-b32d-d4e03cd9d23c	2018-03-01 19:28:29.841067-06	2	[21346] IC 414A	[21041] OSSI-DNOVAK	[293] master	\N	\N
32da184f-0700-415e-ae64-e88dd2369cc8	2018-03-01 19:29:06.151698-06	1	[21347] IC 414A (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
a551e6ae-fefc-4614-ad3f-592c43acbe90	2018-03-01 19:29:06.159699-06	1	[21348] IC 414A (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
768002d3-0d51-4c01-bf94-3e6e88ef5364	2018-03-01 19:29:06.57374-06	1	[21349] IC 414A (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
c8174131-c579-456c-9dbc-7baf97f20830	2018-03-01 19:29:06.591742-06	1	[21350] IC 414A (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
6158ecf3-e76f-4a9f-9bcd-c50a36bd85ac	2018-03-01 19:29:06.612744-06	1	[21351] IC 414A (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
cb89537a-2e7a-4344-adcc-5865d791a715	2018-03-01 19:29:06.618744-06	1	[21352] IC 414A (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
61127d62-7e77-4391-9374-9ca45ff970be	2018-03-01 19:29:06.624745-06	1	[21353] IC 414A (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
b1896e26-a064-4c26-b064-1fab28b19f33	2018-03-01 19:29:47.671849-06	2	[21347] IC 414A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
95d51762-c01c-403d-88c8-5fb80f19133e	2018-03-01 19:30:10.948177-06	2	[21348] IC 414B	[21041] OSSI-DNOVAK	[293] master	\N	\N
7637607c-1180-497d-ba00-dc07d9efd4f3	2018-03-01 19:30:27.242806-06	2	[21349] IC 414B-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
b72d686c-880e-4fd0-96b7-f0e7ef1e99de	2018-03-01 19:30:43.046386-06	2	[21350] IC 422A	[21041] OSSI-DNOVAK	[293] master	\N	\N
b0d64acb-d3bd-444b-aad6-78cd3959bed0	2018-03-01 19:30:58.251907-06	2	[21351] IC 422A-B	[21041] OSSI-DNOVAK	[293] master	\N	\N
b423675a-3523-4a9d-8afa-e3e2bf170c6f	2018-03-01 19:31:13.705452-06	2	[21352] IC 422B	[21041] OSSI-DNOVAK	[293] master	\N	\N
cf99d02a-d557-4c3b-8983-7d971695acf3	2018-03-01 19:31:31.053186-06	2	[21353] IC 422B-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
8a093177-6c0d-498c-af85-16b659d17e18	2018-03-01 19:32:05.582639-06	2	[21251] IC 316B-in B	[4] DLarrabee	[21062] a	\N	\N
b15f8c14-78d5-438c-82b0-4bb47f04e0c5	2018-03-01 19:32:50.924173-06	1	[21354] IC 422B-outB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
b9203394-b5a7-4358-9a0c-65b3b7c19659	2018-03-01 19:34:03.80446-06	2	[21354] IC 438A	[21041] OSSI-DNOVAK	[293] master	\N	\N
e585ac56-e16b-41c1-bfbf-19f823bb8073	2018-03-01 19:34:32.10929-06	1	[21355] New	[4] DLarrabee	[21062] a	\N	\N
8b5d078a-3666-4a5d-9fdb-fe57beafc310	2018-03-01 19:34:32.392319-06	1	[21356] IC 438A (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
892dd862-3fe1-4437-9b1f-c72ae8a12ae8	2018-03-01 19:34:32.397319-06	1	[21357] IC 438A (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
d31e463b-ae91-4856-84bd-d276fd1f3376	2018-03-01 19:34:32.40232-06	1	[21358] IC 438A (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
a5ba5882-1322-4e2e-9715-e811dab0eb02	2018-03-01 19:34:32.40632-06	1	[21359] IC 438A (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
524d4d98-1cf5-4e70-bb45-14d4d36c3405	2018-03-01 19:34:32.41132-06	1	[21360] IC 438A (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
1040dc2e-f3f5-4f5e-a62b-8d52b199b3ee	2018-03-01 19:34:32.415321-06	1	[21361] IC 438A (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
20df8306-a71a-4a4c-a8d2-d9773a4d11d7	2018-03-01 19:34:32.421321-06	1	[21362] IC 438A (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
82caf214-5e08-4dd8-b422-3e652ecf30ba	2018-03-01 19:35:11.667246-06	2	[21356] IC 438A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
40aff007-531b-4d91-ada4-874ba421bb57	2018-03-01 19:36:19.855064-06	2	[21355] Men RR 101	[4] DLarrabee	[21062] a	\N	\N
3fa36a68-2d2c-43fc-869b-cef92f9431fe	2018-03-01 19:36:48.206899-06	1	[21363] Men RR 101 Copy	[4] DLarrabee	[21062] a	\N	\N
74082d9c-28ad-42ba-b138-3770f912a744	2018-03-01 19:37:17.572835-06	2	[21357] IC 439A	[21041] OSSI-DNOVAK	[293] master	\N	\N
85e2a59c-95bd-483c-91a3-07b08de68b7b	2018-03-01 19:37:33.060384-06	2	[21358] IC 439A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
134b4860-194e-4664-bce4-2833678417ff	2018-03-01 19:37:58.639941-06	2	[21359] IC 443A	[21041] OSSI-DNOVAK	[293] master	\N	\N
2ad0b126-fdfb-4f2c-85b6-a44dae94911c	2018-03-01 19:38:04.593537-06	2	[21363] JAN.room 102	[4] DLarrabee	[21062] a	\N	\N
a9de2fbc-c3ed-4f81-95d7-f1b9c148f3c9	2018-03-01 19:38:17.560833-06	2	[21360] IC 443-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
61c1f3b4-1143-4c6c-a3c5-7170f735ec14	2018-03-01 19:38:31.786256-06	2	[21355] Men RR 101	[4] DLarrabee	[21062] a	\N	\N
1631e209-595d-441d-a8d3-3cd22685c269	2018-03-01 19:38:44.587536-06	2	[21361] IC 443B	[21041] OSSI-DNOVAK	[293] master	\N	\N
05018bb3-faca-43a5-93a7-507855ca0d0a	2018-03-01 19:39:05.185595-06	3	[21362] IC 438A (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
daa32179-fc11-4f9f-8c05-52e0ce289289	2018-03-01 19:39:06.600737-06	1	[21362] JAN.room 102 Copy	[4] DLarrabee	[21062] a	\N	\N
f72f9363-6dd9-43f1-809f-cc8502ad6dd0	2018-03-01 19:40:33.64644-06	2	[21362] Room 103	[4] DLarrabee	[21062] a	\N	\N
5c41351d-8ee8-4732-93f1-de023cd47c24	2018-03-01 19:40:42.54433-06	1	[21364] IC 443B Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
27b61cfc-f567-4a09-818b-599a93085d65	2018-03-01 19:41:03.351411-06	1	[21365] Room 103 Copy	[4] DLarrabee	[21062] a	\N	\N
73b4580d-1a1b-4db9-a673-7aea2ad923e4	2018-03-01 19:41:48.071882-06	2	[21365] Room 104	[4] DLarrabee	[21062] a	\N	\N
fc075762-c025-4a24-bfbe-ade0c718eaf0	2018-03-01 19:41:52.726348-06	1	[21366] Room 104 Copy	[4] DLarrabee	[21062] a	\N	\N
1433d6ce-62bb-4be9-b53d-3372697a9a08	2018-03-01 19:42:10.064081-06	2	[21366] Room 105	[4] DLarrabee	[21062] a	\N	\N
33e6ab1e-32f5-4615-b5e9-e1a82a174bf6	2018-03-01 19:42:42.85936-06	2	[21364] IC 443B	[21041] OSSI-DNOVAK	[293] master	\N	\N
83a22c12-b8bb-4019-9740-b545da815a5a	2018-03-01 19:44:09.653039-06	2	[21364] IC 443B-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
8bb58455-ab74-47db-90c6-05d8674c2c0c	2018-03-01 19:44:35.973671-06	1	[21367] IC 443B-outB (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
8931aae4-9536-4512-a8f5-c7ddeb0774d7	2018-03-01 19:44:36.001673-06	1	[21368] IC 443B-outB (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
189663ad-e381-4eac-a3cb-8f21ae93b970	2018-03-01 19:44:36.010674-06	1	[21369] IC 443B-outB (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
bf74448c-c2d9-42dc-9ef8-9d75a7d0ae9c	2018-03-01 19:44:36.016675-06	1	[21370] IC 443B-outB (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
8cbcc360-6726-49bb-8d0c-5f1b0d499a7b	2018-03-01 19:44:36.026676-06	1	[21371] IC 443B-outB (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
b5401811-a019-4855-9ec0-96cc311f8d6a	2018-03-01 19:44:36.029676-06	1	[21372] IC 443B-outB (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
c0529063-2762-4882-9fdd-413d959bfded	2018-03-01 19:44:36.033677-06	1	[21373] IC 443B-outB (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
6ce71b28-07a1-4b37-b8e9-4f045b11f92d	2018-03-01 19:45:41.504223-06	2	[21367] IC 444A	[21041] OSSI-DNOVAK	[293] master	\N	\N
587f2be5-fdf8-4c27-b263-e0155fc24384	2018-03-01 19:46:05.394612-06	2	[21368] IC 444A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
6e2cc838-cb09-4df1-b0ac-2b3c97d50777	2018-03-01 19:46:22.968369-06	2	[21369] IC 444B	[21041] OSSI-DNOVAK	[293] master	\N	\N
ddd775a1-44a5-4299-bad8-8798923e6110	2018-03-01 19:46:39.760048-06	2	[21370] IC 444B-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
9c608ed2-e2e4-4a52-8fb0-609f7d26faba	2018-03-01 19:46:56.466719-06	2	[21371] IC 447A	[21041] OSSI-DNOVAK	[293] master	\N	\N
5c5a395a-0916-4f48-b969-816738f27d48	2018-03-01 19:47:29.925064-06	2	[21372] IC 447A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
0fffd1b6-1a77-432d-ae92-90b52ba6162a	2018-03-01 19:47:44.995571-06	2	[21373] IC 447B	[21041] OSSI-DNOVAK	[293] master	\N	\N
df588adb-076f-4462-8de8-f81a84dfb799	2018-03-01 19:47:53.501421-06	1	[21374] IC 447B Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
390bf375-4b4e-4a8b-921c-226efd279998	2018-03-01 19:49:27.616832-06	2	[21374] IC 447B-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
d405e23d-62ae-471b-aafc-d85b9b4256d1	2018-03-01 19:49:51.889259-06	1	[21375] IC 447B-outB (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
8cc58a6a-4aaf-4d1c-881a-f26e2b17d7e5	2018-03-01 19:49:51.918262-06	1	[21376] IC 447B-outB (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
2a28c0c2-77ba-4a81-a943-0f6304c2376e	2018-03-01 19:49:51.926263-06	1	[21377] IC 447B-outB (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
88723934-b29c-4088-a67d-46f294b3a469	2018-03-01 19:49:51.930263-06	1	[21378] IC 447B-outB (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
7403b9f4-1d76-4689-831f-6f4794061e49	2018-03-01 19:49:52.422312-06	1	[21379] IC 447B-outB (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
db324dad-c0b2-4ccb-bc69-9358dacce55e	2018-03-01 19:49:52.446315-06	1	[21380] IC 447B-outB (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
771d9a9c-3a31-4c77-8a37-ef74e930b01b	2018-03-01 19:49:52.455316-06	1	[21381] IC 447B-outB (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
b839c221-3cd9-4599-a66a-c2da8fed7745	2018-03-01 19:51:46.168686-06	2	[21375] IC 448A	[21041] OSSI-DNOVAK	[293] master	\N	\N
bb4c885c-cb8f-4646-a5c4-41aed4c21780	2018-03-01 19:52:21.298198-06	2	[21376] IC 448A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
fb17b3bf-bf1f-402c-9b25-54f3440966bd	2018-03-01 19:52:39.584027-06	2	[21377] IC 455A	[21041] OSSI-DNOVAK	[293] master	\N	\N
2f06886f-42d2-4fff-80d4-1419928054c3	2018-03-01 19:52:57.493818-06	2	[21378] IC 455A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
35ca748d-f7e2-4bb0-9571-cd47fb43e605	2018-03-01 19:53:23.543422-06	2	[21379] IC 455B	[21041] OSSI-DNOVAK	[293] master	\N	\N
3aea5e8b-09be-49bf-94a6-79ebca8667f3	2018-03-01 19:53:42.652333-06	2	[21380] IC 455B-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
1b6d6557-8fbf-4022-9c98-573a6a5bc547	2018-03-01 19:54:00.009069-06	2	[21381] IC 455D	[21041] OSSI-DNOVAK	[293] master	\N	\N
e0157ac8-dd34-4163-bc86-78d043ca0e0b	2018-03-01 19:57:38.820948-06	2	[21362] Room 103	[21041] OSSI-DNOVAK	[293] master	\N	\N
b0c9627c-2840-4c5c-8ad3-9c9d1f347e46	2018-03-01 19:58:09.432008-06	2	[21362] Room 103	[21041] OSSI-DNOVAK	[293] master	\N	\N
dfb50167-fd36-4b45-b7c5-86ef7972da4c	2018-03-01 19:58:45.712636-06	2	[21362] Room 103	[21041] OSSI-DNOVAK	[293] master	\N	\N
4e5bd807-cede-4de2-b7fe-e34b31f31bf6	2018-03-01 19:59:03.367401-06	2	[21362] Room 103	[21041] OSSI-DNOVAK	[293] master	\N	\N
8753f13c-2774-433d-8489-30154a69b735	2018-03-01 19:59:17.166781-06	2	[21362] Room 103	[21041] OSSI-DNOVAK	[293] master	\N	\N
33ae73e2-d77b-4ef1-87f6-50568eb81cd8	2018-03-01 20:00:15.993663-06	1	[21382] IC 455D Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
ecf38f26-ffec-4100-822b-a1d505f684a4	2018-03-01 20:00:50.196083-06	2	[21382] IC 455D-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
d099f3a4-5e3a-4dbd-830a-69ae2a5b0691	2018-03-01 20:02:10.521115-06	2	[21382] IC 455D-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
4114d022-f696-4e95-be07-08af932b0a0b	2018-03-01 20:02:22.200283-06	2	[21382] IC 455D-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
c9252053-2577-4607-8cd3-6a8c92d8019c	2018-03-01 20:02:42.858348-06	1	[21383] IC 455D-outB (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
16c16ca5-647b-464b-8206-0f7659f667b5	2018-03-01 20:02:42.894352-06	1	[21384] IC 455D-outB (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
079dfe1e-392d-4007-b5b0-35a26d51b4c0	2018-03-01 20:02:42.899352-06	1	[21385] IC 455D-outB (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
19fa284e-247b-44f6-a912-9e33d3605e1c	2018-03-01 20:02:42.904353-06	1	[21386] IC 455D-outB (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
627e56a6-bdb0-4e13-a43e-e0a2b4ff327d	2018-03-01 20:02:42.908353-06	1	[21387] IC 455D-outB (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
30444768-85ad-438e-bcff-7baeebf40170	2018-03-01 20:02:42.912354-06	1	[21388] IC 455D-outB (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
134feaa8-880d-404f-9562-d178b6aa553c	2018-03-01 20:02:42.917354-06	1	[21389] IC 455D-outB (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
40342f65-231d-4b01-a32b-7102e74b7e06	2018-03-01 20:16:49.850039-06	2	[21296] IC 334A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
2d5d6e5d-5806-4534-a3e3-f37c3b21302f	2018-03-01 20:18:32.383291-06	2	[21383] IC 415	[21041] OSSI-DNOVAK	[293] master	\N	\N
19c2ebe9-0c69-4a62-8511-9eb729f64756	2018-03-01 20:19:28.120864-06	2	[21384] IC 418C	[21041] OSSI-DNOVAK	[293] master	\N	\N
eb6b59cc-2030-4172-98a1-de45655b3a49	2018-03-01 20:20:30.000052-06	2	[21385] IC 425C	[21041] OSSI-DNOVAK	[293] master	\N	\N
96a8d05b-974d-495e-abcf-5af1d1fcf842	2018-03-01 20:22:05.58761-06	2	[21386] IC 446	[21041] OSSI-DNOVAK	[293] master	\N	\N
7eac73b3-a261-4de3-adb0-b7e751e2a8c6	2018-03-01 20:23:00.20107-06	2	[21387] IC 448	[21041] OSSI-DNOVAK	[293] master	\N	\N
f4ecaf7d-3d1e-46da-bdd2-1d23086cd2f6	2018-03-01 20:23:14.883538-06	3	[21388] IC 455D-outB (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
0764115d-4899-429c-a985-367fef06bfd7	2018-03-01 20:23:15.114562-06	2	[21389] IC 455D-outB (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
ab45ab8c-13f1-4155-9878-1d2d530e57be	2018-03-01 20:23:19.723022-06	3	[21389] IC 455D-outB (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
478c94eb-dcac-40eb-8e95-bd48024098ee	2018-03-01 20:25:43.856434-06	2	[21365] Room 104	[4] DLarrabee	[21062] a	\N	\N
3c5b3dcf-2ecf-4c1f-b34a-e593d625748a	2018-03-01 20:25:43.862435-06	2	[21366] Room 105	[4] DLarrabee	[21062] a	\N	\N
3e59fd52-68b9-4b0d-8bb6-e1a22938170c	2018-03-01 20:25:43.870436-06	2	[21363] JAN.room 102	[4] DLarrabee	[21062] a	\N	\N
e81a8475-be1a-47a6-bcce-b314d16ab0ad	2018-03-01 20:25:43.878436-06	2	[21355] Men RR 101	[4] DLarrabee	[21062] a	\N	\N
43172691-408f-418a-aae0-5afe6128b3f3	2018-03-01 20:46:24.257462-06	2	[21055] View IC Control	[21041] OSSI-DNOVAK	[293] master	\N	\N
e301b3d1-622d-4e11-b189-ac2585bf04b9	2018-03-01 20:46:40.922128-06	1	[21388] Room 105 Copy	[4] DLarrabee	[21062] a	\N	\N
d64132ef-3adb-4d53-ab19-edc2343a4467	2018-03-01 20:46:49.800016-06	2	[21055] View IC Control	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef878e5d-5e3c-4ff8-bcfb-3e10f07046c2	2018-03-01 20:47:36.853721-06	3	[21389] Door 105	[4] DLarrabee	[21062] a	\N	\N
5c91e964-af83-4e7e-8574-84b5e20deb84	2018-03-01 20:47:41.433179-06	2	[21055] View IC Control	[21041] OSSI-DNOVAK	[293] master	\N	\N
92a85575-87a8-4c98-a668-f36e039e728a	2018-03-01 20:48:07.931828-06	2	[21388] Room 107	[4] DLarrabee	[21062] a	\N	\N
10924034-7a0f-43ca-af8b-e5c5f6b90e69	2018-03-01 20:48:19.195955-06	1	[21389] Room 107 Copy	[4] DLarrabee	[21062] a	\N	\N
b2684ee4-2446-4455-a5de-1d2c79f2713e	2018-03-01 20:48:33.398375-06	1	[21390] Room 107 Copy Copy	[4] DLarrabee	[21062] a	\N	\N
dcba358b-513b-43f1-a8f5-a3d31c1f9f9d	2018-03-01 20:49:07.063741-06	2	[21389] Room 108	[4] DLarrabee	[21062] a	\N	\N
0e9ef27d-2c01-4ba2-9e9e-ec00f3b28ecb	2018-03-01 20:49:27.447779-06	2	[21390] Room 109	[4] DLarrabee	[21062] a	\N	\N
f40c6393-5a88-41bc-9f2e-43d855df7ccb	2018-03-01 20:49:41.729207-06	1	[21391] Room 109 Copy	[4] DLarrabee	[21062] a	\N	\N
32892dbe-04fa-488f-91a5-f2529ec89b0c	2018-03-01 20:50:19.507985-06	2	[21391] Room 112	[4] DLarrabee	[21062] a	\N	\N
84fa2b90-6a9c-416e-a2f3-a55d17f07c62	2018-03-01 20:50:21.051139-06	1	[21392] IC 448 Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
78d393fe-f4b9-423b-83fc-5292e1bb4f6e	2018-03-01 20:51:17.221755-06	1	[21393] Room 112 Copy	[4] DLarrabee	[21062] a	\N	\N
dd390858-4041-400e-be61-af75faaaf10d	2018-03-01 20:51:29.958029-06	2	[21392] IC 134A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
c1be2e3c-811a-46e4-a0ae-45a77284d58b	2018-03-01 20:51:52.085241-06	2	[21393] Room 113	[4] DLarrabee	[21062] a	\N	\N
2a131808-6c45-4c20-82fc-9e110a8e3cf5	2018-03-01 20:52:08.654898-06	1	[21394] Room 113 Copy	[4] DLarrabee	[21062] a	\N	\N
e4fbb8e8-7a47-4326-ab72-31bfe09b267d	2018-03-01 20:52:14.480481-06	2	[21392] IC 134A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
a585155e-5397-42d0-8d1e-bfedfd51cb28	2018-03-01 20:52:27.07874-06	2	[21394] Room 114	[4] DLarrabee	[21062] a	\N	\N
9e1e880b-e1c8-4fd6-9275-e1c69fe9d97c	2018-03-01 20:52:36.402673-06	1	[21395] IC 134A-outB (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
20e6c8c7-c430-484e-88f2-3cbd625d5032	2018-03-01 20:52:36.418674-06	1	[21396] IC 134A-outB (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
8e5b2213-0851-4d6d-9a82-211880f03d9b	2018-03-01 20:52:36.423675-06	1	[21397] IC 134A-outB (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
ebbad1f3-a272-4d94-bd7d-9da9c7a95288	2018-03-01 20:52:36.427675-06	1	[21398] IC 134A-outB (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
47ad6146-78cd-48f9-8cad-9b1b038cc203	2018-03-01 20:52:36.433676-06	1	[21399] IC 134A-outB (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
4cf73f88-8641-4d83-b58c-590ef6b04834	2018-03-01 20:52:36.438676-06	1	[21400] IC 134A-outB (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
82758090-bf9f-4597-a213-babe66c6ee72	2018-03-01 20:52:36.444677-06	1	[21401] IC 134A-outB (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
02dc9bad-b7f4-4a13-9fdc-060b52f5b023	2018-03-01 20:53:06.092641-06	1	[21402] Room 114 Copy	[4] DLarrabee	[21062] a	\N	\N
633f5fb7-2f15-44a2-8a3f-5ad4d90832f6	2018-03-01 20:53:13.812413-06	2	[21392] IC 134A-inB	[21041] OSSI-DNOVAK	[293] master	\N	\N
81666241-c6e0-4f2b-b2b5-26ca0dd920c8	2018-03-01 20:53:28.88492-06	2	[21395] IC 134A-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
ae5841c7-4aee-4504-a1d3-bc41d486794b	2018-03-01 20:53:40.37707-06	2	[21402] Room 115	[4] DLarrabee	[21062] a	\N	\N
0874d9f9-2004-47b2-9a04-6ef8078ed19b	2018-03-01 20:53:46.310663-06	1	[21403] Room 115 Copy	[4] DLarrabee	[21062] a	\N	\N
4447bc2d-ee22-4041-8340-79d8ba78ecd7	2018-03-01 20:53:51.774209-06	2	[21396] IC 134B-inB	[21041] OSSI-DNOVAK	[293] master	\N	\N
4d7a678a-81fe-4e8d-be52-737b2fb47956	2018-03-01 20:54:15.055537-06	2	[21403] Room 116	[4] DLarrabee	[21062] a	\N	\N
a789d092-17c1-45c7-a1c6-87576e85a43a	2018-03-01 20:54:18.520884-06	2	[21397] IC 134B-outB	[21041] OSSI-DNOVAK	[293] master	\N	\N
84e88de0-e2ec-41c2-a397-3844980b3a72	2018-03-01 20:54:31.28516-06	1	[21404] Room 116 Copy	[4] DLarrabee	[21062] a	\N	\N
f6b7e4f8-696a-4e7c-9f02-72121d417eff	2018-03-01 20:54:50.243055-06	2	[21398] IC 122-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
36505ce1-e616-4a53-ac9d-08b7ef0a247b	2018-03-01 20:55:05.430574-06	2	[21404] Room 117	[4] DLarrabee	[21062] a	\N	\N
fd97960e-f918-4f06-a837-b4d13e855c6f	2018-03-01 20:55:10.110042-06	2	[21399] IC 122-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
04ea714f-dc94-416a-ae9a-f3f3ee6aa805	2018-03-01 20:55:29.966027-06	1	[21405] Room 117 Copy	[4] DLarrabee	[21062] a	\N	\N
0a1ed96d-8c16-41ee-9db2-ad8fca2d9a73	2018-03-01 20:55:42.6923-06	2	[21400] IC 123-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
68a72563-341e-430e-bcf5-2c837c2ba0cb	2018-03-01 20:56:00.076038-06	2	[21401] IC 123B-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
2ac04e15-c063-47f0-99f4-ef5ac1d15192	2018-03-01 20:56:06.343665-06	2	[21405] Room 119	[4] DLarrabee	[21062] a	\N	\N
265bc989-4624-4828-aee9-2302c81dba33	2018-03-01 20:56:07.053736-06	1	[21406] IC 123B-OutB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
afe20a8f-5ed7-493f-8d32-35d970ba6b52	2018-03-01 20:56:11.902221-06	1	[21407] Room 119 Copy	[4] DLarrabee	[21062] a	\N	\N
dc9e25d7-93d2-4331-b565-e395c38047aa	2018-03-01 20:57:13.480378-06	2	[21406] IC 136	[21041] OSSI-DNOVAK	[293] master	\N	\N
55003b8b-f950-4178-ad86-d98f5dd7926a	2018-03-01 20:57:29.771007-06	2	[21407] Room 120	[4] DLarrabee	[21062] a	\N	\N
0b1b5781-7d1e-4d5d-adc6-49b028af687b	2018-03-01 20:57:41.986228-06	1	[21408] IC 136 (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
46f0ba7d-2e53-4937-a929-d56a4def1781	2018-03-01 20:57:41.992229-06	1	[21409] IC 136 (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
34d7e9e8-c235-46c6-b499-11266940a3c0	2018-03-01 20:57:42.000229-06	1	[21410] IC 136 (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
e1cf5d49-7b45-4e54-b8e6-498b983b8b4a	2018-03-01 20:57:42.00523-06	1	[21411] IC 136 (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
deea5c63-eaca-44a0-aac8-4feb6a4d5cda	2018-03-01 20:57:42.011231-06	1	[21412] IC 136 (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
3de81d31-0c18-49ac-976e-96ee787e84d2	2018-03-01 20:57:42.016231-06	1	[21413] IC 136 (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
108b3c67-2a11-4718-96fd-8bd572189dca	2018-03-01 20:57:42.021232-06	1	[21414] IC 136 (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
53772316-79d0-45e0-a6c5-6191f18f1416	2018-03-01 20:57:44.90652-06	1	[21415] Room 120 Copy	[4] DLarrabee	[21062] a	\N	\N
9986f958-51fc-44a2-b132-fd9150281ec3	2018-03-01 20:58:05.495579-06	2	[21408] IC 137	[21041] OSSI-DNOVAK	[293] master	\N	\N
0d9f2abc-9f21-4153-a73d-fe8cac7303c4	2018-03-01 20:58:19.393968-06	2	[21409] IC 138	[21041] OSSI-DNOVAK	[293] master	\N	\N
aaa7b3e7-88ba-4b50-b0dd-39b5800859a3	2018-03-01 20:58:31.940223-06	2	[21410] IC 141	[21041] OSSI-DNOVAK	[293] master	\N	\N
48971e3b-7868-4ebf-af97-94c7ceaf1c94	2018-03-01 20:58:41.761205-06	2	[21411] IC 142	[21041] OSSI-DNOVAK	[293] master	\N	\N
96c14ded-8eb7-4f4d-b142-9e349442af0f	2018-03-01 20:58:44.792508-06	2	[21407] Room 121	[4] DLarrabee	[21062] a	\N	\N
8ccd27bf-ee32-4ade-9869-df9201667ea4	2018-03-01 20:58:55.359565-06	2	[21412] IC 124	[21041] OSSI-DNOVAK	[293] master	\N	\N
95292615-df7e-4bb0-be55-6f6dd2ce7252	2018-03-01 20:59:00.522081-06	2	[21415] Room 122	[4] DLarrabee	[21062] a	\N	\N
dd2df329-8a90-4b5e-8ddd-a199bce43bf2	2018-03-01 20:59:05.529582-06	2	[21413] IC 125	[21041] OSSI-DNOVAK	[293] master	\N	\N
79986d19-f1a8-4b63-bbfb-2c7c335fcf13	2018-03-01 20:59:16.144643-06	2	[21414] IC 126	[21041] OSSI-DNOVAK	[293] master	\N	\N
225dc057-7f55-4e5d-a6da-b93811061671	2018-03-01 20:59:47.048733-06	2	[21415] Room 122	[4] DLarrabee	[21062] a	\N	\N
dd0ea31c-eee0-476f-bc62-ea9029fa4622	2018-03-01 20:59:50.267055-06	1	[21416] Room 122 Copy	[4] DLarrabee	[21062] a	\N	\N
f2f4e5cf-5ea8-4622-9fe9-90a39c16f218	2018-03-01 20:59:59.260954-06	1	[21417] IC 126 Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
27454385-20b9-4316-9365-a74f6ae7bf44	2018-03-01 21:00:16.466675-06	2	[21416] Room 123	[4] DLarrabee	[21062] a	\N	\N
26125c36-8e95-4a47-ae7f-3371cd385cbe	2018-03-01 21:00:26.105638-06	2	[21417] IC 128	[21041] OSSI-DNOVAK	[293] master	\N	\N
1cd1c3f9-01b5-4144-9684-8ae7d35ba946	2018-03-01 21:01:06.006628-06	2	[21417] IC 128	[21041] OSSI-DNOVAK	[293] master	\N	\N
0200211a-27e6-4c72-b901-a37495df7503	2018-03-01 21:01:17.32876-06	1	[21418] Room 123 Copy	[4] DLarrabee	[21062] a	\N	\N
10f4ad31-23eb-4e72-9c75-17e7cf5e126e	2018-03-01 21:01:30.284056-06	1	[21419] Room 123 Copy Copy	[4] DLarrabee	[21062] a	\N	\N
1d1f92fb-2780-4238-ae1c-3306c00cf19b	2018-03-01 21:01:31.42417-06	1	[21420] IC 128 (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
48e10408-84c4-4c29-a274-d0c77ad6e016	2018-03-01 21:01:31.455173-06	1	[21421] IC 128 (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
390f2e0a-8411-454c-b9d3-de457dd59402	2018-03-01 21:01:31.470174-06	1	[21422] IC 128 (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
f547452f-7d98-40ea-9a1e-7e4c8839fa03	2018-03-01 21:01:31.478175-06	1	[21423] IC 128 (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
b882fb0f-fa57-4cbc-b960-3612b8e5e8ba	2018-03-01 21:01:31.482175-06	1	[21424] IC 128 (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
7b572946-1bea-4c05-a859-6c5b43ea6a87	2018-03-01 21:01:31.487176-06	1	[21425] IC 128 (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
5878b2f5-5e70-4ca6-9c92-959f04467f45	2018-03-01 21:01:31.498177-06	1	[21426] IC 128 (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
7e8abfd0-7f2c-4be7-aa54-4e1fca22098f	2018-03-01 21:01:33.995427-06	1	[21427] Room 123 Copy Copy Copy	[4] DLarrabee	[21062] a	\N	\N
ba4e061d-beaf-4c29-a0da-04969e6a4b31	2018-03-01 21:01:39.160943-06	1	[21428] Room 123 Copy Copy Copy Copy	[4] DLarrabee	[21062] a	\N	\N
d4ba799e-da98-4c96-b6a7-2cb954fc3496	2018-03-01 21:01:55.018529-06	2	[21418] Room 124	[4] DLarrabee	[21062] a	\N	\N
db1162de-3f02-44a0-8bef-b7a0894d6013	2018-03-01 21:01:56.394666-06	2	[21420] IC 129	[21041] OSSI-DNOVAK	[293] master	\N	\N
0b07be68-c667-45c6-b7a0-2f2489ccd82d	2018-03-01 21:02:07.283755-06	2	[21421] IC 131	[21041] OSSI-DNOVAK	[293] master	\N	\N
e6c32f1a-172f-432c-a513-e77f12a9975f	2018-03-01 21:02:19.167943-06	2	[21419] Room 125	[4] DLarrabee	[21062] a	\N	\N
8f2b8562-31ad-438b-9fe1-633624a698c1	2018-03-01 21:02:19.176944-06	2	[21422] IC 132	[21041] OSSI-DNOVAK	[293] master	\N	\N
ff016f61-4d2e-499c-862a-4c912161b3b4	2018-03-01 21:02:30.691096-06	2	[21423] IC 115	[21041] OSSI-DNOVAK	[293] master	\N	\N
d285f277-3754-45a0-ad5b-782c439c8d49	2018-03-01 21:02:38.915918-06	2	[21427] Room 126	[4] DLarrabee	[21062] a	\N	\N
201b4701-b2e7-4e75-bed6-a3ce1b15c053	2018-03-01 21:02:41.991226-06	2	[21424] IC 116	[21041] OSSI-DNOVAK	[293] master	\N	\N
b63e16e5-1c83-4f2b-a3ed-4fb75cc91de4	2018-03-01 21:02:51.247151-06	2	[21425] IC 117	[21041] OSSI-DNOVAK	[293] master	\N	\N
7a887dea-0e85-4369-b7d0-8fb9bc530540	2018-03-01 21:03:01.578184-06	2	[21426] IC 119	[21041] OSSI-DNOVAK	[293] master	\N	\N
99f9111f-3629-47e3-b3ac-5ad569f8d95a	2018-03-01 21:03:18.856912-06	1	[21429] IC 119 Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
1783ca28-9b7e-42fa-b6c7-83ec49999c20	2018-03-01 21:03:25.446571-06	2	[21428] Room 128	[4] DLarrabee	[21062] a	\N	\N
2e9d1b4d-971d-4a7e-8446-0fedcc771ffc	2018-03-01 21:03:33.925418-06	1	[21430] Room 128 Copy	[4] DLarrabee	[21062] a	\N	\N
d07ffb54-b9b7-4c3b-97f8-e4a28710c821	2018-03-01 21:03:49.43897-06	2	[21430] Room 129	[4] DLarrabee	[21062] a	\N	\N
cb7e0750-d492-4b6c-9385-9637c16ccf4c	2018-03-01 21:03:56.988725-06	1	[21431] Room 129 Copy	[4] DLarrabee	[21062] a	\N	\N
09d2fcde-d5a5-4abe-aa66-115529887154	2018-03-01 21:04:25.64959-06	2	[21431] Room 131	[4] DLarrabee	[21062] a	\N	\N
9ec1f53b-82f4-46ed-92f2-e83828a4f4ee	2018-03-01 21:04:29.996025-06	1	[21432] Room 131 Copy	[4] DLarrabee	[21062] a	\N	\N
1aaed0ed-7525-4950-8711-f837d5d480ba	2018-03-01 21:04:30.341059-06	2	[21429] IC 121	[21041] OSSI-DNOVAK	[293] master	\N	\N
2750eee4-e3c5-4e8a-8e58-5c7b82a2f99e	2018-03-01 21:04:54.478473-06	2	[21432] Room 132	[4] DLarrabee	[21062] a	\N	\N
7ada7321-0191-402e-be9f-e5207c0c5cb6	2018-03-01 21:05:04.936519-06	1	[21433] IC 121 (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
95522f5f-3759-47a8-b0f6-13f2405e095d	2018-03-01 21:05:04.941519-06	1	[21434] IC 121 (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
8a075d2d-d2b5-4ff4-8bc3-ca2aed4c5c05	2018-03-01 21:05:04.94552-06	1	[21435] IC 121 (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
fbb1e136-be8f-4497-bc49-c907eedfabd4	2018-03-01 21:05:04.95052-06	1	[21436] IC 121 (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
7fc3ae17-7d55-48e9-932b-c3f0cce01dbc	2018-03-01 21:05:04.957521-06	1	[21437] IC 121 (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
a4793549-ccd8-43de-b195-e123c162ec91	2018-03-01 21:05:04.962521-06	1	[21438] IC 121 (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
447a2676-0cab-498b-8461-8b95fea84c31	2018-03-01 21:05:04.966522-06	1	[21439] IC 121 (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
71cce9bd-415a-4caa-a04f-b49dd725e1b6	2018-03-01 21:05:31.781203-06	1	[21440] Room 132 Copy	[4] DLarrabee	[21062] a	\N	\N
75bbcf4e-a521-4c44-ba21-eed413eabf12	2018-03-01 21:05:32.768302-06	2	[21433] IC 114A-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
908251d0-c731-4385-9f78-aeead48db0a5	2018-03-01 21:05:51.694194-06	2	[21434] IC 114A-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
af8c17ed-af74-4ebe-b0d7-1c157f566f53	2018-03-01 21:06:01.110135-06	2	[21440] Room 133	[4] DLarrabee	[21062] a	\N	\N
dfd437af-1b27-4360-af71-633c84914721	2018-03-01 21:06:09.337958-06	2	[21435] IC 114B-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
0adcb46e-6208-4ece-8904-8d5e202b3c27	2018-03-01 21:06:10.435068-06	1	[21441] Room 133 Copy	[4] DLarrabee	[21062] a	\N	\N
290e080a-bb13-4609-a75f-a53d7bd88ed0	2018-03-01 21:06:23.609385-06	2	[21436] IC 114B-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
30524926-ab3d-4890-9f47-b24865641edc	2018-03-01 21:06:24.744499-06	2	[21441] Room 134	[4] DLarrabee	[21062] a	\N	\N
ff593a65-afa9-42f9-8dea-dcb1294e91d8	2018-03-01 21:06:36.517676-06	2	[21437] IC 103	[21041] OSSI-DNOVAK	[293] master	\N	\N
b8553448-113e-4cea-a72c-f7c59179ddec	2018-03-01 21:06:45.716596-06	2	[21438] IC 104	[21041] OSSI-DNOVAK	[293] master	\N	\N
a3f9be00-1443-4e91-ad7b-b8fea60093fa	2018-03-01 21:06:58.125836-06	2	[21439] IC 105	[21041] OSSI-DNOVAK	[293] master	\N	\N
1cce6dd5-430d-47c5-9029-4822e0b25569	2018-03-01 21:07:19.818005-06	1	[21442] Room 134 Copy	[4] DLarrabee	[21062] a	\N	\N
c4bae55b-b005-4386-9245-fffaac0f9c5d	2018-03-01 21:07:28.142838-06	1	[21443] IC 105 Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
900374f7-2a17-4933-9140-f725268e449a	2018-03-01 21:07:34.885512-06	2	[21442] Room 136	[4] DLarrabee	[21062] a	\N	\N
45fc8eb3-7d57-4dc8-85d0-b8a6a05a1616	2018-03-01 21:07:42.584282-06	1	[21444] Room 136 Copy	[4] DLarrabee	[21062] a	\N	\N
6545e3c6-fcf3-4686-83c8-ef6812df12aa	2018-03-01 21:07:57.26775-06	2	[21444] Room 137	[4] DLarrabee	[21062] a	\N	\N
ff2a269d-e1bb-4dbc-9b55-7686599e74c7	2018-03-01 21:08:03.717395-06	1	[21445] Room 137 Copy	[4] DLarrabee	[21062] a	\N	\N
aa08e649-c7b1-4805-a71c-4af3b8be59af	2018-03-01 21:08:14.744498-06	2	[21443] IC 107	[21041] OSSI-DNOVAK	[293] master	\N	\N
74f8f6c9-a4db-402b-9b8e-2ac1370b5804	2018-03-01 21:08:17.550778-06	2	[21445] Room 138	[4] DLarrabee	[21062] a	\N	\N
b000d828-a165-4ab7-9206-8e73f3a1dd52	2018-03-01 21:08:46.924715-06	1	[21446] IC 107 (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
d0d57428-c65e-48f7-8e47-204cb958b25d	2018-03-01 21:08:46.943717-06	1	[21447] IC 107 (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
acde58ec-38bd-499c-9e13-bb0d4bd47471	2018-03-01 21:08:46.950718-06	1	[21448] IC 107 (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
cdaa8326-ad02-4eb1-8358-56924ccd258a	2018-03-01 21:08:46.954718-06	1	[21449] IC 107 (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
c2486d0c-726f-47aa-ac04-ab577bf833c0	2018-03-01 21:08:46.958719-06	1	[21450] IC 107 (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
98b916fb-fa24-493a-9ef8-49658813ce19	2018-03-01 21:08:46.962719-06	1	[21451] IC 107 (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
6947b155-820a-40d2-b99e-cb1365bed037	2018-03-01 21:08:46.96772-06	1	[21452] IC 107 (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
8094ad92-a700-45c0-a94f-f8c7cf8f6695	2018-03-01 21:09:04.521475-06	2	[21446] IC 108	[21041] OSSI-DNOVAK	[293] master	\N	\N
35de6f25-f757-454d-9450-fc392025c062	2018-03-01 21:09:11.731196-06	1	[21453] Room 133 Copy	[4] DLarrabee	[21062] a	\N	\N
e1202f60-e4d4-44b0-88b5-c4bce7d2ad10	2018-03-01 21:09:15.189541-06	2	[21447] IC 109	[21041] OSSI-DNOVAK	[293] master	\N	\N
626aa2a2-d132-4d6f-b227-dda5f7c345ab	2018-03-01 21:09:26.126635-06	2	[21448] IC 112	[21041] OSSI-DNOVAK	[293] master	\N	\N
173c6ec5-3522-47ef-be93-e64d76bce6d7	2018-03-01 21:09:40.311053-06	2	[21453] Room 141	[4] DLarrabee	[21062] a	\N	\N
5e5036fc-b47a-4f01-a49c-525d270dc3b3	2018-03-01 21:09:50.413063-06	2	[21449] IC 113 In-B	[21041] OSSI-DNOVAK	[293] master	\N	\N
456db360-249d-4102-b513-647ea2caa682	2018-03-01 21:09:55.167539-06	1	[21454] Room 133 Copy	[4] DLarrabee	[21062] a	\N	\N
aa33ddf8-6243-4117-a4ef-bc7c8cf559dc	2018-03-01 21:10:07.208743-06	2	[21450] IC 113--OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
a0c19933-e72b-4e26-9738-ccf9180cf72a	2018-03-01 21:10:12.911313-06	2	[21454] Room 142	[4] DLarrabee	[21062] a	\N	\N
6265fc60-13b2-44e2-a462-af343703ed4f	2018-03-01 21:10:23.072329-06	2	[21451] IC 133-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
7a1e2761-df15-4820-be4f-b615d9224558	2018-03-01 21:10:40.401062-06	2	[21452] IC 133-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
0528d559-864d-4071-b16e-2bf9c98a9fcb	2018-03-01 21:11:11.607182-06	1	[21455] IC 133-OutB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
3274262e-34d2-4e2a-9bfd-d455489c9b7d	2018-03-01 21:11:35.729594-06	1	[21456] Room 133 Copy	[4] DLarrabee	[21062] a	\N	\N
32ea121d-d2ca-4b6f-8fa6-530610218664	2018-03-01 21:11:57.201741-06	2	[21456] Room 145	[4] DLarrabee	[21062] a	\N	\N
73c1c71c-6038-44de-8620-717b5d39e41a	2018-03-01 21:12:05.746595-06	2	[21455] IC 145-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
61bf1ca3-2dc3-4e95-9345-e31971f025ba	2018-03-01 21:12:14.430464-06	1	[21457] Room 145 Copy	[4] DLarrabee	[21062] a	\N	\N
d6eda45a-b3a1-4858-86b4-e020a430dcf1	2018-03-01 21:12:40.509071-06	2	[21457] Room 146	[4] DLarrabee	[21062] a	\N	\N
05ce0f0e-750e-48b6-bb30-5101b3e997bd	2018-03-01 21:12:42.827303-06	1	[21458] IC 145-InB (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
3080762d-34e0-4452-a094-bca7e01e2053	2018-03-01 21:12:42.842305-06	1	[21459] IC 145-InB (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
9b189070-fe53-41d3-81ad-1f23b1f22d0f	2018-03-01 21:12:42.849305-06	1	[21460] IC 145-InB (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
0f97addd-4d37-435b-b916-604994e11185	2018-03-01 21:12:42.89931-06	1	[21461] IC 145-InB (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
2847f810-0a1a-4b50-987f-2b80bac18a0f	2018-03-01 21:12:42.907311-06	1	[21462] IC 145-InB (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
3ba88727-7747-4007-b167-05128044d3c9	2018-03-01 21:12:42.915312-06	1	[21463] IC 145-InB (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
762f795d-4df9-48eb-84ec-8b50502759bf	2018-03-01 21:12:42.923313-06	1	[21464] IC 145-InB (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
17536c8c-5c0a-4979-8cca-6e591fffb6f3	2018-03-01 21:13:47.295749-06	2	[21458] IC 145-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
abe505a0-07ee-4699-aaf6-fb5b3d2df134	2018-03-01 21:14:25.869606-06	2	[21459] IC 146-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
6c6da33e-cd2a-4cae-ace4-8352c3dd9c23	2018-03-01 21:14:48.840903-06	2	[21460] IC 146-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
45bc76fb-8e13-4743-943b-2d7174d6d48e	2018-03-01 21:15:09.426962-06	2	[21461] IC 156-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
8d5c5a62-25bd-4cac-8a85-cec180e1b550	2018-03-01 21:15:34.524471-06	2	[21462] IC 156-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
b759af78-0196-4990-a212-739472b2390b	2018-03-01 21:15:48.134832-06	2	[21463] IC 201	[21041] OSSI-DNOVAK	[293] master	\N	\N
1076f12c-138b-4c76-aa18-641a09dcd799	2018-03-01 21:16:03.925411-06	2	[21464] IC 202	[21041] OSSI-DNOVAK	[293] master	\N	\N
d0c64d85-bd9e-438b-8063-de6090314c10	2018-03-01 21:16:30.206039-06	1	[21465] IC 202 Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
8a524e7d-55a1-485f-ad37-2b5c2f9a2550	2018-03-01 21:17:21.793197-06	2	[21465] IC 203	[21041] OSSI-DNOVAK	[293] master	\N	\N
1324cc00-1dbb-4c59-b5dd-6b49d2dc0ac7	2018-03-01 21:17:46.915709-06	1	[21466] IC 203 (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
91421139-50f7-43fa-881e-6f3171ebc3d8	2018-03-01 21:17:46.920709-06	1	[21467] IC 203 (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
d492ccc7-68a9-4808-95a8-937ff3aa46a9	2018-03-01 21:17:46.92671-06	1	[21468] IC 203 (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
bdddeffb-8cdd-44d8-a03f-5b42a0fd1c98	2018-03-01 21:17:46.933711-06	1	[21469] IC 203 (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
19f22653-2cae-45d4-95d5-c4d853f324eb	2018-03-01 21:17:47.594777-06	1	[21470] IC 203 (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
82719b1c-fb3e-43af-87e7-946a9760b714	2018-03-01 21:17:47.598777-06	1	[21471] IC 203 (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
011a8683-5f41-46d6-9030-12a0484b159c	2018-03-01 21:18:13.463363-06	2	[21466] IC 205	[21041] OSSI-DNOVAK	[293] master	\N	\N
b269f492-35bf-4633-a8bc-0eca6d7d67b7	2018-03-01 21:18:37.083725-06	2	[21467] IC 206	[21041] OSSI-DNOVAK	[293] master	\N	\N
854d0e79-ad3d-47cb-9e61-a6c805eae597	2018-03-01 21:18:50.609078-06	2	[21468] IC 207	[21041] OSSI-DNOVAK	[293] master	\N	\N
96e3b9aa-009b-4d28-9dd5-e57d738e224e	2018-03-01 21:19:13.951412-06	2	[21469] IC 209A-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
b42d4c1f-e3cb-4f35-9fd8-9d6780a660f4	2018-03-01 21:19:29.420958-06	2	[21470] IC 209A-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
6ba50531-e9ed-4e38-9221-ad3368e3a43d	2018-03-01 21:19:50.596076-06	2	[21471] IC 209B-inB	[21041] OSSI-DNOVAK	[293] master	\N	\N
e0a0297b-f2b5-4c8d-bf48-6af38b748290	2018-03-01 22:27:55.877563-06	1	[21472] Room 145 Copy	[4] DLarrabee	[21062] a	\N	\N
6aea496d-2663-4366-b7b9-380574ba62c9	2018-03-01 22:32:49.841957-06	3	[21179] Door 145	[4] DLarrabee	[21062] a	\N	\N
64197155-da36-4153-a609-abfb427b448f	2018-03-01 22:32:50.096982-06	2	[21455] IC 145-InB	[4] DLarrabee	[21062] a	\N	\N
83f06978-adec-42c7-83a3-ac8c2d9f79a6	2018-03-01 22:32:50.100982-06	2	[21458] IC 145-OutB	[4] DLarrabee	[21062] a	\N	\N
85f35dcf-b4c9-4c83-9ad3-10499186929b	2018-03-01 22:33:09.805953-06	3	[21458] IC 145-OutB	[4] DLarrabee	[21062] a	\N	\N
f86b0207-4046-4fe2-b935-dc0df997957f	2018-03-01 22:33:10.07798-06	3	[21455] IC 145-InB	[4] DLarrabee	[21062] a	\N	\N
6756d14f-4b42-4d05-a10e-3d98c7916b46	2018-03-01 22:33:27.673739-06	2	[21456] Room 156	[4] DLarrabee	[21062] a	\N	\N
2f465f08-4ff7-4c26-b06a-fbf41985d0b4	2018-03-01 22:34:06.569629-06	2	[21456] Room 156	[4] DLarrabee	[21062] a	\N	\N
f793c838-09ca-4d3e-9053-427c328d8ecb	2018-03-01 22:34:37.660737-06	2	[21472] Room 145	[4] DLarrabee	[21062] a	\N	\N
a51ba921-c9a0-488f-a224-6877c360658f	2018-03-01 22:35:31.198091-06	2	[21473] Door 145	[4] DLarrabee	[21062] a	\N	\N
0ad1e976-986d-43df-9960-aa02deef7bfd	2018-03-01 22:35:44.210392-06	2	[21475] IC 145-OutB	[4] DLarrabee	[21062] a	\N	\N
d3e559cb-ee9c-488f-ad7b-09b1051448ae	2018-03-01 22:36:18.504821-06	2	[21475] IC 145inB	[4] DLarrabee	[21062] a	\N	\N
5fe130c3-d42a-41e7-83a7-e3786fc5e8b1	2018-03-01 22:39:06.61663-06	2	[21473] Door 145	[4] DLarrabee	[21062] a	\N	\N
d2ed3d5e-039d-493d-9b52-ffe9d76ee151	2018-03-01 22:40:56.747642-06	2	[21475] IC 145inB	[4] DLarrabee	[21062] a	\N	\N
8253fd40-1c52-4b32-b5a5-649cbfa83cfa	2018-03-01 22:41:14.832451-06	2	[21474] IC 145-InB	[4] DLarrabee	[21062] a	\N	\N
6b082747-c127-4d1f-bca9-6e3334ea4930	2018-03-02 05:58:44.370203-06	1	[21179] camera_left_lt_grey.png	[4] DLarrabee	[21062] a	\N	\N
dfa85e20-0dfd-4572-9520-a7ca71ff7f91	2018-03-02 05:59:37.14348-06	2	[21179] camera_left_lt_grey.png	[4] DLarrabee	[21062] a	\N	\N
60252b62-2fd0-46f6-874d-e35f172c4b45	2018-03-02 06:00:40.276792-06	1	[21455] New Counter Group	[4] DLarrabee	[21062] a	\N	\N
a7a840a5-e48f-4e0c-bda9-be469193d4b7	2018-03-02 06:00:47.304495-06	1	[21458] New Counter	[4] DLarrabee	[21062] a	\N	\N
123ef0f1-2c46-4420-87f4-d23551a8c3a8	2018-03-02 06:00:47.313496-06	1	[21476] New Counter (1)	[4] DLarrabee	[21062] a	\N	\N
2d422da6-3118-48d3-b84b-fac864cce224	2018-03-02 06:00:47.317496-06	1	[21477] New Counter (2)	[4] DLarrabee	[21062] a	\N	\N
093f8919-e0d8-4a8e-ae3e-fc509846cf43	2018-03-02 06:00:47.322497-06	1	[21478] New Counter (3)	[4] DLarrabee	[21062] a	\N	\N
3a42317e-7830-464c-b351-ac1b73ec89c4	2018-03-02 06:00:47.326497-06	1	[21479] New Counter (4)	[4] DLarrabee	[21062] a	\N	\N
66398cc8-5ac4-4e3d-a7b6-7b20e61c3aec	2018-03-02 06:00:47.329498-06	1	[21480] New Counter (5)	[4] DLarrabee	[21062] a	\N	\N
c359bca9-158f-42f5-a581-43cf5d747f77	2018-03-02 06:01:06.182383-06	2	[21455] Camera Counters	[4] DLarrabee	[21062] a	\N	\N
ea9471d6-45cd-4614-aa3b-ee2e85afcc99	2018-03-02 06:01:39.784743-06	1	[21481] 1	[4] DLarrabee	[21062] a	\N	\N
0176ef64-61ce-4b16-90ed-7c59f67c9d22	2018-03-02 06:01:39.787743-06	1	[21482] 2	[4] DLarrabee	[21062] a	\N	\N
60e3aedb-e948-4e1a-9d29-7bd16a5b6290	2018-03-02 06:01:39.790743-06	1	[21483] 3	[4] DLarrabee	[21062] a	\N	\N
c22fd285-daeb-4d8d-8fd4-42ac6d44c573	2018-03-02 06:01:39.792743-06	1	[21484] 4	[4] DLarrabee	[21062] a	\N	\N
b324ac5e-722e-4252-a52b-7dfbe8928b92	2018-03-02 06:01:39.795744-06	1	[21485] 5	[4] DLarrabee	[21062] a	\N	\N
af6543e2-80d2-403e-8371-4ca7475e7c4a	2018-03-02 06:01:39.798744-06	1	[21486] 6	[4] DLarrabee	[21062] a	\N	\N
10c16fd6-cb26-4d84-8a68-6466bceba62a	2018-03-02 06:01:39.806745-06	1	[21487] 7	[4] DLarrabee	[21062] a	\N	\N
6f9d5d67-c5b0-4628-a77b-c181dc9bf95e	2018-03-02 06:01:39.810745-06	1	[21488] 8	[4] DLarrabee	[21062] a	\N	\N
6fbf888b-1cc6-4dd1-8bf5-85db1c96a1f4	2018-03-02 06:01:39.829747-06	1	[21489] 9	[4] DLarrabee	[21062] a	\N	\N
88e76b56-503c-4d1c-ad88-46f657bf4efd	2018-03-02 06:01:39.834748-06	1	[21490] 10	[4] DLarrabee	[21062] a	\N	\N
a007006d-1476-4fa8-91a0-4293ddc81f38	2018-03-02 06:01:39.839748-06	1	[21491] 11	[4] DLarrabee	[21062] a	\N	\N
e1eee278-7ae0-49eb-a75e-1a4bee3eba78	2018-03-02 06:01:39.844749-06	1	[21492] 12	[4] DLarrabee	[21062] a	\N	\N
fa5e3147-e116-485b-a35f-a73d26e4beaf	2018-03-02 06:01:39.848749-06	1	[21493] 13	[4] DLarrabee	[21062] a	\N	\N
e8a32b1c-e93b-4d7b-82d8-968ec7d64133	2018-03-02 06:01:39.851749-06	1	[21494] 14	[4] DLarrabee	[21062] a	\N	\N
02878cd4-ec03-4456-b72a-d6fd5927255c	2018-03-02 06:01:39.85475-06	1	[21495] 15	[4] DLarrabee	[21062] a	\N	\N
7c0540ec-ea2c-4772-8424-2e2ba57d633a	2018-03-02 06:01:39.85775-06	1	[21496] 16	[4] DLarrabee	[21062] a	\N	\N
bce89d50-7083-4bbb-a292-6dfb03fd679d	2018-03-02 06:01:39.86175-06	1	[21497] 17	[4] DLarrabee	[21062] a	\N	\N
cd0896d0-4f0e-4ac1-a66c-7046156e38f0	2018-03-02 06:01:39.865751-06	1	[21498] 18	[4] DLarrabee	[21062] a	\N	\N
f831da36-577c-42f3-b3d3-5758c23f5c59	2018-03-02 06:01:39.870751-06	1	[21499] 19	[4] DLarrabee	[21062] a	\N	\N
96c047f3-f052-4953-b888-06dc6855185e	2018-03-02 06:01:39.873752-06	1	[21500] 20	[4] DLarrabee	[21062] a	\N	\N
2802d1b5-6de5-4589-a945-9bada73f03ae	2018-03-02 06:01:39.877752-06	1	[21501] 21	[4] DLarrabee	[21062] a	\N	\N
6e752e0a-2822-4b58-a339-ed0c2385f2a2	2018-03-02 06:01:39.881752-06	1	[21502] 22	[4] DLarrabee	[21062] a	\N	\N
45da70e1-d18e-40d8-a111-11fa14835bb5	2018-03-02 06:01:39.884753-06	1	[21503] 23	[4] DLarrabee	[21062] a	\N	\N
2500bb10-e053-41cf-aa11-c548e1dea17a	2018-03-02 06:01:39.894754-06	1	[21504] 24	[4] DLarrabee	[21062] a	\N	\N
ac5085f5-29a6-40e5-85d0-58b9965283ee	2018-03-02 06:01:39.897754-06	1	[21505] 25	[4] DLarrabee	[21062] a	\N	\N
1321f434-cf4b-4811-b943-6329711b20d5	2018-03-02 06:01:49.715736-06	1	[21506] 1	[4] DLarrabee	[21062] a	\N	\N
99b61474-ddca-4dbd-9a7d-901eaa78be01	2018-03-02 06:01:49.721736-06	1	[21507] 2	[4] DLarrabee	[21062] a	\N	\N
a7fdc32c-5017-442f-bf95-0cf61ad6b3ef	2018-03-02 06:01:49.727737-06	1	[21508] 3	[4] DLarrabee	[21062] a	\N	\N
ee35098f-cc12-466c-918e-7810e25a6720	2018-03-02 06:01:49.730737-06	1	[21509] 4	[4] DLarrabee	[21062] a	\N	\N
fe117b45-4925-4e6e-897f-7058bac91808	2018-03-02 06:01:49.734738-06	1	[21510] 5	[4] DLarrabee	[21062] a	\N	\N
b5fd4de5-df93-47bb-a276-76f21a7be99f	2018-03-02 06:01:49.737738-06	1	[21511] 6	[4] DLarrabee	[21062] a	\N	\N
6dc51c3c-5202-42f9-a063-3abd0e0c7363	2018-03-02 06:01:49.743738-06	1	[21512] 7	[4] DLarrabee	[21062] a	\N	\N
7597f1fc-d02c-4534-9865-47299d17d2b5	2018-03-02 06:01:49.747739-06	1	[21513] 8	[4] DLarrabee	[21062] a	\N	\N
63db2136-37bf-4b5a-a35a-ec53908770ee	2018-03-02 06:01:49.751739-06	1	[21514] 9	[4] DLarrabee	[21062] a	\N	\N
41133f44-48ab-4c74-bdee-313c21d88447	2018-03-02 06:01:49.75474-06	1	[21515] 10	[4] DLarrabee	[21062] a	\N	\N
85556418-1759-45fe-a1a9-fcf6dbe957a0	2018-03-02 06:01:49.75974-06	1	[21516] 11	[4] DLarrabee	[21062] a	\N	\N
be980af6-145a-4856-9e36-4ba2763fce45	2018-03-02 06:01:49.76274-06	1	[21517] 12	[4] DLarrabee	[21062] a	\N	\N
60ea3e72-2113-4b79-a8f1-902889da3b21	2018-03-02 06:01:49.765741-06	1	[21518] 13	[4] DLarrabee	[21062] a	\N	\N
3030702b-d6b7-43d8-bbb6-5f4cc58135d2	2018-03-02 06:01:49.769741-06	1	[21519] 14	[4] DLarrabee	[21062] a	\N	\N
1e8ef72e-3154-4a3d-bd26-5313f7aa9953	2018-03-02 06:01:49.773741-06	1	[21520] 15	[4] DLarrabee	[21062] a	\N	\N
033660a7-f0a3-4f47-9a78-63ebb95554a6	2018-03-02 06:01:49.777742-06	1	[21521] 16	[4] DLarrabee	[21062] a	\N	\N
10f8f14b-41d7-48b2-b175-51ac333df329	2018-03-02 06:01:49.782742-06	1	[21522] 17	[4] DLarrabee	[21062] a	\N	\N
a25e5d7d-a725-4109-ae81-090aae9349e5	2018-03-02 06:01:49.785743-06	1	[21523] 18	[4] DLarrabee	[21062] a	\N	\N
9c250dbb-a69c-4e52-ae67-e5f53b3342e3	2018-03-02 06:01:49.788743-06	1	[21524] 19	[4] DLarrabee	[21062] a	\N	\N
3dc61694-3571-4710-8967-f1e8c168db6e	2018-03-02 06:01:49.791743-06	1	[21525] 20	[4] DLarrabee	[21062] a	\N	\N
012aee88-e730-47aa-b4ae-0ab601f4152f	2018-03-02 06:01:49.795744-06	1	[21526] 21	[4] DLarrabee	[21062] a	\N	\N
e18dba21-c8c0-43a3-9610-d228c286e994	2018-03-02 06:01:49.798744-06	1	[21527] 22	[4] DLarrabee	[21062] a	\N	\N
1f57ebbf-8ee4-4cea-a256-11cfdb1d5db1	2018-03-02 06:01:49.801744-06	1	[21528] 23	[4] DLarrabee	[21062] a	\N	\N
32d22e1d-2d08-4c93-83f5-9418cee2e4d1	2018-03-02 06:01:49.805745-06	1	[21529] 24	[4] DLarrabee	[21062] a	\N	\N
6a1b08b4-fd06-4f91-a430-f331342460ad	2018-03-02 06:01:49.810745-06	1	[21530] 25	[4] DLarrabee	[21062] a	\N	\N
08c3da04-878a-48ab-a539-13ef45e2f67a	2018-03-02 06:01:49.816746-06	1	[21531] 26	[4] DLarrabee	[21062] a	\N	\N
23f88a9f-a506-46ad-bcb5-4a4994247240	2018-03-02 06:01:49.820746-06	1	[21532] 27	[4] DLarrabee	[21062] a	\N	\N
88868640-5ead-4801-986d-db1eafaf8fb8	2018-03-02 06:01:49.823746-06	1	[21533] 28	[4] DLarrabee	[21062] a	\N	\N
27d60891-5bfc-4e3d-a4ee-e06900d7844e	2018-03-02 06:01:49.827747-06	1	[21534] 29	[4] DLarrabee	[21062] a	\N	\N
eef926af-b38f-4f95-9d48-f8a97db91a11	2018-03-02 06:01:49.830747-06	1	[21535] 30	[4] DLarrabee	[21062] a	\N	\N
a738b568-c251-4f9e-be84-a823e4861200	2018-03-02 06:02:01.531917-06	1	[21536] 1	[4] DLarrabee	[21062] a	\N	\N
641fb6a3-50d0-404c-a00d-3ab844a38bc3	2018-03-02 06:02:01.56492-06	1	[21537] 2	[4] DLarrabee	[21062] a	\N	\N
e2120d57-5453-4f6b-bee7-68d6372b92ea	2018-03-02 06:02:01.567921-06	1	[21538] 3	[4] DLarrabee	[21062] a	\N	\N
7d7ba1e0-cd22-40c4-b172-8a4e2544c330	2018-03-02 06:02:01.570921-06	1	[21539] 4	[4] DLarrabee	[21062] a	\N	\N
f710398c-c78e-480d-9e63-242d325886e4	2018-03-02 06:02:01.573921-06	1	[21540] 5	[4] DLarrabee	[21062] a	\N	\N
3799f5d8-ecb3-41e1-bbcf-05faec97af72	2018-03-02 06:02:01.576922-06	1	[21541] 6	[4] DLarrabee	[21062] a	\N	\N
96dfc6bc-9b87-4a88-a293-10735128ceb0	2018-03-02 06:02:01.584922-06	1	[21542] 7	[4] DLarrabee	[21062] a	\N	\N
a1955b28-291f-41c0-b712-c4429e95d87c	2018-03-02 06:02:01.586923-06	1	[21543] 8	[4] DLarrabee	[21062] a	\N	\N
5331e043-5371-457f-8419-6cb7b3c3ac01	2018-03-02 06:02:01.589923-06	1	[21544] 9	[4] DLarrabee	[21062] a	\N	\N
26a7e4f6-3438-4cae-a772-4d4efbcd937c	2018-03-02 06:02:01.592923-06	1	[21545] 10	[4] DLarrabee	[21062] a	\N	\N
9b038e79-bcec-415b-bf29-8d19ffb9abf6	2018-03-02 06:02:01.595924-06	1	[21546] 11	[4] DLarrabee	[21062] a	\N	\N
b5d30fad-c90d-4beb-bd88-2c1c00414b8f	2018-03-02 06:02:01.597924-06	1	[21547] 12	[4] DLarrabee	[21062] a	\N	\N
79c84589-62e1-4329-9258-3bffb85592f5	2018-03-02 06:02:01.600924-06	1	[21548] 13	[4] DLarrabee	[21062] a	\N	\N
74222172-b9f3-43ac-a52b-73a020ff9408	2018-03-02 06:02:01.603924-06	1	[21549] 14	[4] DLarrabee	[21062] a	\N	\N
62f1962f-517d-4307-b99b-5752e08da24f	2018-03-02 06:02:01.606925-06	1	[21550] 15	[4] DLarrabee	[21062] a	\N	\N
494feccf-58ca-42c0-961b-468f0c2009e9	2018-03-02 06:02:01.609925-06	1	[21551] 16	[4] DLarrabee	[21062] a	\N	\N
cffc9a8a-2dd3-470c-875a-5366ffa1c328	2018-03-02 06:02:01.612925-06	1	[21552] 17	[4] DLarrabee	[21062] a	\N	\N
c04c7911-8dbf-4b38-bbb1-655862f0ef3c	2018-03-02 06:02:01.616926-06	1	[21553] 18	[4] DLarrabee	[21062] a	\N	\N
a5b02c49-365f-432f-9244-e8a1c41f6f00	2018-03-02 06:02:01.620926-06	1	[21554] 19	[4] DLarrabee	[21062] a	\N	\N
54de0e0c-9186-45b6-8624-8e0859d19bbc	2018-03-02 06:02:01.625927-06	1	[21555] 20	[4] DLarrabee	[21062] a	\N	\N
ea3e972a-ebaa-4bc9-b978-751ab03ac632	2018-03-02 06:02:01.629927-06	1	[21556] 21	[4] DLarrabee	[21062] a	\N	\N
8420a30c-4ee8-4006-bcbf-f718db4e7948	2018-03-02 06:02:01.632927-06	1	[21557] 22	[4] DLarrabee	[21062] a	\N	\N
b3cda5d7-d83c-4764-9bda-1aa6f2f8a43e	2018-03-02 06:02:01.636928-06	1	[21558] 23	[4] DLarrabee	[21062] a	\N	\N
1fdf14e1-80d1-452e-b397-6c07a7edcbd0	2018-03-02 06:02:01.639928-06	1	[21559] 24	[4] DLarrabee	[21062] a	\N	\N
bd872027-68a1-4c61-8f67-aa640ae971da	2018-03-02 06:02:01.644928-06	1	[21560] 25	[4] DLarrabee	[21062] a	\N	\N
0d41b550-13f6-411a-94ec-446eb3dc5074	2018-03-02 06:02:01.648929-06	1	[21561] 26	[4] DLarrabee	[21062] a	\N	\N
3d5f281a-af2c-4d76-93ad-062d8ef786de	2018-03-02 06:02:01.650929-06	1	[21562] 27	[4] DLarrabee	[21062] a	\N	\N
b32d8c2c-92bf-4213-b955-1cefe1469fbc	2018-03-02 06:02:01.654929-06	1	[21563] 28	[4] DLarrabee	[21062] a	\N	\N
ac237f5e-dab5-49c3-b4e0-710ae36d7f3b	2018-03-02 06:02:01.65793-06	1	[21564] 29	[4] DLarrabee	[21062] a	\N	\N
6d824f81-52ea-4551-b43c-5a7886485c87	2018-03-02 06:02:01.66093-06	1	[21565] 30	[4] DLarrabee	[21062] a	\N	\N
3c95c8a6-d5e4-482d-9e0a-f4b4bf1ab6c6	2018-03-02 06:02:01.66493-06	1	[21566] 31	[4] DLarrabee	[21062] a	\N	\N
36519181-634b-4dff-abe7-ae9ea7cbfafb	2018-03-02 06:02:25.280292-06	1	[21567] 1	[4] DLarrabee	[21062] a	\N	\N
df5bb480-cf2b-4c79-a8d2-53f5d158e1f8	2018-03-02 06:02:25.305294-06	1	[21568] 2	[4] DLarrabee	[21062] a	\N	\N
ed5db987-f178-4d4b-8454-a132a83a1fa6	2018-03-02 06:02:25.308295-06	1	[21569] 3	[4] DLarrabee	[21062] a	\N	\N
513207ac-353d-43ad-b6cc-a59218b20ab5	2018-03-02 06:02:25.315295-06	1	[21570] 4	[4] DLarrabee	[21062] a	\N	\N
f8b7b76a-98b7-40be-a535-30dcfa72c9fd	2018-03-02 06:02:25.317295-06	1	[21571] 5	[4] DLarrabee	[21062] a	\N	\N
9e1d3a24-36e0-4615-9dc3-ccba80e0acae	2018-03-02 06:02:25.320296-06	1	[21572] 6	[4] DLarrabee	[21062] a	\N	\N
d7b702de-a4e9-4831-8e76-d1c8ea173193	2018-03-02 06:02:25.322296-06	1	[21573] 7	[4] DLarrabee	[21062] a	\N	\N
7751bb1c-50e8-445e-a718-346644c82edc	2018-03-02 06:02:25.325296-06	1	[21574] 8	[4] DLarrabee	[21062] a	\N	\N
8a720b27-2707-4ae8-b64a-ee59cd2be240	2018-03-02 06:02:25.327296-06	1	[21575] 9	[4] DLarrabee	[21062] a	\N	\N
479dc1a1-7f56-4d18-889d-1edf7f4048db	2018-03-02 06:02:25.329297-06	1	[21576] 10	[4] DLarrabee	[21062] a	\N	\N
24536396-d689-4397-8217-43b4ba980370	2018-03-02 06:02:25.332297-06	1	[21577] 11	[4] DLarrabee	[21062] a	\N	\N
d8824dfd-67ed-415f-a08c-605e4e2592b8	2018-03-02 06:02:25.334297-06	1	[21578] 12	[4] DLarrabee	[21062] a	\N	\N
5a017a7c-fff6-429e-ad63-018a9afb3be7	2018-03-02 06:02:25.337297-06	1	[21579] 13	[4] DLarrabee	[21062] a	\N	\N
62234389-2664-40e5-806f-ac53c2f5e0af	2018-03-02 06:02:25.340298-06	1	[21580] 14	[4] DLarrabee	[21062] a	\N	\N
3c122946-e9b0-4859-9687-3b9092968933	2018-03-02 06:02:25.343298-06	1	[21581] 15	[4] DLarrabee	[21062] a	\N	\N
7a9fe8b5-f8b9-47b1-a7ef-0f114eabe6ef	2018-03-02 06:02:25.347298-06	1	[21582] 16	[4] DLarrabee	[21062] a	\N	\N
838f315a-41aa-440e-a186-76d91e912eea	2018-03-02 06:02:25.350299-06	1	[21583] 17	[4] DLarrabee	[21062] a	\N	\N
fd8963d1-d6ed-45b3-a3e9-7083544c9cb8	2018-03-02 06:02:25.354299-06	1	[21584] 18	[4] DLarrabee	[21062] a	\N	\N
e1d87c29-8ed8-419b-b420-5402ee5cfaf2	2018-03-02 06:02:25.357299-06	1	[21585] 19	[4] DLarrabee	[21062] a	\N	\N
a8085e2c-b65f-4341-b5f5-70e2d802e147	2018-03-02 06:02:25.3613-06	1	[21586] 20	[4] DLarrabee	[21062] a	\N	\N
f97089a8-aba1-4ce6-94d4-23bca472bea9	2018-03-02 06:02:25.3653-06	1	[21587] 21	[4] DLarrabee	[21062] a	\N	\N
383ff033-cf50-411b-aba6-6ea80eb878eb	2018-03-02 06:02:25.369301-06	1	[21588] 22	[4] DLarrabee	[21062] a	\N	\N
a5a80a83-3e4d-4aae-aa46-44f6ce25c6f1	2018-03-02 06:02:25.373301-06	1	[21589] 23	[4] DLarrabee	[21062] a	\N	\N
92b6f7ad-a931-49a1-becb-43d554e748f5	2018-03-02 06:02:25.376301-06	1	[21590] 24	[4] DLarrabee	[21062] a	\N	\N
b984833f-0b5d-4c17-9003-149a6a0606a6	2018-03-02 06:02:25.379302-06	1	[21591] 25	[4] DLarrabee	[21062] a	\N	\N
6b3c6711-3a77-48ba-90e6-4f843d83980b	2018-03-02 06:02:25.383302-06	1	[21592] 26	[4] DLarrabee	[21062] a	\N	\N
168ed077-9d4a-4a7f-a5af-60c39c090586	2018-03-02 06:02:25.387302-06	1	[21593] 27	[4] DLarrabee	[21062] a	\N	\N
c7ef35be-2d12-4ca3-ae0f-6c9629bf5f46	2018-03-02 06:02:25.391303-06	1	[21594] 28	[4] DLarrabee	[21062] a	\N	\N
bce385a0-38b2-4d97-8564-256e21782795	2018-03-02 06:02:46.001364-06	1	[21595] 1	[4] DLarrabee	[21062] a	\N	\N
5b55727c-5ea3-40df-b199-c47de6ad786f	2018-03-02 06:02:46.007364-06	1	[21596] 2	[4] DLarrabee	[21062] a	\N	\N
013d7fac-3a11-4063-a7da-9358b3717604	2018-03-02 06:02:46.014365-06	1	[21597] 3	[4] DLarrabee	[21062] a	\N	\N
dd09bce5-5f1d-4365-a1f2-b6f651dd602b	2018-03-02 06:02:46.017365-06	1	[21598] 4	[4] DLarrabee	[21062] a	\N	\N
93a9a42e-e986-4c57-a737-2b8049ac57c2	2018-03-02 06:02:46.021366-06	1	[21599] 5	[4] DLarrabee	[21062] a	\N	\N
a04d26b2-8026-41e9-a8df-f70fef3d451e	2018-03-02 06:02:46.024366-06	1	[21600] 6	[4] DLarrabee	[21062] a	\N	\N
a0e3664d-3bb2-4a3b-a782-610210d54a2e	2018-03-02 06:02:46.027366-06	1	[21601] 7	[4] DLarrabee	[21062] a	\N	\N
7b3dc662-c105-46a1-bf29-bf8cd9dd5f79	2018-03-02 06:02:46.031367-06	1	[21602] 8	[4] DLarrabee	[21062] a	\N	\N
86a5325a-0130-4356-919a-0a70963c32bb	2018-03-02 06:02:46.034367-06	1	[21603] 9	[4] DLarrabee	[21062] a	\N	\N
d8b3a201-71de-445f-b659-f837807148c4	2018-03-02 06:02:46.038367-06	1	[21604] 10	[4] DLarrabee	[21062] a	\N	\N
ada3747a-59a2-40be-9685-a3e617acc9c8	2018-03-02 06:02:46.041368-06	1	[21605] 11	[4] DLarrabee	[21062] a	\N	\N
e9cd5ecc-dd6c-4fc5-b6ea-c768e088d81b	2018-03-02 06:02:46.044368-06	1	[21606] 12	[4] DLarrabee	[21062] a	\N	\N
b3dfcd86-aed1-40c4-8cff-00edfa72879b	2018-03-02 06:02:46.047368-06	1	[21607] 13	[4] DLarrabee	[21062] a	\N	\N
fd8977f1-adb4-42a0-86c5-9a08e6f53665	2018-03-02 06:02:46.051369-06	1	[21608] 14	[4] DLarrabee	[21062] a	\N	\N
19a3753d-04d6-4bfe-b751-48937fc11fe1	2018-03-02 06:02:46.054369-06	1	[21609] 15	[4] DLarrabee	[21062] a	\N	\N
da13a0b6-52bd-444e-bdeb-b3f9162c53be	2018-03-02 06:02:46.057369-06	1	[21610] 16	[4] DLarrabee	[21062] a	\N	\N
b7e7360b-e581-4419-8b2a-6a7f3ff95338	2018-03-02 06:02:46.06037-06	1	[21611] 17	[4] DLarrabee	[21062] a	\N	\N
417b2d44-117d-454b-86e1-9c6707b430ef	2018-03-02 06:02:46.06237-06	1	[21612] 18	[4] DLarrabee	[21062] a	\N	\N
cdf2aedd-0531-4c9b-acae-0bba83d7491d	2018-03-02 06:02:46.06537-06	1	[21613] 19	[4] DLarrabee	[21062] a	\N	\N
6afa918c-e691-4ef5-b6be-930ae09cd05f	2018-03-02 06:02:46.06837-06	1	[21614] 20	[4] DLarrabee	[21062] a	\N	\N
94b4cf62-eec8-48f9-baac-7c76262871c9	2018-03-02 06:02:46.072371-06	1	[21615] 21	[4] DLarrabee	[21062] a	\N	\N
e525e1db-983c-4266-bf4c-d9fd5778ccee	2018-03-02 06:02:46.076371-06	1	[21616] 22	[4] DLarrabee	[21062] a	\N	\N
acd8bf5f-7c35-4473-ba0c-ba7c9fdc79b1	2018-03-02 06:02:46.079371-06	1	[21617] 23	[4] DLarrabee	[21062] a	\N	\N
4dac2723-8ee1-4f75-8942-ab52c2bf068c	2018-03-02 06:02:46.082372-06	1	[21618] 24	[4] DLarrabee	[21062] a	\N	\N
7eb695da-8abd-458b-b76b-6ad794ed62dd	2018-03-02 06:02:46.085372-06	1	[21619] 25	[4] DLarrabee	[21062] a	\N	\N
a9be3a70-a5cb-4881-9d50-6a596d4d2e10	2018-03-02 06:02:46.088372-06	1	[21620] 26	[4] DLarrabee	[21062] a	\N	\N
9ef569f2-a01e-43e3-aa1e-d44f0dbdf590	2018-03-02 06:02:46.093373-06	1	[21621] 27	[4] DLarrabee	[21062] a	\N	\N
537f8243-d031-4165-a6e0-3356828ac873	2018-03-02 06:02:46.095373-06	1	[21622] 28	[4] DLarrabee	[21062] a	\N	\N
29789546-066c-47bf-a138-a14f452dec0a	2018-03-02 06:02:46.099373-06	1	[21623] 29	[4] DLarrabee	[21062] a	\N	\N
7264a15f-53ac-417f-87b5-2fce50ac4ad6	2018-03-02 06:02:46.102374-06	1	[21624] 30	[4] DLarrabee	[21062] a	\N	\N
e2d92108-9852-4755-8259-e48d13a3246f	2018-03-02 06:02:46.105374-06	1	[21625] 31	[4] DLarrabee	[21062] a	\N	\N
e758a1a9-c5c9-42dd-b5ce-9aa9cfa416da	2018-03-02 06:02:46.109374-06	1	[21626] 32	[4] DLarrabee	[21062] a	\N	\N
019067f1-f723-4a15-b96c-d6bac783414e	2018-03-02 06:02:46.112375-06	1	[21627] 33	[4] DLarrabee	[21062] a	\N	\N
533d6481-577c-4a22-962f-3d2c76fb90fa	2018-03-02 06:02:46.116375-06	1	[21628] 34	[4] DLarrabee	[21062] a	\N	\N
7da9b76d-fb31-427f-a5cc-e10d6a44bfdc	2018-03-02 06:02:46.119375-06	1	[21629] 35	[4] DLarrabee	[21062] a	\N	\N
73e11238-0aac-4eb8-82f4-22750b29c7a7	2018-03-02 06:02:46.123376-06	1	[21630] 36	[4] DLarrabee	[21062] a	\N	\N
08eaf717-dba3-45df-9281-c7f72423430c	2018-03-02 06:02:46.126376-06	1	[21631] 37	[4] DLarrabee	[21062] a	\N	\N
1ac11212-6d76-4695-b86a-5fad168cfb25	2018-03-02 06:02:46.130377-06	1	[21632] 38	[4] DLarrabee	[21062] a	\N	\N
efb7efe0-89f4-44c4-96ef-6db7c5c679b5	2018-03-02 06:02:46.134377-06	1	[21633] 39	[4] DLarrabee	[21062] a	\N	\N
651555b1-855e-40bc-a8cf-8fb58a5bf187	2018-03-02 06:02:46.138377-06	1	[21634] 40	[4] DLarrabee	[21062] a	\N	\N
99ff612e-f995-4485-aad8-06ce80c09d57	2018-03-02 06:02:46.140378-06	1	[21635] 41	[4] DLarrabee	[21062] a	\N	\N
1d1f9c2f-7a9a-4131-8cc7-683ff5b4ba24	2018-03-02 06:02:46.144378-06	1	[21636] 42	[4] DLarrabee	[21062] a	\N	\N
59a3a06d-4fc0-441e-8868-f5159c550dd0	2018-03-02 06:02:46.147378-06	1	[21637] 43	[4] DLarrabee	[21062] a	\N	\N
e7961c6f-46b3-461c-b872-1f94edf9dcf0	2018-03-02 06:02:46.151379-06	1	[21638] 44	[4] DLarrabee	[21062] a	\N	\N
7f48dcde-a4d8-4d6a-b1a6-05ea6cc69636	2018-03-02 06:02:46.154379-06	1	[21639] 45	[4] DLarrabee	[21062] a	\N	\N
48098ed8-365d-4872-987b-979116c4680f	2018-03-02 06:02:46.157379-06	1	[21640] 46	[4] DLarrabee	[21062] a	\N	\N
31bccd41-46d9-4130-8ae5-a438f504d6c8	2018-03-02 06:02:46.16238-06	1	[21641] 47	[4] DLarrabee	[21062] a	\N	\N
d59a7560-62ba-45d8-adb3-acab42292fb9	2018-03-02 06:02:46.16638-06	1	[21642] 48	[4] DLarrabee	[21062] a	\N	\N
c54b2b0f-8a0a-4f5e-9612-150df02e8b57	2018-03-02 06:02:46.16938-06	1	[21643] 49	[4] DLarrabee	[21062] a	\N	\N
e15c3f7a-2788-4ba7-af0b-e27f458a1f92	2018-03-02 06:02:46.173381-06	1	[21644] 50	[4] DLarrabee	[21062] a	\N	\N
114637ce-43a6-48c2-a27f-5b02574ce4c3	2018-03-02 06:02:46.176381-06	1	[21645] 51	[4] DLarrabee	[21062] a	\N	\N
166c57cf-fb7c-4e5b-ae33-517f0513c38c	2018-03-02 06:02:46.180382-06	1	[21646] 52	[4] DLarrabee	[21062] a	\N	\N
a1926d77-d2b1-4ac6-bf6f-f6bcc2d3a04c	2018-03-02 06:02:46.183382-06	1	[21647] 53	[4] DLarrabee	[21062] a	\N	\N
1822bb8d-e726-4aab-a104-bd6af07da771	2018-03-02 06:02:46.187382-06	1	[21648] 54	[4] DLarrabee	[21062] a	\N	\N
7da55ee9-0eb9-4e70-bb8d-0a2c89f404d9	2018-03-02 06:02:46.190383-06	1	[21649] 55	[4] DLarrabee	[21062] a	\N	\N
f874674d-67f0-4f8a-af5e-1f4ff5b03d21	2018-03-02 06:02:46.194383-06	1	[21650] 56	[4] DLarrabee	[21062] a	\N	\N
9886eb2c-5cc9-4e6a-958f-9990e20fc62b	2018-03-02 06:02:46.199383-06	1	[21651] 57	[4] DLarrabee	[21062] a	\N	\N
9b4ae717-ad78-49f6-9a86-398008ff3429	2018-03-02 06:02:46.203384-06	1	[21652] 58	[4] DLarrabee	[21062] a	\N	\N
86087cce-81d2-452d-8db4-0a49cb964252	2018-03-02 06:02:46.210385-06	1	[21653] 59	[4] DLarrabee	[21062] a	\N	\N
77bffa69-995c-4968-bc6b-8e53214eb2dc	2018-03-02 06:02:46.215385-06	1	[21654] 60	[4] DLarrabee	[21062] a	\N	\N
c4f3a9bd-d721-4858-9cbf-49a5dfc92296	2018-03-02 06:02:58.27059-06	1	[21655] 1	[4] DLarrabee	[21062] a	\N	\N
380c444a-74f8-4587-bb15-29c59c1047f3	2018-03-02 06:02:58.288592-06	1	[21656] 2	[4] DLarrabee	[21062] a	\N	\N
2a964c67-84f8-4689-bd31-75ae9f1fd37a	2018-03-02 06:02:58.292593-06	1	[21657] 3	[4] DLarrabee	[21062] a	\N	\N
b813a274-088b-477d-b80c-c922c621e57a	2018-03-02 06:02:58.295593-06	1	[21658] 4	[4] DLarrabee	[21062] a	\N	\N
f747cace-7e5c-4e59-8332-e8c210e39339	2018-03-02 06:02:58.299593-06	1	[21659] 5	[4] DLarrabee	[21062] a	\N	\N
911303bc-9f02-4fa6-8aa7-9a8ffa970a4f	2018-03-02 06:02:58.303594-06	1	[21660] 6	[4] DLarrabee	[21062] a	\N	\N
3d50d840-e468-423d-ad0f-efb87b01ea3d	2018-03-02 06:02:58.306594-06	1	[21661] 7	[4] DLarrabee	[21062] a	\N	\N
6dd061c2-4649-4275-bd1e-40ab07584953	2018-03-02 06:02:58.309594-06	1	[21662] 8	[4] DLarrabee	[21062] a	\N	\N
cccd192b-63af-43fb-ad5c-b9337b28117b	2018-03-02 06:02:58.314595-06	1	[21663] 9	[4] DLarrabee	[21062] a	\N	\N
fa3b1259-3a8c-4e41-b6cd-fdda5911fd01	2018-03-02 06:02:58.317595-06	1	[21664] 10	[4] DLarrabee	[21062] a	\N	\N
e09ba5ae-4d0b-4a71-bf5f-1dee87a12f56	2018-03-02 06:02:58.321596-06	1	[21665] 11	[4] DLarrabee	[21062] a	\N	\N
89684353-7a9e-46fc-877e-95d8f9f18131	2018-03-02 06:02:58.324596-06	1	[21666] 12	[4] DLarrabee	[21062] a	\N	\N
de54bbd5-11dc-4072-82b4-dcc67b167cc1	2018-03-02 06:02:58.328596-06	1	[21667] 13	[4] DLarrabee	[21062] a	\N	\N
f5029ef2-7ae9-49bd-aa0c-8c62c1988698	2018-03-02 06:02:58.331597-06	1	[21668] 14	[4] DLarrabee	[21062] a	\N	\N
f3544734-f7a0-40ab-8059-4fbdb949ac27	2018-03-02 06:02:58.335597-06	1	[21669] 15	[4] DLarrabee	[21062] a	\N	\N
2fef9686-ff32-417e-beaf-6d653e33d192	2018-03-02 06:02:58.338597-06	1	[21670] 16	[4] DLarrabee	[21062] a	\N	\N
6c20634e-3eb9-4fca-9a5a-83fcd125fe5b	2018-03-02 06:02:58.342598-06	1	[21671] 17	[4] DLarrabee	[21062] a	\N	\N
19afc565-53c4-4e9b-b94e-90c0b4edd97d	2018-03-02 06:02:58.345598-06	1	[21672] 18	[4] DLarrabee	[21062] a	\N	\N
e032a44c-e73a-4ccb-a88f-55cd70922606	2018-03-02 06:02:58.349598-06	1	[21673] 19	[4] DLarrabee	[21062] a	\N	\N
b4eef8cc-bd26-4727-96a7-b66af15f72b9	2018-03-02 06:02:58.353599-06	1	[21674] 20	[4] DLarrabee	[21062] a	\N	\N
146cb2bc-a97f-49a7-bae2-068b76ac0abd	2018-03-02 06:02:58.357599-06	1	[21675] 21	[4] DLarrabee	[21062] a	\N	\N
a15f17d9-3928-4db4-b764-f68a4f7ce776	2018-03-02 06:03:14.880251-06	2	[21458] OC Cameras	[4] DLarrabee	[21062] a	\N	\N
132da5f7-9f3b-4c95-a02a-3db6ad510331	2018-03-02 06:03:14.886252-06	2	[21481] OC 1 AREA A COURTYARD 	[4] DLarrabee	[21062] a	\N	\N
999d79fd-9b54-49cb-8717-541943181cce	2018-03-02 06:03:14.895253-06	2	[21482] OC 2 AREA A COURTYARD 	[4] DLarrabee	[21062] a	\N	\N
9af5a61d-ef15-4f25-860b-29bc8887d3ba	2018-03-02 06:03:14.899253-06	2	[21483] OC 3 AREA B COURTYARD 	[4] DLarrabee	[21062] a	\N	\N
66f97616-d270-439e-b2d0-6550276f56e6	2018-03-02 06:03:14.904254-06	2	[21484] OC 4 AREA B COURTYARD 	[4] DLarrabee	[21062] a	\N	\N
dfe821f4-b934-496e-884e-e8a4ab7a75fc	2018-03-02 06:03:14.909254-06	2	[21485] OC 5 AREA C DOCK 	[4] DLarrabee	[21062] a	\N	\N
f8e2e3db-2e67-4c85-b5d9-9e49e467c09b	2018-03-02 06:03:14.912254-06	2	[21486] OC 6 AREA E ENTRY 	[4] DLarrabee	[21062] a	\N	\N
1399ab56-573c-4ce1-95da-1c623ecd5e8b	2018-03-02 06:03:14.916255-06	2	[21487] OC 7 AREA E ENTRY 	[4] DLarrabee	[21062] a	\N	\N
a9fc4d56-9eaa-4a66-8a72-94fc993135e5	2018-03-02 06:03:14.921255-06	2	[21488] OC 8 SOUTH SITE 	[4] DLarrabee	[21062] a	\N	\N
710b7110-f743-46cd-8c6f-a812b7725da3	2018-03-02 06:03:14.924256-06	2	[21489] OC 9 WEST SITE 	[4] DLarrabee	[21062] a	\N	\N
918af28e-6d02-4cc3-aa80-f52545181c6d	2018-03-02 06:03:14.927256-06	2	[21490] OC 10 WEST SITE	[4] DLarrabee	[21062] a	\N	\N
77776cb3-b49f-4a38-b6ba-ddea4f8919d8	2018-03-02 06:03:14.931256-06	2	[21491] OC 11 NORTH SITE 	[4] DLarrabee	[21062] a	\N	\N
9ce73d3a-0d29-49af-8226-8de579a2b7e6	2018-03-02 06:03:14.935257-06	2	[21492] OC 12 NORTH SITE	[4] DLarrabee	[21062] a	\N	\N
d56da046-460d-4757-b079-f96cafe194d2	2018-03-02 06:03:14.938257-06	2	[21493] OC 13 EAST SITE 	[4] DLarrabee	[21062] a	\N	\N
c539d9a9-fb5a-42c9-8a91-e4bd958d8faf	2018-03-02 06:03:14.941257-06	2	[21494] OC 14 EAST SITE 	[4] DLarrabee	[21062] a	\N	\N
03bbbf76-5488-480e-9e49-5c3cf9f9f0c0	2018-03-02 06:03:14.944258-06	2	[21495] OC 15 EAST SITE	[4] DLarrabee	[21062] a	\N	\N
841ae821-89ae-4bd2-a532-94164c13af36	2018-03-02 06:03:14.948258-06	2	[21496] OC 16 WEST SITE 	[4] DLarrabee	[21062] a	\N	\N
d86ca36f-57de-481b-9ddf-777a330fc875	2018-03-02 06:03:14.952258-06	2	[21497] OC 17 WEST SITE 	[4] DLarrabee	[21062] a	\N	\N
745b7ddc-8c94-4221-b677-a1fe77cc483f	2018-03-02 06:03:14.957259-06	2	[21498] OC 18 WEST SITE 	[4] DLarrabee	[21062] a	\N	\N
98e5a37d-c43f-4900-a40e-073be765d704	2018-03-02 06:03:14.960259-06	2	[21499] OC 19 SOUTH SITE 	[4] DLarrabee	[21062] a	\N	\N
087bb794-7f61-4511-af65-d474e720171c	2018-03-02 06:03:14.96426-06	2	[21500] OC 20 EAST SITE	[4] DLarrabee	[21062] a	\N	\N
657f1a9b-1507-4031-a3e3-7a674ae94e88	2018-03-02 06:03:14.96826-06	2	[21501] OC 21 ENTRY CANOPY	[4] DLarrabee	[21062] a	\N	\N
4ab471ef-4fbf-47db-bf79-e1aa9b6fd964	2018-03-02 06:03:14.97226-06	2	[21502] OC 22 SOUTH SITE	[4] DLarrabee	[21062] a	\N	\N
61ce7eb4-87e4-48b4-9046-2e4af8f5399f	2018-03-02 06:03:14.976261-06	2	[21503] OC 23 EAST SITE	[4] DLarrabee	[21062] a	\N	\N
5a6885b8-73e7-413f-81a8-ab260c3b6aa4	2018-03-02 06:03:14.980261-06	2	[21504] OC 24 SOUTH SITE	[4] DLarrabee	[21062] a	\N	\N
1eb682af-5aff-4ffb-8bf6-789c20365d7a	2018-03-02 06:03:14.985262-06	2	[21505] None	[4] DLarrabee	[21062] a	\N	\N
e636422d-0f5c-4d37-95e1-57ca2eecd329	2018-03-02 06:03:14.988262-06	2	[21476] A Cameras	[4] DLarrabee	[21062] a	\N	\N
f91b9031-8287-49f3-9a99-ebaf29ed1343	2018-03-02 06:03:14.992262-06	2	[21506] A 1 MULTI-USE DINING 122 	[4] DLarrabee	[21062] a	\N	\N
ff0819c4-905c-47bc-9657-b597459f14f8	2018-03-02 06:03:14.996263-06	2	[21507] A 2 MULTI-USE DINING 122	[4] DLarrabee	[21062] a	\N	\N
5c962ab3-499c-461d-8862-1a2fecc12271	2018-03-02 06:03:14.999263-06	2	[21508] A 3 MULTI-USE DINING 123	[4] DLarrabee	[21062] a	\N	\N
05b1aeef-f5b2-49b6-98dd-ed8e27703f28	2018-03-02 06:03:15.003264-06	2	[21509] A 4 MULTI-USE DINING 123	[4] DLarrabee	[21062] a	\N	\N
0605ac7e-fce6-45be-9008-b81883be8d79	2018-03-02 06:03:15.007264-06	2	[21510] A 5 LIVING ROOM 113	[4] DLarrabee	[21062] a	\N	\N
b4cc88b4-340d-41c4-b1cb-10400d1e812d	2018-03-02 06:03:15.010264-06	2	[21511] A 6 LIVING ROOM 113 	[4] DLarrabee	[21062] a	\N	\N
6c41d6f8-3afa-48c1-bc96-23f8c286cf79	2018-03-02 06:03:15.013265-06	2	[21512] A 7 LIVING ROOM 113 	[4] DLarrabee	[21062] a	\N	\N
a77caa4b-fe0a-49de-9759-3a1e0243c584	2018-03-02 06:03:15.017265-06	2	[21513] A 8 LIVING ROOM 113	[4] DLarrabee	[21062] a	\N	\N
6f95af3e-f1d9-4edc-bcce-82e916f55dff	2018-03-02 06:03:15.020265-06	2	[21514] A 9 COURTYARD 114	[4] DLarrabee	[21062] a	\N	\N
95db3da0-8c2c-4886-8af6-91264f950d0e	2018-03-02 06:03:15.023266-06	2	[21515] A 10 LIVING ROOM 133	[4] DLarrabee	[21062] a	\N	\N
b853839c-c3ad-41fd-ae0f-66502afb2a6d	2018-03-02 06:03:15.026266-06	2	[21516] A 11 LIVING ROOM 133	[4] DLarrabee	[21062] a	\N	\N
e895b09e-8a90-4605-ac45-a8a5d41208c6	2018-03-02 06:03:15.030266-06	2	[21517] A 12 LIVING ROOM 133 	[4] DLarrabee	[21062] a	\N	\N
b97622d9-1740-4e25-b267-ee39ff54e0cc	2018-03-02 06:03:15.032266-06	2	[21518] A 13 LIVING ROOM 133 	[4] DLarrabee	[21062] a	\N	\N
25f16eb6-78d3-46ab-a155-0578ad05542d	2018-03-02 06:03:15.036267-06	2	[21519] A 14 COURTYARD 134 	[4] DLarrabee	[21062] a	\N	\N
e34c36b4-6cff-4078-8ac6-74efa32700c8	2018-03-02 06:03:15.040267-06	2	[21520] A 15 COURTYARD 156	[4] DLarrabee	[21062] a	\N	\N
8b2d044e-685b-465a-a697-2dcac6f5789b	2018-03-02 06:03:15.043268-06	2	[21521] A 16 COURTYARD 156	[4] DLarrabee	[21062] a	\N	\N
885835ec-85fd-4451-a438-833800daec50	2018-03-02 06:03:15.046268-06	2	[21522] A 17 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
46447351-25b3-4bd4-a271-40552585c946	2018-03-02 06:03:15.050268-06	2	[21523] A 18 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
ab356223-75a4-42f0-b788-36341c3088c3	2018-03-02 06:03:15.053269-06	2	[21524] A 19 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
8f8e435d-f985-48b3-bc58-f673492c843e	2018-03-02 06:03:15.056269-06	2	[21525] A20 HALL 127	[4] DLarrabee	[21062] a	\N	\N
e9f50f28-c76f-4f29-9a1a-8f55bdc8c48c	2018-03-02 06:03:15.059269-06	2	[21526] A21 SINGLE SLEEPING 137	[4] DLarrabee	[21062] a	\N	\N
7cfae54d-0ba6-4e61-bb99-3d6a3410b74a	2018-03-02 06:03:15.06427-06	2	[21527] A22 HALL 139	[4] DLarrabee	[21062] a	\N	\N
5f80b7c1-cbe7-45e6-a206-a06cb4fc65dd	2018-03-02 06:03:15.06827-06	2	[21528] A23 ADA SLEEPING 125	[4] DLarrabee	[21062] a	\N	\N
8383e61d-1fde-4209-92c1-df440d5cd4e7	2018-03-02 06:03:15.07227-06	2	[21529] A24 ADA SLEEPING 119	[4] DLarrabee	[21062] a	\N	\N
3607bc4c-833f-4b78-aa9b-76801377dc70	2018-03-02 06:03:15.076271-06	2	[21530] A25 HALL 118	[4] DLarrabee	[21062] a	\N	\N
622e80a0-ef50-4c99-aca6-0394ae34809b	2018-03-02 06:03:15.079271-06	2	[21531] A26 HALL 106	[4] DLarrabee	[21062] a	\N	\N
cb53bed0-723b-4665-bfab-ba0c8907439f	2018-03-02 06:03:15.100273-06	2	[21532] A27 SINGLE SLEEPING 103	[4] DLarrabee	[21062] a	\N	\N
6d2f3b60-dd8b-4a02-9f48-7ab3b3a95012	2018-03-02 06:03:15.104274-06	2	[21533] A28 CALMING ROOM 146	[4] DLarrabee	[21062] a	\N	\N
5841a7d7-f1b6-4ab9-9513-25a30de10020	2018-03-02 06:03:15.108274-06	2	[21534] A29 CALMING ROOM 145	[4] DLarrabee	[21062] a	\N	\N
1a8fdf25-ef88-417a-aa46-2075866dc782	2018-03-02 06:03:15.111274-06	2	[21535] None	[4] DLarrabee	[21062] a	\N	\N
fe091aa8-9339-45bf-920d-783fa0962dd6	2018-03-02 06:03:15.115275-06	2	[21477] B Cameras	[4] DLarrabee	[21062] a	\N	\N
6c2a1763-85ec-45c0-bcfc-9f9a431f1a9e	2018-03-02 06:03:15.119275-06	2	[21536] B 1 LIVING ROOM 211	[4] DLarrabee	[21062] a	\N	\N
265783c0-d6a2-4186-b7ea-d5e40d6c91a4	2018-03-02 06:03:15.122275-06	2	[21537] B 2 LIVING ROOM 211	[4] DLarrabee	[21062] a	\N	\N
98fce556-604d-4aec-a6b7-bdb18642b73e	2018-03-02 06:03:15.126276-06	2	[21538] B 3 LIVING ROOM 211 	[4] DLarrabee	[21062] a	\N	\N
6dffc469-5f46-4ec6-9a80-e80e0b6850a1	2018-03-02 06:03:15.129276-06	2	[21539] B 4 LIVING ROOM 211 	[4] DLarrabee	[21062] a	\N	\N
d6c18b1f-397f-472d-8668-afe3e18d1f16	2018-03-02 06:03:15.133277-06	2	[21540] B 5 COURTYARD 209	[4] DLarrabee	[21062] a	\N	\N
481dd70e-5745-4edc-a600-62852e65cec1	2018-03-02 06:03:15.137277-06	2	[21541] B 6 DINING 223 	[4] DLarrabee	[21062] a	\N	\N
5496e65e-488c-4e83-a616-0b2991a0c88a	2018-03-02 06:03:15.140277-06	2	[21542] B 7 DINING 223	[4] DLarrabee	[21062] a	\N	\N
694696ac-38ca-488d-ad06-3e9eb5ff2a10	2018-03-02 06:03:15.143278-06	2	[21543] B 8 LIVING ROOM 236	[4] DLarrabee	[21062] a	\N	\N
1af9c1c0-d5fa-48ea-b504-ec740ae53862	2018-03-02 06:03:15.145278-06	2	[21544] B 9 LIVING ROOM 236	[4] DLarrabee	[21062] a	\N	\N
57d066fa-4f2f-42bf-9b6f-26482afb70d6	2018-03-02 06:03:15.149278-06	2	[21545] B 10 LIVING ROOM 236 	[4] DLarrabee	[21062] a	\N	\N
03292c24-f624-4cb6-8cd8-6f97b907b5bc	2018-03-02 06:03:15.153279-06	2	[21546] B 11 LIVING ROOM 236 	[4] DLarrabee	[21062] a	\N	\N
4ed18444-9e86-4a77-915c-b32a8b8eda26	2018-03-02 06:03:15.157279-06	2	[21547] B 12 COURTYARD 237 	[4] DLarrabee	[21062] a	\N	\N
51eced3b-ef43-48d9-9dc7-4ad60ee9cb65	2018-03-02 06:03:15.160279-06	2	[21548] B 13 DINING 224	[4] DLarrabee	[21062] a	\N	\N
5bddb567-d813-451a-9311-5a388d5305ce	2018-03-02 06:03:15.16328-06	2	[21549] B 14 DINING 224 	[4] DLarrabee	[21062] a	\N	\N
1dcd05a4-65a9-492b-a626-019eb18b5582	2018-03-02 06:03:15.16728-06	2	[21550] B 15 COURTYARD 261	[4] DLarrabee	[21062] a	\N	\N
9256d32b-ebfc-4905-b186-5646c9571989	2018-03-02 06:03:15.17128-06	2	[21551] B 16 COURTYARD 261 	[4] DLarrabee	[21062] a	\N	\N
476aeefb-0ac7-47c3-9ac7-cd0129dd5466	2018-03-02 06:03:15.176281-06	2	[21552] B 17 RESEARCH/READING 206 	[4] DLarrabee	[21062] a	\N	\N
22964ed9-2cb2-41c9-9228-756387800499	2018-03-02 06:03:15.180281-06	2	[21553] B 18 CORRIDOR 259	[4] DLarrabee	[21062] a	\N	\N
fa56fe08-10b3-47a1-be1d-fd3accf6111f	2018-03-02 06:03:15.183282-06	2	[21554] B 19 CORRIDOR 259 	[4] DLarrabee	[21062] a	\N	\N
15cca3e9-df77-421c-a664-b1f4b3d7129a	2018-03-02 06:03:15.186282-06	2	[21555] B 20 CORRIDOR 259 	[4] DLarrabee	[21062] a	\N	\N
d2611bcf-bc33-47e7-ba9b-73016b9acb20	2018-03-02 06:03:15.189282-06	2	[21556] B21 HALL 217	[4] DLarrabee	[21062] a	\N	\N
a8abd221-e3a6-4c0c-b2a6-11438e1b8461	2018-03-02 06:03:15.194283-06	2	[21557] B22 SINGLE SLEEPING 222	[4] DLarrabee	[21062] a	\N	\N
2b91b818-b25f-4122-bdb2-3ec576b26d3c	2018-03-02 06:03:15.198283-06	2	[21558] B23 SINGLE SLEEPING 225	[4] DLarrabee	[21062] a	\N	\N
4e7707f8-b436-4d0c-9721-41e102ffed7a	2018-03-02 06:03:15.201283-06	2	[21559] B24 HALL 229	[4] DLarrabee	[21062] a	\N	\N
234ee178-e7e0-4126-9946-a6beb601f462	2018-03-02 06:03:15.204284-06	2	[21560] B25 CALMING ROOM 252	[4] DLarrabee	[21062] a	\N	\N
cf002b35-3388-4d8d-ab35-a43108bef69a	2018-03-02 06:03:15.208284-06	2	[21561] B26 CALMING ROOM 253	[4] DLarrabee	[21062] a	\N	\N
818e18cd-b45b-4c0e-87a5-2ac83c12f01c	2018-03-02 06:03:15.211284-06	2	[21562] B27 ADA SLEEPING ROOM 201	[4] DLarrabee	[21062] a	\N	\N
fb1d69b4-5659-4bc1-8549-b6a88f3ea2e4	2018-03-02 06:03:15.214285-06	2	[21563] B28 SUICIDE WATCH 246	[4] DLarrabee	[21062] a	\N	\N
14eea085-d5a9-441f-88f5-215fbe132531	2018-03-02 06:03:15.219285-06	2	[21564] B29 ADA SINGLE SLEEPING 246	[4] DLarrabee	[21062] a	\N	\N
722aa679-d99c-4691-b260-baf65d07f965	2018-03-02 06:03:15.223286-06	2	[21565] B30 HALL 204	[4] DLarrabee	[21062] a	\N	\N
a1b8aac7-fd20-44a8-8775-c75da2e00e31	2018-03-02 06:03:15.226286-06	2	[21566] None	[4] DLarrabee	[21062] a	\N	\N
da401d1b-503d-4194-b670-693cf3fa15e9	2018-03-02 06:03:15.229286-06	2	[21478] C Cameras	[4] DLarrabee	[21062] a	\N	\N
48b17d44-fc0c-456d-b93f-f392c123126e	2018-03-02 06:03:15.233287-06	2	[21567] C 1 VEHICLE SALLY PORT 324	[4] DLarrabee	[21062] a	\N	\N
1e1db3f1-c491-4608-ab7f-b9bec403e1fe	2018-03-02 06:03:15.237287-06	2	[21568] C 2 VEHICLE SALLY PORT 324	[4] DLarrabee	[21062] a	\N	\N
7625185d-13e0-4cfe-89fb-021ca6db20c6	2018-03-02 06:03:15.241287-06	2	[21569] C 3 INTAKE 	[4] DLarrabee	[21062] a	\N	\N
9b9be665-4f6c-40a5-a4b8-ed803ac93004	2018-03-02 06:03:15.245288-06	2	[21570] C 4 INTAKE	[4] DLarrabee	[21062] a	\N	\N
dc92b4af-c3b8-40a4-bdf5-47162271cc1f	2018-03-02 06:03:15.249288-06	2	[21571] C 5 INTAKE 	[4] DLarrabee	[21062] a	\N	\N
8a8eb20c-67d8-4a81-a13e-224ed6193338	2018-03-02 06:03:15.252288-06	2	[21572] C 6 INTAKE	[4] DLarrabee	[21062] a	\N	\N
be6f07ee-b5cf-42c1-acac-cc981c0df003	2018-03-02 06:03:15.256289-06	2	[21573] C 7 GROUP MALE 	[4] DLarrabee	[21062] a	\N	\N
d9b71ba2-7a8c-4ba4-804e-cb2a17349c52	2018-03-02 06:03:15.260289-06	2	[21574] C 8 GROUP FEMALE	[4] DLarrabee	[21062] a	\N	\N
50d7dd54-b106-4ac1-9515-28f9cadd0723	2018-03-02 06:03:15.26429-06	2	[21575] C 9 INTAKE SINGLE 343	[4] DLarrabee	[21062] a	\N	\N
7e55bba4-8531-4cd0-b48c-a00465b688fe	2018-03-02 06:03:15.26929-06	2	[21576] C 10 INTAKE SINGLE 346	[4] DLarrabee	[21062] a	\N	\N
ce598ed4-1b36-49ce-a1f9-5d2c9ad706b3	2018-03-02 06:03:15.274291-06	2	[21577] C 11 YOUTH SHOWER 347 	[4] DLarrabee	[21062] a	\N	\N
0abb64d3-387c-4619-b5ad-2ec255297ac1	2018-03-02 06:03:15.278291-06	2	[21578] C 12 YOUTH SHOWER 348 	[4] DLarrabee	[21062] a	\N	\N
af0bde61-79be-43d1-a62c-e11a3705971d	2018-03-02 06:03:15.282291-06	2	[21579] C 13 HALL 326	[4] DLarrabee	[21062] a	\N	\N
5907a7e4-227d-4b54-a587-915d3edaa073	2018-03-02 06:03:15.287292-06	2	[21580] C 14 HALL 326 	[4] DLarrabee	[21062] a	\N	\N
200029a5-a1e4-428d-8a78-8b45b535e77e	2018-03-02 06:03:15.291292-06	2	[21581] C 15 CORRIDOR 327 	[4] DLarrabee	[21062] a	\N	\N
47864ed0-7ea8-4ed6-b504-44d170094823	2018-03-02 06:03:15.294293-06	2	[21582] C 16 CORRIDOR 327 	[4] DLarrabee	[21062] a	\N	\N
3d31366f-5d72-4b9d-ba4a-66400b3e936b	2018-03-02 06:03:15.298293-06	2	[21583] C 17 CORRIDOR 308	[4] DLarrabee	[21062] a	\N	\N
bb4a46e1-5b09-42aa-9259-068f509999bb	2018-03-02 06:03:15.302293-06	2	[21584] C 18 CORRIDOR 308	[4] DLarrabee	[21062] a	\N	\N
4fc0471c-6247-4f27-99ea-063d68dc5e8c	2018-03-02 06:03:15.306294-06	2	[21585] C 19 CORRIDOR 308 	[4] DLarrabee	[21062] a	\N	\N
494890d8-32ac-45dd-bffc-9206bf126db3	2018-03-02 06:03:15.309294-06	2	[21586] C 20 CORRIDOR 308	[4] DLarrabee	[21062] a	\N	\N
a02108fb-a5f6-46f3-8602-d2f76bfc7867	2018-03-02 06:03:15.313295-06	2	[21587] C 21 CORRIDOR 352 	[4] DLarrabee	[21062] a	\N	\N
3172f9c6-0402-498a-92f4-ceefe0e8ceb0	2018-03-02 06:03:15.317295-06	2	[21588] C 22 CORRIDOR 352	[4] DLarrabee	[21062] a	\N	\N
32bccb8d-8f6c-4eac-abc8-1bb0a657af8f	2018-03-02 06:03:15.321295-06	2	[21589] C 23 HALL 378 	[4] DLarrabee	[21062] a	\N	\N
e3f214e8-f3a1-492d-a709-0d2eda5c4395	2018-03-02 06:03:15.325296-06	2	[21590] C 24 HALL 378	[4] DLarrabee	[21062] a	\N	\N
03cce5df-292f-43e5-9543-d26b399f4dc5	2018-03-02 06:03:15.331296-06	2	[21591] C 25 HALL 378 	[4] DLarrabee	[21062] a	\N	\N
f420e3a6-eb7e-4efd-b72b-0eeba8117ea1	2018-03-02 06:03:15.336297-06	2	[21592] C 26 CORRIDOR 317 	[4] DLarrabee	[21062] a	\N	\N
eaf260d2-5097-4959-9394-bab955b50936	2018-03-02 06:03:15.340297-06	2	[21593] C 27 CORRIDOR 317 	[4] DLarrabee	[21062] a	\N	\N
1b671bc9-3c12-4b0a-a154-5e532fc77a40	2018-03-02 06:03:15.344298-06	2	[21594] None	[4] DLarrabee	[21062] a	\N	\N
1a217cf5-0c64-4f64-8bb7-86d3dd73ecfa	2018-03-02 06:03:15.351298-06	2	[21479] D Cameras	[4] DLarrabee	[21062] a	\N	\N
ceaf29d3-f527-4852-9831-433c9c350b87	2018-03-02 06:03:15.356299-06	2	[21595] D 1 CORRIDOR 437 	[4] DLarrabee	[21062] a	\N	\N
189f3ec3-c53b-45a4-86c6-1a1a6038fed6	2018-03-02 06:03:15.360299-06	2	[21596] D 2 CORRIDOR 437 	[4] DLarrabee	[21062] a	\N	\N
5efcff93-55a2-455c-aa30-0ecda359e42c	2018-03-02 06:03:15.3653-06	2	[21597] D 3 CORRIDOR 437	[4] DLarrabee	[21062] a	\N	\N
f8d624c7-1e2a-4186-b87a-f7e6e95b4e90	2018-03-02 06:03:15.3683-06	2	[21598] D 4 CORRIDOR 437 	[4] DLarrabee	[21062] a	\N	\N
9488005a-bfc6-4084-9d95-63301ca57533	2018-03-02 06:03:15.3723-06	2	[21599] D 5 CORRIDOR 437	[4] DLarrabee	[21062] a	\N	\N
4d440e5a-d72d-4f81-b67b-6c6ac61cfc37	2018-03-02 06:03:15.375301-06	2	[21600] D 6 CORRIDOR 414 	[4] DLarrabee	[21062] a	\N	\N
ca4b0130-773c-401a-b5db-33c2388656da	2018-03-02 06:03:15.380301-06	2	[21601] D 7 CORRIDOR 414 	[4] DLarrabee	[21062] a	\N	\N
06eb8590-ab7f-4863-92bc-51eda61d6542	2018-03-02 06:03:15.383302-06	2	[21602] D 8 MA 410 	[4] DLarrabee	[21062] a	\N	\N
3fd1b59d-fbb2-4192-b868-7f98d24e10e2	2018-03-02 06:03:15.387302-06	2	[21603] D 9 MA 410 	[4] DLarrabee	[21062] a	\N	\N
ec742d84-7f37-4a5d-b0cd-09f7acbd4876	2018-03-02 06:03:15.391302-06	2	[21604] D 10 MA 410 	[4] DLarrabee	[21062] a	\N	\N
2b6b60bf-9726-4501-94ca-720923ce6033	2018-03-02 06:03:15.395303-06	2	[21605] D 11 CLASSROOM 415 	[4] DLarrabee	[21062] a	\N	\N
707705c0-ff3b-4290-84dd-811f1ed7e061	2018-03-02 06:03:15.397303-06	2	[21606] D 12 CLASSROOM 415	[4] DLarrabee	[21062] a	\N	\N
14e8d063-8d7c-4e54-a839-891b1ddeb44c	2018-03-02 06:03:15.401303-06	2	[21607] D 13 CLASSROOM 418	[4] DLarrabee	[21062] a	\N	\N
a357b049-67cb-4c9b-abde-d847be3b2e37	2018-03-02 06:03:15.405304-06	2	[21608] D 14 CLASSROOM 418	[4] DLarrabee	[21062] a	\N	\N
0a81c428-0746-4bbb-9f75-c0927efbfd98	2018-03-02 06:03:15.408304-06	2	[21609] D 15 VESTIBULE 422 	[4] DLarrabee	[21062] a	\N	\N
463651c0-77c6-4ab1-b2f6-830d35cf5f85	2018-03-02 06:03:15.412304-06	2	[21610] D 16 WORK ALCOVE 423	[4] DLarrabee	[21062] a	\N	\N
ddec5996-8fc4-47c0-843b-014fcfd48938	2018-03-02 06:03:15.416305-06	2	[21611] D 17 WORK ALCOVE 423 	[4] DLarrabee	[21062] a	\N	\N
933f6287-04e5-47a5-9284-cc061401a36d	2018-03-02 06:03:15.419305-06	2	[21612] D 18 CLASSROOM 425	[4] DLarrabee	[21062] a	\N	\N
90b3a823-a0ae-4549-80bd-2366559724aa	2018-03-02 06:03:15.423306-06	2	[21613] D 19 CLASSROOM 425 	[4] DLarrabee	[21062] a	\N	\N
a6e2a78a-9f73-4033-84f0-8e4310b91afe	2018-03-02 06:03:15.427306-06	2	[21614] D 20 CLASSROOM 428 	[4] DLarrabee	[21062] a	\N	\N
bf164b6d-81b5-4846-861a-19da8f684676	2018-03-02 06:03:15.430306-06	2	[21615] D 21 CLASSROOM 428 	[4] DLarrabee	[21062] a	\N	\N
5e58f87a-c950-4e6a-bbee-1429633d10a7	2018-03-02 06:03:15.434307-06	2	[21616] D 22 VESTIBULE 444 	[4] DLarrabee	[21062] a	\N	\N
3b30771c-a225-4caf-a710-6ec43e57f1d4	2018-03-02 06:03:15.438307-06	2	[21617] D 23 DETENTION HEARING 443	[4] DLarrabee	[21062] a	\N	\N
56a4f7d0-e84f-479d-b63e-8ab9ac7be84f	2018-03-02 06:03:15.442307-06	2	[21618] D 24 CLASSROOM 463 	[4] DLarrabee	[21062] a	\N	\N
768f99b4-4a94-431e-b149-6fcb4e456460	2018-03-02 06:03:15.445308-06	2	[21619] D 25 CLASSROOM 463 	[4] DLarrabee	[21062] a	\N	\N
0d5b4441-3f9d-4016-a6b3-bed8ad66b8da	2018-03-02 06:03:15.448308-06	2	[21620] D 26 CLASSROOM 465	[4] DLarrabee	[21062] a	\N	\N
c625a4e9-d164-4828-a2d3-0ac9c810204d	2018-03-02 06:03:15.451308-06	2	[21621] D 27 CLASSROOM 465 	[4] DLarrabee	[21062] a	\N	\N
6c8e2041-1f5d-4c41-852a-9dffd3ae5eb2	2018-03-02 06:03:15.454309-06	2	[21622] D 28 CORRIDOR 461 	[4] DLarrabee	[21062] a	\N	\N
99956aac-e1da-499b-8fe7-c5bdb1d9c109	2018-03-02 06:03:15.458309-06	2	[21623] D 29 CALMING ROOM 456 	[4] DLarrabee	[21062] a	\N	\N
15c7233c-2275-4782-af30-b8bc9891012c	2018-03-02 06:03:15.462309-06	2	[21624] D 30 CALMING ROOM 438 	[4] DLarrabee	[21062] a	\N	\N
040d9de2-a5e1-4f11-acb4-4214107ab011	2018-03-02 06:03:15.46531-06	2	[21625] D 31 CALMING ROOM 439	[4] DLarrabee	[21062] a	\N	\N
8d6c9205-c2ed-4d3d-ab87-dce649ea13c8	2018-03-02 06:03:15.46931-06	2	[21626] D 32 GYM 455	[4] DLarrabee	[21062] a	\N	\N
14d82b2d-8d8d-4b4b-9660-ac0d38f809e6	2018-03-02 06:03:15.47231-06	2	[21627] D 33 GYM 455 	[4] DLarrabee	[21062] a	\N	\N
68769d13-0a23-49d0-82c2-99c5a923ebd8	2018-03-02 06:03:15.476311-06	2	[21628] D 34 GYM 455 	[4] DLarrabee	[21062] a	\N	\N
af40eacd-4558-459d-b4b4-799ae275cb02	2018-03-02 06:03:15.480311-06	2	[21629] D 35 GYM 455 	[4] DLarrabee	[21062] a	\N	\N
a4c40f28-d29a-4106-abec-5892c7897c0b	2018-03-02 06:03:15.483312-06	2	[21630] D 36 FITNESS 452 	[4] DLarrabee	[21062] a	\N	\N
3958a4d1-a2d8-45b1-80fd-c0312069c60a	2018-03-02 06:03:15.487312-06	2	[21631] D 37 FITNESS 452 	[4] DLarrabee	[21062] a	\N	\N
44d22fde-db99-48a0-a92b-11f692d30c7c	2018-03-02 06:03:15.491312-06	2	[21632] D 38 COURTYARD 451	[4] DLarrabee	[21062] a	\N	\N
6ce88bdc-7be4-498e-b1a8-d2d3e072abc7	2018-03-02 06:03:15.495313-06	2	[21633] D 39 COURTYARD 451 	[4] DLarrabee	[21062] a	\N	\N
d5c3560a-cc4b-4bb0-932a-c1f1b182213f	2018-03-02 06:03:15.499313-06	2	[21634] D 40 VISITING 448 	[4] DLarrabee	[21062] a	\N	\N
6914ebb7-69f6-42a1-b645-1d3610e110be	2018-03-02 06:03:15.502313-06	2	[21635] D 41 VISITING 445 	[4] DLarrabee	[21062] a	\N	\N
84b13373-f769-4628-9a3e-a5fad3ceefb3	2018-03-02 06:03:15.506314-06	2	[21636] D 42 VISITING 445	[4] DLarrabee	[21062] a	\N	\N
6f8e7bcd-f9b4-4f65-9e02-175d93e09107	2018-03-02 06:03:15.508314-06	2	[21637] D 43 VISITING 446 	[4] DLarrabee	[21062] a	\N	\N
f3eda5a6-696c-426c-add0-29e59845449a	2018-03-02 06:03:15.511314-06	2	[21638] D 44 WAITING 382 	[4] DLarrabee	[21062] a	\N	\N
0a96d86f-be47-4acd-b720-bd784a0b4c40	2018-03-02 06:03:15.515315-06	2	[21639] D 45 WAITING 382 	[4] DLarrabee	[21062] a	\N	\N
08445be5-117c-459a-b2eb-0ad05079a3c1	2018-03-02 06:03:15.519315-06	2	[21640] D 46 WAITING 382 	[4] DLarrabee	[21062] a	\N	\N
f1ce1ab0-c6f6-4f9f-b5fb-e0cddbcfff86	2018-03-02 06:03:15.522315-06	2	[21641] D 47 WAITING 382 	[4] DLarrabee	[21062] a	\N	\N
f9c4859e-7b19-47ba-ada3-4c4369832653	2018-03-02 06:03:15.527316-06	2	[21642] D 48 VENDING 492	[4] DLarrabee	[21062] a	\N	\N
88abc7f4-f468-4385-81f9-6a9a5e286950	2018-03-02 06:03:15.530316-06	2	[21643] D 49 CORRIDOR 484 	[4] DLarrabee	[21062] a	\N	\N
c8be3aff-a23f-4585-b5b5-d2fe730719a0	2018-03-02 06:03:15.534317-06	2	[21644] D 50 CORRIDOR 484	[4] DLarrabee	[21062] a	\N	\N
5902a2f4-a5e1-429f-b1ee-79c154cfbc33	2018-03-02 06:03:15.539317-06	2	[21645] D 51 CORRIDOR 484 	[4] DLarrabee	[21062] a	\N	\N
65b2d3b4-89ce-4363-a633-778322f27d5e	2018-03-02 06:03:15.543318-06	2	[21646] D 52 CORRIDOR 484 	[4] DLarrabee	[21062] a	\N	\N
9f5eb46f-4c86-4d72-b9d8-46cd5fc7bae7	2018-03-02 06:03:15.546318-06	2	[21647] D 53 CORRIDOR 484 	[4] DLarrabee	[21062] a	\N	\N
e84040e5-e5f4-4c9b-b9a5-a987470514d0	2018-03-02 06:03:15.549318-06	2	[21648] D 54 CORRIDOR 484 	[4] DLarrabee	[21062] a	\N	\N
8b213826-6efc-4a9e-86f4-871ff7f2e637	2018-03-02 06:03:15.551318-06	2	[21649] D 55 INTERVIEW 466 	[4] DLarrabee	[21062] a	\N	\N
b3fae1b1-1632-4d3e-9d3e-30bb47472038	2018-03-02 06:03:15.555319-06	2	[21650] D 56 MEETING 467	[4] DLarrabee	[21062] a	\N	\N
dd9a0d00-f6dd-4257-aed5-71f5f939d086	2018-03-02 06:03:15.558319-06	2	[21651] D 57 CORRIDOR 484 	[4] DLarrabee	[21062] a	\N	\N
ad8a53f0-cfaf-4c54-b131-82be2b538c27	2018-03-02 06:03:15.561319-06	2	[21652] D58 VISITING ROOM 445	[4] DLarrabee	[21062] a	\N	\N
d7ae3509-7288-4690-af54-d78f6331d58d	2018-03-02 06:03:15.56432-06	2	[21653] D59 MEDS STORAGE 401	[4] DLarrabee	[21062] a	\N	\N
35c2f346-a4a6-4893-afa5-11de9ac47294	2018-03-02 06:03:15.56732-06	2	[21654] None	[4] DLarrabee	[21062] a	\N	\N
f568c40e-787e-4a93-bfb2-b28fb9322c45	2018-03-02 06:03:15.57232-06	2	[21480] E Cameras	[4] DLarrabee	[21062] a	\N	\N
bb061a60-f212-4271-a273-3ffbd0ffb889	2018-03-02 06:03:15.575321-06	2	[21655] E 1 HALL 544 	[4] DLarrabee	[21062] a	\N	\N
14ce07d7-70bf-4370-a43d-166f185c34cf	2018-03-02 06:03:15.579321-06	2	[21656] E 2 HALL 544 	[4] DLarrabee	[21062] a	\N	\N
fb85537d-79e9-4370-aa95-0da8e8291be9	2018-03-02 06:03:15.583322-06	2	[21657] E 3 HALL 544 	[4] DLarrabee	[21062] a	\N	\N
bb29a11e-53a0-4858-a1a5-4211db545cca	2018-03-02 06:03:15.587322-06	2	[21658] E 4 LIVING ROOM 529 	[4] DLarrabee	[21062] a	\N	\N
7daa4a60-25ba-47d9-a888-122b4d9ea681	2018-03-02 06:03:15.591322-06	2	[21659] E 5 LIVING ROOM 529 	[4] DLarrabee	[21062] a	\N	\N
5901dd2b-a6ef-4613-8b5d-da1cbbb5d361	2018-03-02 06:03:15.595323-06	2	[21660] E 6 LIVING ROOM 529 	[4] DLarrabee	[21062] a	\N	\N
e6e9e99d-4831-4231-9880-70ac353a9542	2018-03-02 06:03:15.599323-06	2	[21661] E 7 LIVING ROOM 529 	[4] DLarrabee	[21062] a	\N	\N
b091414d-1344-4d81-9c56-b255e07247dd	2018-03-02 06:03:15.603324-06	2	[21662] E 8 LIVING ROOM 529 	[4] DLarrabee	[21062] a	\N	\N
a93a6aa7-ba90-4ef9-95fc-d23b254d04b6	2018-03-02 06:03:15.606324-06	2	[21663] E 9 DINING 515	[4] DLarrabee	[21062] a	\N	\N
3f57e949-6633-4891-9613-fd0689fb8b45	2018-03-02 06:03:15.609324-06	2	[21664] E 10 DINING 515	[4] DLarrabee	[21062] a	\N	\N
c85416d5-9f85-49e0-9837-1398f89c2efd	2018-03-02 06:03:15.613325-06	2	[21665] E 11 LIVING ROOM 514 	[4] DLarrabee	[21062] a	\N	\N
2b634137-05df-47bb-8e1c-f141c40c72a9	2018-03-02 06:03:15.617325-06	2	[21666] E 12 LIVING ROOM 514	[4] DLarrabee	[21062] a	\N	\N
51cb3580-b3a3-4d05-bf68-b985f0438ab9	2018-03-02 06:03:15.619325-06	2	[21667] E 13 LIVING ROOM 514	[4] DLarrabee	[21062] a	\N	\N
fdb7dfbe-44d8-494f-b264-88f24d2fd625	2018-03-02 06:03:15.623326-06	2	[21668] E 14 LIVING ROOM 514 	[4] DLarrabee	[21062] a	\N	\N
affd3d3d-4d90-425f-b0c7-052d1189052f	2018-03-02 06:03:15.626326-06	2	[21669] E 15 CALMING ROOM 535	[4] DLarrabee	[21062] a	\N	\N
2a3c0319-b46b-4d83-8ecd-822a0f30df8a	2018-03-02 06:03:15.630326-06	2	[21670] E 16 COURTYARD 503	[4] DLarrabee	[21062] a	\N	\N
6a8b9e66-7bc7-48e8-991d-199a61913bc6	2018-03-02 06:03:15.635327-06	2	[21671] E17 SINGLE SLEEPING 509	[4] DLarrabee	[21062] a	\N	\N
de47220c-26b7-4331-813e-45506ea69526	2018-03-02 06:03:15.639327-06	2	[21672] E18 ADA SLEEPING 513	[4] DLarrabee	[21062] a	\N	\N
c03e8578-6a3c-4209-8a6a-45081c2d6c44	2018-03-02 06:03:15.643328-06	2	[21673] E19 ADA SLEEPING 518	[4] DLarrabee	[21062] a	\N	\N
865666e9-1ce8-405a-813a-05bcc1db39d7	2018-03-02 06:03:15.649328-06	2	[21674] E20 SINGLE SLEEPING 520	[4] DLarrabee	[21062] a	\N	\N
414b21e1-5963-4e4a-bd84-df281dda7170	2018-03-02 06:03:15.653329-06	2	[21675] None	[4] DLarrabee	[21062] a	\N	\N
86cce5aa-6ba7-4d50-8fc2-cd960f31fc3d	2018-03-02 06:04:52.449007-06	1	[21676] IC 209B-inB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
20ec66a4-3605-4412-b175-89bacaa316f1	2018-03-02 06:06:53.053066-06	2	[21676] IC 209B-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
2b678ea8-48d9-4714-960d-a8c688a4f8fb	2018-03-02 06:07:17.855546-06	2	[21179] camera_left_lt_grey.png	[4] DLarrabee	[21062] a	\N	\N
1af7a7db-04b0-4b3f-a56b-9a02020033d9	2018-03-02 06:07:36.746435-06	1	[21677] IC 209B-OutB (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
107e9c01-172b-473d-9ae1-4c6463eb034a	2018-03-02 06:07:36.753436-06	1	[21678] IC 209B-OutB (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
53b40839-6436-4453-8c7b-54ee1d605048	2018-03-02 06:07:36.785439-06	1	[21679] IC 209B-OutB (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
759b3a45-d2b6-408b-8d4e-5c3559f25e15	2018-03-02 06:07:36.78944-06	1	[21680] IC 209B-OutB (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
b882179f-1eb0-4784-95dd-10a67b0f2f39	2018-03-02 06:07:36.79644-06	1	[21681] IC 209B-OutB (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
d08d0339-1ac7-4b3b-b4e9-5f91fc45904d	2018-03-02 06:07:36.801441-06	1	[21682] IC 209B-OutB (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
056f9a2b-e668-4667-a4a1-a971af4dfb00	2018-03-02 06:07:36.807441-06	1	[21683] IC 209B-OutB (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
cdc48291-ca96-4939-a130-e4d19d589f08	2018-03-02 06:08:10.115772-06	1	[21684] camera_left_lt_grey.png (1)	[4] DLarrabee	[21062] a	\N	\N
4d6f3507-20a5-43e7-8b8d-0ae84e97c192	2018-03-02 06:08:10.120772-06	1	[21685] camera_left_lt_grey.png (2)	[4] DLarrabee	[21062] a	\N	\N
b4715745-0fd0-4028-93fb-45011d508423	2018-03-02 06:08:10.125773-06	1	[21686] camera_left_lt_grey.png (3)	[4] DLarrabee	[21062] a	\N	\N
dd14fe7d-c59b-43bd-8f92-11e8ae7c98c5	2018-03-02 06:08:10.131773-06	1	[21687] camera_left_lt_grey.png (4)	[4] DLarrabee	[21062] a	\N	\N
e13a9238-4370-4d0d-bdbb-9c5f65c56fc8	2018-03-02 06:08:10.140774-06	1	[21688] camera_left_lt_grey.png (5)	[4] DLarrabee	[21062] a	\N	\N
8d1d0930-f182-4f4e-8b82-441a5281da27	2018-03-02 06:08:10.145775-06	1	[21689] camera_left_lt_grey.png (6)	[4] DLarrabee	[21062] a	\N	\N
dc455e19-6242-469e-a63f-0ed8937775e7	2018-03-02 06:08:10.151775-06	1	[21690] camera_left_lt_grey.png (7)	[4] DLarrabee	[21062] a	\N	\N
34709a5c-b3c1-4e85-82fc-917b086a0639	2018-03-02 06:08:10.157776-06	1	[21691] camera_left_lt_grey.png (8)	[4] DLarrabee	[21062] a	\N	\N
e906704d-ea1e-4f32-b8be-eb49a4e63f2e	2018-03-02 06:08:10.162777-06	1	[21692] camera_left_lt_grey.png (9)	[4] DLarrabee	[21062] a	\N	\N
8289c801-ee24-414f-87d7-7b24de2cc26c	2018-03-02 06:08:10.168777-06	1	[21693] camera_left_lt_grey.png (10)	[4] DLarrabee	[21062] a	\N	\N
1eac903b-394f-4f57-9aa4-cbd403d6fe19	2018-03-02 06:08:10.174778-06	1	[21694] camera_left_lt_grey.png (11)	[4] DLarrabee	[21062] a	\N	\N
2425dcc2-4737-42fc-8bb4-bf828e99fa19	2018-03-02 06:08:10.179778-06	1	[21695] camera_left_lt_grey.png (12)	[4] DLarrabee	[21062] a	\N	\N
87ea4835-f078-4d41-8afb-ac5d47222ee0	2018-03-02 06:08:10.184779-06	1	[21696] camera_left_lt_grey.png (13)	[4] DLarrabee	[21062] a	\N	\N
16abed2c-56fa-40be-9b37-e1e7b47bfc70	2018-03-02 06:08:10.189779-06	1	[21697] camera_left_lt_grey.png (14)	[4] DLarrabee	[21062] a	\N	\N
64642311-23fd-46aa-b7f6-47972ce64be9	2018-03-02 06:08:10.19578-06	1	[21698] camera_left_lt_grey.png (15)	[4] DLarrabee	[21062] a	\N	\N
f7d0742f-f83e-43d1-b955-fa3e809352e9	2018-03-02 06:08:10.205781-06	1	[21699] camera_left_lt_grey.png (16)	[4] DLarrabee	[21062] a	\N	\N
037458ff-4d3f-4edd-b6e0-d04a84e2930b	2018-03-02 06:08:10.211781-06	1	[21700] camera_left_lt_grey.png (17)	[4] DLarrabee	[21062] a	\N	\N
a505aab3-9d01-4036-b7fd-9301516d070b	2018-03-02 06:08:10.216782-06	1	[21701] camera_left_lt_grey.png (18)	[4] DLarrabee	[21062] a	\N	\N
25a72025-173b-4d9a-93a2-484c9a699c59	2018-03-02 06:08:10.221782-06	1	[21702] camera_left_lt_grey.png (19)	[4] DLarrabee	[21062] a	\N	\N
f48f81aa-b53d-4a98-96e4-8b2b19ca0ada	2018-03-02 06:08:10.227783-06	1	[21703] camera_left_lt_grey.png (20)	[4] DLarrabee	[21062] a	\N	\N
1ac06d22-3ef3-43be-96d1-259c1f221a52	2018-03-02 06:08:10.232784-06	1	[21704] camera_left_lt_grey.png (21)	[4] DLarrabee	[21062] a	\N	\N
f99f79f2-336d-47b4-be98-c5fa2049c595	2018-03-02 06:08:10.238784-06	1	[21705] camera_left_lt_grey.png (22)	[4] DLarrabee	[21062] a	\N	\N
7b4e5522-efbf-4178-981e-b9120cf5b035	2018-03-02 06:08:10.244785-06	1	[21706] camera_left_lt_grey.png (23)	[4] DLarrabee	[21062] a	\N	\N
6f06cf5e-51c2-4bd4-8606-6c2ff3496260	2018-03-02 06:08:10.249785-06	1	[21707] camera_left_lt_grey.png (24)	[4] DLarrabee	[21062] a	\N	\N
5ce0ac92-d47c-4068-90be-15d5ee31efff	2018-03-02 06:08:10.255786-06	1	[21708] camera_left_lt_grey.png (25)	[4] DLarrabee	[21062] a	\N	\N
8967bc06-9ac3-486f-b9a2-12bfa6429933	2018-03-02 06:08:10.261786-06	1	[21709] camera_left_lt_grey.png (26)	[4] DLarrabee	[21062] a	\N	\N
41bb20cc-a895-46ff-b591-ad0caac3969d	2018-03-02 06:08:10.266787-06	1	[21710] camera_left_lt_grey.png (27)	[4] DLarrabee	[21062] a	\N	\N
281fc6a1-28c3-4fa7-aacb-4038d017713f	2018-03-02 06:08:10.271787-06	1	[21711] camera_left_lt_grey.png (28)	[4] DLarrabee	[21062] a	\N	\N
dfde0086-e37d-42f4-9aa8-e8a9dcaf9da9	2018-03-02 06:08:10.275788-06	1	[21712] camera_left_lt_grey.png (29)	[4] DLarrabee	[21062] a	\N	\N
968bd846-5970-4748-b63f-554f7670f8c5	2018-03-02 06:08:57.023462-06	2	[21677] IC 211B-InB 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3eee54fe-80f5-4605-9146-2e8eeab84e78	2018-03-02 06:09:15.360296-06	2	[21678] IC 211B-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
8341bece-003e-4e00-8c2e-0a73d1e0a1ba	2018-03-02 06:09:29.734733-06	3	[21684] camera_left_lt_grey.png (1)	[4] DLarrabee	[21062] a	\N	\N
a90d8a3d-b1aa-4076-92b3-1949ba0411ce	2018-03-02 06:09:29.987758-06	2	[21685] camera_left_lt_grey.png (2)	[4] DLarrabee	[21062] a	\N	\N
f20d015a-b645-4d40-bd9c-ebef6f96453e	2018-03-02 06:09:29.993759-06	2	[21686] camera_left_lt_grey.png (3)	[4] DLarrabee	[21062] a	\N	\N
cac84680-2b11-4ff5-aea5-94cd576bf1e3	2018-03-02 06:09:29.999759-06	2	[21687] camera_left_lt_grey.png (4)	[4] DLarrabee	[21062] a	\N	\N
f8828b05-383b-4b3d-b7e7-bfb67fc83aee	2018-03-02 06:09:30.00376-06	2	[21688] camera_left_lt_grey.png (5)	[4] DLarrabee	[21062] a	\N	\N
da6b2d0f-1d04-4294-9d70-6736e85f7906	2018-03-02 06:09:30.00776-06	2	[21689] camera_left_lt_grey.png (6)	[4] DLarrabee	[21062] a	\N	\N
58180661-0fe8-4694-9e98-9c7ee7d5d6ee	2018-03-02 06:09:30.011761-06	2	[21690] camera_left_lt_grey.png (7)	[4] DLarrabee	[21062] a	\N	\N
49da2a67-7c8a-47fb-9f09-420349f1847e	2018-03-02 06:09:30.015761-06	2	[21691] camera_left_lt_grey.png (8)	[4] DLarrabee	[21062] a	\N	\N
e762c1c7-3cf7-4122-8306-ef0cc3c410d9	2018-03-02 06:09:30.019761-06	2	[21692] camera_left_lt_grey.png (9)	[4] DLarrabee	[21062] a	\N	\N
25a236b2-a8cf-46ba-ba3a-0a390b2ec778	2018-03-02 06:09:30.024762-06	2	[21693] camera_left_lt_grey.png (10)	[4] DLarrabee	[21062] a	\N	\N
34ad6c28-53d1-4b89-97a5-0ce40386566c	2018-03-02 06:09:30.028762-06	2	[21694] camera_left_lt_grey.png (11)	[4] DLarrabee	[21062] a	\N	\N
250313cf-f143-4cca-9ec4-3f18827a53f4	2018-03-02 06:09:30.033763-06	2	[21695] camera_left_lt_grey.png (12)	[4] DLarrabee	[21062] a	\N	\N
6d75cadf-bca0-468a-9f10-5d46f8d91022	2018-03-02 06:09:30.037763-06	2	[21696] camera_left_lt_grey.png (13)	[4] DLarrabee	[21062] a	\N	\N
87823a70-f79a-4c6d-ae0f-d69d10cdd976	2018-03-02 06:09:30.043764-06	2	[21697] camera_left_lt_grey.png (14)	[4] DLarrabee	[21062] a	\N	\N
2cd09a05-660c-482a-8186-5213bc9340c7	2018-03-02 06:09:30.046764-06	2	[21698] camera_left_lt_grey.png (15)	[4] DLarrabee	[21062] a	\N	\N
5d9413c0-4f31-46e9-9b24-5de08b495ba2	2018-03-02 06:09:30.051765-06	2	[21699] camera_left_lt_grey.png (16)	[4] DLarrabee	[21062] a	\N	\N
5ee6f1cd-498b-4f70-bc42-bbb1b51a1e67	2018-03-02 06:09:30.056765-06	2	[21700] camera_left_lt_grey.png (17)	[4] DLarrabee	[21062] a	\N	\N
627ad57f-6878-4324-ad99-431bd61fb64c	2018-03-02 06:09:30.059765-06	2	[21701] camera_left_lt_grey.png (18)	[4] DLarrabee	[21062] a	\N	\N
8d9f7c7d-bf23-4b38-bc57-9baa1ed5946d	2018-03-02 06:09:30.064766-06	2	[21702] camera_left_lt_grey.png (19)	[4] DLarrabee	[21062] a	\N	\N
0acc1480-4990-4bb1-9c2a-14972d901176	2018-03-02 06:09:30.070767-06	2	[21703] camera_left_lt_grey.png (20)	[4] DLarrabee	[21062] a	\N	\N
e1d0c47a-5575-491e-b17d-7df0df9823d4	2018-03-02 06:09:30.074767-06	2	[21704] camera_left_lt_grey.png (21)	[4] DLarrabee	[21062] a	\N	\N
28b2c56f-547e-4ae5-b1bb-a7c39dc43049	2018-03-02 06:09:30.079767-06	2	[21705] camera_left_lt_grey.png (22)	[4] DLarrabee	[21062] a	\N	\N
5c2de28b-e9b8-4e1b-a962-b945a8f21ddf	2018-03-02 06:09:30.083768-06	2	[21706] camera_left_lt_grey.png (23)	[4] DLarrabee	[21062] a	\N	\N
847b00c5-0b96-4839-a91e-b141071a541d	2018-03-02 06:09:30.087768-06	2	[21707] camera_left_lt_grey.png (24)	[4] DLarrabee	[21062] a	\N	\N
82b8c075-811c-4bb3-bd6c-ca86d4084288	2018-03-02 06:09:30.091769-06	2	[21708] camera_left_lt_grey.png (25)	[4] DLarrabee	[21062] a	\N	\N
486289a5-bbf0-41ce-999a-c23436e03746	2018-03-02 06:09:30.095769-06	2	[21709] camera_left_lt_grey.png (26)	[4] DLarrabee	[21062] a	\N	\N
4c8bf859-1f9b-4913-b897-4f0e33933573	2018-03-02 06:09:30.099769-06	2	[21710] camera_left_lt_grey.png (27)	[4] DLarrabee	[21062] a	\N	\N
772ab865-54d9-4a8c-8f46-910bd0c6e5d4	2018-03-02 06:09:30.10377-06	2	[21711] camera_left_lt_grey.png (28)	[4] DLarrabee	[21062] a	\N	\N
4f4f0de1-0b20-4105-a88f-3f5eb732c443	2018-03-02 06:09:30.10777-06	2	[21712] camera_left_lt_grey.png (29)	[4] DLarrabee	[21062] a	\N	\N
2f2e3772-5679-4346-9c01-272fa74c1212	2018-03-02 06:09:34.30819-06	3	[21685] camera_left_lt_grey.png (2)	[4] DLarrabee	[21062] a	\N	\N
07154c74-728e-4449-b7cd-a0900c9d3d9f	2018-03-02 06:09:34.463206-06	2	[21679] IC 213	[21041] OSSI-DNOVAK	[293] master	\N	\N
5a3aa3aa-13c0-406f-95ba-6e60b7f17f1b	2018-03-02 06:09:34.582218-06	2	[21686] camera_left_lt_grey.png (3)	[4] DLarrabee	[21062] a	\N	\N
87b529f9-d4c9-4844-bee9-bc0568cd52a0	2018-03-02 06:09:34.587218-06	2	[21687] camera_left_lt_grey.png (4)	[4] DLarrabee	[21062] a	\N	\N
4d36b182-bc56-4fc0-adef-be5e8fc01e83	2018-03-02 06:09:34.591219-06	2	[21688] camera_left_lt_grey.png (5)	[4] DLarrabee	[21062] a	\N	\N
3765a176-adcc-4518-bc54-a1d2fba2325e	2018-03-02 06:09:34.595219-06	2	[21689] camera_left_lt_grey.png (6)	[4] DLarrabee	[21062] a	\N	\N
0bc38306-acc8-4640-994c-062941cd7a93	2018-03-02 06:09:34.599219-06	2	[21690] camera_left_lt_grey.png (7)	[4] DLarrabee	[21062] a	\N	\N
5bc50228-fd1f-4d07-a29c-29f850b9201f	2018-03-02 06:09:34.60322-06	2	[21691] camera_left_lt_grey.png (8)	[4] DLarrabee	[21062] a	\N	\N
4e1285ff-5534-4dcf-bf40-5a94d7cd349c	2018-03-02 06:09:34.60722-06	2	[21692] camera_left_lt_grey.png (9)	[4] DLarrabee	[21062] a	\N	\N
c34d966c-b330-4691-af6a-8f8424bb9db2	2018-03-02 06:09:34.611221-06	2	[21693] camera_left_lt_grey.png (10)	[4] DLarrabee	[21062] a	\N	\N
93435e82-1456-47fd-a82e-43124b912bcb	2018-03-02 06:09:34.615221-06	2	[21694] camera_left_lt_grey.png (11)	[4] DLarrabee	[21062] a	\N	\N
1c94fadf-ca59-4bae-95b0-88ab894a87b3	2018-03-02 06:09:34.619221-06	2	[21695] camera_left_lt_grey.png (12)	[4] DLarrabee	[21062] a	\N	\N
73758a5c-fcc7-4468-9f8d-a6dee3b1c2ff	2018-03-02 06:09:34.623222-06	2	[21696] camera_left_lt_grey.png (13)	[4] DLarrabee	[21062] a	\N	\N
51f95893-5ae0-4bc2-961b-9f16fba941b7	2018-03-02 06:09:34.627222-06	2	[21697] camera_left_lt_grey.png (14)	[4] DLarrabee	[21062] a	\N	\N
7b75da00-23fc-424c-9290-e59c7830fca3	2018-03-02 06:09:34.632223-06	2	[21698] camera_left_lt_grey.png (15)	[4] DLarrabee	[21062] a	\N	\N
886a93aa-7206-435f-b94c-77931731d82d	2018-03-02 06:09:34.636223-06	2	[21699] camera_left_lt_grey.png (16)	[4] DLarrabee	[21062] a	\N	\N
0c1238dd-6f07-4b33-bd80-1c18107dd637	2018-03-02 06:09:34.639223-06	2	[21700] camera_left_lt_grey.png (17)	[4] DLarrabee	[21062] a	\N	\N
abd7d407-4580-491e-8590-cb4e18846f7d	2018-03-02 06:09:34.642224-06	2	[21701] camera_left_lt_grey.png (18)	[4] DLarrabee	[21062] a	\N	\N
eba3175a-25a9-49b6-9877-208a16deb012	2018-03-02 06:09:34.646224-06	2	[21702] camera_left_lt_grey.png (19)	[4] DLarrabee	[21062] a	\N	\N
bc0a089e-fbf0-4bb2-9510-174932b4439e	2018-03-02 06:09:34.650224-06	2	[21703] camera_left_lt_grey.png (20)	[4] DLarrabee	[21062] a	\N	\N
933b9bcb-476a-4947-9b0c-36b1664f640a	2018-03-02 06:09:34.654225-06	2	[21704] camera_left_lt_grey.png (21)	[4] DLarrabee	[21062] a	\N	\N
be740cbf-6bd0-482a-bf23-303673af2402	2018-03-02 06:09:34.657225-06	2	[21705] camera_left_lt_grey.png (22)	[4] DLarrabee	[21062] a	\N	\N
5ff192dc-6317-4d3a-a936-37866037ad92	2018-03-02 06:09:34.661226-06	2	[21706] camera_left_lt_grey.png (23)	[4] DLarrabee	[21062] a	\N	\N
ce85aee4-bd0a-4e5f-b7fa-95b303f77a80	2018-03-02 06:09:34.665226-06	2	[21707] camera_left_lt_grey.png (24)	[4] DLarrabee	[21062] a	\N	\N
bb8922ba-c52c-4021-b4e3-27d290ee1411	2018-03-02 06:09:34.668226-06	2	[21708] camera_left_lt_grey.png (25)	[4] DLarrabee	[21062] a	\N	\N
0cb9886d-65e4-4fd1-b26d-650409d9978e	2018-03-02 06:09:34.672227-06	2	[21709] camera_left_lt_grey.png (26)	[4] DLarrabee	[21062] a	\N	\N
5d891dff-d406-4961-b936-8b2a8646ac23	2018-03-02 06:09:34.676227-06	2	[21710] camera_left_lt_grey.png (27)	[4] DLarrabee	[21062] a	\N	\N
7927fd6b-91e5-4b44-bb0f-d7bd77a99b68	2018-03-02 06:09:34.681228-06	2	[21711] camera_left_lt_grey.png (28)	[4] DLarrabee	[21062] a	\N	\N
e3859896-1231-4a6e-bc68-6630dade18fb	2018-03-02 06:09:34.684228-06	2	[21712] camera_left_lt_grey.png (29)	[4] DLarrabee	[21062] a	\N	\N
80bf2fe6-4d3d-46cd-be21-238c48a7e38a	2018-03-02 06:09:43.545114-06	3	[21712] camera_left_lt_grey.png (29)	[4] DLarrabee	[21062] a	\N	\N
82ee7795-6c5c-4940-98f9-491bbf668fb4	2018-03-02 06:09:45.925352-06	3	[21711] camera_left_lt_grey.png (28)	[4] DLarrabee	[21062] a	\N	\N
58847b75-6bda-4051-95bf-6245503ac2bf	2018-03-02 06:09:46.761435-06	2	[21680] IC 214	[21041] OSSI-DNOVAK	[293] master	\N	\N
6bc540d1-b07a-477c-a2e3-d4de7b208e1a	2018-03-02 06:09:47.962556-06	3	[21710] camera_left_lt_grey.png (27)	[4] DLarrabee	[21062] a	\N	\N
ad64febb-fe63-49e1-9d82-0f950526fe79	2018-03-02 06:09:52.439003-06	3	[21709] camera_left_lt_grey.png (26)	[4] DLarrabee	[21062] a	\N	\N
bf6b664f-5272-4e89-bd09-5720df6d46cc	2018-03-02 06:09:54.130172-06	3	[21708] camera_left_lt_grey.png (25)	[4] DLarrabee	[21062] a	\N	\N
4f87339c-2dd9-4b96-a829-3b2e987572e5	2018-03-02 06:09:55.90735-06	3	[21707] camera_left_lt_grey.png (24)	[4] DLarrabee	[21062] a	\N	\N
8491bb18-9849-4526-9edb-9da3fb4ae27b	2018-03-02 06:10:00.182777-06	3	[21706] camera_left_lt_grey.png (23)	[4] DLarrabee	[21062] a	\N	\N
cb1a780e-8b0b-4246-913b-aa0a0ad38f2b	2018-03-02 06:10:02.019961-06	3	[21705] camera_left_lt_grey.png (22)	[4] DLarrabee	[21062] a	\N	\N
4bcc5ce4-9104-4d05-ab56-68e47a766742	2018-03-02 06:10:02.736033-06	2	[21681] IC 215	[21041] OSSI-DNOVAK	[293] master	\N	\N
d79b1811-9633-4637-86b5-3aa0c729475b	2018-03-02 06:10:03.80414-06	3	[21704] camera_left_lt_grey.png (21)	[4] DLarrabee	[21062] a	\N	\N
ccdef481-cf22-4e53-aad4-5f4f970e1991	2018-03-02 06:10:05.434303-06	3	[21703] camera_left_lt_grey.png (20)	[4] DLarrabee	[21062] a	\N	\N
b5435860-8575-4403-ad9f-cabd005996c9	2018-03-02 06:10:07.103469-06	3	[21702] camera_left_lt_grey.png (19)	[4] DLarrabee	[21062] a	\N	\N
1cb5d7cd-02a7-40db-8ee7-cf8fcda24d5c	2018-03-02 06:10:08.746634-06	3	[21701] camera_left_lt_grey.png (18)	[4] DLarrabee	[21062] a	\N	\N
6bee1e6e-27d4-4bfe-92c7-fde3cd192c8a	2018-03-02 06:10:10.244784-06	3	[21700] camera_left_lt_grey.png (17)	[4] DLarrabee	[21062] a	\N	\N
6124e347-8468-4a38-9246-710e857bf746	2018-03-02 06:10:11.916951-06	3	[21699] camera_left_lt_grey.png (16)	[4] DLarrabee	[21062] a	\N	\N
dfcd7f5e-a371-46c4-ab92-16396ed1d44f	2018-03-02 06:10:13.551114-06	3	[21698] camera_left_lt_grey.png (15)	[4] DLarrabee	[21062] a	\N	\N
cdbaff04-c77f-4bfa-a322-7895d9f2c8f2	2018-03-02 06:10:14.91225-06	2	[21682] IC 216	[21041] OSSI-DNOVAK	[293] master	\N	\N
61e90f76-5b2b-47e8-a3d3-717aac8ef616	2018-03-02 06:10:15.20828-06	3	[21697] camera_left_lt_grey.png (14)	[4] DLarrabee	[21062] a	\N	\N
92008ecb-f4d3-4d29-8121-829647020373	2018-03-02 06:10:16.788438-06	3	[21696] camera_left_lt_grey.png (13)	[4] DLarrabee	[21062] a	\N	\N
413a1aa5-97fc-4ad6-9143-4aee302a303b	2018-03-02 06:10:18.321591-06	3	[21695] camera_left_lt_grey.png (12)	[4] DLarrabee	[21062] a	\N	\N
cc0ed03b-792c-47ab-b35d-349673e23881	2018-03-02 06:10:19.834742-06	3	[21694] camera_left_lt_grey.png (11)	[4] DLarrabee	[21062] a	\N	\N
b9a6721c-e306-433f-8fb5-9a75d6526867	2018-03-02 06:10:21.387898-06	3	[21693] camera_left_lt_grey.png (10)	[4] DLarrabee	[21062] a	\N	\N
33b221b9-7190-45ba-b289-9944b2afed30	2018-03-02 06:10:22.765035-06	3	[21692] camera_left_lt_grey.png (9)	[4] DLarrabee	[21062] a	\N	\N
4068858d-4166-446e-84d7-b85032b84497	2018-03-02 06:10:24.11517-06	3	[21691] camera_left_lt_grey.png (8)	[4] DLarrabee	[21062] a	\N	\N
2ae0e6f8-6966-4a88-a7f4-521b28bcb2a2	2018-03-02 06:10:24.91325-06	2	[21683] IC 218	[21041] OSSI-DNOVAK	[293] master	\N	\N
27863ec1-e2f8-438f-97e5-0bbcbd993099	2018-03-02 06:10:25.492308-06	3	[21690] camera_left_lt_grey.png (7)	[4] DLarrabee	[21062] a	\N	\N
05e18724-7585-4117-a0f0-c33da9e4fbd6	2018-03-02 06:10:26.817441-06	3	[21689] camera_left_lt_grey.png (6)	[4] DLarrabee	[21062] a	\N	\N
a32ef603-776c-41d9-b62a-02fa9a0f2e02	2018-03-02 06:10:28.139573-06	3	[21688] camera_left_lt_grey.png (5)	[4] DLarrabee	[21062] a	\N	\N
9720418d-0713-400f-a21b-325cfddd2d0f	2018-03-02 06:10:29.635722-06	3	[21687] camera_left_lt_grey.png (4)	[4] DLarrabee	[21062] a	\N	\N
0c827c18-1bfa-4deb-8ff4-6a2fe34f6286	2018-03-02 06:10:32.742033-06	3	[21686] camera_left_lt_grey.png (3)	[4] DLarrabee	[21062] a	\N	\N
da318050-594a-4a74-b715-c2fe0bfb4f05	2018-03-02 06:10:41.932952-06	1	[21684] camera_left_lt_grey.png Copy	[4] DLarrabee	[21062] a	\N	\N
559a882f-f67a-4f7c-8549-6cece4c9c62a	2018-03-02 06:11:16.896448-06	2	[21179] Cameras	[4] DLarrabee	[21062] a	\N	\N
9750644d-2c1e-42e5-b6e3-3bd2ba2d22ad	2018-03-02 06:11:30.594818-06	2	[21684] camera_left_lt_grey.png Copy	[4] DLarrabee	[21062] a	\N	\N
518184ee-fa5e-4d4f-93f8-90c7341a7f54	2018-03-02 06:11:49.669725-06	1	[21685] IC 218 Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
863608ef-d3db-4801-a6f0-2acc59c5c381	2018-03-02 06:12:38.990657-06	1	[21686] camera_left_lt_grey.png Copy (1)	[4] DLarrabee	[21062] a	\N	\N
d6d11aa6-3760-4747-96bc-1b99f7686545	2018-03-02 06:12:38.997657-06	1	[21687] camera_left_lt_grey.png Copy (2)	[4] DLarrabee	[21062] a	\N	\N
9dc21dab-230b-4959-857e-3e325352d097	2018-03-02 06:12:39.002658-06	1	[21688] camera_left_lt_grey.png Copy (3)	[4] DLarrabee	[21062] a	\N	\N
60df41d8-35eb-4a90-b205-e8134355116f	2018-03-02 06:12:39.008658-06	1	[21689] camera_left_lt_grey.png Copy (4)	[4] DLarrabee	[21062] a	\N	\N
eec56302-15a9-47f1-b381-64641081ea00	2018-03-02 06:12:39.011659-06	1	[21690] camera_left_lt_grey.png Copy (5)	[4] DLarrabee	[21062] a	\N	\N
6cbfa47b-4206-47c9-a745-8dfaaa369a68	2018-03-02 06:12:39.016659-06	1	[21691] camera_left_lt_grey.png Copy (6)	[4] DLarrabee	[21062] a	\N	\N
6a725245-079d-4ff1-baf5-5fa0ff872cda	2018-03-02 06:12:39.02166-06	1	[21692] camera_left_lt_grey.png Copy (7)	[4] DLarrabee	[21062] a	\N	\N
2f02281e-6021-4122-b94d-3d9c665b2684	2018-03-02 06:12:39.02666-06	1	[21693] camera_left_lt_grey.png Copy (8)	[4] DLarrabee	[21062] a	\N	\N
bc35aacb-22a2-4ca1-b3d9-0736fd0def7d	2018-03-02 06:12:39.031661-06	1	[21694] camera_left_lt_grey.png Copy (9)	[4] DLarrabee	[21062] a	\N	\N
30b4e1f7-f735-4ebc-9991-30de5a556dde	2018-03-02 06:12:39.035661-06	1	[21695] camera_left_lt_grey.png Copy (10)	[4] DLarrabee	[21062] a	\N	\N
6b5e162b-efb0-4593-9b1e-6f3f7c64c736	2018-03-02 06:12:39.040662-06	1	[21696] camera_left_lt_grey.png Copy (11)	[4] DLarrabee	[21062] a	\N	\N
14a85aca-8cc7-4771-a928-1b1f55e1af53	2018-03-02 06:12:39.044662-06	1	[21697] camera_left_lt_grey.png Copy (12)	[4] DLarrabee	[21062] a	\N	\N
c7349be4-594f-4a33-b772-c992ed8243e1	2018-03-02 06:12:39.049663-06	1	[21698] camera_left_lt_grey.png Copy (13)	[4] DLarrabee	[21062] a	\N	\N
4691aeb5-078d-4e46-b43c-b81a261471ef	2018-03-02 06:12:39.054663-06	1	[21699] camera_left_lt_grey.png Copy (14)	[4] DLarrabee	[21062] a	\N	\N
a9042204-450a-4b27-8966-048aecb41d51	2018-03-02 06:12:39.057663-06	1	[21700] camera_left_lt_grey.png Copy (15)	[4] DLarrabee	[21062] a	\N	\N
01e2bcb8-188a-4d81-a972-6e079834942d	2018-03-02 06:12:39.062664-06	1	[21701] camera_left_lt_grey.png Copy (16)	[4] DLarrabee	[21062] a	\N	\N
0948ecb4-0b83-4cea-a77e-211002c50141	2018-03-02 06:12:39.066664-06	1	[21702] camera_left_lt_grey.png Copy (17)	[4] DLarrabee	[21062] a	\N	\N
1c677598-dacb-44c5-b9cd-94702b389be0	2018-03-02 06:12:39.070665-06	1	[21703] camera_left_lt_grey.png Copy (18)	[4] DLarrabee	[21062] a	\N	\N
e9ab74da-e9b3-477f-b14b-502ede592ec8	2018-03-02 06:12:39.075665-06	1	[21704] camera_left_lt_grey.png Copy (19)	[4] DLarrabee	[21062] a	\N	\N
13ad5c78-3eb8-4967-b7ac-cb0f3d528e5c	2018-03-02 06:12:39.080666-06	1	[21705] camera_left_lt_grey.png Copy (20)	[4] DLarrabee	[21062] a	\N	\N
0c43ce6e-4ffc-476a-b2d6-00bb96796573	2018-03-02 06:12:39.084666-06	1	[21706] camera_left_lt_grey.png Copy (21)	[4] DLarrabee	[21062] a	\N	\N
dd41d11f-f5e2-453b-a4d5-ed3501e84a8c	2018-03-02 06:12:39.088666-06	1	[21707] camera_left_lt_grey.png Copy (22)	[4] DLarrabee	[21062] a	\N	\N
33268470-7c67-4ec2-b6d5-dcddd3b90d69	2018-03-02 06:12:39.092667-06	1	[21708] camera_left_lt_grey.png Copy (23)	[4] DLarrabee	[21062] a	\N	\N
271a3610-4730-45f9-b5a5-ea4e8cb7e1fa	2018-03-02 06:12:39.096667-06	1	[21709] camera_left_lt_grey.png Copy (24)	[4] DLarrabee	[21062] a	\N	\N
b55da865-491a-4ceb-8e6a-b6877b103cfa	2018-03-02 06:12:39.102668-06	1	[21710] camera_left_lt_grey.png Copy (25)	[4] DLarrabee	[21062] a	\N	\N
d189919a-614b-4408-a9d0-80811101be7a	2018-03-02 06:12:39.106668-06	1	[21711] camera_left_lt_grey.png Copy (26)	[4] DLarrabee	[21062] a	\N	\N
971ad079-c5b2-441c-bfbe-9c4cbe33bdd5	2018-03-02 06:12:39.110669-06	1	[21712] camera_left_lt_grey.png Copy (27)	[4] DLarrabee	[21062] a	\N	\N
14f911c3-e1a9-4fd8-91e7-84c2fe6d0a99	2018-03-02 06:12:39.115669-06	1	[21713] camera_left_lt_grey.png Copy (28)	[4] DLarrabee	[21062] a	\N	\N
4ba821a9-171c-4f2b-b85a-26e6d62b46ab	2018-03-02 06:16:57.567512-06	2	[21751] None	[4] DLarrabee	[21062] a	\N	\N
458e0ff6-515d-4d0d-88dc-b7b7d5d55140	2018-03-02 06:12:39.11967-06	1	[21714] camera_left_lt_grey.png Copy (29)	[4] DLarrabee	[21062] a	\N	\N
550ad685-c830-44be-8b1a-cabceca6e687	2018-03-02 06:13:45.181275-06	2	[21685] IC 219 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0140157a-3cbf-4356-8098-d914dd09ef59	2018-03-02 06:14:26.751432-06	1	[21715] IC 219  (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
29dc545a-ceff-4ca1-8c2d-b5d418a4cf77	2018-03-02 06:14:26.760433-06	1	[21716] IC 219  (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
05204b7f-3365-4833-8cee-971eaa3a40b1	2018-03-02 06:14:26.776434-06	1	[21717] IC 219  (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
e9478da5-6b8a-462d-a3eb-3b4bc9bb2280	2018-03-02 06:14:26.783435-06	1	[21718] IC 219  (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
2172099f-41d9-4336-8be2-8faa52688f82	2018-03-02 06:14:26.789435-06	1	[21719] IC 219  (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
b24488ec-0e12-49bb-9b15-c0782cdbacb5	2018-03-02 06:14:26.793436-06	1	[21720] IC 219  (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
643123ba-eb0b-4ad1-9904-948a2b98f845	2018-03-02 06:14:26.803437-06	1	[21721] IC 219  (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef89b2fa-5887-46da-8fd8-e819fdcc7162	2018-03-02 06:14:35.254282-06	1	[21722] A 1 MULTI-USE DINING 122 	[4] DLarrabee	[21062] a	\N	\N
5aa8e316-4559-41e7-9888-644622131325	2018-03-02 06:15:03.793135-06	2	[21715] IC 220	[21041] OSSI-DNOVAK	[293] master	\N	\N
c8e5fbec-4331-4a57-99ee-19cb700d6402	2018-03-02 06:15:14.797236-06	1	[21723] A 2 MULTI-USE DINING 122	[4] DLarrabee	[21062] a	\N	\N
d94125b0-2c64-4b52-bf0f-9c9294d6b480	2018-03-02 06:15:14.803236-06	1	[21724] A 3 MULTI-USE DINING 123	[4] DLarrabee	[21062] a	\N	\N
7bc4ff00-d3a1-468f-9aca-67372ff906a2	2018-03-02 06:15:14.809237-06	1	[21725] A 4 MULTI-USE DINING 123	[4] DLarrabee	[21062] a	\N	\N
6bbf2aa0-8dc2-4f60-a7e9-f8d3d1f3b5bb	2018-03-02 06:15:14.816238-06	1	[21726] A 5 LIVING ROOM 113	[4] DLarrabee	[21062] a	\N	\N
44019f05-4f34-4e10-b69c-e82146ec8653	2018-03-02 06:15:14.821238-06	1	[21727] A 6 LIVING ROOM 113 	[4] DLarrabee	[21062] a	\N	\N
f3b80332-4df5-4fb2-9d53-360738ddda7d	2018-03-02 06:15:14.832239-06	1	[21728] A 7 LIVING ROOM 113 	[4] DLarrabee	[21062] a	\N	\N
1eb1790c-6a36-485d-a100-2af9162cf6b4	2018-03-02 06:15:14.83824-06	1	[21729] A 8 LIVING ROOM 113	[4] DLarrabee	[21062] a	\N	\N
ddb335a1-4e8f-430e-81fd-0c90ea29012c	2018-03-02 06:15:14.846241-06	1	[21730] A 9 COURTYARD 114	[4] DLarrabee	[21062] a	\N	\N
f3e31f72-8e14-46b1-a02f-9bbb6e19f171	2018-03-02 06:15:14.852241-06	1	[21731] A 10 LIVING ROOM 133	[4] DLarrabee	[21062] a	\N	\N
7e6e72af-0681-44cd-9df4-2c12f456645d	2018-03-02 06:15:14.859242-06	1	[21732] A 11 LIVING ROOM 133	[4] DLarrabee	[21062] a	\N	\N
ae4d68b2-4c9a-45bf-ba2f-75ec4ecc7437	2018-03-02 06:15:14.864242-06	1	[21733] A 12 LIVING ROOM 133 	[4] DLarrabee	[21062] a	\N	\N
be56b538-034d-4846-a352-04286e31fb50	2018-03-02 06:15:14.869243-06	1	[21734] A 13 LIVING ROOM 133 	[4] DLarrabee	[21062] a	\N	\N
d7f30a2d-3ad5-4ac3-a8e1-e0bb7b795356	2018-03-02 06:15:14.875244-06	1	[21735] A 14 COURTYARD 134 	[4] DLarrabee	[21062] a	\N	\N
c5e8e37c-40ca-4e01-899a-5b7f443dadfb	2018-03-02 06:15:14.880244-06	1	[21736] A 15 COURTYARD 156	[4] DLarrabee	[21062] a	\N	\N
3fb2b89d-f773-4bd7-8776-c66fbfa7e3fb	2018-03-02 06:15:14.886245-06	1	[21737] A 16 COURTYARD 156	[4] DLarrabee	[21062] a	\N	\N
5cd798d3-ff2f-4e8e-8021-395a3ca94295	2018-03-02 06:15:14.892245-06	1	[21738] A 17 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
77c39090-593d-4330-b466-a00cabceb027	2018-03-02 06:15:14.897246-06	1	[21739] A 18 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
e0476bc9-bb4a-4d38-9f45-7c980e670af9	2018-03-02 06:15:14.902246-06	1	[21740] A 19 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
0f6640b3-212a-4767-861b-c292ebbe4c1f	2018-03-02 06:15:14.906247-06	1	[21741] A20 HALL 127	[4] DLarrabee	[21062] a	\N	\N
9f3dfd9c-7b83-4f02-87ef-cddc222817b8	2018-03-02 06:15:14.911247-06	1	[21742] A21 SINGLE SLEEPING 137	[4] DLarrabee	[21062] a	\N	\N
b7434494-6cd1-4e2b-bd58-31e3b3c7b383	2018-03-02 06:15:14.916248-06	1	[21743] A22 HALL 139	[4] DLarrabee	[21062] a	\N	\N
ad33834c-dfdb-4abc-a357-3d88995811ec	2018-03-02 06:15:14.921248-06	1	[21744] A23 ADA SLEEPING 125	[4] DLarrabee	[21062] a	\N	\N
8ec6d8c2-3c33-4834-bae4-a06b9019c134	2018-03-02 06:15:14.926249-06	1	[21745] A24 ADA SLEEPING 119	[4] DLarrabee	[21062] a	\N	\N
3f8b6a3e-9876-48f0-a364-47f0a04ac217	2018-03-02 06:15:14.931249-06	1	[21746] A25 HALL 118	[4] DLarrabee	[21062] a	\N	\N
c3ee6104-c9d3-4358-915c-d500ac4130d1	2018-03-02 06:15:14.93625-06	1	[21747] A26 HALL 106	[4] DLarrabee	[21062] a	\N	\N
dcb773dd-3cbf-43cb-95d1-1fb534e915fa	2018-03-02 06:15:14.94325-06	1	[21748] A27 SINGLE SLEEPING 103	[4] DLarrabee	[21062] a	\N	\N
fedc7f56-ce48-45a3-b5a5-db4d8600914b	2018-03-02 06:15:14.948251-06	1	[21749] A28 CALMING ROOM 146	[4] DLarrabee	[21062] a	\N	\N
7ca5a0cd-dfdd-492b-96ae-18059e32e1fb	2018-03-02 06:15:14.954251-06	1	[21750] A29 CALMING ROOM 145	[4] DLarrabee	[21062] a	\N	\N
6780141f-b8a5-41fd-ab83-60f7541dd589	2018-03-02 06:15:14.959252-06	1	[21751] None	[4] DLarrabee	[21062] a	\N	\N
cb245c8b-0747-43d7-9eff-f763a0e4a1f0	2018-03-02 06:15:26.179374-06	2	[21715] IC 221	[21041] OSSI-DNOVAK	[293] master	\N	\N
d3718c4e-fa2f-477c-a665-b2419135d2fd	2018-03-02 06:15:36.783434-06	2	[21716] IC 222	[21041] OSSI-DNOVAK	[293] master	\N	\N
bc3e9c8d-3e0a-4d38-ace1-51ad39859e0c	2018-03-02 06:15:58.855641-06	2	[21717] IC 223-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
e6e2b0ad-934f-44ff-99f3-2f25116cb645	2018-03-02 06:16:11.104866-06	2	[21718] IC 223-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
00d0d56a-a25a-4565-9bae-c2e9827b25ac	2018-03-02 06:16:23.579113-06	2	[21722] A 1 MULTI-USE DINING 122 	[4] DLarrabee	[21062] a	\N	\N
c02e8ab4-d6b9-432b-bcff-99c6f18b4e64	2018-03-02 06:16:38.842639-06	2	[21719] IC 224-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
7e8e815a-6a1a-4412-9eaa-22cf978ffdba	2018-03-02 06:16:55.030258-06	2	[21720] IC 224-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
854c2a27-734c-4e76-bdce-2e09a568a64f	2018-03-02 06:16:57.381493-06	2	[21723] A 2 MULTI-USE DINING 122	[4] DLarrabee	[21062] a	\N	\N
e50d3126-3420-4c09-b28d-1e301d22c2c0	2018-03-02 06:16:57.394494-06	2	[21724] A 3 MULTI-USE DINING 123	[4] DLarrabee	[21062] a	\N	\N
f64dda14-e20e-4ec4-b08f-236f9992fe82	2018-03-02 06:16:57.418497-06	2	[21725] A 4 MULTI-USE DINING 123	[4] DLarrabee	[21062] a	\N	\N
66fedf66-0e4d-4e46-97c2-36abe9a14aad	2018-03-02 06:16:57.424497-06	2	[21726] A 5 LIVING ROOM 113	[4] DLarrabee	[21062] a	\N	\N
e401cedb-f737-4b85-a490-cb8566e0bc8c	2018-03-02 06:16:57.430498-06	2	[21727] A 6 LIVING ROOM 113 	[4] DLarrabee	[21062] a	\N	\N
eaace27b-da46-498c-849a-e4a01b5bcbc0	2018-03-02 06:16:57.436499-06	2	[21733] A 12 LIVING ROOM 133 	[4] DLarrabee	[21062] a	\N	\N
53c2d4ed-c1ae-4104-85eb-325e4b39256a	2018-03-02 06:16:57.441499-06	2	[21732] A 11 LIVING ROOM 133	[4] DLarrabee	[21062] a	\N	\N
93bee2b1-0571-432d-b336-68d7f37fd367	2018-03-02 06:16:57.4465-06	2	[21731] A 10 LIVING ROOM 133	[4] DLarrabee	[21062] a	\N	\N
15ff76ab-b6d0-4708-9cd8-30a356c19cbe	2018-03-02 06:16:57.4525-06	2	[21730] A 9 COURTYARD 114	[4] DLarrabee	[21062] a	\N	\N
73e78551-45d9-4ae7-a233-dc40eda3bd0d	2018-03-02 06:16:57.458501-06	2	[21729] A 8 LIVING ROOM 113	[4] DLarrabee	[21062] a	\N	\N
75d54992-a586-4092-91b7-3ee17ee631f5	2018-03-02 06:16:57.464501-06	2	[21728] A 7 LIVING ROOM 113 	[4] DLarrabee	[21062] a	\N	\N
27ffb926-4e93-4434-9c2a-988599f60c66	2018-03-02 06:16:57.470502-06	2	[21734] A 13 LIVING ROOM 133 	[4] DLarrabee	[21062] a	\N	\N
877dbe60-1917-477f-b102-de3641faf53a	2018-03-02 06:16:57.475503-06	2	[21735] A 14 COURTYARD 134 	[4] DLarrabee	[21062] a	\N	\N
648da84a-b1ff-436a-99c0-a4dbbd6095fe	2018-03-02 06:16:57.480503-06	2	[21736] A 15 COURTYARD 156	[4] DLarrabee	[21062] a	\N	\N
594bcd0d-c7be-4793-a2e6-f00ab8206b1f	2018-03-02 06:16:57.486504-06	2	[21737] A 16 COURTYARD 156	[4] DLarrabee	[21062] a	\N	\N
a223716d-74b0-4d2d-8f10-eb60563e0c8c	2018-03-02 06:16:57.490504-06	2	[21738] A 17 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
8f63f550-c55a-4bd1-806a-74c1e5ba2938	2018-03-02 06:16:57.495505-06	2	[21739] A 18 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
b9e036f3-6c1e-47cc-8bbb-f73e3a21d755	2018-03-02 06:16:57.501505-06	2	[21745] A24 ADA SLEEPING 119	[4] DLarrabee	[21062] a	\N	\N
8ebda7c5-1d08-473c-beaf-3ef7e92b28d6	2018-03-02 06:16:57.507506-06	2	[21744] A23 ADA SLEEPING 125	[4] DLarrabee	[21062] a	\N	\N
f2895db7-6ce7-47e4-8594-d034359cfe8c	2018-03-02 06:16:57.512506-06	2	[21743] A22 HALL 139	[4] DLarrabee	[21062] a	\N	\N
57aad09c-d34d-4221-b0fb-3507d789043c	2018-03-02 06:16:57.518507-06	2	[21742] A21 SINGLE SLEEPING 137	[4] DLarrabee	[21062] a	\N	\N
03e38878-a672-46af-ab0c-c8dfcb983c7d	2018-03-02 06:16:57.525508-06	2	[21741] A20 HALL 127	[4] DLarrabee	[21062] a	\N	\N
e3900a45-b291-4f62-aa1c-aa3a83b395e6	2018-03-02 06:16:57.531508-06	2	[21740] A 19 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
b022635e-38c2-43e9-b694-325862badad0	2018-03-02 06:16:57.537509-06	2	[21746] A25 HALL 118	[4] DLarrabee	[21062] a	\N	\N
76acfeec-d6d0-4a29-b012-e2ce3be522f3	2018-03-02 06:16:57.543509-06	2	[21747] A26 HALL 106	[4] DLarrabee	[21062] a	\N	\N
6134bcda-c667-4bd1-83b5-79ac881bb8f4	2018-03-02 06:16:57.54951-06	2	[21748] A27 SINGLE SLEEPING 103	[4] DLarrabee	[21062] a	\N	\N
596b5ac8-2761-48b7-bc3c-2a0f868a14b1	2018-03-02 06:16:57.556511-06	2	[21749] A28 CALMING ROOM 146	[4] DLarrabee	[21062] a	\N	\N
e0e59482-f87c-4044-8508-f9037b67baf0	2018-03-02 06:16:57.562511-06	2	[21750] A29 CALMING ROOM 145	[4] DLarrabee	[21062] a	\N	\N
05ebeee4-867c-4965-aad2-afbe3103815c	2018-03-02 06:17:09.005655-06	2	[21723] A 2 MULTI-USE DINING 122	[4] DLarrabee	[21062] a	\N	\N
72553192-6230-4e6a-a17e-1166b80ba81d	2018-03-02 06:17:09.014656-06	2	[21724] A 3 MULTI-USE DINING 123	[4] DLarrabee	[21062] a	\N	\N
ceb66a56-69f1-4685-b68b-d47a8f4e29ac	2018-03-02 06:17:09.020657-06	2	[21725] A 4 MULTI-USE DINING 123	[4] DLarrabee	[21062] a	\N	\N
e76ebe1e-1b07-4bb7-9549-a158c335773d	2018-03-02 06:17:09.025657-06	2	[21726] A 5 LIVING ROOM 113	[4] DLarrabee	[21062] a	\N	\N
543d8be7-f151-4091-ac31-a27804775c45	2018-03-02 06:17:09.033658-06	2	[21727] A 6 LIVING ROOM 113 	[4] DLarrabee	[21062] a	\N	\N
85def069-a42d-4771-a962-f65829e05f52	2018-03-02 06:17:09.039659-06	2	[21733] A 12 LIVING ROOM 133 	[4] DLarrabee	[21062] a	\N	\N
260a9716-9530-4bf7-a097-4678084c4e83	2018-03-02 06:17:09.043659-06	2	[21732] A 11 LIVING ROOM 133	[4] DLarrabee	[21062] a	\N	\N
16bd4b63-7cf2-4b74-8ed2-0635ee4ea69d	2018-03-02 06:17:09.05066-06	2	[21731] A 10 LIVING ROOM 133	[4] DLarrabee	[21062] a	\N	\N
1a2668b8-4a38-470e-959c-09a490f1baf7	2018-03-02 06:17:09.05566-06	2	[21730] A 9 COURTYARD 114	[4] DLarrabee	[21062] a	\N	\N
a3bb5f2b-78f5-4633-b403-0daba416cfc0	2018-03-02 06:17:09.061661-06	2	[21729] A 8 LIVING ROOM 113	[4] DLarrabee	[21062] a	\N	\N
7c1c2087-d3e3-48cf-bf00-03791584eaa3	2018-03-02 06:17:09.066662-06	2	[21728] A 7 LIVING ROOM 113 	[4] DLarrabee	[21062] a	\N	\N
1c64769b-fa44-45aa-a3f7-d61ec39d8a3b	2018-03-02 06:17:09.071662-06	2	[21734] A 13 LIVING ROOM 133 	[4] DLarrabee	[21062] a	\N	\N
03a42d3e-3d5d-4c90-9160-642d90c49438	2018-03-02 06:17:09.078663-06	2	[21735] A 14 COURTYARD 134 	[4] DLarrabee	[21062] a	\N	\N
9a3bbf2b-76b0-4e5e-8b29-db22d21e20b1	2018-03-02 06:17:09.084663-06	2	[21736] A 15 COURTYARD 156	[4] DLarrabee	[21062] a	\N	\N
4cbd8912-8b6b-4ff0-a832-6016806638c9	2018-03-02 06:17:09.090664-06	2	[21737] A 16 COURTYARD 156	[4] DLarrabee	[21062] a	\N	\N
f2d2938c-32a5-40c3-8e02-5a4885705855	2018-03-02 06:17:09.096665-06	2	[21738] A 17 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
c9ac208e-c7eb-441c-8879-74ffbb2c9ca8	2018-03-02 06:17:09.101665-06	2	[21739] A 18 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
34b7109d-0ff8-4229-b88b-34ec51efe64a	2018-03-02 06:17:09.106666-06	2	[21745] A24 ADA SLEEPING 119	[4] DLarrabee	[21062] a	\N	\N
c1b728df-4047-40f5-83c9-80d41a578fab	2018-03-02 06:17:09.112666-06	2	[21744] A23 ADA SLEEPING 125	[4] DLarrabee	[21062] a	\N	\N
c2701eee-aa02-49ed-a21c-fe34c114dd44	2018-03-02 06:17:09.119667-06	2	[21743] A22 HALL 139	[4] DLarrabee	[21062] a	\N	\N
6e945f8b-f06d-4762-b51a-043413f259ba	2018-03-02 06:17:09.125667-06	2	[21742] A21 SINGLE SLEEPING 137	[4] DLarrabee	[21062] a	\N	\N
697a4e75-cdda-4522-83bf-ad7880c2c7c5	2018-03-02 06:17:09.131668-06	2	[21741] A20 HALL 127	[4] DLarrabee	[21062] a	\N	\N
d1a43e03-5a4c-4a06-88f8-d2c4f517f293	2018-03-02 06:17:09.136669-06	2	[21740] A 19 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
9affe453-ba69-4c98-97d2-49c0ee0859a6	2018-03-02 06:17:09.142669-06	2	[21746] A25 HALL 118	[4] DLarrabee	[21062] a	\N	\N
860c23fc-6404-44e1-ae43-104f252804d4	2018-03-02 06:17:09.14967-06	2	[21747] A26 HALL 106	[4] DLarrabee	[21062] a	\N	\N
edb0614b-3a11-45aa-9620-e6f7c220e93c	2018-03-02 06:17:09.15467-06	2	[21748] A27 SINGLE SLEEPING 103	[4] DLarrabee	[21062] a	\N	\N
76a487c3-9edc-4011-81b1-4d9e253b603d	2018-03-02 06:17:09.159671-06	2	[21749] A28 CALMING ROOM 146	[4] DLarrabee	[21062] a	\N	\N
8424faac-3170-4ac4-addf-c0cf35dcba6b	2018-03-02 06:17:09.164671-06	2	[21750] A29 CALMING ROOM 145	[4] DLarrabee	[21062] a	\N	\N
5197e8c7-cc20-4a0b-a7f0-277f990dc50a	2018-03-02 06:17:09.169672-06	2	[21751] None	[4] DLarrabee	[21062] a	\N	\N
d4696ac0-ef1d-47de-8202-1ce8a3101a5a	2018-03-02 06:17:12.936048-06	2	[21721] IC 225	[21041] OSSI-DNOVAK	[293] master	\N	\N
0bd6757e-1cd1-47e3-9884-6876c3823fc2	2018-03-02 06:17:17.582513-06	1	[21752] IC 225 Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
18908077-be31-475f-bc71-b00278ef165c	2018-03-02 06:17:18.04756-06	2	[21723] A 2 MULTI-USE DINING 122	[4] DLarrabee	[21062] a	\N	\N
60382e26-0813-45ca-962b-0e2423fb42fd	2018-03-02 06:17:18.05356-06	2	[21724] A 3 MULTI-USE DINING 123	[4] DLarrabee	[21062] a	\N	\N
7a3632ab-cfdf-4196-b1cf-0e47530fdb03	2018-03-02 06:17:18.059561-06	2	[21725] A 4 MULTI-USE DINING 123	[4] DLarrabee	[21062] a	\N	\N
f834f9d9-ddf3-4245-8726-9b5506a772aa	2018-03-02 06:17:18.072562-06	2	[21726] A 5 LIVING ROOM 113	[4] DLarrabee	[21062] a	\N	\N
68b367c3-1e91-4bcf-9d53-13e82cc58b1c	2018-03-02 06:17:18.080563-06	2	[21727] A 6 LIVING ROOM 113 	[4] DLarrabee	[21062] a	\N	\N
65c9f067-57f1-442f-a394-f62e39d62296	2018-03-02 06:17:18.086563-06	2	[21733] A 12 LIVING ROOM 133 	[4] DLarrabee	[21062] a	\N	\N
176f4c8c-e43f-4c62-be96-b1fc6abcdf7b	2018-03-02 06:17:18.093564-06	2	[21732] A 11 LIVING ROOM 133	[4] DLarrabee	[21062] a	\N	\N
d66d3bc0-ba25-4d90-82e3-3d28583cd43b	2018-03-02 06:17:18.099565-06	2	[21731] A 10 LIVING ROOM 133	[4] DLarrabee	[21062] a	\N	\N
a2079e15-3d56-4ae3-abf5-c10678c42b9a	2018-03-02 06:17:18.105565-06	2	[21730] A 9 COURTYARD 114	[4] DLarrabee	[21062] a	\N	\N
e232f9d3-9116-4006-860a-6b5b28802cd0	2018-03-02 06:17:18.111566-06	2	[21729] A 8 LIVING ROOM 113	[4] DLarrabee	[21062] a	\N	\N
1bbfae8b-9176-4540-8b6c-76cfbe6fe160	2018-03-02 06:17:18.117567-06	2	[21728] A 7 LIVING ROOM 113 	[4] DLarrabee	[21062] a	\N	\N
6aa616cd-01c0-4182-a5a1-671ddc9a0b33	2018-03-02 06:17:18.123567-06	2	[21734] A 13 LIVING ROOM 133 	[4] DLarrabee	[21062] a	\N	\N
d7de9e37-d64c-4dd1-8ca6-7764db79b27c	2018-03-02 06:17:18.128568-06	2	[21735] A 14 COURTYARD 134 	[4] DLarrabee	[21062] a	\N	\N
d10ec00b-0e0f-4410-8ac7-486086cb9398	2018-03-02 06:17:18.135568-06	2	[21736] A 15 COURTYARD 156	[4] DLarrabee	[21062] a	\N	\N
afdb45eb-1a6e-4dfd-9313-229d25fc286d	2018-03-02 06:17:18.141569-06	2	[21737] A 16 COURTYARD 156	[4] DLarrabee	[21062] a	\N	\N
05b1666f-877f-44f4-aec4-d0d8a4e0ed59	2018-03-02 06:17:18.14757-06	2	[21738] A 17 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
8fa539ef-2f96-46d3-9e9e-6665ce97b4a5	2018-03-02 06:17:18.15457-06	2	[21739] A 18 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
86a3aacc-cc03-4f55-a073-f1fd6f0f1b36	2018-03-02 06:17:18.159571-06	2	[21745] A24 ADA SLEEPING 119	[4] DLarrabee	[21062] a	\N	\N
bff3a5fe-0879-4db6-9e90-004480485bb4	2018-03-02 06:17:18.165571-06	2	[21744] A23 ADA SLEEPING 125	[4] DLarrabee	[21062] a	\N	\N
433eff8f-e20b-49bb-8c70-24ba6598a536	2018-03-02 06:17:18.171572-06	2	[21743] A22 HALL 139	[4] DLarrabee	[21062] a	\N	\N
686599cc-4c07-4439-bab9-5f81a4af4eff	2018-03-02 06:17:18.176572-06	2	[21742] A21 SINGLE SLEEPING 137	[4] DLarrabee	[21062] a	\N	\N
fb14bc35-9b7d-40f3-8837-5b59164403e8	2018-03-02 06:17:18.182573-06	2	[21741] A20 HALL 127	[4] DLarrabee	[21062] a	\N	\N
ba64574d-ba7b-4ece-82ae-fef690eb67e3	2018-03-02 06:17:18.188574-06	2	[21740] A 19 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
5b6b562d-18aa-4f1a-8499-363fddade0b0	2018-03-02 06:17:18.193574-06	2	[21746] A25 HALL 118	[4] DLarrabee	[21062] a	\N	\N
214423d0-0ff4-4280-a83d-bb060e4c37a1	2018-03-02 06:17:18.201575-06	2	[21747] A26 HALL 106	[4] DLarrabee	[21062] a	\N	\N
4ba2d0f4-d1c1-4c10-876e-512e4198de96	2018-03-02 06:17:18.206575-06	2	[21748] A27 SINGLE SLEEPING 103	[4] DLarrabee	[21062] a	\N	\N
03fb1938-8670-4653-af98-4d721d03bf4f	2018-03-02 06:17:18.212576-06	2	[21749] A28 CALMING ROOM 146	[4] DLarrabee	[21062] a	\N	\N
36070ee7-17bf-482b-bf6c-45db59a7d5c3	2018-03-02 06:17:18.217577-06	2	[21750] A29 CALMING ROOM 145	[4] DLarrabee	[21062] a	\N	\N
c21f721f-e69c-46c5-b67f-5a20d506bd6c	2018-03-02 06:17:18.221577-06	2	[21751] None	[4] DLarrabee	[21062] a	\N	\N
c6308009-c728-44be-b6a8-7dc65544c6ad	2018-03-02 06:17:54.310185-06	1	[21753] A 2 MULTI-USE DINING 122 (1)	[4] DLarrabee	[21062] a	\N	\N
c689da81-9917-4254-b49c-3b8eb91273a3	2018-03-02 06:17:54.324187-06	1	[21754] A 3 MULTI-USE DINING 123 (1)	[4] DLarrabee	[21062] a	\N	\N
ab7a5e67-dcc7-437d-8b32-7f93e28df269	2018-03-02 06:17:54.330187-06	1	[21755] A 4 MULTI-USE DINING 123 (1)	[4] DLarrabee	[21062] a	\N	\N
26026418-533f-47c7-b622-54c114e3e0cb	2018-03-02 06:17:54.336188-06	1	[21756] A 5 LIVING ROOM 113 (1)	[4] DLarrabee	[21062] a	\N	\N
e93e5d04-0b9a-4f3f-973c-9ed01cf404fb	2018-03-02 06:17:54.342189-06	1	[21757] A 6 LIVING ROOM 113  (1)	[4] DLarrabee	[21062] a	\N	\N
43327e55-5eee-4db8-8d79-3b8475f18275	2018-03-02 06:17:54.348189-06	1	[21758] A 7 LIVING ROOM 113  (1)	[4] DLarrabee	[21062] a	\N	\N
6ab162d2-3194-4bed-935f-94ee50075a08	2018-03-02 06:17:54.35819-06	1	[21759] A 8 LIVING ROOM 113 (1)	[4] DLarrabee	[21062] a	\N	\N
76600002-b8e7-4b07-b2dc-41b174eed055	2018-03-02 06:17:54.364191-06	1	[21760] A 9 COURTYARD 114 (1)	[4] DLarrabee	[21062] a	\N	\N
69e9bab7-4a3d-411a-8906-baee623f5a73	2018-03-02 06:17:54.370191-06	1	[21761] A 10 LIVING ROOM 133 (1)	[4] DLarrabee	[21062] a	\N	\N
920048a9-b0cb-452e-bb4d-65450e0b776a	2018-03-02 06:17:54.377192-06	1	[21762] A 11 LIVING ROOM 133 (1)	[4] DLarrabee	[21062] a	\N	\N
ad1b7ee7-c998-41ba-9356-d15abd1a6fd1	2018-03-02 06:17:54.382193-06	1	[21763] A 12 LIVING ROOM 133  (1)	[4] DLarrabee	[21062] a	\N	\N
dfebb7d7-cc36-467b-9d16-3f95149cd5c8	2018-03-02 06:17:54.387193-06	1	[21764] A 13 LIVING ROOM 133  (1)	[4] DLarrabee	[21062] a	\N	\N
df59d2f8-91c7-406e-8557-ff66ee4c1700	2018-03-02 06:17:54.394194-06	1	[21765] A 14 COURTYARD 134  (1)	[4] DLarrabee	[21062] a	\N	\N
a70be8b4-c6cf-490e-969d-781127f44ff8	2018-03-02 06:17:54.399194-06	1	[21766] A 15 COURTYARD 156 (1)	[4] DLarrabee	[21062] a	\N	\N
6fecc8f2-d7c2-4198-bb7f-16eb4112cf12	2018-03-02 06:17:54.404195-06	1	[21767] A 16 COURTYARD 156 (1)	[4] DLarrabee	[21062] a	\N	\N
a3f2ddb7-6d1e-4611-a604-d577975d0ba1	2018-03-02 06:17:54.410195-06	1	[21768] A 17 CORRIDOR 154 (1)	[4] DLarrabee	[21062] a	\N	\N
6228a1bb-fd43-4bd9-bb14-ca2b57229d0b	2018-03-02 06:17:54.429197-06	1	[21769] A 18 CORRIDOR 154 (1)	[4] DLarrabee	[21062] a	\N	\N
3b35ddd7-76b3-4d52-a6f3-f5d9d79b4bda	2018-03-02 06:17:54.433198-06	1	[21770] A 19 CORRIDOR 154 (1)	[4] DLarrabee	[21062] a	\N	\N
40675dd5-2741-4249-a603-02c3536bf974	2018-03-02 06:17:54.438198-06	1	[21771] A20 HALL 127 (1)	[4] DLarrabee	[21062] a	\N	\N
f8d3bbba-8d83-495d-8069-1e16738f8e61	2018-03-02 06:17:54.444199-06	1	[21772] A21 SINGLE SLEEPING 137 (1)	[4] DLarrabee	[21062] a	\N	\N
f628e04e-9ed2-44dd-a7f8-9ab0b6236d63	2018-03-02 06:17:54.448199-06	1	[21773] A22 HALL 139 (1)	[4] DLarrabee	[21062] a	\N	\N
395fbe4d-30ac-4448-b395-7b210cca3df6	2018-03-02 06:17:54.4532-06	1	[21774] A23 ADA SLEEPING 125 (1)	[4] DLarrabee	[21062] a	\N	\N
32980d0f-8e74-4f45-a806-17e6e53ff236	2018-03-02 06:17:54.4582-06	1	[21775] A24 ADA SLEEPING 119 (1)	[4] DLarrabee	[21062] a	\N	\N
d10fbfe9-b43a-47e8-9817-fdbf00dc67a2	2018-03-02 06:17:54.463201-06	1	[21776] A25 HALL 118 (1)	[4] DLarrabee	[21062] a	\N	\N
70569b5f-567f-4227-823f-fce22613d8d5	2018-03-02 06:17:54.468201-06	1	[21777] A26 HALL 106 (1)	[4] DLarrabee	[21062] a	\N	\N
278a4384-2e30-4873-81ae-559f699d8d73	2018-03-02 06:17:54.473202-06	1	[21778] A27 SINGLE SLEEPING 103 (1)	[4] DLarrabee	[21062] a	\N	\N
ff9a715d-61fc-4ec3-ba7d-da3aed5a9ecd	2018-03-02 06:17:54.478202-06	1	[21779] A28 CALMING ROOM 146 (1)	[4] DLarrabee	[21062] a	\N	\N
6ceb78de-98f5-4d75-bfe3-051ebf19922b	2018-03-02 06:17:54.484203-06	1	[21780] A29 CALMING ROOM 145 (1)	[4] DLarrabee	[21062] a	\N	\N
2647db0d-2887-4ed7-83b2-9c19fbcb1cd6	2018-03-02 06:17:54.489203-06	1	[21781] None (1)	[4] DLarrabee	[21062] a	\N	\N
3c1459cb-f7d8-4f2d-81b8-b785fba26557	2018-03-02 06:18:47.819536-06	2	[21752] IC 226	[21041] OSSI-DNOVAK	[293] master	\N	\N
1f8f82fa-3732-4a13-9dc4-a2f256753fe5	2018-03-02 06:19:40.890842-06	1	[21782] IC 226 (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
14353c79-a15a-4fd5-af90-ae51a24a443a	2018-03-02 06:19:40.899843-06	1	[21783] IC 226 (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
5b8a37fc-26f5-4b13-9f4b-fe3c591a7593	2018-03-02 06:19:40.905844-06	1	[21784] IC 226 (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
1940458a-0450-4aba-a8b1-1afa67e7d6bf	2018-03-02 06:19:40.911845-06	1	[21785] IC 226 (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
bf4d0597-abb7-4c43-a111-f1a3b83f51d5	2018-03-02 06:19:40.917845-06	1	[21786] IC 226 (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
6c21adb0-f555-4a7a-9b2b-5a2885151f70	2018-03-02 06:19:40.923846-06	1	[21787] IC 226 (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
b8bae916-6de4-4908-a6a1-4692fc52844f	2018-03-02 06:19:40.928846-06	1	[21788] IC 226 (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
977e7f16-d8a6-4c3f-8d08-0525b9b9dc23	2018-03-02 06:20:34.434196-06	3	[21179] Cameras	[4] DLarrabee	[21062] a	\N	\N
466c13d1-6e61-4dac-96c9-7359673e3a88	2018-03-02 06:20:35.039257-06	2	[21676] IC 209B-OutB	[4] DLarrabee	[21062] a	\N	\N
81ae95b1-46c3-47d0-ac78-3e07038a575a	2018-03-02 06:20:35.043257-06	2	[21677] IC 211B-InB 	[4] DLarrabee	[21062] a	\N	\N
f2221599-d90b-4117-85bd-525666cf3098	2018-03-02 06:20:35.048258-06	2	[21678] IC 211B-OutB	[4] DLarrabee	[21062] a	\N	\N
52043380-4261-43c7-95c9-0e3a05fb3f63	2018-03-02 06:20:35.054258-06	2	[21679] IC 213	[4] DLarrabee	[21062] a	\N	\N
78d850c9-4be7-4350-8bd8-0ee82b71a20d	2018-03-02 06:20:35.060259-06	2	[21680] IC 214	[4] DLarrabee	[21062] a	\N	\N
85c174f4-4169-4b14-b167-48e7d7f9b1ad	2018-03-02 06:20:35.065259-06	2	[21681] IC 215	[4] DLarrabee	[21062] a	\N	\N
d8e2bd79-876f-4904-98c6-dfdde684de49	2018-03-02 06:20:35.06926-06	2	[21682] IC 216	[4] DLarrabee	[21062] a	\N	\N
8790fd2a-9451-48c8-89aa-19f9dee30c54	2018-03-02 06:20:35.07326-06	2	[21683] IC 218	[4] DLarrabee	[21062] a	\N	\N
522da4bf-6e06-47fe-80d8-8664876c4246	2018-03-02 06:20:35.077261-06	2	[21685] IC 219 	[4] DLarrabee	[21062] a	\N	\N
3d224ae8-746d-4ad6-8a53-7515781e49ab	2018-03-02 06:20:35.081261-06	2	[21715] IC 221	[4] DLarrabee	[21062] a	\N	\N
a533d6f4-0ef3-4ddc-bf04-ccee21d84d1c	2018-03-02 06:20:35.086261-06	2	[21716] IC 222	[4] DLarrabee	[21062] a	\N	\N
43e4786f-a27e-4008-9479-36bfeaa2ceac	2018-03-02 06:20:35.089262-06	2	[21717] IC 223-InB	[4] DLarrabee	[21062] a	\N	\N
437ba451-cef4-4b9d-adf0-a5989d908772	2018-03-02 06:20:35.093262-06	2	[21718] IC 223-OutB	[4] DLarrabee	[21062] a	\N	\N
445ee21a-3f4b-47f5-a09f-1bda366c1564	2018-03-02 06:20:35.098263-06	2	[21719] IC 224-InB	[4] DLarrabee	[21062] a	\N	\N
01cdde3b-8e29-42e3-88f4-d97549084ad3	2018-03-02 06:20:35.102263-06	2	[21720] IC 224-OutB	[4] DLarrabee	[21062] a	\N	\N
03d1fff4-8174-44ac-a62d-de0e6465f8b8	2018-03-02 06:20:35.108264-06	2	[21721] IC 225	[4] DLarrabee	[21062] a	\N	\N
680a4c83-ba73-4035-ab73-f57366a72c8e	2018-03-02 06:20:35.111264-06	2	[21752] IC 226	[4] DLarrabee	[21062] a	\N	\N
6059b4f5-901b-4421-9041-d89a1837419d	2018-03-02 06:20:35.116264-06	2	[21782] IC 226 (1)	[4] DLarrabee	[21062] a	\N	\N
002b808e-7712-425b-9cf5-a99af2bd96fc	2018-03-02 06:20:35.121265-06	2	[21783] IC 226 (2)	[4] DLarrabee	[21062] a	\N	\N
2c68315d-5a6b-4eda-bcf9-1c6cd2d55d2b	2018-03-02 06:20:35.125265-06	2	[21784] IC 226 (3)	[4] DLarrabee	[21062] a	\N	\N
dfc4a201-4763-4fde-8be3-cab6853c2d8e	2018-03-02 06:20:35.129266-06	2	[21785] IC 226 (4)	[4] DLarrabee	[21062] a	\N	\N
6e873b92-1694-46e1-9c7e-328489f44c11	2018-03-02 06:20:35.134266-06	2	[21786] IC 226 (5)	[4] DLarrabee	[21062] a	\N	\N
2bc97755-69bf-4ae8-abea-13c3d753be62	2018-03-02 06:20:35.139267-06	2	[21787] IC 226 (6)	[4] DLarrabee	[21062] a	\N	\N
d7895fd7-c684-4f23-8524-6e84922f6c75	2018-03-02 06:20:35.143267-06	2	[21788] IC 226 (7)	[4] DLarrabee	[21062] a	\N	\N
7f55b1c9-d66a-46a7-84bc-a3fc37c58c92	2018-03-02 06:20:55.294282-06	1	[21179] New	[4] DLarrabee	[21062] a	\N	\N
a0ca9173-ee8b-4ac8-9041-ffb6caf0d2e9	2018-03-02 06:21:15.297282-06	2	[21179] Cameras	[4] DLarrabee	[21062] a	\N	\N
6cbe1d35-62c0-47c9-a666-d307c08d99e3	2018-03-02 06:21:22.012954-06	2	[21782] IC 227	[21041] OSSI-DNOVAK	[293] master	\N	\N
ba1661db-4aa3-496d-ac15-2df142d8b26a	2018-03-02 06:21:57.723524-06	2	[21783] IC 228	[21041] OSSI-DNOVAK	[293] master	\N	\N
213dfe2b-aa7e-4d61-862e-081d63b117a5	2018-03-02 06:22:09.362688-06	2	[21784] IC 231	[21041] OSSI-DNOVAK	[293] master	\N	\N
4b59d8d2-9306-441b-aece-bc33bd8923af	2018-03-02 06:22:19.4787-06	2	[21785] IC 232	[21041] OSSI-DNOVAK	[293] master	\N	\N
069f5ba0-9f26-4a51-8208-b536a81a9bb2	2018-03-02 06:22:32.87904-06	2	[21786] IC 233	[21041] OSSI-DNOVAK	[293] master	\N	\N
7a1b0523-cc18-4317-b946-7f7962208fb1	2018-03-02 06:22:43.620114-06	2	[21787] IC 235	[21041] OSSI-DNOVAK	[293] master	\N	\N
555c3efc-dcc0-49f1-b863-f21c9e7d4488	2018-03-02 06:23:06.506402-06	2	[21788] IC 236-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
b8360fdc-09ee-4bdc-8529-9d7db6721256	2018-03-02 06:23:32.273978-06	1	[21684] IC 236-InB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
7c24181b-4839-435f-8c32-bd0a1f02ae71	2018-03-02 06:24:01.273878-06	1	[21686] A 1 MULTI-USE DINING 122 	[4] DLarrabee	[21062] a	\N	\N
07d44e5c-9c06-4de2-b2ca-e867abcb5163	2018-03-02 06:24:44.144165-06	2	[21686] A 1 MULTI-USE DINING 122 	[4] DLarrabee	[21062] a	\N	\N
36db4270-237e-4a43-b89b-6c2253146d7a	2018-03-02 06:26:47.319481-06	2	[21684] IC 236-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
f8390f79-5d89-45c9-8d5a-f029ca789d11	2018-03-02 06:26:55.11326-06	1	[21687] A 2 MULTI-USE DINING 122	[4] DLarrabee	[21062] a	\N	\N
bcb1ad76-c602-40fe-9e8c-176466634e2e	2018-03-02 06:26:55.117261-06	1	[21688] A 3 MULTI-USE DINING 123	[4] DLarrabee	[21062] a	\N	\N
d99fcdcc-6034-4fd7-9a7b-080d784bfefb	2018-03-02 06:26:55.156265-06	1	[21689] A 4 MULTI-USE DINING 123	[4] DLarrabee	[21062] a	\N	\N
c5dc2eda-933e-4cf6-a259-60a474ed547e	2018-03-02 06:26:55.169266-06	1	[21690] A 5 LIVING ROOM 113	[4] DLarrabee	[21062] a	\N	\N
0b818a6c-5c54-45c4-8000-a8aefcdf3cb5	2018-03-02 06:26:55.173266-06	1	[21691] A 6 LIVING ROOM 113 	[4] DLarrabee	[21062] a	\N	\N
34a466cc-5032-4b5d-954f-1221a0c73327	2018-03-02 06:26:55.178267-06	1	[21692] A 7 LIVING ROOM 113 	[4] DLarrabee	[21062] a	\N	\N
3afccfae-25f8-48b4-9e95-393604d303c0	2018-03-02 06:26:55.183267-06	1	[21693] A 8 LIVING ROOM 113	[4] DLarrabee	[21062] a	\N	\N
1564c498-d6ac-4951-8aaa-f70616b8f83b	2018-03-02 06:26:55.189268-06	1	[21694] A 9 COURTYARD 114	[4] DLarrabee	[21062] a	\N	\N
24caa10a-dcb9-4afb-bafb-650b74276c85	2018-03-02 06:26:55.194268-06	1	[21695] A 10 LIVING ROOM 133	[4] DLarrabee	[21062] a	\N	\N
33430864-35af-4502-b4ea-651914cb968f	2018-03-02 06:26:55.200269-06	1	[21696] A 11 LIVING ROOM 133	[4] DLarrabee	[21062] a	\N	\N
eb576384-b97d-4771-99f1-9e4d7dd0c75e	2018-03-02 06:26:55.20527-06	1	[21697] A 12 LIVING ROOM 133 	[4] DLarrabee	[21062] a	\N	\N
b5845234-3411-47d6-8fa0-c0ae076b449e	2018-03-02 06:26:55.21127-06	1	[21698] A 13 LIVING ROOM 133 	[4] DLarrabee	[21062] a	\N	\N
af83ef39-8712-4f09-b9db-1b9a49855c56	2018-03-02 06:26:55.215271-06	1	[21699] A 14 COURTYARD 134 	[4] DLarrabee	[21062] a	\N	\N
1998658c-d8b9-46f6-95e1-c401f9aafd52	2018-03-02 06:26:55.222271-06	1	[21700] A 15 COURTYARD 156	[4] DLarrabee	[21062] a	\N	\N
32960c4e-eea2-4dae-877d-dbd80af60b5c	2018-03-02 06:26:55.228272-06	1	[21701] A 16 COURTYARD 156	[4] DLarrabee	[21062] a	\N	\N
4cc20f92-7bc5-4014-9f65-acc92cdff8f4	2018-03-02 06:26:55.234272-06	1	[21702] A 17 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
51e0a62b-57be-4334-988d-f83b58a27afc	2018-03-02 06:26:55.239273-06	1	[21703] A 18 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
4b40f203-c54e-4df3-81ba-3c1bf7736788	2018-03-02 06:26:55.245274-06	1	[21704] A 19 CORRIDOR 154	[4] DLarrabee	[21062] a	\N	\N
c618e48a-d132-478c-a9a4-d185f2e482ea	2018-03-02 06:26:55.250274-06	1	[21705] A20 HALL 127	[4] DLarrabee	[21062] a	\N	\N
02932e28-22e4-4adb-ae80-7d60fc0a9bb5	2018-03-02 06:26:55.256275-06	1	[21706] A21 SINGLE SLEEPING 137	[4] DLarrabee	[21062] a	\N	\N
6e35d922-4116-464b-840b-5d0a2334fe6c	2018-03-02 06:26:55.262275-06	1	[21707] A22 HALL 139	[4] DLarrabee	[21062] a	\N	\N
d5ddb1f8-4c13-48a9-9d3b-b54d78e5e00e	2018-03-02 06:26:55.268276-06	1	[21708] A23 ADA SLEEPING 125	[4] DLarrabee	[21062] a	\N	\N
9b1c92ab-39c2-4df9-8450-5056c7ba45a8	2018-03-02 06:26:55.274276-06	1	[21709] A24 ADA SLEEPING 119	[4] DLarrabee	[21062] a	\N	\N
5b63411e-fcf9-4293-a132-57e1bc14fbdc	2018-03-02 06:26:55.282277-06	1	[21710] A25 HALL 118	[4] DLarrabee	[21062] a	\N	\N
5f9e428f-d3f2-475f-bba8-be395825fb92	2018-03-02 06:26:55.288278-06	1	[21711] A26 HALL 106	[4] DLarrabee	[21062] a	\N	\N
39f68315-6ffa-404c-ae26-80a1568c3e53	2018-03-02 06:26:55.293278-06	1	[21712] A27 SINGLE SLEEPING 103	[4] DLarrabee	[21062] a	\N	\N
619ee79d-4814-40fb-a2ba-ff5b53d03060	2018-03-02 06:26:55.299279-06	1	[21713] A28 CALMING ROOM 146	[4] DLarrabee	[21062] a	\N	\N
3f0ad09e-393f-4722-8ae5-6796214ff367	2018-03-02 06:26:55.30528-06	1	[21714] A29 CALMING ROOM 145	[4] DLarrabee	[21062] a	\N	\N
d4c8c9f5-622d-465b-ab85-7f41f8e8a004	2018-03-02 06:26:55.30928-06	1	[21722] None	[4] DLarrabee	[21062] a	\N	\N
f42c4347-3f07-45d3-bcba-10c0b180146e	2018-03-02 06:27:37.824531-06	1	[21723] IC 236-OutB (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
fd8188ac-a411-4f7f-a84b-a773d5a3a5b0	2018-03-02 06:27:37.830532-06	1	[21724] IC 236-OutB (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
4a89aacc-f691-4d4c-9265-166d73059c01	2018-03-02 06:27:37.838532-06	1	[21725] IC 236-OutB (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
dad6304a-8db2-4a85-bcbb-e57ba5d03b74	2018-03-02 06:27:37.850534-06	1	[21726] IC 236-OutB (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
96b6b705-1ae7-47ed-bfac-487c8df85e0f	2018-03-02 06:27:37.855534-06	1	[21727] IC 236-OutB (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
7636b982-e9a5-4b14-80bb-f16630798f3c	2018-03-02 06:27:37.860535-06	1	[21728] IC 236-OutB (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
e140bd03-b0e3-42d5-a4d4-6806d151dae1	2018-03-02 06:27:37.866535-06	1	[21729] IC 236-OutB (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
c243d16f-5c6f-4da9-8e0e-6811b89da625	2018-03-02 06:27:50.5138-06	1	[21730] New Video Display	[4] DLarrabee	[21062] a	\N	\N
4bb3acb4-9032-4c56-bc37-338eb2ee7e24	2018-03-02 06:28:19.211669-06	2	[21723] IC 237-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
063e4128-e7b5-4140-9fd5-021503bda592	2018-03-02 06:28:31.991947-06	2	[21730] New Video Display	[4] DLarrabee	[21062] a	\N	\N
677d27c1-a9fe-4b53-8812-390e3bd37bdd	2018-03-02 06:28:34.962244-06	2	[21724] IC 237-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
f53325fb-1bfd-48d8-8b57-e8f61aefb6ab	2018-03-02 06:29:01.584906-06	2	[21725] IC 237B-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
cc215053-bc22-48ba-8aad-1d968a29e18a	2018-03-02 06:29:25.617309-06	2	[21725] IC 237B-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
b704f7db-71c3-42fc-813c-ea0fcc356d71	2018-03-02 06:29:41.644912-06	2	[21726] IC 237N-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
a56ce985-f618-4251-a484-52f1c4a0fb6a	2018-03-02 06:29:53.154063-06	2	[21727] IC 239	[21041] OSSI-DNOVAK	[293] master	\N	\N
c353523b-9c8e-4241-9939-15b7e88de73e	2018-03-02 06:30:02.365984-06	2	[21728] IC 241	[21041] OSSI-DNOVAK	[293] master	\N	\N
4696f098-1455-4c4e-ae9e-24dfccbb2cc2	2018-03-02 06:30:12.384986-06	2	[21729] IC 242	[21041] OSSI-DNOVAK	[293] master	\N	\N
cb171df3-65a9-4751-ab9e-d7f0feba1f29	2018-03-02 06:31:08.409587-06	1	[21731] New Digital Watchdog Driver	[4] DLarrabee	[21062] a	\N	\N
604ba2cb-5773-42e6-83b2-2d05b98463bc	2018-03-02 06:31:11.988945-06	2	[21731] New Digital Watchdog Driver	[4] DLarrabee	[21062] a	\N	\N
061d463b-dcb8-4027-9a13-9c82a3ffdc2f	2018-03-02 06:31:32.780024-06	1	[21732] New DW Spectrum NVR	[4] DLarrabee	[21062] a	\N	\N
0ab02d23-ef0b-49d6-9089-fd10256f1e49	2018-03-02 06:31:32.797026-06	2	[21731] New Digital Watchdog Driver	[4] DLarrabee	[21062] a	\N	\N
909c5d36-447e-407f-9536-6bd7a4bcb341	2018-03-02 06:36:23.027046-06	2	[21730] New Video Display	[4] DLarrabee	[21062] a	\N	\N
0be25910-ff51-49c0-b2b9-b0eaaf2cb9d2	2018-03-02 06:43:15.702309-06	2	[21730] New Video Display	[4] DLarrabee	[21062] a	\N	\N
4c25b3d3-58a3-4b33-9248-44e19c47acab	2018-03-02 06:44:21.223861-06	2	[21046] Tool 240x320.png	[4] DLarrabee	[21062] a	\N	\N
28f8496a-ad5b-400d-a193-82137e80c019	2018-03-02 06:45:25.407279-06	1	[21736] New	[4] DLarrabee	[21062] a	\N	\N
2aea9142-c182-4a22-95d6-33d4fa97f5bd	2018-03-02 06:46:07.111449-06	2	[21736] New	[4] DLarrabee	[21062] a	\N	\N
482b8e69-788f-431e-8737-0f2b52595490	2018-03-02 06:46:15.354273-06	1	[21737] IC 242 Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
4c3168d1-5da2-41e9-8a3a-377b24e860f6	2018-03-02 06:47:33.619099-06	2	[21736] New	[4] DLarrabee	[21062] a	\N	\N
11ff6f48-b2ac-498a-b799-520f6a8bc6f7	2018-03-02 06:47:49.302667-06	2	[21737] IC 243	[21041] OSSI-DNOVAK	[293] master	\N	\N
35751e89-48a3-4fd1-8380-227c6c8acaf8	2018-03-02 06:48:21.004837-06	1	[21738] IC 243 (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
3a7cb15e-e670-4587-8cce-9c9081a1ea1c	2018-03-02 06:48:21.009837-06	1	[21739] IC 243 (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
d8f5fd7b-362f-490c-870e-c17e4fa7dcba	2018-03-02 06:48:21.019838-06	1	[21740] IC 243 (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
d19d2ddc-d13f-4240-abe5-ba9ee7b60f55	2018-03-02 06:48:21.024839-06	1	[21741] IC 243 (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
86e97f94-9706-4184-a7c7-5c15aca21574	2018-03-02 06:48:21.03484-06	1	[21742] IC 243 (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
b7e47bf2-4bee-47e7-a776-d7e891505c41	2018-03-02 06:48:21.03984-06	1	[21743] IC 243 (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
24ca3bda-763a-4554-9a31-5146b848ec71	2018-03-02 06:48:21.046841-06	1	[21744] IC 243 (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
7e5d2b19-4562-4991-b51e-e968338452d0	2018-03-02 06:48:25.389275-06	2	[21736] New	[4] DLarrabee	[21062] a	\N	\N
05bea1bd-38e8-4370-89ea-798ed868002e	2018-03-02 06:48:38.795616-06	2	[21736] New	[4] DLarrabee	[21062] a	\N	\N
4c455b9b-feed-4971-87f3-bf5166a81a2d	2018-03-02 06:48:55.706306-06	2	[21738] IC 245	[21041] OSSI-DNOVAK	[293] master	\N	\N
66e8d28e-5e32-437a-921e-5409d0932c12	2018-03-02 06:49:05.455281-06	2	[21739] IC 246	[21041] OSSI-DNOVAK	[293] master	\N	\N
0fc35970-1aba-4574-988d-84aa5c563d37	2018-03-02 06:49:24.802216-06	2	[21740] IC 246-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
084b36fc-dabf-4ba3-bc6f-366d38aae782	2018-03-02 06:49:40.383774-06	2	[21736] New	[4] DLarrabee	[21062] a	\N	\N
8f2a0f60-5e80-4124-836a-b637f168c665	2018-03-02 06:49:41.922928-06	2	[21739] IC 246-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
c6f9b3d4-fecc-43ab-91f8-dd91e749be1f	2018-03-02 06:49:58.358571-06	2	[21736] New	[4] DLarrabee	[21062] a	\N	\N
8262695b-de55-40c1-b015-c68fc0bd19cc	2018-03-02 06:50:12.516987-06	2	[21736] New	[4] DLarrabee	[21062] a	\N	\N
2440da8f-f24d-440f-9876-8029deb8e203	2018-03-02 06:50:17.35347-06	2	[21741] IC 247-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
63ce9c6e-b1b3-4d11-ac33-5ce45a7ff230	2018-03-02 06:50:34.677203-06	2	[21742] IC 247-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
0123c529-10e9-4e54-b793-10918e7dddb1	2018-03-02 06:50:46.667401-06	2	[21743] IC 248-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
828197df-7622-4edf-b840-876df019698e	2018-03-02 06:50:58.717606-06	2	[21744] IC 248-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
afaefef3-db06-4666-b06a-60f3a2c2ffbb	2018-03-02 06:51:01.613896-06	2	[21736] New	[4] DLarrabee	[21062] a	\N	\N
b9d52e10-9635-47b5-8959-11d4ad399587	2018-03-02 06:51:41.35887-06	1	[21745] IC 248-OutB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
f3deeb99-fcf2-4a16-b841-2a0a504ad1da	2018-03-02 06:52:15.577292-06	2	[21736] New	[4] DLarrabee	[21062] a	\N	\N
8f93ceff-76bb-4d00-a44d-147ccbb58d90	2018-03-02 06:52:31.382872-06	2	[21476] A Cameras	[4] DLarrabee	[21062] a	\N	\N
36c1566e-a70c-400d-a656-d09f0d159e91	2018-03-02 06:53:17.360469-06	2	[21736] New	[4] DLarrabee	[21062] a	\N	\N
7267c3a4-9cc6-428a-b4ab-2ba1a5280f14	2018-03-02 06:53:34.321165-06	2	[21046] Tool 240x320.png	[4] DLarrabee	[21062] a	\N	\N
e68c8221-9c72-4d7e-838d-ce95f0bf2a2a	2018-03-02 06:53:43.764109-06	2	[21745] IC 252-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
b8663109-0a3d-4154-9e5a-1b83491416b7	2018-03-02 06:53:47.346468-06	2	[21736] New	[4] DLarrabee	[21062] a	\N	\N
a535cd92-4d17-4904-8641-dea4ae823075	2018-03-02 06:54:32.17995-06	1	[21746] IC 252-InB (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
604d5c7f-9628-4f9c-acd6-1da2cbb5d77b	2018-03-02 06:54:32.206953-06	1	[21747] IC 252-InB (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
10616024-bd22-45e0-a385-34d794cef23d	2018-03-02 06:54:32.214954-06	1	[21748] IC 252-InB (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef7ca1ed-d216-4acc-9ef4-bba1606507e5	2018-03-02 06:54:32.218954-06	1	[21749] IC 252-InB (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
80e0bcb7-2d00-4cbc-9ca4-237afd4b6080	2018-03-02 06:54:32.225955-06	1	[21750] IC 252-InB (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
6ce37df4-8b47-4dcb-8ff2-3f404ba7e51a	2018-03-02 06:54:32.229955-06	1	[21751] IC 252-InB (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
7505a34a-6dee-4b04-bc6a-ee05f242c5e7	2018-03-02 06:54:32.234956-06	1	[21753] IC 252-InB (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
60f40b92-e8a7-4a3c-b1c0-26119b21362d	2018-03-02 06:54:34.07714-06	2	[21736] New	[4] DLarrabee	[21062] a	\N	\N
2b4abba3-e579-4c6b-affc-e13fb984fe1b	2018-03-02 06:54:46.985431-06	2	[21736] New	[4] DLarrabee	[21062] a	\N	\N
9245c70d-8c0c-4773-9620-0116b88f0630	2018-03-02 06:54:54.202152-06	2	[21746] IC 252-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
840e534e-6a6a-41d1-987a-918845ec3155	2018-03-02 06:55:12.88402-06	2	[21736] New	[4] DLarrabee	[21062] a	\N	\N
b6a052a9-64e8-4163-b7e8-d74f0016d8ab	2018-03-02 06:55:39.220654-06	2	[21736] Camera Label Frame	[4] DLarrabee	[21062] a	\N	\N
0c3e4e0c-ae62-4c03-8ee1-f7b0a71e1785	2018-03-02 06:55:41.804912-06	2	[21747] IC 253-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
67a27ee2-d42b-4d58-88a0-690f00d0640d	2018-03-02 06:56:00.652797-06	2	[21748] IC 253-OutB 	[21041] OSSI-DNOVAK	[293] master	\N	\N
230c2674-14e9-4d3a-822e-cb139db926dc	2018-03-02 06:56:20.261758-06	2	[21749] IC 259-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
6689abb0-f9f3-4020-97da-2aad8a8434e0	2018-03-02 06:56:38.150546-06	2	[21750] IC 259-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
7df6414f-7dc5-4afb-ad64-0a31693f4674	2018-03-02 06:56:51.622893-06	2	[21751] IC 261-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
3b60ba61-d9e0-483b-b9bb-8ef4e2fdccfc	2018-03-02 06:57:07.558487-06	2	[21046] Video Frame	[4] DLarrabee	[21062] a	\N	\N
08b4a221-8441-45ea-b43f-504562bf99e7	2018-03-02 06:57:10.672798-06	2	[21753] IC 261-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
bb6e42fb-8617-4f89-90f2-fe6302a50d43	2018-03-02 06:57:39.058636-06	1	[21754] IC 261-OutB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
148ac760-bb88-4163-84ed-0183b316adcb	2018-03-02 06:57:46.074338-06	1	[21755] Video Frame	[4] DLarrabee	[21062] a	\N	\N
35a62dd2-551e-4647-87d1-012fc90f3f55	2018-03-02 06:57:50.846815-06	3	[21217] Tool 240x320.png	[4] DLarrabee	[21062] a	\N	\N
024050ff-8dec-4dc3-9ab9-efe466f8ec47	2018-03-02 06:57:51.09584-06	2	[21225] Nav Tool	[4] DLarrabee	[21062] a	\N	\N
2e67e996-40a3-4810-b99d-225895d7d33a	2018-03-02 06:57:51.09984-06	2	[21058] Main Button Tool	[4] DLarrabee	[21062] a	\N	\N
a099bf75-93fc-4a72-97ff-b07d6519fa8f	2018-03-02 06:57:51.114842-06	2	[21755] Video Frame	[4] DLarrabee	[21062] a	\N	\N
6cb111a4-4bb7-4393-96f1-bff521dd92f8	2018-03-02 06:58:00.732804-06	1	[21217] Video Frame	[4] DLarrabee	[21062] a	\N	\N
aa96066b-c311-44e6-b5cc-898aecfe6429	2018-03-02 06:58:05.385269-06	1	[21760] Video Frame	[4] DLarrabee	[21062] a	\N	\N
596bc0db-13d2-4968-bb52-49f750d03cd0	2018-03-02 06:58:13.463077-06	1	[21763] Video Frame	[4] DLarrabee	[21062] a	\N	\N
99838411-c549-4f56-a940-53dc628fcc93	2018-03-02 06:58:19.083639-06	3	[21232] Tool 240x320.png	[4] DLarrabee	[21062] a	\N	\N
3c9e4013-f4f1-43bc-8a04-8b1c0963b8f3	2018-03-02 06:58:19.350665-06	2	[21240] Nav Tool	[4] DLarrabee	[21062] a	\N	\N
a2a1e63a-e956-4c56-9435-2afdb6c00518	2018-03-02 06:58:19.354666-06	2	[21221] Main Button Tool	[4] DLarrabee	[21062] a	\N	\N
8600b460-4e52-4a2d-85da-f34914ef1a3a	2018-03-02 06:58:19.359666-06	2	[21217] Video Frame	[4] DLarrabee	[21062] a	\N	\N
f82429ac-f500-4eca-827c-78d3769d2858	2018-03-02 06:58:23.073037-06	3	[21246] Tool 240x320.png	[4] DLarrabee	[21062] a	\N	\N
a1de31bb-cfd1-4197-b52b-db8d1d0fd27b	2018-03-02 06:58:23.342064-06	2	[21254] Nav Tool	[4] DLarrabee	[21062] a	\N	\N
b09a495c-9a7b-44b5-9c3b-2521466636d5	2018-03-02 06:58:23.346065-06	2	[21234] Main Button Tool	[4] DLarrabee	[21062] a	\N	\N
36d0ddba-f651-4e47-a10f-3a9cd499a668	2018-03-02 06:58:23.353065-06	2	[21760] Video Frame	[4] DLarrabee	[21062] a	\N	\N
08d0beff-5eec-4bd8-a351-c08a63e682d2	2018-03-02 06:58:30.467777-06	3	[21261] Tool 240x320.png	[4] DLarrabee	[21062] a	\N	\N
e06a169b-a3f9-441a-8251-c360c8db6a55	2018-03-02 06:58:30.715802-06	2	[21269] Nav Tool	[4] DLarrabee	[21062] a	\N	\N
d356edef-b1f5-4c1e-9ae7-06735d128fb8	2018-03-02 06:58:30.723802-06	2	[21239] Main Button Tool	[4] DLarrabee	[21062] a	\N	\N
2170ddce-f9a2-4f26-83d2-9a055ad356e3	2018-03-02 06:58:30.727803-06	2	[21763] Video Frame	[4] DLarrabee	[21062] a	\N	\N
8290a101-4d27-46b6-b930-50ee306c3c82	2018-03-02 06:58:50.342764-06	2	[21754] IC 301A-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
5f9d8dbb-dc47-44e3-81ae-a1095352f001	2018-03-02 06:59:15.093239-06	1	[21232] IC 301A-InB (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
4213a942-8702-4901-8b5d-35c59d5c6e1d	2018-03-02 06:59:15.098239-06	1	[21246] IC 301A-InB (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
dbf31d48-e104-4b4e-b726-be2cd0bfcace	2018-03-02 06:59:15.10724-06	1	[21261] IC 301A-InB (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
5b5d4b43-32fc-4578-bf1b-0776d0c84df2	2018-03-02 06:59:15.114241-06	1	[21766] IC 301A-InB (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
3aab1f38-9c47-4118-a138-eab860411c40	2018-03-02 06:59:15.119242-06	1	[21767] IC 301A-InB (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
76f36fc3-d1bd-44dd-a3e4-addf5e38bd4a	2018-03-02 06:59:15.125242-06	1	[21768] IC 301A-InB (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
f0518e4d-7efa-4648-bcd9-194ad359589e	2018-03-02 06:59:15.129243-06	1	[21769] IC 301A-InB (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
0df6f77f-3152-459f-9ef7-a34a5bbf6e5b	2018-03-02 06:59:58.242553-06	2	[21232] IC 301A-OutB 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cb290cee-dc12-447d-bfc1-eba09e3845a0	2018-03-02 07:00:18.345564-06	2	[21246] IC 301B-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
ce3ecb00-9fed-480b-b38b-8894d95ce15f	2018-03-02 07:00:35.958325-06	2	[21261] IC 301B-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
e0e62184-3411-4b3b-8a8f-453100f8cb8a	2018-03-02 07:01:16.591388-06	2	[21766] IC 306B-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
c5fac1f6-837a-4091-859a-d4bafedc9e85	2018-03-02 07:01:35.087237-06	2	[21767] IC 306B-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
840da1c6-b711-488a-be70-659f1908645e	2018-03-02 07:01:53.303058-06	3	[21769] IC 301A-InB (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
8c7c0d16-bbc8-499a-97f5-6f743fae2e88	2018-03-02 07:01:57.077436-06	3	[21768] IC 301A-InB (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
b639affb-8834-4acf-b7d2-9af4c832bf9c	2018-03-02 07:06:40.729798-06	2	[21471] IC 209B-inB	[21041] OSSI-DNOVAK	[293] master	\N	\N
8cd42fc4-6684-4fd2-802f-0ec43a9fd390	2018-03-02 07:17:24.602179-06	1	[21768] IC 337A Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
49889e78-72a2-4e1c-bd05-3f5c186471a0	2018-03-02 07:17:30.997818-06	3	[21768] IC 337A Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
323a0759-6e1f-4ac8-a1f6-bd0cdb037538	2018-03-02 07:23:10.583774-06	2	[21231] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
79a4ccfd-f9f3-4966-978c-9663e16fa492	2018-03-02 07:26:42.276941-06	2	[21231] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
7f53c618-dbf4-4908-9af4-34f164d5afeb	2018-03-02 07:31:46.233333-06	1	[21768] IC 344A-outB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
e2017589-4735-4b09-ad12-31b9091d74b3	2018-03-02 07:31:52.769987-06	1	[21769] IC 344A-outB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
9bd3b027-8d25-46e2-ba45-e8e8c15f8e2f	2018-03-02 07:31:56.609371-06	1	[21770] IC 344A-outB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
705a6dff-6edb-4f31-b9b0-b38170abf69b	2018-03-02 07:32:18.865596-06	1	[21771] IC 344A-outB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
b19c8612-3ea7-49a6-8dcf-a75bb067fc09	2018-03-02 07:32:32.793989-06	1	[21772] IC 337A Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
c3ef81fc-ad4b-476c-a44d-5fbe79627444	2018-03-02 07:33:23.852094-06	3	[21772] IC 337A Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
8bf67719-04c6-40c2-bb40-5d77935487d6	2018-03-02 07:33:27.050414-06	3	[21771] IC 344A-outB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
075a4460-0991-4f01-a0e2-1208d93c9114	2018-03-02 07:33:30.000709-06	3	[21770] IC 344A-outB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
53b13269-ea9b-474e-a55e-fb782707c277	2018-03-02 07:33:33.036013-06	3	[21769] IC 344A-outB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
97850c4a-3580-42d2-a210-f49c6cb67a7f	2018-03-02 07:34:55.493258-06	2	[21768] IC 307-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
ce341167-5c78-4b3d-9504-9804024f884e	2018-03-02 07:35:18.583566-06	1	[21769] IC 307-InB (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
24df59da-1f5b-4b15-b4a9-608c7929da56	2018-03-02 07:35:18.587567-06	1	[21770] IC 307-InB (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
4c75b2e4-c454-4e15-b23e-fba7b8da07a4	2018-03-02 07:35:18.592567-06	1	[21771] IC 307-InB (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
5811b59d-ad16-4a77-9bef-cf411bc422da	2018-03-02 07:35:18.597568-06	1	[21772] IC 307-InB (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
d363e859-f43b-4e7d-8a7d-9bbcdfee0687	2018-03-02 07:35:18.600568-06	1	[21773] IC 307-InB (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
9967a030-56bc-4b77-9307-d202174aa0ac	2018-03-02 07:35:18.605569-06	1	[21774] IC 307-InB (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
19b8e861-eace-4e65-9f03-7c58b2e61ce9	2018-03-02 07:35:18.608569-06	1	[21775] IC 307-InB (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
0910341e-23e4-485d-a4f5-c0e03b096928	2018-03-02 07:35:40.271735-06	2	[21768] IC 307-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
75a21aaa-37f8-4718-aec4-58dc50bf0dd4	2018-03-02 07:36:26.670374-06	2	[21222] View IC Control	[21041] OSSI-DNOVAK	[293] master	\N	\N
fc1c9330-6eb8-4b32-abc6-7d2d9032651b	2018-03-02 09:03:57.797435-06	2	[21952] 215	[4] DLarrabee	[293] master	\N	\N
2cbc4093-95d7-49a6-8a35-2220af797963	2018-03-02 07:37:21.702877-06	2	[21222] View IC Control	[21041] OSSI-DNOVAK	[293] master	\N	\N
766c3133-2878-4b2f-89c1-c2df4d929a80	2018-03-02 07:37:52.547961-06	2	[21222] View IC Control	[21041] OSSI-DNOVAK	[293] master	\N	\N
dda0cd0c-2eb5-465e-bf72-c436041f989b	2018-03-02 07:38:30.591765-06	2	[21769] IC 307-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
4033e21e-e61f-4804-b81c-59a2cd8b7fea	2018-03-02 07:38:44.111117-06	2	[21770] IC 309-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
28599943-2bfd-4f65-81a9-b4ac50d0486f	2018-03-02 07:39:00.448751-06	1	[21776] B 1 LIVING ROOM 211	[4] DLarrabee	[293] master	\N	\N
cb5a0b04-4ec1-4b08-be51-d36debb5baa9	2018-03-02 07:39:02.527959-06	2	[21771] IC 309-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
61c9279f-d1e3-4e22-ada0-3942fee795c0	2018-03-02 07:39:15.74328-06	2	[21772] IC 314-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
8f310d8c-38f5-4a98-beab-3f199fa20937	2018-03-02 07:39:29.522658-06	2	[21773] IC 314-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
5c8b5706-81ef-4437-a321-a60ffc73761c	2018-03-02 07:39:45.471252-06	2	[21776] B 1 LIVING ROOM 211	[4] DLarrabee	[293] master	\N	\N
fd6623d8-63b5-4ca2-b308-a32f9552d8ff	2018-03-02 07:39:48.939599-06	2	[21774] IC 322-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
683cd679-b965-46b6-9442-eb9876e6f76f	2018-03-02 07:40:03.884094-06	2	[21775] IC 322-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
0e20eac2-29fe-4be1-9bd0-fd4823e02c6a	2018-03-02 07:40:10.008706-06	1	[21777] IC 322-OutB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
f2c59df4-07c3-45c9-9ddd-2fae26a00075	2018-03-02 07:40:23.517057-06	1	[21778] B 1 LIVING ROOM 211 Copy	[4] DLarrabee	[293] master	\N	\N
e0f574a0-7962-479d-91c8-086966fd992f	2018-03-02 07:40:49.869692-06	2	[21776] Cameras	[4] DLarrabee	[293] master	\N	\N
48413018-860e-4b30-8c3a-e7eaecdd8847	2018-03-02 07:41:20.776782-06	2	[21778] B 1 LIVING ROOM 211 Copy	[4] DLarrabee	[293] master	\N	\N
6e54b8d9-db64-4c0d-88a6-b6158321533c	2018-03-02 07:41:38.35954-06	2	[21777] IC 324-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
72397550-6bb8-411f-a4fc-86373a91ba5a	2018-03-02 07:41:44.378142-06	1	[21779] B 1 LIVING ROOM 211 Copy (1)	[4] DLarrabee	[293] master	\N	\N
f5cb1a26-df78-4578-8504-e29f07285ed8	2018-03-02 07:41:44.383142-06	1	[21780] B 1 LIVING ROOM 211 Copy (2)	[4] DLarrabee	[293] master	\N	\N
308ab6f2-5039-4a8b-a84d-42f7fd6aa6e3	2018-03-02 07:41:44.392143-06	1	[21781] B 1 LIVING ROOM 211 Copy (3)	[4] DLarrabee	[293] master	\N	\N
6ee17021-e533-4b85-9001-d45932069540	2018-03-02 07:41:44.399144-06	1	[21789] B 1 LIVING ROOM 211 Copy (4)	[4] DLarrabee	[293] master	\N	\N
187054ea-a2c5-4d44-a5f1-a7e3fa8b2ec7	2018-03-02 07:41:44.409145-06	1	[21790] B 1 LIVING ROOM 211 Copy (5)	[4] DLarrabee	[293] master	\N	\N
e767f7f3-2b90-4070-8d1e-4fe4ab9065dc	2018-03-02 07:41:44.416146-06	1	[21791] B 1 LIVING ROOM 211 Copy (6)	[4] DLarrabee	[293] master	\N	\N
eae1354f-def6-42bb-83b7-004db5313101	2018-03-02 07:41:44.423146-06	1	[21792] B 1 LIVING ROOM 211 Copy (7)	[4] DLarrabee	[293] master	\N	\N
c9bf57aa-7d0a-42d4-9493-9e3346a7fec0	2018-03-02 07:41:44.427147-06	1	[21793] B 1 LIVING ROOM 211 Copy (8)	[4] DLarrabee	[293] master	\N	\N
bb955654-d5b1-4465-b24a-be7c0a421ab0	2018-03-02 07:41:44.431147-06	1	[21794] B 1 LIVING ROOM 211 Copy (9)	[4] DLarrabee	[293] master	\N	\N
b62a7010-333a-4f49-88c4-47f55077a29b	2018-03-02 07:41:44.437148-06	1	[21795] B 1 LIVING ROOM 211 Copy (10)	[4] DLarrabee	[293] master	\N	\N
7864a285-7f08-4395-bade-098e8e9e12c9	2018-03-02 07:41:44.441148-06	1	[21796] B 1 LIVING ROOM 211 Copy (11)	[4] DLarrabee	[293] master	\N	\N
2a8708b3-c68c-47f3-984c-49503ee450bd	2018-03-02 07:41:44.446149-06	1	[21797] B 1 LIVING ROOM 211 Copy (12)	[4] DLarrabee	[293] master	\N	\N
deea172f-f923-4da3-8197-6a9300db2ed2	2018-03-02 07:41:44.452149-06	1	[21798] B 1 LIVING ROOM 211 Copy (13)	[4] DLarrabee	[293] master	\N	\N
84b335d2-fac5-4035-87cb-46ae94079f10	2018-03-02 07:41:44.45815-06	1	[21799] B 1 LIVING ROOM 211 Copy (14)	[4] DLarrabee	[293] master	\N	\N
e9bc7811-dc8e-41e4-a2b1-591163413dd8	2018-03-02 07:41:44.464151-06	1	[21800] B 1 LIVING ROOM 211 Copy (15)	[4] DLarrabee	[293] master	\N	\N
a5281c84-0291-4d33-95d0-f4b8cb296791	2018-03-02 07:41:44.473151-06	1	[21801] B 1 LIVING ROOM 211 Copy (16)	[4] DLarrabee	[293] master	\N	\N
9f1e3c03-634a-468d-a484-93e6e1b34f3c	2018-03-02 07:41:44.491153-06	1	[21802] B 1 LIVING ROOM 211 Copy (17)	[4] DLarrabee	[293] master	\N	\N
dd7fb031-fdfd-45a9-b5fa-0bad8240610a	2018-03-02 07:41:44.496154-06	1	[21803] B 1 LIVING ROOM 211 Copy (18)	[4] DLarrabee	[293] master	\N	\N
560992ca-21c8-46ea-aa4c-afbd2cae5a0d	2018-03-02 07:41:44.503154-06	1	[21804] B 1 LIVING ROOM 211 Copy (19)	[4] DLarrabee	[293] master	\N	\N
3d21e3bf-d8e2-41fd-968b-e3ac0f0006bc	2018-03-02 07:41:44.508155-06	1	[21805] B 1 LIVING ROOM 211 Copy (20)	[4] DLarrabee	[293] master	\N	\N
3e67ef74-c2a9-4f8c-bc50-c868400e3ee7	2018-03-02 07:41:44.513155-06	1	[21806] B 1 LIVING ROOM 211 Copy (21)	[4] DLarrabee	[293] master	\N	\N
606d2e97-8a53-438d-b941-91e492cacafa	2018-03-02 07:41:44.520156-06	1	[21807] B 1 LIVING ROOM 211 Copy (22)	[4] DLarrabee	[293] master	\N	\N
fec074c1-89a7-4135-a132-2e3691f95d7e	2018-03-02 07:41:44.526157-06	1	[21808] B 1 LIVING ROOM 211 Copy (23)	[4] DLarrabee	[293] master	\N	\N
1a56b358-309d-4260-b7bf-a2f1e004b91a	2018-03-02 07:41:44.531157-06	1	[21809] B 1 LIVING ROOM 211 Copy (24)	[4] DLarrabee	[293] master	\N	\N
97b11e59-befa-4b98-b1e9-efd2f240fca7	2018-03-02 07:41:44.535158-06	1	[21810] B 1 LIVING ROOM 211 Copy (25)	[4] DLarrabee	[293] master	\N	\N
7374b022-3b5c-4957-8b1c-d5413f5c9d95	2018-03-02 07:41:44.541158-06	1	[21811] B 1 LIVING ROOM 211 Copy (26)	[4] DLarrabee	[293] master	\N	\N
57d5ff42-2953-4133-bbf9-8ddb1286b04a	2018-03-02 07:41:44.546159-06	1	[21812] B 1 LIVING ROOM 211 Copy (27)	[4] DLarrabee	[293] master	\N	\N
1afef730-46c9-47ea-b597-1514d2a718a0	2018-03-02 07:41:44.551159-06	1	[21813] B 1 LIVING ROOM 211 Copy (28)	[4] DLarrabee	[293] master	\N	\N
e62a73cc-1da2-46ee-a412-880ba98a7a0e	2018-03-02 07:41:44.55616-06	1	[21814] B 1 LIVING ROOM 211 Copy (29)	[4] DLarrabee	[293] master	\N	\N
5333ad01-a243-46b4-af78-2445e3be61a2	2018-03-02 07:41:44.56216-06	1	[21815] B 1 LIVING ROOM 211 Copy (30)	[4] DLarrabee	[293] master	\N	\N
898d9621-b3b9-4687-8df4-b557622ce573	2018-03-02 07:42:13.000004-06	1	[21816] IC 324-InB (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
e2da0c91-813c-48d4-aafc-6ed70e974d14	2018-03-02 07:42:13.005004-06	1	[21817] IC 324-InB (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
5fd190ff-f95c-4f3f-adb6-6eaf195a6537	2018-03-02 07:42:13.010005-06	1	[21818] IC 324-InB (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
8308b1ce-1011-492e-b515-d8b0cd3e32f8	2018-03-02 07:42:13.014005-06	1	[21819] IC 324-InB (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
31096ac7-7adf-447f-894d-86be80c11ec5	2018-03-02 07:42:13.018006-06	1	[21820] IC 324-InB (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
f2df7570-de26-4002-99fb-c51d04541594	2018-03-02 07:42:13.021006-06	1	[21821] IC 324-InB (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
a40bc6e1-2f6a-4f37-9526-0a19e3c3079d	2018-03-02 07:42:13.026006-06	1	[21822] IC 324-InB (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
963c5caf-6c35-4863-8e91-c58ceb279721	2018-03-02 07:42:24.721176-06	1	[21823] New	[4] DLarrabee	[293] master	\N	\N
8e62b07f-3684-4c4f-b25b-616e5417ad91	2018-03-02 07:42:32.547958-06	2	[21823] New	[4] DLarrabee	[293] master	\N	\N
fabda9ef-1269-4d71-8eb0-0d2ef5100061	2018-03-02 07:43:10.803784-06	2	[21816] IC 324-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
39099994-2ec2-42d9-88bc-995e2afc6b38	2018-03-02 07:43:15.430246-06	2	[21823] Cameras	[4] DLarrabee	[293] master	\N	\N
159a395a-36cd-4b3a-8e55-1cc1a2bf6184	2018-03-02 07:43:27.488452-06	2	[21817] IC 324B-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
b9eeab93-5e27-42c6-b9f2-57e96af039af	2018-03-02 07:43:31.899893-06	1	[21824] C 1 VEHICLE SALLY PORT 324	[4] DLarrabee	[293] master	\N	\N
bd112c00-8409-45a2-8eb1-da3d1f81f7cd	2018-03-02 07:43:35.518255-06	2	[21816] IC 324A-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
974100c3-2868-4e22-8bce-0db0e4d93f2a	2018-03-02 07:43:43.192022-06	2	[21777] IC 324A-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
e712f1aa-764c-4d77-914c-0ee2126fef01	2018-03-02 07:44:07.536456-06	2	[21818] IC 324-CInB	[21041] OSSI-DNOVAK	[293] master	\N	\N
14a13d30-5d75-4e12-95b1-548f18b7f56a	2018-03-02 07:44:16.095312-06	2	[21824] C 1 VEHICLE SALLY PORT 324	[4] DLarrabee	[293] master	\N	\N
9427c959-ba03-462f-b2be-bbb14b7dafd9	2018-03-02 07:44:27.469449-06	2	[21819] IC 324C-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef115ab0-95ab-46af-a56c-673b0038a247	2018-03-02 07:44:49.644667-06	2	[21820] IC 333-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
170b8067-1ea4-4006-8dd2-304f8f6bb05c	2018-03-02 07:44:59.107613-06	1	[21825] C 2 VEHICLE SALLY PORT 324	[4] DLarrabee	[293] master	\N	\N
54915b7c-1eca-443a-9b9a-3d5b61e9e6c8	2018-03-02 07:44:59.115614-06	1	[21826] C 3 INTAKE 	[4] DLarrabee	[293] master	\N	\N
7909748a-539a-4a26-8ccd-16e3b707530c	2018-03-02 07:44:59.122614-06	1	[21827] C 4 INTAKE	[4] DLarrabee	[293] master	\N	\N
8d91aedd-726c-4a37-93d6-2f8c440a31ba	2018-03-02 07:44:59.126615-06	1	[21828] C 5 INTAKE 	[4] DLarrabee	[293] master	\N	\N
e6fcb1c9-b8b6-4839-a9d5-e16a5f079c41	2018-03-02 07:44:59.130615-06	1	[21829] C 6 INTAKE	[4] DLarrabee	[293] master	\N	\N
df0d01ac-db15-401b-9680-20bf41749c55	2018-03-02 07:44:59.135616-06	1	[21830] C 7 GROUP MALE 	[4] DLarrabee	[293] master	\N	\N
3a1863d8-a123-41cb-a216-f51a6c6c1190	2018-03-02 07:44:59.140616-06	1	[21831] C 8 GROUP FEMALE	[4] DLarrabee	[293] master	\N	\N
88970de5-0010-4565-9731-fbda79a51f50	2018-03-02 07:44:59.145617-06	1	[21832] C 9 INTAKE SINGLE 343	[4] DLarrabee	[293] master	\N	\N
526d2638-f224-4989-b42a-e04c58beb959	2018-03-02 07:44:59.148617-06	1	[21833] C 10 INTAKE SINGLE 346	[4] DLarrabee	[293] master	\N	\N
186484a5-20a3-4e29-b031-fef3337f5e13	2018-03-02 07:44:59.152617-06	1	[21834] C 11 YOUTH SHOWER 347 	[4] DLarrabee	[293] master	\N	\N
3d928ce9-26dc-4b95-b863-b70cf00b9272	2018-03-02 07:44:59.159618-06	1	[21835] C 12 YOUTH SHOWER 348 	[4] DLarrabee	[293] master	\N	\N
bac6b9a1-bc6d-4c43-851f-9e299f542ee0	2018-03-02 07:44:59.164619-06	1	[21836] C 13 HALL 326	[4] DLarrabee	[293] master	\N	\N
56f1e419-9df8-4171-a77d-8eb50aaf9c70	2018-03-02 07:44:59.17362-06	1	[21837] C 14 HALL 326 	[4] DLarrabee	[293] master	\N	\N
9730a0c8-a931-47ee-994a-8ecbbbc4090e	2018-03-02 07:44:59.186621-06	1	[21838] C 15 CORRIDOR 327 	[4] DLarrabee	[293] master	\N	\N
e862b21a-ce21-4671-8864-2598cf8575a3	2018-03-02 07:44:59.192621-06	1	[21839] C 16 CORRIDOR 327 	[4] DLarrabee	[293] master	\N	\N
86458845-de44-41a1-b651-bab77648126e	2018-03-02 07:44:59.196622-06	1	[21840] C 17 CORRIDOR 308	[4] DLarrabee	[293] master	\N	\N
a920b4c3-e8ea-4224-a8b6-ac9d52833c63	2018-03-02 07:44:59.201622-06	1	[21841] C 18 CORRIDOR 308	[4] DLarrabee	[293] master	\N	\N
2824ca65-dd0a-4128-b622-70da93752bc5	2018-03-02 07:44:59.207623-06	1	[21842] C 19 CORRIDOR 308 	[4] DLarrabee	[293] master	\N	\N
1d546332-a0d0-425b-994c-c2b00634bb8e	2018-03-02 07:44:59.212623-06	1	[21843] C 20 CORRIDOR 308	[4] DLarrabee	[293] master	\N	\N
c5b03255-c6ce-4f97-9292-b9a823a56e32	2018-03-02 07:44:59.217624-06	1	[21844] C 21 CORRIDOR 352 	[4] DLarrabee	[293] master	\N	\N
ba76140d-bd2f-4d26-ab17-c73d8d9a09b3	2018-03-02 07:44:59.221624-06	1	[21845] C 22 CORRIDOR 352	[4] DLarrabee	[293] master	\N	\N
94f53fea-dd9c-4e05-881c-f06de17e6880	2018-03-02 07:44:59.226625-06	1	[21846] C 23 HALL 378 	[4] DLarrabee	[293] master	\N	\N
de3e62b5-2d9b-4f0d-a8fa-d970e36e155f	2018-03-02 07:44:59.231625-06	1	[21847] C 24 HALL 378	[4] DLarrabee	[293] master	\N	\N
ec6be76c-8a30-4ff9-8c1f-26a70170f31c	2018-03-02 07:44:59.238626-06	1	[21848] C 25 HALL 378 	[4] DLarrabee	[293] master	\N	\N
86931b35-802f-4e9a-86fa-99396398c7c6	2018-03-02 07:44:59.242626-06	1	[21849] C 26 CORRIDOR 317 	[4] DLarrabee	[293] master	\N	\N
7491d8c0-54c1-4d40-8b5a-a80d5958ff64	2018-03-02 07:44:59.247627-06	1	[21850] C 27 CORRIDOR 317 	[4] DLarrabee	[293] master	\N	\N
a330b195-50ac-4d23-adc0-1c6730807356	2018-03-02 07:44:59.252627-06	1	[21851] None	[4] DLarrabee	[293] master	\N	\N
4f3c11f5-6215-49d4-b735-7e3938285315	2018-03-02 07:45:08.084511-06	2	[21821] IC 333-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
eaed1df1-e13e-47cb-9a61-818ec606fac3	2018-03-02 07:45:45.143216-06	2	[21822] IC 333-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
fbf2d030-009e-473a-8ebc-2c6231d7b563	2018-03-02 07:45:52.529955-06	1	[21852] New	[4] DLarrabee	[293] master	\N	\N
9ef93227-ba20-4b79-80a4-834e15651d0a	2018-03-02 07:45:58.661568-06	2	[21821] IC 333-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
9552b2a7-3fc5-49fe-a35a-e2e511f4de97	2018-03-02 07:46:10.913793-06	2	[21852] Cameras	[4] DLarrabee	[293] master	\N	\N
cffbf093-c005-4d19-bbf7-f372a5ebdffc	2018-03-02 07:46:16.410342-06	2	[21819] IC 324C-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
1b01f05d-31a5-46db-a222-1e897ceac928	2018-03-02 07:46:25.501251-06	2	[21818] IC 324-CInB	[21041] OSSI-DNOVAK	[293] master	\N	\N
290361f7-be65-43a3-bc0a-b888a265fd07	2018-03-02 07:46:36.005302-06	1	[21853] D 1 CORRIDOR 437 	[4] DLarrabee	[293] master	\N	\N
1ab47409-e9f9-49b5-9a67-adab6226cfde	2018-03-02 07:47:11.477849-06	1	[21854] IC 324C-OutB Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
42d28bdc-ce35-4c66-8379-b0149cadbd59	2018-03-02 07:47:26.114312-06	2	[21853] D 1 CORRIDOR 437 	[4] DLarrabee	[293] master	\N	\N
a53f60c3-be2b-4e33-93ac-13d11114fae3	2018-03-02 07:47:58.921593-06	1	[21855] D 2 CORRIDOR 437 	[4] DLarrabee	[293] master	\N	\N
23d43a3b-8119-4298-b85f-2629667b3dc4	2018-03-02 07:47:58.932594-06	1	[21856] D 3 CORRIDOR 437	[4] DLarrabee	[293] master	\N	\N
94a6636a-45e3-4e06-8c77-80b751a626cb	2018-03-02 07:47:58.940594-06	1	[21857] D 4 CORRIDOR 437 	[4] DLarrabee	[293] master	\N	\N
80ddc299-4fa2-4842-bf5e-d9a22568b767	2018-03-02 07:47:58.943595-06	1	[21858] D 5 CORRIDOR 437	[4] DLarrabee	[293] master	\N	\N
fd06b7e2-92bf-4df0-add5-4ceda0460f8a	2018-03-02 07:47:58.953596-06	1	[21859] D 6 CORRIDOR 414 	[4] DLarrabee	[293] master	\N	\N
cf7ad382-d7ea-49fc-bfc6-4e7a5d1154d8	2018-03-02 07:47:58.958596-06	1	[21860] D 7 CORRIDOR 414 	[4] DLarrabee	[293] master	\N	\N
e3c99b7b-9b10-4a97-972b-521da7648c25	2018-03-02 07:47:58.963597-06	1	[21861] D 8 MA 410 	[4] DLarrabee	[293] master	\N	\N
09361694-72eb-4272-b8b6-744f1ff6624c	2018-03-02 07:47:58.987599-06	1	[21862] D 9 MA 410 	[4] DLarrabee	[293] master	\N	\N
22b469b7-3960-44e1-b036-dc7780b83e38	2018-03-02 07:47:59.004601-06	1	[21863] D 10 MA 410 	[4] DLarrabee	[293] master	\N	\N
062ca93a-d8d1-41d7-8e28-b448dc7d0638	2018-03-02 07:47:59.009601-06	1	[21864] D 11 CLASSROOM 415 	[4] DLarrabee	[293] master	\N	\N
f6b31ec8-c0ef-4e2b-8d6c-5b1d421492a0	2018-03-02 07:47:59.013602-06	1	[21865] D 12 CLASSROOM 415	[4] DLarrabee	[293] master	\N	\N
71c400db-343a-4818-b60e-1a97e61f4080	2018-03-02 07:47:59.018602-06	1	[21866] D 13 CLASSROOM 418	[4] DLarrabee	[293] master	\N	\N
65fdfc30-7813-4166-aa4a-96236b0b4a8d	2018-03-02 07:47:59.023603-06	1	[21867] D 14 CLASSROOM 418	[4] DLarrabee	[293] master	\N	\N
716a0c58-3c87-4d04-8640-588286d275f6	2018-03-02 07:47:59.027603-06	1	[21868] D 15 VESTIBULE 422 	[4] DLarrabee	[293] master	\N	\N
74e03b11-1447-48b7-a022-9b326ed9728d	2018-03-02 07:47:59.032604-06	1	[21869] D 16 WORK ALCOVE 423	[4] DLarrabee	[293] master	\N	\N
ac05b770-a905-4a49-841c-fdde9daced19	2018-03-02 07:47:59.037604-06	1	[21870] D 17 WORK ALCOVE 423 	[4] DLarrabee	[293] master	\N	\N
158f096d-4b57-4234-a3ab-45bf1ac5f7dc	2018-03-02 07:47:59.042605-06	1	[21871] D 18 CLASSROOM 425	[4] DLarrabee	[293] master	\N	\N
c8321156-6bac-48f1-b5a8-0306acc1713a	2018-03-02 07:47:59.046605-06	1	[21872] D 19 CLASSROOM 425 	[4] DLarrabee	[293] master	\N	\N
189f01ab-3f31-46cb-a8c2-3489126de838	2018-03-02 07:47:59.050605-06	1	[21873] D 20 CLASSROOM 428 	[4] DLarrabee	[293] master	\N	\N
0d65a30d-9270-4968-8b76-fe6b1a714962	2018-03-02 07:47:59.055606-06	1	[21874] D 21 CLASSROOM 428 	[4] DLarrabee	[293] master	\N	\N
8b73f2dd-65d1-4754-b8c5-19df0e1b2729	2018-03-02 07:47:59.060606-06	1	[21875] D 22 VESTIBULE 444 	[4] DLarrabee	[293] master	\N	\N
28657f4e-c869-4de1-be7e-80683df96026	2018-03-02 07:47:59.066607-06	1	[21876] D 23 DETENTION HEARING 443	[4] DLarrabee	[293] master	\N	\N
03b842ce-2096-4c3d-b01f-b113830ac008	2018-03-02 07:47:59.070607-06	1	[21877] D 24 CLASSROOM 463 	[4] DLarrabee	[293] master	\N	\N
14dfd96e-cea4-4fe0-81ae-4ed65e97d1a6	2018-03-02 07:47:59.077608-06	1	[21878] D 25 CLASSROOM 463 	[4] DLarrabee	[293] master	\N	\N
fe2b3e94-4da5-431a-8ee3-13e3b82084aa	2018-03-02 07:47:59.083609-06	1	[21879] D 26 CLASSROOM 465	[4] DLarrabee	[293] master	\N	\N
0eb3c81c-072d-499e-9236-bc62095d335c	2018-03-02 07:47:59.089609-06	1	[21880] D 27 CLASSROOM 465 	[4] DLarrabee	[293] master	\N	\N
7f65fd05-5fd3-4cee-8945-da682cb1bd12	2018-03-02 07:47:59.09461-06	1	[21881] D 28 CORRIDOR 461 	[4] DLarrabee	[293] master	\N	\N
388194e9-6895-4795-b516-30a3acd2a31d	2018-03-02 07:47:59.09961-06	1	[21882] D 29 CALMING ROOM 456 	[4] DLarrabee	[293] master	\N	\N
8472cc1c-c2ef-49a3-b863-28843690980e	2018-03-02 07:47:59.106611-06	1	[21883] D 30 CALMING ROOM 438 	[4] DLarrabee	[293] master	\N	\N
cbca4ab8-5916-4794-af16-7084e6e4cbfa	2018-03-02 07:47:59.111612-06	1	[21884] D 31 CALMING ROOM 439	[4] DLarrabee	[293] master	\N	\N
dab68b9b-248c-4b6c-84c8-aaee1cb16f67	2018-03-02 07:47:59.115612-06	1	[21885] D 32 GYM 455	[4] DLarrabee	[293] master	\N	\N
bb412ef9-097f-48d4-88d0-7e7cd9954ae0	2018-03-02 07:47:59.120612-06	1	[21886] D 33 GYM 455 	[4] DLarrabee	[293] master	\N	\N
42458b84-ec28-4864-bd84-917fc7f43773	2018-03-02 07:47:59.126613-06	1	[21887] D 34 GYM 455 	[4] DLarrabee	[293] master	\N	\N
c54d09f7-31ca-413a-80b9-56cfa8d953f6	2018-03-02 07:47:59.131614-06	1	[21888] D 35 GYM 455 	[4] DLarrabee	[293] master	\N	\N
cf579d1f-955c-45c3-9d27-3c1c4455ac3c	2018-03-02 07:47:59.135614-06	1	[21889] D 36 FITNESS 452 	[4] DLarrabee	[293] master	\N	\N
3d0d59bb-1000-45ab-8900-ee04993fa21d	2018-03-02 07:47:59.140614-06	1	[21890] D 37 FITNESS 452 	[4] DLarrabee	[293] master	\N	\N
a13cfa63-1cb7-418e-bb93-b223c6f07433	2018-03-02 07:47:59.146615-06	1	[21891] D 38 COURTYARD 451	[4] DLarrabee	[293] master	\N	\N
243e47c1-13cc-4883-897b-66b5a8b81162	2018-03-02 07:47:59.151616-06	1	[21892] D 39 COURTYARD 451 	[4] DLarrabee	[293] master	\N	\N
17d9d9ba-9939-4c10-9ef6-380a7e12ddbe	2018-03-02 07:47:59.155616-06	1	[21893] D 40 VISITING 448 	[4] DLarrabee	[293] master	\N	\N
f83105c0-f471-41b2-b89a-47d650e69ecb	2018-03-02 07:47:59.160616-06	1	[21894] D 41 VISITING 445 	[4] DLarrabee	[293] master	\N	\N
767ab995-c2ca-4c05-8706-2007e97a3125	2018-03-02 07:47:59.164617-06	1	[21895] D 42 VISITING 445	[4] DLarrabee	[293] master	\N	\N
18efd29e-aa96-4742-ae3f-11e3e46fa180	2018-03-02 07:47:59.169617-06	1	[21896] D 43 VISITING 446 	[4] DLarrabee	[293] master	\N	\N
27b2a920-f0a9-425e-ae78-6a4ee0bb800d	2018-03-02 07:47:59.174618-06	1	[21897] D 44 WAITING 382 	[4] DLarrabee	[293] master	\N	\N
5bb69dba-29fc-4d76-90ec-7d8b64658d75	2018-03-02 07:47:59.180618-06	1	[21898] D 45 WAITING 382 	[4] DLarrabee	[293] master	\N	\N
f3c59c84-0d5f-4477-8844-f75a09d02840	2018-03-02 07:47:59.185619-06	1	[21899] D 46 WAITING 382 	[4] DLarrabee	[293] master	\N	\N
5ba711b1-bb55-48a9-b4f8-0ed7b0ab4183	2018-03-02 07:47:59.189619-06	1	[21900] D 47 WAITING 382 	[4] DLarrabee	[293] master	\N	\N
490db2ec-d8d7-4a4e-aca2-daf740ba33ce	2018-03-02 07:47:59.19462-06	1	[21901] D 48 VENDING 492	[4] DLarrabee	[293] master	\N	\N
9fa696d9-c158-45e9-a86d-07c5a3f9afdb	2018-03-02 07:47:59.19962-06	1	[21902] D 49 CORRIDOR 484 	[4] DLarrabee	[293] master	\N	\N
1d2ae2ab-69a0-4bc4-9671-558a54ead568	2018-03-02 07:47:59.204621-06	1	[21903] D 50 CORRIDOR 484	[4] DLarrabee	[293] master	\N	\N
6aada4be-061c-4292-8100-afc4692fb2a2	2018-03-02 07:47:59.209621-06	1	[21904] D 51 CORRIDOR 484 	[4] DLarrabee	[293] master	\N	\N
2e221d32-c830-452b-97e4-2a5657150f47	2018-03-02 07:47:59.213622-06	1	[21905] D 52 CORRIDOR 484 	[4] DLarrabee	[293] master	\N	\N
809137e8-67f6-40e2-b6e1-de220c7a7497	2018-03-02 07:47:59.218622-06	1	[21906] D 53 CORRIDOR 484 	[4] DLarrabee	[293] master	\N	\N
6e771931-3dd1-46b5-b009-8d540656f225	2018-03-02 07:47:59.223623-06	1	[21907] D 54 CORRIDOR 484 	[4] DLarrabee	[293] master	\N	\N
46afdc55-0cf7-4972-b90e-d0bc0e0d4239	2018-03-02 07:47:59.228623-06	1	[21908] D 55 INTERVIEW 466 	[4] DLarrabee	[293] master	\N	\N
45422a5b-4f26-4695-b7d9-368cacfd3534	2018-03-02 07:47:59.233624-06	1	[21909] D 56 MEETING 467	[4] DLarrabee	[293] master	\N	\N
273469bd-dacd-4d7c-871a-d4afc224f5af	2018-03-02 07:47:59.237624-06	1	[21910] D 57 CORRIDOR 484 	[4] DLarrabee	[293] master	\N	\N
c14f7ee2-aed2-4942-9d1a-9bada83181d1	2018-03-02 07:47:59.243625-06	1	[21911] D58 VISITING ROOM 445	[4] DLarrabee	[293] master	\N	\N
4bc8eb9c-1618-4909-8baf-6bfbb579a58c	2018-03-02 07:47:59.248625-06	1	[21912] D59 MEDS STORAGE 401	[4] DLarrabee	[293] master	\N	\N
89e39dd2-abc9-4572-9368-ccdcd2b2a685	2018-03-02 07:47:59.252626-06	1	[21913] None	[4] DLarrabee	[293] master	\N	\N
ad7982d4-fda5-407f-8f2e-f7e7e4a035f3	2018-03-02 07:48:35.347235-06	1	[21914] New	[4] DLarrabee	[293] master	\N	\N
3b91c508-3ba2-4bb8-ae43-c4fef642c101	2018-03-02 07:48:51.016802-06	2	[21914] Cameras	[4] DLarrabee	[293] master	\N	\N
799f6d40-7fe7-498c-8151-7e9187f81d5a	2018-03-02 07:49:03.326032-06	1	[21915] E 1 HALL 544 	[4] DLarrabee	[293] master	\N	\N
59f5ea74-bfc0-4105-83c2-6a7ab5785b2f	2018-03-02 07:49:36.40634-06	2	[21854] IC 330A-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
7dcfc69e-0030-4dbb-8f3d-98255999e262	2018-03-02 07:49:48.138513-06	2	[21915] E 1 HALL 544 	[4] DLarrabee	[293] master	\N	\N
c4bcca37-9fa6-4864-8d00-6802122a4c8d	2018-03-02 07:50:13.61206-06	1	[21916] E 2 HALL 544 	[4] DLarrabee	[293] master	\N	\N
aa6da260-b801-42da-8cbe-c5a121c4140b	2018-03-02 07:50:13.619061-06	1	[21917] E 3 HALL 544 	[4] DLarrabee	[293] master	\N	\N
1a15c250-29eb-4e9b-8509-ac2e62e405af	2018-03-02 07:50:13.626062-06	1	[21918] E 4 LIVING ROOM 529 	[4] DLarrabee	[293] master	\N	\N
3ab58000-8ee1-44a6-b015-d3595972b7d8	2018-03-02 07:50:13.631062-06	1	[21919] E 5 LIVING ROOM 529 	[4] DLarrabee	[293] master	\N	\N
122dc2f5-ab17-41a3-bb3d-87025521036b	2018-03-02 07:50:13.635063-06	1	[21920] E 6 LIVING ROOM 529 	[4] DLarrabee	[293] master	\N	\N
88946e46-6a5f-46d6-92d4-a829a0d47e52	2018-03-02 07:50:13.641063-06	1	[21921] E 7 LIVING ROOM 529 	[4] DLarrabee	[293] master	\N	\N
fec3f2ef-7166-4274-965d-91a163a41d1d	2018-03-02 07:50:13.645064-06	1	[21922] E 8 LIVING ROOM 529 	[4] DLarrabee	[293] master	\N	\N
cc05d9cd-589f-4cac-b5cb-26ef00ee52b3	2018-03-02 07:50:13.651064-06	1	[21923] E 9 DINING 515	[4] DLarrabee	[293] master	\N	\N
a5cbabfb-c1ad-4a15-bf2c-7cefb9414d19	2018-03-02 07:50:13.655065-06	1	[21924] E 10 DINING 515	[4] DLarrabee	[293] master	\N	\N
e8ceb544-f748-4e37-95a9-c8ea8851db10	2018-03-02 07:50:13.660065-06	1	[21925] E 11 LIVING ROOM 514 	[4] DLarrabee	[293] master	\N	\N
b6d6600a-b088-456c-977c-e471cb80e9b8	2018-03-02 07:50:13.665066-06	1	[21926] E 12 LIVING ROOM 514	[4] DLarrabee	[293] master	\N	\N
a353faec-db87-454d-8e54-ba78bd8d96df	2018-03-02 07:50:13.670066-06	1	[21927] E 13 LIVING ROOM 514	[4] DLarrabee	[293] master	\N	\N
cd61b41d-516f-4f6c-8a7a-6df254b2f0a3	2018-03-02 07:50:13.675067-06	1	[21928] E 14 LIVING ROOM 514 	[4] DLarrabee	[293] master	\N	\N
07abd6a0-960f-4db7-b7ac-e1ed357de7f6	2018-03-02 07:50:13.679067-06	1	[21929] E 15 CALMING ROOM 535	[4] DLarrabee	[293] master	\N	\N
af8e86c5-1841-4514-83ab-5f81f5542ff0	2018-03-02 07:50:13.684067-06	1	[21930] E 16 COURTYARD 503	[4] DLarrabee	[293] master	\N	\N
7b4e231d-1769-4715-9aef-56507c77a98a	2018-03-02 07:50:13.689068-06	1	[21931] E17 SINGLE SLEEPING 509	[4] DLarrabee	[293] master	\N	\N
741b5a74-6a96-4e77-a194-e710837e95e8	2018-03-02 07:50:13.694068-06	1	[21932] E18 ADA SLEEPING 513	[4] DLarrabee	[293] master	\N	\N
c7831982-3596-4fcf-b29d-2e98c05065c1	2018-03-02 07:50:13.698069-06	1	[21933] E19 ADA SLEEPING 518	[4] DLarrabee	[293] master	\N	\N
98123441-aff8-4409-a5a1-5beaad90d91a	2018-03-02 07:50:13.702069-06	1	[21934] E20 SINGLE SLEEPING 520	[4] DLarrabee	[293] master	\N	\N
a759246a-60d5-45e6-aec0-8e6ad6de961f	2018-03-02 07:50:13.70607-06	1	[21935] None	[4] DLarrabee	[293] master	\N	\N
11d12f09-c22e-4d7a-8ab4-0a41e060e260	2018-03-02 07:50:34.930192-06	1	[21936] IC 330A-InB (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
5b59a743-7d23-4426-b71e-871407fcd73b	2018-03-02 07:50:34.935192-06	1	[21937] IC 330A-InB (2)	[21041] OSSI-DNOVAK	[293] master	\N	\N
8beb60a8-a8f5-46d3-bac4-a549eabb2338	2018-03-02 07:50:34.943193-06	1	[21938] IC 330A-InB (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
a91c0b3d-f22f-4f35-80e7-bd276df55992	2018-03-02 07:50:34.947194-06	1	[21939] IC 330A-InB (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
bdcb6c44-9bff-4239-b2d6-50f37e41a3cd	2018-03-02 07:50:34.956194-06	1	[21940] IC 330A-InB (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
2d3617c3-cac8-4146-a19b-d3d20eda1fb0	2018-03-02 07:50:34.963195-06	1	[21941] IC 330A-InB (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
0ae6550f-fca8-49b3-af0a-8c54055b156d	2018-03-02 07:50:34.969196-06	1	[21942] IC 330A-InB (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
9a723d8d-a7ed-406b-8ed1-93d22e0bed22	2018-03-02 07:50:41.548854-06	2	[21480] E Cameras	[4] DLarrabee	[293] master	\N	\N
56fc1d0e-0cd3-4136-9b31-dd16a796caaf	2018-03-02 07:50:42.60796-06	2	[21765] Camera Label Frame	[4] DLarrabee	[293] master	\N	\N
95db9405-32af-4fb1-aecc-f7ab09ba0888	2018-03-02 07:50:53.981097-06	2	[21936] IC 330A-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
89008b5a-9a09-4d09-823f-0d21dc126d9c	2018-03-02 07:50:59.773676-06	2	[21762] Camera Label Frame	[4] DLarrabee	[293] master	\N	\N
522dc69d-66a1-4ffd-82a9-a58fe96e62ac	2018-03-02 07:51:09.860685-06	2	[21937] IC 330B-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
1e7f7e7b-f228-4b37-815b-abc641f3294b	2018-03-02 07:51:12.696968-06	2	[21759] Camera Label Frame	[4] DLarrabee	[293] master	\N	\N
6def4a22-daf6-4f04-b845-ab8334e16240	2018-03-02 07:51:27.651463-06	2	[21757] Camera Label Frame	[4] DLarrabee	[293] master	\N	\N
fb5049d9-9bca-49f5-9364-cb687ff6fa78	2018-03-02 07:51:28.795578-06	2	[21938] IC 330B-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
e6c55dfa-761c-493b-96c9-8b5d21cd4ddf	2018-03-02 07:51:47.760474-06	2	[21477] B Cameras	[4] DLarrabee	[293] master	\N	\N
7d1b89e8-a120-4b00-85c3-7abaef0f0ac6	2018-03-02 07:51:53.644062-06	2	[21478] C Cameras	[4] DLarrabee	[293] master	\N	\N
a7be5807-f1b7-4827-a2cb-26d4bcdb9544	2018-03-02 07:51:56.529351-06	2	[21939] IC 378-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
fcb3f5f4-b199-41b5-a56a-09f7c06c2d8e	2018-03-02 07:51:58.732571-06	2	[21479] D Cameras	[4] DLarrabee	[293] master	\N	\N
1c2e1ffb-f7f0-4fef-be01-908b477bff03	2018-03-02 07:52:20.241722-06	2	[21940] IC 378-OutB	[21041] OSSI-DNOVAK	[293] master	\N	\N
402be0ff-0eaf-4bab-81af-0fd6580a7a02	2018-03-02 07:52:52.62896-06	2	[21941] IC 448-InB	[21041] OSSI-DNOVAK	[293] master	\N	\N
ff6d9f21-8e46-49d3-b087-551e493f7c21	2018-03-02 07:52:58.338531-06	3	[21942] IC 330A-InB (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
cf8df8c3-efc3-4c80-9e27-5afe5b9c603d	2018-03-02 07:53:25.920289-06	2	[21757] Camera Label Frame	[4] DLarrabee	[293] master	\N	\N
df119d47-7d43-4e2d-8f75-49d3ad209826	2018-03-02 07:53:45.662263-06	2	[21759] Camera Label Frame	[4] DLarrabee	[293] master	\N	\N
fe0ff66c-78da-4946-9906-ee7b5a20f69e	2018-03-02 07:54:06.004297-06	2	[21762] Camera Label Frame	[4] DLarrabee	[293] master	\N	\N
1830c651-5fe9-4661-99cd-27e27820504c	2018-03-02 07:54:23.582055-06	2	[21765] Camera Label Frame	[4] DLarrabee	[293] master	\N	\N
97d74549-6edc-4679-85eb-188962935e8d	2018-03-02 07:57:34.489144-06	2	[21756] New Video Display	[4] DLarrabee	[293] master	\N	\N
7b7c5317-c999-4a4e-82a6-61b828f29021	2018-03-02 07:59:38.909584-06	2	[21758] New Video Display	[4] DLarrabee	[293] master	\N	\N
97c6f160-be33-4082-84ed-7ce20584b29e	2018-03-02 08:04:18.982589-06	2	[21761] New Video Display	[4] DLarrabee	[293] master	\N	\N
15d4817d-be60-438f-8d48-f0bb5c8b6fba	2018-03-02 08:05:58.275517-06	2	[21764] New Video Display	[4] DLarrabee	[293] master	\N	\N
a8a32cf8-cd91-40f7-8255-e8ddd78c166b	2018-03-02 08:06:14.50814-06	2	[21764] E Video Display	[4] DLarrabee	[293] master	\N	\N
d71078d3-bc37-4130-a670-6a994b2c7d1c	2018-03-02 08:06:24.047094-06	2	[21761] D Video Display	[4] DLarrabee	[293] master	\N	\N
2317a683-b9a2-46d9-8808-54c675434571	2018-03-02 08:06:38.951584-06	2	[21758] C Video Display	[4] DLarrabee	[293] master	\N	\N
521a1840-56a8-4c67-bb4c-7efa200e1695	2018-03-02 08:06:54.134102-06	2	[21756] B Video Display	[4] DLarrabee	[293] master	\N	\N
cd119dd0-b3dc-4d7a-a3b6-de3d55be237e	2018-03-02 08:07:07.553444-06	2	[21730] A Video Display	[4] DLarrabee	[293] master	\N	\N
e467f446-c494-456d-a3c8-40a14a0e8643	2018-03-02 08:20:37.202401-06	2	[21475] IC 145OutB	[4] DLarrabee	[293] master	\N	\N
ea969920-85ed-4038-a3e9-6ab151283dfc	2018-03-02 08:28:30.974774-06	1	[21942] New	[4] DLarrabee	[293] master	\N	\N
f8584b25-adf3-41b4-a601-1aae5f9baf36	2018-03-02 08:29:47.762452-06	2	[21942] 201	[4] DLarrabee	[293] master	\N	\N
ed17f4dc-83b8-40df-9e5b-3eeaa074c35d	2018-03-02 08:54:20.251686-06	1	[21943] New	[4] DLarrabee	[293] master	\N	\N
71cfc3dc-0f36-4c63-9ee2-41bd2b3f3dd8	2018-03-02 08:54:41.154776-06	2	[21943] 202	[4] DLarrabee	[293] master	\N	\N
0ac17b89-bc7c-4e8c-b863-a19627a33ab8	2018-03-02 08:56:55.656225-06	1	[21944] 202 Copy	[4] DLarrabee	[293] master	\N	\N
40f828b5-34dd-4937-a648-ed5dd3796a2e	2018-03-02 08:56:59.144573-06	1	[21945] 202 Copy	[4] DLarrabee	[293] master	\N	\N
80b00173-55f5-4819-9506-0581e4f1be1f	2018-03-02 08:57:01.118771-06	1	[21946] 202 Copy	[4] DLarrabee	[293] master	\N	\N
04c72d10-4811-4291-ab1b-f7e87bb9b5f7	2018-03-02 08:57:01.494808-06	1	[21947] 202 Copy	[4] DLarrabee	[293] master	\N	\N
6ebe316b-586f-46dd-90c7-6f29b9ebefcb	2018-03-02 08:57:01.876847-06	1	[21948] 202 Copy	[4] DLarrabee	[293] master	\N	\N
07305ca0-f138-405c-879d-b587c754c9dc	2018-03-02 08:57:01.881847-06	1	[21949] 202 Copy	[4] DLarrabee	[293] master	\N	\N
39986800-e088-4da1-a430-cdb36c4b5c4e	2018-03-02 08:57:02.270886-06	1	[21950] 202 Copy	[4] DLarrabee	[293] master	\N	\N
b9bc6250-0929-4fe5-abec-9d1a573cc345	2018-03-02 08:57:02.273886-06	1	[21951] 202 Copy	[4] DLarrabee	[293] master	\N	\N
89a96f88-74d9-4153-8769-39e16aeb791c	2018-03-02 08:57:02.661925-06	1	[21952] 202 Copy	[4] DLarrabee	[293] master	\N	\N
18d228f1-e2bb-4743-8f6f-e2e4ecdf28bc	2018-03-02 08:57:02.664925-06	1	[21953] 202 Copy	[4] DLarrabee	[293] master	\N	\N
b956abae-bde9-4b5d-8fa1-379a3ab6a95f	2018-03-02 08:57:03.053964-06	1	[21954] 202 Copy	[4] DLarrabee	[293] master	\N	\N
4f0a4267-75da-401b-90ab-a3dedcb4fb7f	2018-03-02 08:57:03.058965-06	1	[21955] 202 Copy	[4] DLarrabee	[293] master	\N	\N
2a815408-2d9e-4069-a6ce-dd4c35b03032	2018-03-02 08:57:03.444003-06	1	[21956] 202 Copy	[4] DLarrabee	[293] master	\N	\N
09e9aeb1-1b52-4b91-9850-99e18658e5fa	2018-03-02 08:57:03.450004-06	1	[21957] 202 Copy	[4] DLarrabee	[293] master	\N	\N
1e29470c-1d40-418d-86df-fb935f846aef	2018-03-02 08:57:03.835042-06	1	[21958] 202 Copy	[4] DLarrabee	[293] master	\N	\N
6d5a7fe1-3a27-4e0c-98d7-2028eb89628d	2018-03-02 08:57:04.229082-06	1	[21959] 202 Copy	[4] DLarrabee	[293] master	\N	\N
5c876ef5-0942-4350-8ad9-ded46d86cd08	2018-03-02 08:57:04.233082-06	1	[21960] 202 Copy	[4] DLarrabee	[293] master	\N	\N
1e0a1fb4-0ee3-441c-959b-b685513501e7	2018-03-02 08:57:04.631122-06	1	[21961] 202 Copy	[4] DLarrabee	[293] master	\N	\N
57b26fc0-e69d-453b-9ea8-9c8f7072afbe	2018-03-02 08:57:04.637123-06	1	[21962] 202 Copy	[4] DLarrabee	[293] master	\N	\N
e6859f85-7596-41b9-9b42-9c78a21db06c	2018-03-02 08:57:05.040163-06	1	[21963] 202 Copy	[4] DLarrabee	[293] master	\N	\N
e27803b2-3f87-49e6-9c19-954b9d352d7a	2018-03-02 08:57:05.044163-06	1	[21964] 202 Copy	[4] DLarrabee	[293] master	\N	\N
f87e0bb5-fa96-47fd-b8c2-f2c40105b24b	2018-03-02 08:57:05.430202-06	1	[21965] 202 Copy	[4] DLarrabee	[293] master	\N	\N
78dab5a3-5eba-4894-8d21-e2da5454e266	2018-03-02 08:57:05.434202-06	1	[21966] 202 Copy	[4] DLarrabee	[293] master	\N	\N
712ec8d5-d405-48a6-8d2f-46e2a5333fb0	2018-03-02 08:57:05.469206-06	1	[21967] 202 Copy	[4] DLarrabee	[293] master	\N	\N
a64efb6f-c890-4471-9579-2b9c02b83989	2018-03-02 08:57:05.825241-06	1	[21968] 202 Copy	[4] DLarrabee	[293] master	\N	\N
60ed5c5d-1e15-4373-a3f2-c414f64d50cb	2018-03-02 08:57:06.205279-06	1	[21969] 202 Copy	[4] DLarrabee	[293] master	\N	\N
fc11b2c3-99ed-4c63-95e6-c82f54526681	2018-03-02 08:57:06.21228-06	1	[21970] 202 Copy	[4] DLarrabee	[293] master	\N	\N
9bbaaf2a-1a63-4de6-884c-4c641dcf5af7	2018-03-02 08:57:06.602319-06	1	[21971] 202 Copy	[4] DLarrabee	[293] master	\N	\N
b6346398-7a72-4441-84f8-ed2aeadc0e77	2018-03-02 08:57:06.60632-06	1	[21972] 202 Copy	[4] DLarrabee	[293] master	\N	\N
ccf16d6d-5238-4125-805e-9b4bff1110b0	2018-03-02 08:57:07.005359-06	1	[21973] 202 Copy	[4] DLarrabee	[293] master	\N	\N
3babf7f7-27fe-4f41-a754-bc7729063eb3	2018-03-02 08:57:07.01136-06	1	[21974] 202 Copy	[4] DLarrabee	[293] master	\N	\N
9a321f8d-1236-4805-baa2-0b34940db35e	2018-03-02 08:57:07.021361-06	1	[21975] 202 Copy	[4] DLarrabee	[293] master	\N	\N
109aafb8-a263-440a-8774-bc1a5f50152f	2018-03-02 08:57:07.404399-06	1	[21976] 202 Copy	[4] DLarrabee	[293] master	\N	\N
89d6b617-00eb-4b85-8d1d-545be08a3bea	2018-03-02 08:57:07.4094-06	1	[21977] 202 Copy	[4] DLarrabee	[293] master	\N	\N
879be46a-8284-49fa-8e7e-745080f05866	2018-03-02 08:57:07.81344-06	1	[21978] 202 Copy	[4] DLarrabee	[293] master	\N	\N
2658b728-d5c6-4945-9b54-65ad3d231821	2018-03-02 08:57:07.817441-06	1	[21979] 202 Copy	[4] DLarrabee	[293] master	\N	\N
c24ee06b-3cd9-4865-9374-aa1b9079f2f4	2018-03-02 08:57:08.201479-06	1	[21980] 202 Copy	[4] DLarrabee	[293] master	\N	\N
1e13acac-ec9e-4084-aa01-afdf00ab3588	2018-03-02 08:57:08.20648-06	1	[21981] 202 Copy	[4] DLarrabee	[293] master	\N	\N
a10dc29c-c66b-418d-9b90-8ce0a656153d	2018-03-02 08:57:08.592518-06	1	[21982] 202 Copy	[4] DLarrabee	[293] master	\N	\N
8f213ead-3b11-494c-9e65-05756e993f1f	2018-03-02 08:57:08.596519-06	1	[21983] 202 Copy	[4] DLarrabee	[293] master	\N	\N
f18424e6-b395-4544-b61c-24728673e365	2018-03-02 08:57:08.989558-06	1	[21984] 202 Copy	[4] DLarrabee	[293] master	\N	\N
37bff229-40c6-46c3-b869-8c8e4603e0db	2018-03-02 08:57:08.993558-06	1	[21985] 202 Copy	[4] DLarrabee	[293] master	\N	\N
1d928748-80e8-42ad-be48-111bbe2aedc7	2018-03-02 08:57:09.379597-06	1	[21986] 202 Copy	[4] DLarrabee	[293] master	\N	\N
4af99002-6517-4cd4-ac29-40ec43441691	2018-03-02 08:57:09.384597-06	1	[21987] 202 Copy	[4] DLarrabee	[293] master	\N	\N
7a65c16f-3ed1-4761-94af-39cb6b0403db	2018-03-02 08:57:09.768636-06	1	[21988] 202 Copy	[4] DLarrabee	[293] master	\N	\N
78604e0c-dce0-44b9-9fe8-5aa0ef29249e	2018-03-02 08:57:09.772636-06	1	[21989] 202 Copy	[4] DLarrabee	[293] master	\N	\N
a61107c1-54dc-43df-93a2-1dbb5df8e2f5	2018-03-02 08:57:10.174676-06	1	[21990] 202 Copy	[4] DLarrabee	[293] master	\N	\N
38566a0b-983d-4ca7-b177-84de20aa3065	2018-03-02 08:57:10.179677-06	1	[21991] 202 Copy	[4] DLarrabee	[293] master	\N	\N
7ad5d449-cafa-48b7-ac00-16abb7a9f9d9	2018-03-02 08:57:10.582717-06	1	[21992] 202 Copy	[4] DLarrabee	[293] master	\N	\N
356b76d3-951d-4b3a-830f-124d8eae3818	2018-03-02 08:57:10.586718-06	1	[21993] 202 Copy	[4] DLarrabee	[293] master	\N	\N
fce8f2e6-902a-44b3-afc3-e006443bea71	2018-03-02 08:57:10.969756-06	1	[21994] 202 Copy	[4] DLarrabee	[293] master	\N	\N
7f8dd304-fb3c-4091-9899-eeff4f0c580e	2018-03-02 08:57:10.973756-06	1	[21995] 202 Copy	[4] DLarrabee	[293] master	\N	\N
2e137722-43f5-4d2d-8a3a-14eee1bcdefc	2018-03-02 08:57:11.359795-06	1	[21996] 202 Copy	[4] DLarrabee	[293] master	\N	\N
3e45c926-f9f8-46b7-a4e6-608888655b11	2018-03-02 08:57:11.373796-06	1	[21997] 202 Copy	[4] DLarrabee	[293] master	\N	\N
045e1bdb-2846-46f9-b916-20af2ac188f1	2018-03-02 08:57:11.772836-06	1	[21998] 202 Copy	[4] DLarrabee	[293] master	\N	\N
f6618ca8-b7f0-4610-bea5-2e29c5578f7f	2018-03-02 08:57:11.776837-06	1	[21999] 202 Copy	[4] DLarrabee	[293] master	\N	\N
331d58cc-c6e7-4b44-a95c-2e3caa48a8d8	2018-03-02 08:57:12.164875-06	1	[22000] 202 Copy	[4] DLarrabee	[293] master	\N	\N
5cea986f-141b-437b-9dae-a52b2e6cd393	2018-03-02 08:57:12.171876-06	1	[22001] 202 Copy	[4] DLarrabee	[293] master	\N	\N
cba15dba-29c0-4ba9-abde-f28b2b5d30e9	2018-03-02 08:57:12.553914-06	1	[22002] 202 Copy	[4] DLarrabee	[293] master	\N	\N
b45f517d-4b7f-461f-9354-9b036cb5b35f	2018-03-02 08:57:12.557915-06	1	[22003] 202 Copy	[4] DLarrabee	[293] master	\N	\N
083b96f5-4fe7-4752-b799-9115c42f7a26	2018-03-02 08:57:12.955954-06	1	[22004] 202 Copy	[4] DLarrabee	[293] master	\N	\N
6b2bb71f-e620-4d6f-b007-4cc944c582e2	2018-03-02 08:57:12.959955-06	1	[22005] 202 Copy	[4] DLarrabee	[293] master	\N	\N
3733dbe0-fadd-427f-9fd8-4389354d06bb	2018-03-02 08:57:13.341993-06	1	[22006] 202 Copy	[4] DLarrabee	[293] master	\N	\N
585b9e8a-26c6-4680-991a-0714be7fee6f	2018-03-02 08:57:13.346994-06	1	[22007] 202 Copy	[4] DLarrabee	[293] master	\N	\N
060d196e-af25-4b30-9259-f985b1eeacd7	2018-03-02 08:57:13.728032-06	1	[22008] 202 Copy	[4] DLarrabee	[293] master	\N	\N
a10bb06f-81d2-4e36-ad68-81591b0217ce	2018-03-02 08:58:18.146473-06	2	[21944] 203	[4] DLarrabee	[293] master	\N	\N
53185206-ecc6-4823-844d-6bd5f5e81897	2018-03-02 08:58:56.387297-06	2	[21945] 205	[4] DLarrabee	[293] master	\N	\N
3d0fcb7c-0d98-4f99-9131-e8a08002cc88	2018-03-02 08:59:51.757833-06	2	[21946] 206	[4] DLarrabee	[293] master	\N	\N
894a45ce-a6a1-477b-a25f-f25bddf7a4df	2018-03-02 09:00:25.862243-06	2	[21947] 207	[4] DLarrabee	[293] master	\N	\N
ed0336e5-4ffd-4ded-9f18-a6fb696ca394	2018-03-02 09:01:14.959152-06	2	[21948] 209	[4] DLarrabee	[293] master	\N	\N
83dea1ba-78e6-40b8-b6e6-6011dccf258a	2018-03-02 09:02:01.884844-06	2	[21949] 211	[4] DLarrabee	[293] master	\N	\N
d9b2ffc9-02d9-4ea3-bf89-37544a0b32b9	2018-03-02 09:02:52.229878-06	2	[21950] 213	[4] DLarrabee	[293] master	\N	\N
963015d2-d889-4bf0-801a-8d3f21a27c00	2018-03-02 09:03:30.733728-06	2	[21951] 214	[4] DLarrabee	[293] master	\N	\N
65964f25-408f-4ff8-98bf-3efe4f4ac191	2018-03-02 09:04:18.663521-06	2	[21953] 216	[4] DLarrabee	[293] master	\N	\N
f2d93b58-1246-4882-a749-b9419304c65b	2018-03-02 09:04:46.991353-06	2	[21954] 218	[4] DLarrabee	[293] master	\N	\N
8fe4181f-d1b0-4eb0-86ce-6e2723493446	2018-03-02 09:06:06.073261-06	2	[21955] 219	[4] DLarrabee	[293] master	\N	\N
b16f6748-b7c6-4cb4-a45b-6b3d250d2f43	2018-03-02 09:06:34.746128-06	2	[21956] 221	[4] DLarrabee	[293] master	\N	\N
173f2b97-afea-40b6-b595-4a4d2f62e425	2018-03-02 09:07:06.4693-06	2	[21957] 222	[4] DLarrabee	[293] master	\N	\N
2a37f8e2-bc4f-4bca-adaa-398777fbd5cb	2018-03-02 09:08:56.023254-06	2	[21958] 223	[4] DLarrabee	[293] master	\N	\N
4fa69163-14fc-49e3-bc0e-1a3ed3e469f1	2018-03-02 09:09:39.309582-06	2	[21959] 224	[4] DLarrabee	[293] master	\N	\N
dd6fcade-4d05-4c16-9233-6b324100d866	2018-03-02 09:10:15.058157-06	2	[21960] 2225	[4] DLarrabee	[293] master	\N	\N
2e86e20e-a89c-4bc7-8d03-3c6f52ff0f39	2018-03-02 09:10:43.378989-06	2	[21960] 225	[4] DLarrabee	[293] master	\N	\N
3a1b4c4e-4f25-463b-ab8c-159a7ea27470	2018-03-02 09:11:03.19497-06	2	[21961] 226	[4] DLarrabee	[293] master	\N	\N
1046525a-b10c-4bd3-99da-afd17e839eb3	2018-03-02 09:11:39.228573-06	2	[21962] 227	[4] DLarrabee	[293] master	\N	\N
4bddb6af-adcd-4c18-b26e-6a27442a2abf	2018-03-02 09:12:10.674717-06	2	[21963] 228	[4] DLarrabee	[293] master	\N	\N
33cda93b-9b82-4023-b0d0-39658572a77f	2018-03-02 09:13:02.528902-06	2	[21964] 231	[4] DLarrabee	[293] master	\N	\N
bb3397b5-b169-4a1b-80ce-55d7c93d6438	2018-03-02 09:13:41.673816-06	2	[21965] 232	[4] DLarrabee	[293] master	\N	\N
f6a12ef1-1275-427e-b64b-f94e76031924	2018-03-02 09:14:09.91664-06	2	[21966] 233	[4] DLarrabee	[293] master	\N	\N
7cdb3e0b-bae2-43fc-aa41-f0e115329ae4	2018-03-02 09:14:58.145463-06	2	[21967] 235	[4] DLarrabee	[293] master	\N	\N
67ea1b2d-d55e-43b4-85b8-9374e9a0934d	2018-03-02 09:16:26.703318-06	2	[21968] 236	[4] DLarrabee	[293] master	\N	\N
d42beecf-3c94-4e2c-9518-b0019cdddb50	2018-03-02 09:17:02.991946-06	2	[21969] 237	[4] DLarrabee	[293] master	\N	\N
c3cb498a-9674-41cc-a52d-4a66b810acf1	2018-03-02 09:17:45.467193-06	2	[21970] 239	[4] DLarrabee	[293] master	\N	\N
0f1c648a-72e1-41dd-899e-98d1d0d87196	2018-03-02 09:19:10.750721-06	2	[21971] 241	[4] DLarrabee	[293] master	\N	\N
1b8b2604-dc05-4c8b-96d1-a0d75979bdfe	2018-03-02 09:19:41.34378-06	2	[21972] 242	[4] DLarrabee	[293] master	\N	\N
fa87dd13-e43d-4bc0-99e9-b70c387bff70	2018-03-02 09:20:11.580803-06	2	[21973] 243	[4] DLarrabee	[293] master	\N	\N
4e8dc282-3547-4d67-9f19-2de11f2fc534	2018-03-02 09:21:17.703415-06	2	[21974] 245	[4] DLarrabee	[293] master	\N	\N
33ed9f93-31f8-4a6a-ba88-bbf9154cda3a	2018-03-02 09:21:52.137858-06	2	[21975] 246	[4] DLarrabee	[293] master	\N	\N
639071fe-01a2-4c87-bfbe-98aa0c3dc22c	2018-03-02 09:22:29.626606-06	2	[21976] 247	[4] DLarrabee	[293] master	\N	\N
5e8a912e-e61f-4492-88da-12b4b117847f	2018-03-02 09:23:24.640107-06	2	[21977] 248	[4] DLarrabee	[293] master	\N	\N
e48a8e4c-bc16-4b9c-896b-ed780821236e	2018-03-02 09:26:02.573899-06	2	[21978] 252	[4] DLarrabee	[293] master	\N	\N
adaf0086-27dc-4285-a9b4-430adc3f0e20	2018-03-02 09:26:36.946336-06	2	[21979] 253	[4] DLarrabee	[293] master	\N	\N
341a1322-e8cd-4202-ac5d-f4f22291ef45	2018-03-02 09:29:28.769516-06	2	[21980] 261	[4] DLarrabee	[293] master	\N	\N
4e80b95b-7f3a-4afd-9a03-ceebf2fa8669	2018-03-02 09:30:21.576797-06	2	[21981] 306	[4] DLarrabee	[293] master	\N	\N
06d8cdb4-d2a1-4276-9d50-251c4218e85c	2018-03-02 09:32:48.643502-06	3	[22008] 202 Copy	[4] DLarrabee	[293] master	\N	\N
540c42ef-3a10-446a-9b6a-5e61526e8191	2018-03-02 09:33:04.853123-06	3	[22007] 202 Copy	[4] DLarrabee	[293] master	\N	\N
2487f194-ea40-4031-a0d4-2f4b1ae63d57	2018-03-02 09:33:16.702307-06	3	[21982] 202 Copy	[4] DLarrabee	[293] master	\N	\N
be923f19-f6f1-45cf-859a-a58e9e542809	2018-03-02 09:33:16.960333-06	2	[21983] 202 Copy	[4] DLarrabee	[293] master	\N	\N
8ce11157-9a2a-4744-952d-341e93220fb4	2018-03-02 09:33:16.964334-06	2	[21984] 202 Copy	[4] DLarrabee	[293] master	\N	\N
bb7395ed-f0c7-4908-a962-9ca5ac9a8271	2018-03-02 09:33:16.967334-06	2	[21985] 202 Copy	[4] DLarrabee	[293] master	\N	\N
be3182d6-8d7c-4baf-a96e-4dfe84230735	2018-03-02 09:33:16.972334-06	2	[21986] 202 Copy	[4] DLarrabee	[293] master	\N	\N
cc4d87be-e793-4ad0-b613-421f366d275f	2018-03-02 09:33:16.975335-06	2	[21987] 202 Copy	[4] DLarrabee	[293] master	\N	\N
7b21ecba-d335-4613-bfb4-237177b783b9	2018-03-02 09:33:16.979335-06	2	[21988] 202 Copy	[4] DLarrabee	[293] master	\N	\N
497a3e0d-8290-4ac2-b8c8-0007afad6738	2018-03-02 09:33:16.982335-06	2	[21989] 202 Copy	[4] DLarrabee	[293] master	\N	\N
77be791a-23d2-486e-b004-0cb9402e7518	2018-03-02 09:33:16.985336-06	2	[21990] 202 Copy	[4] DLarrabee	[293] master	\N	\N
69baf23c-6fc2-4047-bea7-ac77616bb477	2018-03-02 09:33:16.989336-06	2	[21991] 202 Copy	[4] DLarrabee	[293] master	\N	\N
9ac1740d-bbd7-4efc-b322-6a77ab293482	2018-03-02 09:33:16.994337-06	2	[21992] 202 Copy	[4] DLarrabee	[293] master	\N	\N
9aceca76-bf76-4cb0-9f60-7691213a764d	2018-03-02 09:33:16.999337-06	2	[21993] 202 Copy	[4] DLarrabee	[293] master	\N	\N
b81ee875-6eda-40d7-9df6-99fcc5d7adb9	2018-03-02 09:33:17.002337-06	2	[21994] 202 Copy	[4] DLarrabee	[293] master	\N	\N
455db501-5a6e-4b71-b9f7-e9be59164441	2018-03-02 09:33:17.005338-06	2	[21995] 202 Copy	[4] DLarrabee	[293] master	\N	\N
ebf30e63-d6ce-42e5-8493-cadd63bd41a1	2018-03-02 09:33:17.009338-06	2	[21996] 202 Copy	[4] DLarrabee	[293] master	\N	\N
846de56a-d7e7-4c8f-8f9b-763b2de356b6	2018-03-02 09:33:17.012338-06	2	[21997] 202 Copy	[4] DLarrabee	[293] master	\N	\N
22674ad2-78e7-4069-9b38-3db73de9e5ef	2018-03-02 09:33:17.014339-06	2	[21998] 202 Copy	[4] DLarrabee	[293] master	\N	\N
df49bc9f-5c83-4bef-80e0-a3ca95c63b1c	2018-03-02 09:33:17.017339-06	2	[21999] 202 Copy	[4] DLarrabee	[293] master	\N	\N
e12c5fd7-a87f-40fd-8e6f-8b27ceb31a97	2018-03-02 09:33:17.021339-06	2	[22000] 202 Copy	[4] DLarrabee	[293] master	\N	\N
b93beffc-a1ac-4732-a673-9baf8ef58f17	2018-03-02 09:33:17.02534-06	2	[22001] 202 Copy	[4] DLarrabee	[293] master	\N	\N
388f1bbc-9304-46e4-835f-3c05f525456b	2018-03-02 09:33:17.02834-06	2	[22002] 202 Copy	[4] DLarrabee	[293] master	\N	\N
fa27fa3c-b075-435a-b1c1-fc9978bf31c9	2018-03-02 09:33:17.03234-06	2	[22003] 202 Copy	[4] DLarrabee	[293] master	\N	\N
fc3a12e9-2c05-4cb1-9d5f-97e8391b4d59	2018-03-02 09:33:17.037341-06	2	[22004] 202 Copy	[4] DLarrabee	[293] master	\N	\N
0299ee17-468e-44eb-ba68-c89d7517f924	2018-03-02 09:33:17.041341-06	2	[22005] 202 Copy	[4] DLarrabee	[293] master	\N	\N
98f7998c-a51f-42fd-b6f3-87e3546ffbb7	2018-03-02 09:33:17.045342-06	2	[22006] 202 Copy	[4] DLarrabee	[293] master	\N	\N
79a5d004-cf0c-4242-aaed-21f19e33affe	2018-03-02 09:35:00.452681-06	3	[22005] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3fc25bd4-8b12-443b-b092-1f706fc9b1f5	2018-03-02 09:35:00.712707-06	2	[22006] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d6f13aac-52b3-4baf-a5a1-b59f9c4e7eb9	2018-03-02 09:35:05.548191-06	3	[22006] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0f38eba4-0443-4407-bee1-314b32cccb6d	2018-03-02 10:03:14.022021-06	2	[21742] IC 247-OutB	[4] DLarrabee	[21062] a	\N	\N
c48fe023-866c-442f-ac7e-fd340d91e2fc	2018-03-02 10:03:26.977317-06	2	[21743] IC 248-InB	[4] DLarrabee	[21062] a	\N	\N
701f59d6-b664-4667-8e1d-7577df75903c	2018-03-02 11:00:50.523637-06	2	[21726] IC 237B-OutB	[4] DLarrabee	[21062] a	\N	\N
305a3067-a425-4a52-82f1-113e90e74583	2018-03-02 11:01:17.047289-06	2	[21726] IC 237B-OutB	[4] DLarrabee	[21062] a	\N	\N
1474c79f-3cec-43bd-ad7a-a952a5a91e09	2018-03-02 11:18:03.282903-06	2	[22004] 259	[4] DLarrabee	[21062] a	\N	\N
4068362d-f892-4baa-915f-d2edcc1289af	2018-03-02 11:31:26.899256-06	2	[21288] Door 259	[4] DLarrabee	[21062] a	\N	\N
4ef519bd-3e7d-4414-a3aa-6a4221756040	2018-03-02 11:34:35.667131-06	2	[22003] 301	[4] DLarrabee	[21062] a	\N	\N
0f647613-8f70-4f4d-bd63-d79c43fa064e	2018-03-02 11:39:07.757337-06	2	[17095] 301B Trigger	[4] DLarrabee	[21062] a	\N	\N
8d2c905e-05b8-4f28-82cc-ad588c21ae51	2018-03-02 11:40:18.549416-06	2	[17095] 301A Trigger	[4] DLarrabee	[21062] a	\N	\N
0b4ab7d8-3f61-4911-b3ab-aad6739431e6	2018-03-02 11:40:25.127074-06	2	[17096] 301B Trigger	[4] DLarrabee	[21062] a	\N	\N
08326fb3-b1ea-4588-9250-46b658a370b0	2018-03-02 11:52:33.856939-06	2	[2000] DR-316B Trigger	[4] DLarrabee	[21062] a	\N	\N
1b0d1f27-01ed-432b-926f-87ec8522fc0d	2018-03-02 11:52:33.926946-06	2	[2001] DR-326A Trigger	[4] DLarrabee	[21062] a	\N	\N
92d5bffb-a4a9-44c0-918b-06d44972deeb	2018-03-02 11:52:33.930947-06	2	[2002] DR-327A Trigger	[4] DLarrabee	[21062] a	\N	\N
bf50a5f1-dd16-4304-ab31-c4f2e3195b89	2018-03-02 11:52:33.934947-06	2	[2003] DR329A Trigger	[4] DLarrabee	[21062] a	\N	\N
52aa3036-18c0-40ef-b359-ce67833f6762	2018-03-02 11:52:33.938948-06	2	[2004] DR-329B Trigger	[4] DLarrabee	[21062] a	\N	\N
fd187c44-782e-4c9e-94a2-b554e5f22f2d	2018-03-02 11:52:33.942948-06	2	[2005] DR-334A Trigger	[4] DLarrabee	[21062] a	\N	\N
7d94f8e8-0853-4fa5-9053-01c12237b9d6	2018-03-02 11:52:33.947948-06	2	[2006] DR-335A Trigger	[4] DLarrabee	[21062] a	\N	\N
25a5d7b8-63ab-4382-ba6d-4b707dc135e3	2018-03-02 11:52:33.951949-06	2	[2007] DR-336A Trigger	[4] DLarrabee	[21062] a	\N	\N
3ff23424-376c-4c88-8c08-cd2de89d66f5	2018-03-02 11:52:33.956949-06	2	[2008] DR-337A Trigger	[4] DLarrabee	[21062] a	\N	\N
300a5424-0c67-4562-bd33-0bcb3b21f8f4	2018-03-02 11:52:33.95995-06	2	[2009] DR-338A Trigger	[4] DLarrabee	[21062] a	\N	\N
59f6bf92-a3f0-403a-bd4f-c360d374da7a	2018-03-02 11:52:33.96395-06	2	[2010] DR-343A Trigger	[4] DLarrabee	[21062] a	\N	\N
57034397-3e7e-48c2-babd-2be82dcc977f	2018-03-02 11:52:33.96695-06	2	[2011] DR-344A Trigger	[4] DLarrabee	[21062] a	\N	\N
eefe8f5d-0dc2-492f-880e-b6dee2b885a1	2018-03-02 11:52:33.969951-06	2	[2012] DR-346A Trigger	[4] DLarrabee	[21062] a	\N	\N
e4446166-80c5-4169-9e87-32f7150d6446	2018-03-02 11:52:33.972951-06	2	[2013] DR-347A Trigger	[4] DLarrabee	[21062] a	\N	\N
a874e53f-b8c4-430f-b821-cb304bea0dd3	2018-03-02 11:52:33.975951-06	2	[2014] DR-348A Trigger	[4] DLarrabee	[21062] a	\N	\N
7608c7de-e583-4b16-af64-72a9ab272b87	2018-03-02 11:52:33.979952-06	2	[2015] DR-349A Trigger	[4] DLarrabee	[21062] a	\N	\N
501778c3-1596-40e5-a664-14f838df16ae	2018-03-02 11:54:43.221875-06	2	[2320]  DR-351A Trigger	[4] DLarrabee	[21062] a	\N	\N
bea84bbf-576b-4063-b3b9-5127a686e72a	2018-03-02 11:54:43.256878-06	2	[2321]  DR-351B Trigger	[4] DLarrabee	[21062] a	\N	\N
f3878ab0-e956-43aa-8bf8-6638e926b33f	2018-03-02 11:54:43.263879-06	2	[2322]  DR-352A Trigger	[4] DLarrabee	[21062] a	\N	\N
05ee1036-7ecc-4274-aa1a-64719a4ef490	2018-03-02 11:54:43.267879-06	2	[2323]  DR-405A Trigger	[4] DLarrabee	[21062] a	\N	\N
e32da87c-f230-4e21-bd20-089bd82743ab	2018-03-02 11:54:43.27188-06	2	[2324]  DR-414A Trigger	[4] DLarrabee	[21062] a	\N	\N
f28b221b-74b2-4fad-9d9b-3168b9e40cb3	2018-03-02 11:54:43.27588-06	2	[2325]  DR-414B Trigger	[4] DLarrabee	[21062] a	\N	\N
d8be5fa0-bb99-44b7-97f3-d77ed2b1473d	2018-03-02 11:54:43.27988-06	2	[2326]  DR-422A Trigger	[4] DLarrabee	[21062] a	\N	\N
97a64edb-72c7-4c76-b2b6-2bb1c76bdd6a	2018-03-02 11:54:43.283881-06	2	[2327]  DR-422B Trigger	[4] DLarrabee	[21062] a	\N	\N
b8d9c61c-3335-468b-8b8c-2f9352c61fc3	2018-03-02 11:54:43.288881-06	2	[2328]  DR-438A Trigger	[4] DLarrabee	[21062] a	\N	\N
cf10c52e-b5c0-4d60-b05e-3810e4d90b7d	2018-03-02 11:54:43.291882-06	2	[2329]  DR-439A Trigger	[4] DLarrabee	[21062] a	\N	\N
1b658de2-4a47-4708-b3e7-aa5a484663dc	2018-03-02 11:54:43.296882-06	2	[2330]  DR-443A Trigger	[4] DLarrabee	[21062] a	\N	\N
a20227f9-0ef6-47ba-8b6c-67d9eac133d9	2018-03-02 11:54:43.300882-06	2	[2331]  DR-443B Trigger	[4] DLarrabee	[21062] a	\N	\N
56000b90-c43f-4686-8bf3-a4155013e162	2018-03-02 11:54:43.304883-06	2	[2332]  DR-444A Trigger	[4] DLarrabee	[21062] a	\N	\N
b78c33b2-f8ee-483f-b4e8-9bc60566fafd	2018-03-02 11:54:43.308883-06	2	[2333]  DR-444B Trigger	[4] DLarrabee	[21062] a	\N	\N
23f5fe69-45e2-45c6-9869-aac968ff82e8	2018-03-02 11:54:43.312884-06	2	[2334]  DR-447A Trigger	[4] DLarrabee	[21062] a	\N	\N
2a37d034-50d6-46b8-adda-26607a24aeba	2018-03-02 11:54:43.316884-06	2	[2335]  DR-447B Trigger	[4] DLarrabee	[21062] a	\N	\N
7c7530f4-59e4-4585-aeac-32e396a8cab9	2018-03-02 11:55:53.629915-06	2	[2640]  DR-448A Trigger	[4] DLarrabee	[21062] a	\N	\N
e068e1be-b9b8-4a2b-8171-7b3b715c5895	2018-03-02 11:55:53.640916-06	2	[2641]  DR-455A Trigger	[4] DLarrabee	[21062] a	\N	\N
c4503c63-01ab-4967-a4d8-9f31c93ff390	2018-03-02 11:55:53.644916-06	2	[2642]  DR-455B Trigger	[4] DLarrabee	[21062] a	\N	\N
141aa80b-c575-4390-9969-9c29ec078b20	2018-03-02 11:55:53.648917-06	2	[2643]  DR-455D Trigger	[4] DLarrabee	[21062] a	\N	\N
03a9cb53-3737-4165-b624-970a09c73f37	2018-03-02 11:55:53.651917-06	2	[2644]  DR-316B Trigger	[4] DLarrabee	[21062] a	\N	\N
2863ccc6-61f1-400d-a8a2-8335c5776003	2018-03-02 11:55:53.656917-06	2	[2645]  DR-326A Trigger	[4] DLarrabee	[21062] a	\N	\N
60c36db1-a6ad-4320-b367-66ac2a21f68e	2018-03-02 11:55:53.660918-06	2	[2646]  DR-327A Trigger	[4] DLarrabee	[21062] a	\N	\N
961cc067-cc0a-45f3-9cae-5a604520518f	2018-03-02 11:55:53.664918-06	2	[2647]  DR-329A Trigger	[4] DLarrabee	[21062] a	\N	\N
6b346f5d-5965-4faa-a96a-e4ebc5847b31	2018-03-02 11:55:53.670919-06	2	[2648]  DR-329B Trigger	[4] DLarrabee	[21062] a	\N	\N
a94f4513-02eb-433c-953d-0642e7caa524	2018-03-02 11:55:53.675919-06	2	[2649]  DR-334A Trigger	[4] DLarrabee	[21062] a	\N	\N
45244a44-578e-4b43-b41c-a187f2fd6fd2	2018-03-02 11:59:11.874333-06	2	[15803] DR-103 Trigger	[4] DLarrabee	[21062] a	\N	\N
a5e3bda2-2da5-4d11-aacc-07d587772f8b	2018-03-02 11:59:11.89332-06	2	[15804] DR-104 Trigger	[4] DLarrabee	[21062] a	\N	\N
44a930f1-575c-4f8b-ac1f-f5bfbf23c967	2018-03-02 11:59:11.897317-06	2	[15805] DR-105 Trigger	[4] DLarrabee	[21062] a	\N	\N
49ce1575-e0bf-4ddd-a87e-fcebf01c3d72	2018-03-02 11:59:11.901314-06	2	[15806] DR-107 Trigger	[4] DLarrabee	[21062] a	\N	\N
185b7b5d-0c07-403c-a01e-a435285af125	2018-03-02 11:59:11.905311-06	2	[15807] DR-108 Trigger	[4] DLarrabee	[21062] a	\N	\N
b9523f20-19c0-40b4-83af-4ed91a2deee7	2018-03-02 11:59:11.93529-06	2	[15808] DR-109 Trigger	[4] DLarrabee	[21062] a	\N	\N
4350e677-dd17-433f-b4e9-28352890d762	2018-03-02 11:59:11.941286-06	2	[15809] DR-112 Trigger	[4] DLarrabee	[21062] a	\N	\N
a71849b6-ced3-4b39-a9a5-8ba101a0f13c	2018-03-02 11:59:11.945283-06	2	[15810] DR-113 Trigger	[4] DLarrabee	[21062] a	\N	\N
0abe15d0-b0eb-4398-b655-2272179430d4	2018-03-02 11:59:11.948281-06	2	[15811] DR-114A Trigger	[4] DLarrabee	[21062] a	\N	\N
c897eaab-fa24-436f-9dff-372c83f050ef	2018-03-02 11:59:11.952278-06	2	[15812] DR-114B Trigger	[4] DLarrabee	[21062] a	\N	\N
53eb9a44-291c-4240-9ef2-3812c0945424	2018-03-02 11:59:11.957275-06	2	[15813] DR-115 Trigger	[4] DLarrabee	[21062] a	\N	\N
2972a86d-447e-4ea0-ab25-9f4725ff47a0	2018-03-02 11:59:11.960273-06	2	[15814] DR-116 Trigger	[4] DLarrabee	[21062] a	\N	\N
f190aa49-42b9-44f1-b8f7-16dda6f3adb2	2018-03-02 11:59:11.96427-06	2	[15815] DR-117 Trigger	[4] DLarrabee	[21062] a	\N	\N
57f8fdcb-82fc-4c70-ba9f-3b89f654ada6	2018-03-02 11:59:11.969266-06	2	[15816] DR-119 Trigger	[4] DLarrabee	[21062] a	\N	\N
4006e667-1ae6-4367-be36-8dd87bb9a391	2018-03-02 11:59:11.975262-06	2	[15817] DR-121 Trigger	[4] DLarrabee	[21062] a	\N	\N
f8517814-92bc-4732-aea2-497bfc392fac	2018-03-02 11:59:11.979259-06	2	[15818] DR-122 Trigger	[4] DLarrabee	[21062] a	\N	\N
60927432-8665-4d97-b68d-c0aae58e4a4d	2018-03-02 12:00:27.146605-06	2	[16123] DR-123 Trigger	[4] DLarrabee	[21062] a	\N	\N
7d6cdc4e-12f1-4a5d-aa32-4344bd9f1b9d	2018-03-02 12:00:27.153601-06	2	[16124] DR-124 Trigger	[4] DLarrabee	[21062] a	\N	\N
460d9974-39ca-43f6-bb47-4cb8dde5285b	2018-03-02 12:00:27.157598-06	2	[16125] DR-125 Trigger	[4] DLarrabee	[21062] a	\N	\N
757719d9-e846-470e-b8a5-c458d887b4cc	2018-03-02 12:00:27.161595-06	2	[16126] DR-126 Trigger	[4] DLarrabee	[21062] a	\N	\N
01aa0f6f-b851-4a24-b01a-b2599422e8de	2018-03-02 12:00:27.165592-06	2	[16127] DR-128 Trigger	[4] DLarrabee	[21062] a	\N	\N
99d2a153-3f57-41ad-87d4-33992ad3983a	2018-03-02 12:00:27.169589-06	2	[16128] DR-129 Trigger	[4] DLarrabee	[21062] a	\N	\N
99fb42c0-92d3-46da-bcfc-3aa3623adf35	2018-03-02 12:00:27.175585-06	2	[16129] DR-131 Trigger	[4] DLarrabee	[21062] a	\N	\N
0ac5eb4a-03ac-4f16-ae80-e35c978b9e18	2018-03-02 12:00:27.179582-06	2	[16130] DR-132 Trigger	[4] DLarrabee	[21062] a	\N	\N
c5a19ec3-aa95-4182-bcaf-adccc4ef9a72	2018-03-02 12:00:27.18358-06	2	[16131] DR-133 Trigger	[4] DLarrabee	[21062] a	\N	\N
a052b989-57bb-420a-9bd9-f8c51c5e0cb4	2018-03-02 12:00:27.187577-06	2	[16132] DR-134A Trigger	[4] DLarrabee	[21062] a	\N	\N
6c38b671-5cd2-4e84-8ecb-701562aab821	2018-03-02 12:00:27.191574-06	2	[16133] DR-134B Trigger	[4] DLarrabee	[21062] a	\N	\N
cab944f3-adb3-4f8e-acfc-f22d39ce26c1	2018-03-02 12:00:27.195571-06	2	[16134] DR-136 Trigger	[4] DLarrabee	[21062] a	\N	\N
5ae8ea3d-34ab-4b9b-a7f3-a824fcfb7a9f	2018-03-02 12:00:27.198569-06	2	[16135] DR-137 Trigger	[4] DLarrabee	[21062] a	\N	\N
c979847a-bcec-4063-b59b-505a689167d9	2018-03-02 12:00:27.202566-06	2	[16136] DR-138 Trigger	[4] DLarrabee	[21062] a	\N	\N
ef0de2d5-40e3-447a-a7a2-41893250a85d	2018-03-02 12:00:27.206563-06	2	[16137] DR-141 Trigger	[4] DLarrabee	[21062] a	\N	\N
bf196137-ebe5-44c2-b0ab-41e8a2ae21cd	2018-03-02 12:00:27.210561-06	2	[16138] DR-142 Trigger	[4] DLarrabee	[21062] a	\N	\N
502bf2b5-5055-41b0-a49a-0099ecf546f0	2018-03-02 12:02:03.24606-06	2	[16443] DR-145 Trigger	[4] DLarrabee	[21062] a	\N	\N
19309703-358d-48cf-ab6d-fc9a845b8bd8	2018-03-02 12:02:03.250059-06	2	[16444] DR-146 Trigger	[4] DLarrabee	[21062] a	\N	\N
8a1e62bc-ee1e-4811-9f0c-117c510a235a	2018-03-02 12:02:03.265056-06	2	[16445] DR-201 Trigger	[4] DLarrabee	[21062] a	\N	\N
b8c872fd-5204-4b73-9880-4f795b16b9db	2018-03-02 12:02:03.270055-06	2	[16446] DR-202 Trigger	[4] DLarrabee	[21062] a	\N	\N
c5d4315a-78da-46d5-8738-2c81b84b53ec	2018-03-02 12:02:03.274054-06	2	[16447] DR-203 Trigger	[4] DLarrabee	[21062] a	\N	\N
a74fc024-2e9d-425f-bae8-644a6b66abbf	2018-03-02 12:02:03.278053-06	2	[16448] DR-205 Trigger	[4] DLarrabee	[21062] a	\N	\N
926a9c98-0c3f-49c9-ba74-4c8ebf17e251	2018-03-02 12:02:03.29205-06	2	[16449] DR-206 Trigger	[4] DLarrabee	[21062] a	\N	\N
6b9d5cb6-b52c-4a52-8d08-1b6bc401c1e7	2018-03-02 12:02:03.298049-06	2	[16450] DR-207 Trigger	[4] DLarrabee	[21062] a	\N	\N
07cae569-42d0-494c-9464-71703039555a	2018-03-02 12:02:03.305048-06	2	[16451] DR-209A Trigger	[4] DLarrabee	[21062] a	\N	\N
2f074329-687e-4b3b-820d-282222ebb85e	2018-03-02 12:02:03.309047-06	2	[16452] DR-209B Trigger	[4] DLarrabee	[21062] a	\N	\N
f5f48c88-b461-4de1-8b1f-951926b74212	2018-03-02 12:02:03.316046-06	2	[16453] DR-211 Trigger	[4] DLarrabee	[21062] a	\N	\N
151a1c93-afa0-4d8f-9e9d-155c172c1215	2018-03-02 12:02:03.319045-06	2	[16454] DR-213 Trigger	[4] DLarrabee	[21062] a	\N	\N
1fb0a206-b5bb-49b3-bc3c-33ad24913b11	2018-03-02 12:02:03.322044-06	2	[16455] DR-214 Trigger	[4] DLarrabee	[21062] a	\N	\N
c2bdb18e-977a-4ee8-b8cd-b33c0e2976d7	2018-03-02 12:02:03.326044-06	2	[16456] DR-215 Trigger	[4] DLarrabee	[21062] a	\N	\N
c66e4038-4032-4a2f-ac2f-df434fed06b9	2018-03-02 12:02:03.330043-06	2	[16457] DR-216 Trigger	[4] DLarrabee	[21062] a	\N	\N
4c719029-eb25-477c-adfb-810e11bb19d1	2018-03-02 12:02:03.334042-06	2	[16458] DR-218 Trigger	[4] DLarrabee	[21062] a	\N	\N
5069e554-473a-4b0c-a779-5880806651b1	2018-03-02 12:03:21.704365-06	2	[16763] DR-219 Trigger	[4] DLarrabee	[21062] a	\N	\N
864da134-5d9b-41e7-9c89-2f875fab338b	2018-03-02 12:03:21.709364-06	2	[16764] DR-221 Trigger	[4] DLarrabee	[21062] a	\N	\N
593e1e3a-e435-4993-b5a4-ed53e7b1c70f	2018-03-02 12:03:21.716362-06	2	[16765] DR-222 Trigger	[4] DLarrabee	[21062] a	\N	\N
0f722064-fd6d-4022-821a-bdec18f731f7	2018-03-02 12:03:21.720362-06	2	[16766] DR-223 Trigger	[4] DLarrabee	[21062] a	\N	\N
0ad4cdc9-cfec-471f-8681-d6b4247dfa90	2018-03-02 12:03:21.723361-06	2	[16767] DR-224 Trigger	[4] DLarrabee	[21062] a	\N	\N
8d6520d1-ecf6-44f0-8cc7-a07ba55125d0	2018-03-02 12:03:21.72736-06	2	[16768] DR-225 Trigger	[4] DLarrabee	[21062] a	\N	\N
03d2409d-7858-4d86-a217-cffffa7e1edf	2018-03-02 12:03:21.735359-06	2	[16769] DR-226 Trigger	[4] DLarrabee	[21062] a	\N	\N
c4f9b186-16f5-4f1f-b110-debc69e054af	2018-03-02 12:03:21.739358-06	2	[16770] DR-227 Trigger	[4] DLarrabee	[21062] a	\N	\N
315873f6-1d96-4d55-acf9-721adf29ad69	2018-03-02 12:03:21.742357-06	2	[16771] DR-228 Trigger	[4] DLarrabee	[21062] a	\N	\N
cba43a42-d50b-45c8-aa3b-df377c3ea2b4	2018-03-02 12:03:21.747356-06	2	[16772] DR-231 Trigger	[4] DLarrabee	[21062] a	\N	\N
bdc40b34-2d6f-4208-8bcf-d9596b610ac3	2018-03-02 12:03:21.750356-06	2	[16773] DR-232 Trigger	[4] DLarrabee	[21062] a	\N	\N
8392f3b7-903e-47ba-833a-cdf6221af93b	2018-03-02 12:03:21.754355-06	2	[16774] DR-233 Trigger	[4] DLarrabee	[21062] a	\N	\N
096f3a4c-4a3b-47e4-829c-ed907397af4f	2018-03-02 12:03:21.758354-06	2	[16775] DR-235 Trigger	[4] DLarrabee	[21062] a	\N	\N
31636c1a-42ef-4405-bf73-011eb5b28eb1	2018-03-02 12:03:21.762353-06	2	[16776] DR-236 Trigger	[4] DLarrabee	[21062] a	\N	\N
c7eb36c7-a02e-441c-89c5-301e68d28bbc	2018-03-02 12:03:21.766352-06	2	[16777] DR-237A Trigger	[4] DLarrabee	[21062] a	\N	\N
94cc4a48-0f0a-4169-8d42-40cfc4aedfda	2018-03-02 12:03:21.770352-06	2	[16778] DR-237B Trigger	[4] DLarrabee	[21062] a	\N	\N
c3515776-0837-435e-9227-53a3175f638e	2018-03-02 12:04:26.376428-06	2	[17083] DR-239 Trigger	[4] DLarrabee	[21062] a	\N	\N
83238eb4-52d1-4cde-83f7-1206e94f50e2	2018-03-02 12:04:26.383426-06	2	[17084] DR-241 Trigger	[4] DLarrabee	[21062] a	\N	\N
2ec329f1-84b1-45c3-b781-fb41ca66a717	2018-03-02 12:04:26.391425-06	2	[17085] DR-242 Trigger	[4] DLarrabee	[21062] a	\N	\N
41ac792b-5104-4e36-8084-d6d50376abd9	2018-03-02 12:04:26.395424-06	2	[17086] DR-243 Trigger	[4] DLarrabee	[21062] a	\N	\N
d66e9999-7020-4625-aac7-e74f1cfdd05f	2018-03-02 12:04:26.399423-06	2	[17087] DR-245 Trigger	[4] DLarrabee	[21062] a	\N	\N
65a93e61-f4db-4552-b416-a19de8cafd00	2018-03-02 12:04:26.403422-06	2	[17088] DR-246 Trigger	[4] DLarrabee	[21062] a	\N	\N
d3b70028-5c3f-4e2e-84cd-27a0d0f5956d	2018-03-02 12:04:26.407422-06	2	[17089] DR-247 Trigger	[4] DLarrabee	[21062] a	\N	\N
f9d042b3-eb00-4c3a-9d9a-716be2492eb2	2018-03-02 12:04:26.411421-06	2	[17090] DR-248 Trigger	[4] DLarrabee	[21062] a	\N	\N
5ec3b931-d92c-4841-9e14-903be5ce2868	2018-03-02 12:04:26.41642-06	2	[17091] DR-252 Trigger	[4] DLarrabee	[21062] a	\N	\N
34152926-1821-454a-95be-204f09dc1266	2018-03-02 12:04:26.420419-06	2	[17092] DR-253 Trigger	[4] DLarrabee	[21062] a	\N	\N
a9dad59e-9b5b-4c12-8da0-4f319c67b26a	2018-03-02 12:04:26.423418-06	2	[17093] DR-259 Trigger	[4] DLarrabee	[21062] a	\N	\N
d10f82d7-7287-4c2b-b179-5e2ba1bc07c5	2018-03-02 12:04:26.427418-06	2	[17094] DR-261 Trigger	[4] DLarrabee	[21062] a	\N	\N
df590890-5363-410a-aff9-e4faa229a4b4	2018-03-02 12:04:26.431417-06	2	[17095] DR-301A Trigger	[4] DLarrabee	[21062] a	\N	\N
b2f18fcb-3f48-4e7c-a208-8e39054dd68b	2018-03-02 12:04:26.435416-06	2	[17096] DR-301B Trigger	[4] DLarrabee	[21062] a	\N	\N
4528010d-4a7a-48e7-b99c-5d40f1e89f1f	2018-03-02 12:04:26.438415-06	2	[17097] DR-306 Trigger	[4] DLarrabee	[21062] a	\N	\N
140bbbab-667d-49e7-8df0-38f787c83df4	2018-03-02 12:05:41.379424-06	2	[19192] DR-307 Trigger	[4] DLarrabee	[21062] a	\N	\N
4af6844a-8bfa-4255-aedd-48fb1e458702	2018-03-02 12:05:41.387423-06	2	[19193] DR-309 Trigger	[4] DLarrabee	[21062] a	\N	\N
314930ba-0a5a-4526-9516-a1579acc9d8f	2018-03-02 12:05:41.390422-06	2	[19194] DR-314 Trigger	[4] DLarrabee	[21062] a	\N	\N
511012a8-ab05-46a4-9e33-47d0440c4ba1	2018-03-02 12:05:41.394421-06	2	[19195] DR-322 Trigger	[4] DLarrabee	[21062] a	\N	\N
064ebf67-64c5-4b37-8380-c7c4b132fed6	2018-03-02 12:05:41.39842-06	2	[19196] DR-324A Trigger	[4] DLarrabee	[21062] a	\N	\N
1888baea-0054-4c65-a604-fc6a8a8471c2	2018-03-02 12:05:41.405419-06	2	[19197] DR-324B Trigger	[4] DLarrabee	[21062] a	\N	\N
145ea7f3-837b-44d5-9fb1-87be1376846d	2018-03-02 12:05:41.411418-06	2	[19198] DR-324C Trigger	[4] DLarrabee	[21062] a	\N	\N
91a8485f-e25e-4a8a-ae2b-8611c450c76d	2018-03-02 12:05:41.414417-06	2	[19199] DR-333 Trigger	[4] DLarrabee	[21062] a	\N	\N
54438e7c-347e-4a71-be3d-b18d65ac9abb	2018-03-02 12:05:41.419416-06	2	[19200] DR-330A Trigger	[4] DLarrabee	[21062] a	\N	\N
f0b6effe-e3b9-4931-859e-bee077009244	2018-03-02 12:05:41.425415-06	2	[19201] DR-330B Trigger	[4] DLarrabee	[21062] a	\N	\N
1941b4c4-70e2-4b62-b748-fd218e3594b9	2018-03-02 12:05:41.429414-06	2	[19202] DR-378 Trigger	[4] DLarrabee	[21062] a	\N	\N
8b5cde39-6e4c-47bd-9289-237457dbbf6c	2018-03-02 12:05:41.435413-06	2	[19203] DR-414A Trigger	[4] DLarrabee	[21062] a	\N	\N
0ecd7f11-c6f0-48e3-8a52-d78c576aaf03	2018-03-02 12:05:41.440412-06	2	[19204] DR-414B Trigger	[4] DLarrabee	[21062] a	\N	\N
3ba75fc5-d8ed-4ba6-bd44-3acd20528782	2018-03-02 12:05:41.444411-06	2	[19205] OPEN-323OHD Trigger	[4] DLarrabee	[21062] a	\N	\N
6d501c1f-4b26-4bf0-a2b3-d769b60562a5	2018-03-02 12:05:41.44841-06	2	[19206] CLOSE-323OHD Trigger	[4] DLarrabee	[21062] a	\N	\N
9da7523f-1f99-41ec-ae7c-2e53d0923aa3	2018-03-02 12:05:41.45141-06	2	[19207] OPEN-324OHDE Trigger	[4] DLarrabee	[21062] a	\N	\N
1f7a2b63-48f7-47fc-98bf-5ed91663d892	2018-03-02 12:06:46.412964-06	2	[19512] CLOSE-324OHDE Trigger	[4] DLarrabee	[21062] a	\N	\N
3d876013-8916-429a-9e32-41bf5e082f07	2018-03-02 12:06:46.417964-06	2	[19513] OPEN-324OHDW Trigger	[4] DLarrabee	[21062] a	\N	\N
b32e83ca-47d3-4529-a2ee-808fd7e19c76	2018-03-02 12:06:46.420964-06	2	[19514] CLOSE-324OHDW Trigger	[4] DLarrabee	[21062] a	\N	\N
9814fb54-c43d-4a42-bea5-cc4013d10ed2	2018-03-02 12:08:24.836964-06	2	[20301] Trigger-429A Trigger	[4] DLarrabee	[21062] a	\N	\N
c42ecea7-a237-44c6-b75f-f7d470365703	2018-03-02 12:08:24.841964-06	2	[20302] Trigger-429B Trigger	[4] DLarrabee	[21062] a	\N	\N
965c3cd6-c558-491f-935d-c55277533edf	2018-03-02 12:08:24.845964-06	2	[20303] Trigger-429C Trigger	[4] DLarrabee	[21062] a	\N	\N
d1bf6dab-d457-4ed8-9125-b3234e38b231	2018-03-02 12:08:24.850964-06	2	[20304] Trigger-456 Trigger	[4] DLarrabee	[21062] a	\N	\N
427d0143-f943-4366-a916-d7c3d6be0745	2018-03-02 12:08:24.853964-06	2	[20305] Trigger-461 Trigger	[4] DLarrabee	[21062] a	\N	\N
d0199c62-cbc1-48a1-947e-00e4b6b3df9b	2018-03-02 12:08:24.857964-06	2	[20306] Trigger-514 Trigger	[4] DLarrabee	[21062] a	\N	\N
57b99ad0-dd5a-42fe-8590-886d2b7e1a5f	2018-03-02 12:08:24.861964-06	2	[20307] Trigger-529 Trigger	[4] DLarrabee	[21062] a	\N	\N
0b92ec0d-4937-4be0-9221-2a39178ed3d2	2018-03-02 12:10:11.036964-06	2	[21732] New DW Spectrum NVR	[4] DLarrabee	[21062] a	\N	\N
687b6dc9-f6ba-42c8-9d02-7e879baa9de7	2018-03-02 12:10:11.073964-06	1	[21982] New Digital Watchdog Camera	[4] DLarrabee	[21062] a	\N	\N
4562c473-86f8-434d-87dc-dd8d74960192	2018-03-02 12:10:11.095964-06	1	[22006] New Digital Watchdog Camera (1)	[4] DLarrabee	[21062] a	\N	\N
88da0f37-88e9-4aa8-8601-c73900a6e31f	2018-03-02 12:10:11.112964-06	1	[22008] New Digital Watchdog Camera (2)	[4] DLarrabee	[21062] a	\N	\N
14a9c5b9-7b28-43c2-a5a1-619a451723ba	2018-03-02 12:10:11.127964-06	1	[22010] New Digital Watchdog Camera (3)	[4] DLarrabee	[21062] a	\N	\N
eaf7ba9c-d7a7-472b-a2b5-e9dfefda0d50	2018-03-02 12:10:11.142964-06	1	[22012] New Digital Watchdog Camera (4)	[4] DLarrabee	[21062] a	\N	\N
27c564e0-a913-46c0-89a2-d0939a3835cc	2018-03-02 12:35:24.449034-06	2	[21157] Door 103	[4] DLarrabee	[21062] a	\N	\N
3c7e5957-d10e-4ef3-8bc7-656e2d17c1f0	2018-03-02 12:35:41.253714-06	2	[21158] Door 104	[4] DLarrabee	[21062] a	\N	\N
8aacb63f-6cfc-45f2-9c6c-aa734ae6e3fa	2018-03-02 12:36:08.940483-06	2	[21159] Door 105	[4] DLarrabee	[21062] a	\N	\N
eb15e43e-cdaf-45d8-8705-642cb78fcb5d	2018-03-02 12:36:36.689257-06	2	[21160] Door 107	[4] DLarrabee	[21062] a	\N	\N
e60f1f8a-b424-4967-9e69-257e195dc752	2018-03-02 12:37:08.845473-06	2	[21161] Door 108	[4] DLarrabee	[21062] a	\N	\N
916569de-c463-4f94-b539-9031d340414f	2018-03-02 12:37:35.593147-06	2	[21163] Door 109	[4] DLarrabee	[21062] a	\N	\N
8daf6b01-ecdd-45d8-8ce9-6a4aaf34eae1	2018-03-02 12:38:26.792266-06	2	[21053] Door 112	[4] DLarrabee	[21062] a	\N	\N
76f88c4e-82de-41b7-91bf-e1898ef57b6c	2018-03-02 12:38:42.656853-06	1	[22014] IC 405A Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
b37ca72b-7f1e-4fce-a08c-a3d174ccd0b9	2018-03-02 12:38:55.061093-06	2	[21212] Door 113	[4] DLarrabee	[21062] a	\N	\N
2dbda93a-1c5e-4d0c-87d4-70ef7ce93065	2018-03-02 12:39:41.478734-06	2	[22014] IC 429A	[21041] OSSI-DNOVAK	[293] master	\N	\N
8691b4b0-81b2-4e9c-a318-02c31906a3ce	2018-03-02 12:39:42.146801-06	2	[21078] Door 114A	[4] DLarrabee	[21062] a	\N	\N
8d8e2597-6e78-4af6-a554-dd831536d07d	2018-03-02 12:39:46.580244-06	1	[22015] IC 429A Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
540e5e06-abb0-4da1-8fa7-c776323a254e	2018-03-02 12:40:26.655252-06	2	[22015] IC 429B	[21041] OSSI-DNOVAK	[293] master	\N	\N
3d33e0e8-761d-4538-9921-6cca8a653485	2018-03-02 12:40:32.03679-06	1	[22016] IC 429B Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
a50f6f2e-91c9-41d2-9f44-5bda07d827ae	2018-03-02 12:40:52.348821-06	2	[21227] Door 114B	[4] DLarrabee	[21062] a	\N	\N
754c25a2-e43d-495f-bf75-1ed3819b928e	2018-03-02 12:41:31.856771-06	2	[22016] IC 429C	[21041] OSSI-DNOVAK	[293] master	\N	\N
f07ee67c-36f4-48df-9e0e-986cd9509d65	2018-03-02 12:41:32.04879-06	2	[21079] Door 115	[4] DLarrabee	[21062] a	\N	\N
e8ce4139-9043-4f6b-9f39-978364e2d089	2018-03-02 12:42:01.84877-06	2	[21080] Door 116	[4] DLarrabee	[21062] a	\N	\N
1954ad0f-2433-4082-8179-b1f03d4b2e86	2018-03-02 12:42:15.781163-06	1	[22017] IC 429C Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
c5cdf5c5-ed2d-4359-8430-6656377cc632	2018-03-02 12:42:30.261611-06	2	[21083] Door 117	[4] DLarrabee	[21062] a	\N	\N
938c0f83-99b9-4392-b79e-29e26e1c8677	2018-03-02 12:43:08.966481-06	2	[22017] IC 456	[21041] OSSI-DNOVAK	[293] master	\N	\N
76ad14f5-9c31-4cd5-a4de-6241bd756f43	2018-03-02 12:43:14.117996-06	1	[22018] IC 456 Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
3f9f450a-66ef-4674-9fc6-0bf36b6a1705	2018-03-02 12:43:28.989483-06	2	[21061] Door 119	[4] DLarrabee	[21062] a	\N	\N
f32269d2-a6a7-47af-8eb3-9281b5964572	2018-03-02 12:43:58.911475-06	2	[22018] IC 461	[21041] OSSI-DNOVAK	[293] master	\N	\N
8db2499d-3894-4a72-bcf3-7dbbcc1af90e	2018-03-02 12:44:15.473131-06	2	[21164] Door 121	[4] DLarrabee	[21062] a	\N	\N
14f9a478-3c86-4e34-bf56-697ce8a37be4	2018-03-02 12:44:29.270511-06	1	[22019] IC 461 Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
1292d59e-f1ae-41dd-83df-b55784bd72f0	2018-03-02 12:44:46.439227-06	2	[21165] Door 122	[4] DLarrabee	[21062] a	\N	\N
3128f673-b198-47af-81d9-6b90b0682b14	2018-03-02 12:45:37.996383-06	2	[22019] IC 514	[21041] OSSI-DNOVAK	[293] master	\N	\N
537c9eb1-28bd-43cf-a086-ed4d78b8186f	2018-03-02 12:45:41.159699-06	1	[22020] IC 514 Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
d150dfb4-8fd4-47d2-8359-fac744f7ae37	2018-03-02 12:45:55.033086-06	2	[21166] Door 123	[4] DLarrabee	[21062] a	\N	\N
cbd12c56-c7c0-4a1e-8414-9674f59e016c	2018-03-02 12:46:17.817364-06	2	[22020] IC 529	[21041] OSSI-DNOVAK	[293] master	\N	\N
25e34af2-8049-4762-80ee-5469ea380703	2018-03-02 12:46:19.37852-06	2	[21086] Door 124	[4] DLarrabee	[21062] a	\N	\N
b8ef485e-11cf-431e-aa3a-d2e9ca1d1a29	2018-03-02 12:46:52.367819-06	2	[21082] Door 125	[4] DLarrabee	[21062] a	\N	\N
b10188b7-3a89-46a9-9822-2f289547bacd	2018-03-02 12:47:25.466128-06	2	[21081] Door 126	[4] DLarrabee	[21062] a	\N	\N
58ee8e40-68c7-4a03-a96d-b2c210a3df67	2018-03-02 12:47:51.808762-06	2	[21167] Door 128	[4] DLarrabee	[21062] a	\N	\N
62a31fa8-d570-4460-b180-3b197a1984f6	2018-03-02 12:48:21.014683-06	2	[21168] Door 129	[4] DLarrabee	[21062] a	\N	\N
b626664b-1470-4565-ae80-dfd9cde3c7c3	2018-03-02 12:48:50.359617-06	2	[21169] Door 131	[4] DLarrabee	[21062] a	\N	\N
6e80f5be-8ba0-4167-81ac-e211c599661e	2018-03-02 12:49:33.760957-06	2	[21170] Door 132	[4] DLarrabee	[21062] a	\N	\N
83b21715-46ea-44fe-b6d3-6d6bb6fd967f	2018-03-02 12:49:55.560136-06	2	[21171] Door 133	[4] DLarrabee	[21062] a	\N	\N
761fe20f-9d86-4abb-92c7-a44b4a0af615	2018-03-02 12:50:29.156496-06	2	[21172] Door 134A	[4] DLarrabee	[21062] a	\N	\N
2e271738-2f66-4fbf-91cf-8dde65d8afe6	2018-03-02 12:50:53.00088-06	2	[21173] Door 134B	[4] DLarrabee	[21062] a	\N	\N
0c53e1a4-57e7-4a91-bd3e-ce6ebeb7efdf	2018-03-02 12:51:22.313811-06	2	[21174] Door 136	[4] DLarrabee	[21062] a	\N	\N
05a8110a-50bc-4b55-990c-0eb98c617c42	2018-03-02 12:51:51.338713-06	2	[21175] Door 137	[4] DLarrabee	[21062] a	\N	\N
56c83029-ce33-420f-8111-e1e3f5cb8109	2018-03-02 12:52:17.562335-06	2	[21176] Door 138	[4] DLarrabee	[21062] a	\N	\N
f3088a2e-ab61-411b-8cbf-926b810cab0d	2018-03-02 12:53:17.453324-06	2	[21177] Door 141	[4] DLarrabee	[21062] a	\N	\N
cd9c1aff-5bd7-429d-b010-7ace8683ff50	2018-03-02 12:55:36.33221-06	2	[1980] R1C3-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
6e939618-d02f-43d9-a268-b7bdf58f67cf	2018-03-02 13:06:54.452015-06	2	[2300] R1C4-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
544d1bd0-8cb1-4d6b-b179-15663ffb8d72	2018-03-02 13:12:33.442911-06	2	[2620] R1C5-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
cd2503d9-d3f4-497b-b67f-5287e3a1b0da	2018-03-02 13:26:10.598618-06	2	[21178] Door 142	[4] DLarrabee	[21062] a	\N	\N
9b779fce-d07e-480d-95ae-c0b570f8c8ab	2018-03-02 13:27:49.100468-06	2	[21180] Door 146	[4] DLarrabee	[21062] a	\N	\N
38ad5791-045c-4427-87e7-144e1ce2b6b5	2018-03-02 13:28:54.994056-06	2	[21473] Door 145	[4] DLarrabee	[21062] a	\N	\N
a33be136-a872-4e66-b26b-6fa148835d53	2018-03-02 13:29:47.627319-06	2	[21473] Door 145	[4] DLarrabee	[21062] a	\N	\N
050e5b67-1f40-4097-97cd-f2525dba5048	2018-03-02 13:32:22.069762-06	2	[21180] Door 146	[4] DLarrabee	[21062] a	\N	\N
746799fa-5082-4fad-9b0e-d77e4cf5a773	2018-03-02 13:32:40.984653-06	2	[21473] Door 145	[4] DLarrabee	[21062] a	\N	\N
a5f70b59-8dde-4602-ac26-e26c7a586d40	2018-03-02 13:34:45.407094-06	2	[15783] R7C1-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
cca6aab3-25a7-43f1-b37f-5e934f6fdaf8	2018-03-02 13:36:20.885641-06	2	[15783] R7C1-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
e971bda3-d61f-4b50-a01e-c89fda5f2c4b	2018-03-02 13:36:49.306483-06	2	[21181] Door 201	[4] DLarrabee	[21062] a	\N	\N
912ed4b4-7dde-41f6-93ac-bd03234bef75	2018-03-02 13:37:14.38399-06	2	[21182] Door 202	[4] DLarrabee	[21062] a	\N	\N
6ac342f2-62a1-43a9-8c9d-8e21aaf820f0	2018-03-02 13:37:37.513303-06	2	[21183] Door 203	[4] DLarrabee	[21062] a	\N	\N
e9f02ec9-0b3a-49aa-8163-1edbf9fd9dee	2018-03-02 13:38:01.100662-06	2	[21184] Door 205	[4] DLarrabee	[21062] a	\N	\N
6cd0c473-144d-40fd-8d24-2793db64d6d9	2018-03-02 13:38:30.924644-06	2	[21185] Door 206	[4] DLarrabee	[21062] a	\N	\N
2806db9b-8970-47f3-8a92-75dd4bd17be0	2018-03-02 13:39:30.541605-06	2	[21185] Door 206	[4] DLarrabee	[21062] a	\N	\N
4fa1d910-513f-4f21-a952-2f122824596e	2018-03-02 13:39:50.260576-06	2	[21186] Door 207	[4] DLarrabee	[21062] a	\N	\N
8e01eb3f-a801-45b9-b101-25887ac9fabb	2018-03-02 13:40:17.280278-06	2	[21187] Door 209A	[4] DLarrabee	[21062] a	\N	\N
131792f6-3879-49fa-9191-0240fe3aaad3	2018-03-02 13:40:43.885938-06	2	[21188] Door 209B	[4] DLarrabee	[21062] a	\N	\N
76934307-b573-4823-b68e-89d983dc9b00	2018-03-02 13:41:18.679417-06	2	[21189] Door 211	[4] DLarrabee	[21062] a	\N	\N
45ae3a6f-9628-4f7c-bf23-9c2a59b42502	2018-03-02 13:41:26.626212-06	2	[16103] R7C2-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
6331b701-2dc7-4615-a451-810f5811f1a8	2018-03-02 13:41:46.414191-06	2	[21190] Door 213	[4] DLarrabee	[21062] a	\N	\N
7e61995d-ef55-4d7c-beb3-fcd05dcedbe2	2018-03-02 13:42:12.783827-06	2	[21191] Door 214	[4] DLarrabee	[21062] a	\N	\N
92a726d9-cffe-4b6f-b480-91fab2dbecff	2018-03-02 13:42:42.41079-06	2	[21192] Door 215	[4] DLarrabee	[21062] a	\N	\N
a2397aa0-ccbc-41fd-ad72-d428263f319a	2018-03-02 13:43:08.392388-06	2	[21193] Door 216	[4] DLarrabee	[21062] a	\N	\N
8c732407-bb78-468a-afa8-e8061077502a	2018-03-02 13:43:45.125061-06	2	[21194] Door 218	[4] DLarrabee	[21062] a	\N	\N
596a4e50-c5ee-4757-91e1-5df7846db52e	2018-03-02 13:45:40.413588-06	2	[21195] Door 219	[4] DLarrabee	[21062] a	\N	\N
e8d03965-021b-4a78-8d76-44787472ab66	2018-03-02 13:45:58.12936-06	2	[16423] R7C3-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
6fba4ff1-3429-468c-8098-035787029cd5	2018-03-02 13:46:47.658312-06	2	[21196] Door 221	[4] DLarrabee	[21062] a	\N	\N
a70001a8-319e-43f0-9fed-4addf607eabd	2018-03-02 13:47:29.64451-06	2	[21197] Door 222	[4] DLarrabee	[21062] a	\N	\N
73060969-9791-430c-9eff-79681b396168	2018-03-02 13:47:58.192365-06	2	[21198] Door 223	[4] DLarrabee	[21062] a	\N	\N
b7bac1a5-5f06-4aed-96bc-5d9fd6116921	2018-03-02 13:48:25.880133-06	2	[21199] Door 224	[4] DLarrabee	[21062] a	\N	\N
5b231f89-7822-4783-bc24-2b3f7a163d27	2018-03-02 13:48:55.24907-06	2	[21200] Door 225	[4] DLarrabee	[21062] a	\N	\N
4462d6e8-233d-451b-81de-991671005644	2018-03-02 13:49:23.476892-06	2	[21201] Door 226	[4] DLarrabee	[21062] a	\N	\N
239b4d6f-483f-4c92-bade-1ba423a3ce4f	2018-03-02 13:49:48.846429-06	2	[21202] Door 227	[4] DLarrabee	[21062] a	\N	\N
70aa81fa-166f-4e91-8acf-b88cacad346b	2018-03-02 13:50:17.413285-06	2	[21203] Door 228	[4] DLarrabee	[21062] a	\N	\N
ffab9f18-7bc1-4bc6-92e7-4de3844635c1	2018-03-02 13:50:48.65841-06	2	[21204] Door 231	[4] DLarrabee	[21062] a	\N	\N
ec730164-47b9-4e52-b6ad-2cb935e59178	2018-03-02 13:51:13.282872-06	2	[21205] Door 232	[4] DLarrabee	[21062] a	\N	\N
cca48420-340f-4949-beb6-3fe6b0777178	2018-03-02 13:51:50.46759-06	2	[21205] Door 232	[4] DLarrabee	[21062] a	\N	\N
53f8f533-fcb9-4080-8262-0bbb6030aba9	2018-03-02 13:52:18.156359-06	2	[21206] Door 233	[4] DLarrabee	[21062] a	\N	\N
2932d91e-2216-426e-8030-9d7aaeb29538	2018-03-02 13:52:49.036446-06	2	[21207] Door 235	[4] DLarrabee	[21062] a	\N	\N
89476588-de1b-4442-a909-a9fd877bcc50	2018-03-02 13:53:22.525795-06	2	[21208] Door 236	[4] DLarrabee	[21062] a	\N	\N
102e87c6-01aa-47da-9f2f-44083df1ed8c	2018-03-02 13:53:59.98154-06	2	[21256] Door 237A	[4] DLarrabee	[21062] a	\N	\N
47361c25-ecb5-49ed-b290-63947bed787b	2018-03-02 13:55:10.150556-06	2	[21271] Door 237B	[4] DLarrabee	[21062] a	\N	\N
072519f9-d713-42dd-8bdc-978df8e09ed5	2018-03-02 13:56:00.787619-06	2	[21271] Door 237B	[4] DLarrabee	[21062] a	\N	\N
79da0d3e-fe97-4585-938e-ce5bc16ef114	2018-03-02 13:57:16.837224-06	2	[21272] Door 239	[4] DLarrabee	[21062] a	\N	\N
da967d4f-95f5-4080-befa-d31d676d5e65	2018-03-02 13:57:46.613201-06	2	[21273] Door 241	[4] DLarrabee	[21062] a	\N	\N
098149e6-cb12-43b5-8568-7ff40d0f4886	2018-03-02 13:58:43.11085-06	2	[21274] Door 242	[4] DLarrabee	[21062] a	\N	\N
8be25dc3-185c-4896-83f2-ccae31d39ede	2018-03-02 13:59:07.128252-06	2	[21275] Door 243	[4] DLarrabee	[21062] a	\N	\N
b3e5c442-e929-4ec9-a359-214910718e2d	2018-03-02 13:59:38.027341-06	2	[21276] Door 245	[4] DLarrabee	[21062] a	\N	\N
1e502a87-3b69-4e39-9527-578f10fe2f4e	2018-03-02 14:00:14.353974-06	2	[21283] Door 246	[4] DLarrabee	[21062] a	\N	\N
f4ec19b9-f5a2-4904-bb96-b5ba3322030d	2018-03-02 14:00:42.026741-06	2	[21284] Door 247	[4] DLarrabee	[21062] a	\N	\N
6eb101bf-ae8a-479f-b21c-8c2cbeee4ea5	2018-03-02 14:01:08.558393-06	2	[21285] Door 248	[4] DLarrabee	[21062] a	\N	\N
7a675b4d-abe2-4489-bb61-1ccac9a23d62	2018-03-02 14:01:39.032441-06	2	[21286] Door 252	[4] DLarrabee	[21062] a	\N	\N
f7198d35-d296-48f1-af74-49c58e83dd6b	2018-03-02 14:02:09.720509-06	2	[21287] Door 253	[4] DLarrabee	[21062] a	\N	\N
210022d5-746f-4298-bfd0-ac119d8619c4	2018-03-02 14:02:35.243061-06	2	[21289] Door 261	[4] DLarrabee	[21062] a	\N	\N
9a86b718-904c-4ef4-a4fc-4e96870d73f3	2018-03-02 14:03:11.448681-06	2	[21268] Door 306	[4] DLarrabee	[21062] a	\N	\N
ae4e09ba-a431-4fe8-85fc-d500d5bea2eb	2018-03-02 14:03:50.317568-06	2	[21268] Door 306	[4] DLarrabee	[21062] a	\N	\N
f8aa3f17-060b-4969-9b85-049e1efedf26	2018-03-02 14:05:13.416877-06	2	[16743] R7C4-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
433966b5-2fbc-44c6-a5bd-1bd0dbe4a324	2018-03-02 14:07:09.880522-06	2	[21291] Door 301B	[4] DLarrabee	[21062] a	\N	\N
49cf029f-d66d-46b7-b98f-623e18428021	2018-03-02 14:07:43.104844-06	2	[21290] Door 301A	[4] DLarrabee	[21062] a	\N	\N
ae7e4545-463d-47fb-b7e3-909dc4e3dfc6	2018-03-02 14:09:16.722205-06	2	[21288] Door 259	[4] DLarrabee	[21062] a	\N	\N
28e67c6e-d102-401d-8f5e-fbba586c29cc	2018-03-02 14:09:44.287961-06	2	[17063] R7C5-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
b30538e9-960b-4a5c-a551-75d51bba53b8	2018-03-02 14:12:35.701101-06	2	[21288] Door 259	[4] DLarrabee	[21062] a	\N	\N
fcd812a7-7ee4-41fd-9da8-1ae53a2a70ae	2018-03-02 14:13:54.018932-06	2	[21290] Door 301A	[4] DLarrabee	[21062] a	\N	\N
24a2fe96-57a4-4c83-a885-ae4c5c0f34ff	2018-03-02 14:14:03.226853-06	2	[21291] Door 301B	[4] DLarrabee	[21062] a	\N	\N
566426a5-7589-49e8-8e7f-ba6e481e8828	2018-03-02 14:15:32.959825-06	2	[19172] R8C5-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
8864ef39-6bde-447f-baa1-751dc860ba99	2018-03-02 14:26:56.045127-06	2	[21290] Door 301A	[4] DLarrabee	[21062] a	\N	\N
2ee9c6f5-c599-4edf-978d-dc328c55575b	2018-03-02 14:27:14.802002-06	2	[19208] R8C6	[21041] OSSI-DNOVAK	[293] master	\N	\N
8746a266-7c2a-4550-8341-30081ee70517	2018-03-02 14:27:17.286251-06	2	[19172] R8C5-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
b7bc9d8f-23f0-48b1-9e83-de0a33dd922b	2018-03-02 14:27:20.348557-06	2	[21291] Door 301B	[4] DLarrabee	[21062] a	\N	\N
6abb797d-b440-404c-bc7b-f1ad98ac7edf	2018-03-02 14:27:58.934415-06	2	[19208] R8C6 324OHD Close Relay	[21041] OSSI-DNOVAK	[293] master	\N	\N
f504202a-1ca2-4b99-9079-d7212e8fab02	2018-03-02 14:28:41.179639-06	2	[19172] R8C5-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
56a142f4-7559-4f39-9b74-2aebf3b8ca0a	2018-03-02 14:28:47.370258-06	1	[22021] General 33	[21041] OSSI-DNOVAK	[293] master	\N	\N
c21660b2-eb2e-4809-b423-e30981f52ce5	2018-03-02 14:28:47.401261-06	1	[22022] General 34	[21041] OSSI-DNOVAK	[293] master	\N	\N
c7616bf7-dba2-4813-9dde-10b8419f9e65	2018-03-02 14:28:47.406262-06	1	[22023] General 35	[21041] OSSI-DNOVAK	[293] master	\N	\N
7ac9ca59-246f-4df9-962f-36570e15027a	2018-03-02 14:28:47.410262-06	1	[22024] General 36	[21041] OSSI-DNOVAK	[293] master	\N	\N
a2b64d93-9d4b-4fda-b5f1-307a23680491	2018-03-02 14:28:47.418263-06	1	[22025] General 37	[21041] OSSI-DNOVAK	[293] master	\N	\N
86eb087b-c2da-4191-bbd1-e3b4e8494f12	2018-03-02 14:28:47.429264-06	1	[22026] General 38	[21041] OSSI-DNOVAK	[293] master	\N	\N
6acde5fe-b1a2-45a6-82cc-82dec591ef38	2018-03-02 14:28:47.433264-06	1	[22027] General 39	[21041] OSSI-DNOVAK	[293] master	\N	\N
ba7513ca-df91-49c1-b870-f7460bed2c81	2018-03-02 14:28:47.436265-06	1	[22028] General 40	[21041] OSSI-DNOVAK	[293] master	\N	\N
714da4a9-57cc-49a8-8744-4bb01b4db2d6	2018-03-02 14:28:47.440265-06	1	[22029] General 41	[21041] OSSI-DNOVAK	[293] master	\N	\N
0261f4d1-5f40-479c-bd23-f0e1e3ad9be9	2018-03-02 14:28:47.448266-06	1	[22030] General 42	[21041] OSSI-DNOVAK	[293] master	\N	\N
6c11797b-8f8a-4422-a3fb-c917355feb01	2018-03-02 14:28:47.452266-06	1	[22031] General 43	[21041] OSSI-DNOVAK	[293] master	\N	\N
7819de40-7033-4d14-a7c1-9ad1b3c1d5a5	2018-03-02 14:28:47.456267-06	1	[22032] General 44	[21041] OSSI-DNOVAK	[293] master	\N	\N
447a1fb3-fbe4-414a-b18f-f4ae161baf64	2018-03-02 14:28:47.460267-06	1	[22033] General 45	[21041] OSSI-DNOVAK	[293] master	\N	\N
ebe5a481-bb24-4a1e-8094-4eb281141f15	2018-03-02 14:28:47.465268-06	1	[22034] General 46	[21041] OSSI-DNOVAK	[293] master	\N	\N
842a92db-16cf-4382-8a80-08e6a9a22153	2018-03-02 14:28:47.478269-06	1	[22035] General 47	[21041] OSSI-DNOVAK	[293] master	\N	\N
62110300-9219-4fb6-adfc-d9dd76e0cc3b	2018-03-02 14:28:47.484269-06	1	[22036] General 48	[21041] OSSI-DNOVAK	[293] master	\N	\N
012e04e6-8ab9-4c19-b944-123945e522e8	2018-03-02 14:28:47.48827-06	1	[22037] General 49	[21041] OSSI-DNOVAK	[293] master	\N	\N
63a4dd11-37f1-487f-9269-459aaeac09da	2018-03-02 14:28:47.49327-06	1	[22038] General 50	[21041] OSSI-DNOVAK	[293] master	\N	\N
49876407-ee79-424b-be46-f524335a1127	2018-03-02 14:28:47.496271-06	1	[22039] General 51	[21041] OSSI-DNOVAK	[293] master	\N	\N
8c4c9c2f-8f0e-4f33-9f86-3f75ef079e8b	2018-03-02 14:28:47.500271-06	1	[22040] General 52	[21041] OSSI-DNOVAK	[293] master	\N	\N
807f717f-7954-40e9-a085-c63f684eb51c	2018-03-02 14:28:47.504271-06	1	[22041] General 53	[21041] OSSI-DNOVAK	[293] master	\N	\N
b695ecac-e615-46a1-a9ee-37b0d789137a	2018-03-02 14:28:47.508272-06	1	[22042] General 54	[21041] OSSI-DNOVAK	[293] master	\N	\N
431d40e7-403c-4f8b-8263-42098fc558fa	2018-03-02 14:28:47.512272-06	1	[22043] General 55	[21041] OSSI-DNOVAK	[293] master	\N	\N
5d42b00d-749c-4f5b-8b55-41c8b274e19c	2018-03-02 14:28:47.515273-06	1	[22044] General 56	[21041] OSSI-DNOVAK	[293] master	\N	\N
ac501a42-ee48-43db-b371-a9048f4e022c	2018-03-02 14:28:47.519273-06	1	[22045] General 57	[21041] OSSI-DNOVAK	[293] master	\N	\N
ce61abd1-8772-46d1-a66d-5f0c4518896c	2018-03-02 14:28:47.525274-06	1	[22046] General 58	[21041] OSSI-DNOVAK	[293] master	\N	\N
a95bd9dc-b59c-462b-ba6f-af54a570d857	2018-03-02 14:28:47.529274-06	1	[22047] General 59	[21041] OSSI-DNOVAK	[293] master	\N	\N
d9a9743d-64d5-4f3c-80c9-21be0cf29b82	2018-03-02 14:28:47.532274-06	1	[22048] General 60	[21041] OSSI-DNOVAK	[293] master	\N	\N
b11fbb67-f7c5-45f3-9f71-584767694627	2018-03-02 14:28:47.536275-06	1	[22049] General 61	[21041] OSSI-DNOVAK	[293] master	\N	\N
6c69d0ab-3bbc-4005-9d1a-3bee17c08eda	2018-03-02 14:28:47.541275-06	1	[22050] General 62	[21041] OSSI-DNOVAK	[293] master	\N	\N
d619b5cd-829f-4b32-94f6-27c4c47ff9db	2018-03-02 14:28:47.545276-06	1	[22051] General 63	[21041] OSSI-DNOVAK	[293] master	\N	\N
e2f80f66-969f-42f4-8b04-f2dd7a860a63	2018-03-02 14:28:47.550276-06	1	[22052] General 64	[21041] OSSI-DNOVAK	[293] master	\N	\N
6bb8fe7c-ccbc-41e4-b755-cdc391042c0a	2018-03-02 14:34:11.840702-06	2	[19172] R8C5-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
b6cab78d-ead2-426b-aa0c-d1565a59b179	2018-03-02 14:34:22.790797-06	2	[19172] R8C5-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
1386871d-a251-4bfb-8841-f9b37ef54829	2018-03-02 14:34:40.609578-06	2	[22002] 306	[4] DLarrabee	[21062] a	\N	\N
577eb764-7a90-4c99-9655-32007ca7b9b4	2018-03-02 14:36:56.805197-06	2	[21292] Door 306	[4] DLarrabee	[21062] a	\N	\N
5f3a1366-e530-4b59-be0b-06223ec5a5cf	2018-03-02 14:38:42.022717-06	2	[22001] 316	[4] DLarrabee	[21062] a	\N	\N
4de65a54-0b2a-4883-a4df-44dd5d609c50	2018-03-02 14:43:31.911703-06	2	[19172] R8C5-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
50e5e4c2-ec61-4508-ab4d-42fa2fe55b00	2018-03-02 14:47:14.29594-06	2	[19172] R8C5-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
97d2fb42-7f2a-4384-a68a-3edc15ea1537	2018-03-02 14:48:08.295339-06	2	[19528] R8C6 324OHD Close Relay	[21041] OSSI-DNOVAK	[293] master	\N	\N
f8f3fec9-a053-40fb-8c0b-1c96cf5aef92	2018-03-02 14:53:06.792186-06	2	[21096] Door 316B	[4] DLarrabee	[21062] a	\N	\N
44354928-3ff0-4918-986f-577ecd76d90e	2018-03-02 14:53:40.090515-06	1	[22053] Door 316B Copy	[4] DLarrabee	[21062] a	\N	\N
88af2606-0d13-4a3a-bafd-d3142661327b	2018-03-02 14:55:35.096015-06	2	[19492] R8C6-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
49b846d9-17aa-41b7-8bdc-a10063a51832	2018-03-02 14:57:13.76388-06	2	[22053] Door 316B -2	[4] DLarrabee	[21062] a	\N	\N
fccc8369-d6d0-4225-988c-ec212d1bfa3d	2018-03-02 14:57:39.422446-06	2	[20281] 9C2-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
9c4664da-ff1c-4599-a13c-5cafaf97d425	2018-03-02 15:07:07.249223-06	2	[21251] IC 316B-in B	[4] DLarrabee	[21062] a	\N	\N
183ef1cf-cde5-4a8e-9972-5e49c75924da	2018-03-02 15:09:59.514448-06	2	[21277] IC 316B-OUT B	[4] DLarrabee	[21062] a	\N	\N
cfbc53df-851e-41c7-b3c1-004f562bfcbc	2018-03-02 15:21:56.062095-06	2	[21277] IC 316B-OUT B	[4] DLarrabee	[21062] a	\N	\N
9964c430-27b9-4c48-a6e2-823c92ff11df	2018-03-02 15:32:34.102893-06	2	[16743] R7C4-16R	[4] DLarrabee	[21062] a	\N	\N
b423b278-dd39-48c7-9b8b-c6f17b12ce7e	2018-03-02 16:10:24.941954-06	2	[21096] Door 316B	[4] DLarrabee	[21062] a	\N	\N
bfa1650a-da01-40fa-8480-659c6fd77c93	2018-03-02 16:12:20.71553-06	1	[22054] IC 316B-in B Copy	[4] DLarrabee	[21062] a	\N	\N
753c6707-c36c-4c3c-8269-24a15cbf5a2e	2018-03-02 16:13:09.907449-06	2	[22054] IC 316B-2-in B 	[4] DLarrabee	[21062] a	\N	\N
8bd6787b-c737-4313-a3b2-ad05d45e32f9	2018-03-02 16:13:53.396798-06	1	[22055] IC 316B-2-in B  Copy	[4] DLarrabee	[21062] a	\N	\N
9dfcede5-304a-4297-99a8-7771fb4d0b84	2018-03-02 16:18:47.416197-06	2	[22055] IC 316B-2-Out B	[4] DLarrabee	[21062] a	\N	\N
7bc5e643-af37-4acc-999e-b005a899d763	2018-03-02 16:20:29.790433-06	2	[22054] IC 316B-2-in B 	[4] DLarrabee	[21062] a	\N	\N
8fc0ed6e-1807-4e7f-bbc4-f4166681b6c8	2018-03-02 16:22:42.615714-06	2	[21251] IC 316B-in B	[4] DLarrabee	[21062] a	\N	\N
acf3116b-24ac-4c3d-b46d-263b93388eed	2018-03-02 16:34:54.674913-06	2	[19172] R8C5-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
9483cba7-a456-415b-a231-e101ffcfa089	2018-03-02 16:35:08.362281-06	2	[19172] R8C5-16R	[21041] OSSI-DNOVAK	[293] master	\N	\N
59051722-d8e2-40ca-9a9d-a3fcd865a66e	2018-03-03 08:56:57.915775-06	1	[22056] Area-D Test.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
28669036-f5c0-4989-817a-8d28020b4fd2	2018-03-03 08:57:01.761159-06	2	[22056] Area-D Test.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
0679432b-61e1-4b06-8e29-e8dc8f197c39	2018-03-03 08:57:28.091792-06	2	[21245] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
8268cd9a-d2b0-4d9d-9b30-54a0c0fd6415	2018-03-03 08:58:13.57634-06	3	[21279] Label	[21041] OSSI-DNOVAK	[293] master	\N	\N
cae1fe6d-4f5b-4ec6-8bf4-152896d218f2	2018-03-03 08:58:13.814364-06	2	[21115] Door 405A	[21041] OSSI-DNOVAK	[293] master	\N	\N
0751d674-0ec0-4f78-baa5-d79135a8080d	2018-03-03 08:58:13.823365-06	2	[21116] Door 414A	[21041] OSSI-DNOVAK	[293] master	\N	\N
ec717548-d435-4da1-abfc-d242e52918b1	2018-03-03 08:58:13.831365-06	2	[21117] Door 414B	[21041] OSSI-DNOVAK	[293] master	\N	\N
08222dcb-2df8-4f18-978a-47847afe295f	2018-03-03 08:58:13.841366-06	2	[21118] Door 422A	[21041] OSSI-DNOVAK	[293] master	\N	\N
63390bd8-f3b0-43e6-b422-4827e85dae15	2018-03-03 08:58:13.849367-06	2	[21119] Door 422B	[21041] OSSI-DNOVAK	[293] master	\N	\N
2799e500-951e-452d-a350-c6b323a2261d	2018-03-03 08:58:13.857368-06	2	[21120] Door 438A	[21041] OSSI-DNOVAK	[293] master	\N	\N
35d5cea0-e053-4cec-8229-1f488d788514	2018-03-03 08:58:13.866369-06	2	[21121] Door 439A	[21041] OSSI-DNOVAK	[293] master	\N	\N
6692451c-fd0b-4ff1-b21e-66ed5b3d9e3d	2018-03-03 08:58:13.87537-06	2	[21122] Door 443A	[21041] OSSI-DNOVAK	[293] master	\N	\N
195ff374-9317-48ea-aeb4-ff1596aa3c03	2018-03-03 08:58:13.884371-06	2	[21123] Door 443B	[21041] OSSI-DNOVAK	[293] master	\N	\N
722a47a8-b02e-4496-9aad-2b34bc7edbe9	2018-03-03 08:58:13.893372-06	2	[21124] Door 444A	[21041] OSSI-DNOVAK	[293] master	\N	\N
56f9f70b-202d-43f9-8239-6219021e8143	2018-03-03 08:58:13.905373-06	2	[21125] Door 444B	[21041] OSSI-DNOVAK	[293] master	\N	\N
f5bc4e46-7db8-4286-9981-bfec4a5e9860	2018-03-03 08:58:13.915374-06	2	[21126] Door 447A	[21041] OSSI-DNOVAK	[293] master	\N	\N
0cf952f0-5b26-4de3-8646-9cc67db65661	2018-03-03 08:58:13.924375-06	2	[21127] Door 447B	[21041] OSSI-DNOVAK	[293] master	\N	\N
58efc465-5a4a-4af4-9b23-3aa2a819d7fa	2018-03-03 08:58:13.933376-06	2	[21128] Door 448A	[21041] OSSI-DNOVAK	[293] master	\N	\N
b9d49954-d0cb-4d55-8ae2-e50beaee0118	2018-03-03 08:58:13.941376-06	2	[21129] Door 455A	[21041] OSSI-DNOVAK	[293] master	\N	\N
e1f73003-2b62-44a4-bc25-430167976698	2018-03-03 08:58:13.949377-06	2	[21130] Door 455B	[21041] OSSI-DNOVAK	[293] master	\N	\N
429fbb59-4893-48fb-8222-b4a93f1fa5a4	2018-03-03 08:58:13.959378-06	2	[21131] Door 455D	[21041] OSSI-DNOVAK	[293] master	\N	\N
37e12e07-a1a2-427e-a434-3852e2f708f0	2018-03-03 08:58:13.968379-06	2	[21331] Door 429A	[21041] OSSI-DNOVAK	[293] master	\N	\N
32eb850b-1214-4bfd-b190-4099ce34bac8	2018-03-03 08:58:13.97638-06	2	[21332] Door 429B	[21041] OSSI-DNOVAK	[293] master	\N	\N
28f05ae7-81fc-49a8-bd46-ba3862ce177e	2018-03-03 08:58:13.986381-06	2	[21333] Door 429C	[21041] OSSI-DNOVAK	[293] master	\N	\N
b5895cea-328b-4766-ac12-e206d713fde7	2018-03-03 08:58:13.994382-06	2	[21334] Door 456	[21041] OSSI-DNOVAK	[293] master	\N	\N
cffeb1e5-ea33-4ba9-9ca9-b13b4666bb18	2018-03-03 08:58:14.002383-06	2	[21335] Door 461	[21041] OSSI-DNOVAK	[293] master	\N	\N
064dd288-de24-4542-bfe6-3fa38c847491	2018-03-03 08:58:14.011383-06	2	[21323] Door 414A	[21041] OSSI-DNOVAK	[293] master	\N	\N
b16c91de-afd7-4b54-a208-ffb8fb4e1c5d	2018-03-03 08:58:14.019384-06	2	[21324] Door 414B	[21041] OSSI-DNOVAK	[293] master	\N	\N
ff5caac4-5be3-45bf-bfb0-785d7658d8d8	2018-03-03 08:58:14.021384-06	2	[21852] Cameras	[21041] OSSI-DNOVAK	[293] master	\N	\N
34af8ec8-3517-4c4a-b9e8-08e3e67bd4ca	2018-03-03 09:04:15.819561-06	1	[21279] Area-A Test.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
072d7ebd-7582-44d5-b07f-61676ddfc880	2018-03-03 09:04:18.630842-06	2	[21279] Area-A Test.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
1c3721cc-aef6-4346-af22-ab64871bf240	2018-03-03 09:04:43.000278-06	2	[21045] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
23a1a5c0-fe78-4b8c-800f-a6b6b2e7c6f4	2018-03-03 09:04:57.231701-06	2	[21045] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
d7c733f1-180b-4876-9597-0e068cb430f0	2018-03-03 09:07:41.504127-06	1	[22057] Area-B Test.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
d4d07d81-fef2-4200-ae20-b290b0d5c044	2018-03-03 09:07:43.712348-06	2	[22057] Area-B Test.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
0855cbba-cfdf-4760-883e-3184ab36a22d	2018-03-03 09:08:28.63984-06	2	[21216] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
d8d8d9ba-0f82-4b60-80d3-c947d207f317	2018-03-03 09:08:52.191195-06	2	[21216] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
d723c51c-ba40-46c6-966a-d42cbae5f53f	2018-03-03 09:09:12.434219-06	2	[21216] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
9563ec35-77d1-4730-aae9-b300fcb4f504	2018-03-03 09:13:03.235297-06	1	[22058] Area-C Test.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
737d2e75-3b8e-4c6f-97f0-963817ac2e7d	2018-03-03 09:13:06.088582-06	2	[22058] Area-C Test.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
7bdc6a1c-ab36-46c3-adc3-59c372211897	2018-03-03 09:13:17.522726-06	2	[21231] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
7c3ecfb6-2d5d-4268-b588-0049c0ed7eb0	2018-03-03 09:13:41.979171-06	2	[21231] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
a7225a7c-4229-47df-8423-af058feeba35	2018-03-03 09:19:01.80315-06	1	[22059] Area-E Test.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
a7c69f25-fa1f-4f45-8701-c8f2d285b26e	2018-03-03 09:19:04.665436-06	2	[22059] Area-E Test.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
e6cbc70e-c0ce-458f-bb9d-035612e1655c	2018-03-03 09:19:17.511721-06	3	[21278] Label	[21041] OSSI-DNOVAK	[293] master	\N	\N
2b0c3400-6012-483e-961c-62ef10b5c138	2018-03-03 09:19:17.781748-06	2	[21336] Door 514	[21041] OSSI-DNOVAK	[293] master	\N	\N
c576a14e-598d-40b9-9419-2280f009889f	2018-03-03 09:19:17.793749-06	2	[21337] Door 529	[21041] OSSI-DNOVAK	[293] master	\N	\N
defe53df-c2ac-4679-b366-d202774bd469	2018-03-03 09:19:17.796749-06	2	[21914] Cameras	[21041] OSSI-DNOVAK	[293] master	\N	\N
56c85d02-2dbe-4702-b055-02b36767cedd	2018-03-03 09:19:37.626732-06	2	[21260] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
179bc61e-a7fe-4728-b45f-cb4d5015713f	2018-03-03 09:22:08.065775-06	2	[21260] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
71063c5d-79c5-4c64-acff-317c0dea089e	2018-03-03 10:59:54.842394-06	1	[21278] Area C Target Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
d62209ce-d6e9-45a5-9f0c-fbd88ac579a6	2018-03-03 11:00:31.518061-06	2	[21278] Area C Target Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
610edce8-b014-43b5-a32c-fd4991d92f58	2018-03-03 11:00:57.9167-06	1	[22060] Area C Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
ae2a7063-0eaf-4a24-b8ea-afd1842df081	2018-03-03 11:01:13.420251-06	2	[22060] Area C Left	[21041] OSSI-DNOVAK	[293] master	\N	\N
303003c0-0964-4b67-aa58-071a4a33f888	2018-03-03 11:01:22.758184-06	1	[22236] Area C Left Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
7f1da3dc-562a-45d2-a058-b89822abc8ea	2018-03-03 11:01:39.866895-06	2	[22236] Area C Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
399ed965-448d-4da2-9802-e3f14155d2fb	2018-03-03 11:02:20.794987-06	1	[22412] Area-C-Left Test.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
eb364fe1-1642-4f0d-a9ed-32df45b71a49	2018-03-03 11:02:22.803188-06	2	[22412] Area-C-Left Test.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
38235c47-eff4-48a0-913c-ee0c226c4a70	2018-03-03 11:02:32.606168-06	1	[22413] Area-C-Right Test.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
1779e8cc-b6c8-4eeb-ada7-75de58f58712	2018-03-03 11:02:34.990407-06	2	[22413] Area-C-Right Test.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
3f44e051-9569-4ebe-b273-b66328656800	2018-03-03 11:02:53.782286-06	2	[22063] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
e09c5b72-f81f-4921-847d-11755f5d5a14	2018-03-03 11:04:12.918199-06	2	[22239] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
9a037fbf-7afe-440e-9f13-fad3eda2b4c3	2018-03-03 11:06:28.74578-06	2	[21154] Area C Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
e2cd10be-e2de-4d45-b4fc-19bb42c872fa	2018-03-03 11:06:54.928398-06	2	[21278] Area C Target Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
732bb809-123b-46c7-a9bc-72dfac033075	2018-03-03 11:07:11.397045-06	2	[21154] Area C Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
56f9c12c-af9c-417e-8f51-3dd4eddfd396	2018-03-03 14:27:24.523237-06	2	[22000] 307	[4] DLarrabee	[21062] a	\N	\N
c43f764b-079d-4b14-b11f-785494176c8d	2018-03-03 14:31:34.486231-06	2	[22218] 307	[4] DLarrabee	[21062] a	\N	\N
b8e55f1b-18bc-458d-9242-e87d5f4dd29d	2018-03-03 14:41:20.878864-06	2	[22219] 309	[4] DLarrabee	[21062] a	\N	\N
770ecb87-bbd2-4b1a-91e4-f01289afbbb5	2018-03-03 14:42:05.219298-06	2	[22220] 314	[4] DLarrabee	[21062] a	\N	\N
44405541-c9ef-4637-ae41-6b87f00b0636	2018-03-03 14:43:46.592434-06	2	[22221] 322	[4] DLarrabee	[21062] a	\N	\N
13366c23-90e0-4c9f-b4e3-5cd8a4d41042	2018-03-03 14:52:51.927962-06	2	[22222] 323	[4] DLarrabee	[21062] a	\N	\N
25826aba-846e-49a0-9eba-36c16b8c743d	2018-03-03 14:53:50.424811-06	2	[22223] 324	[4] DLarrabee	[21062] a	\N	\N
74cd0e53-0eb7-420f-a9ec-48ffe85abdee	2018-03-03 14:55:31.91596-06	2	[22224] 326	[4] DLarrabee	[21062] a	\N	\N
cb88bf71-a443-486d-a91c-dd774657731b	2018-03-03 14:56:42.298997-06	2	[22225] 327	[4] DLarrabee	[21062] a	\N	\N
12346d3b-2f69-4155-a4b8-f432952edbfd	2018-03-03 14:57:35.398307-06	2	[22226] 329	[4] DLarrabee	[21062] a	\N	\N
2e8eeefa-6374-4b6d-bf0d-e99917f7af7d	2018-03-03 14:58:22.724039-06	2	[22227] 330	[4] DLarrabee	[21062] a	\N	\N
efb22b23-53d6-4e69-8761-6d41c0136db0	2018-03-03 15:00:36.74644-06	2	[22228] 333	[4] DLarrabee	[21062] a	\N	\N
edfa7287-446a-4339-99c1-163774fc57d4	2018-03-03 15:02:35.772341-06	2	[22229] 334	[4] DLarrabee	[21062] a	\N	\N
ca775625-ac66-4db4-b1b4-2b69ccd2f26f	2018-03-03 15:03:25.876351-06	2	[22230] 335	[4] DLarrabee	[21062] a	\N	\N
8082995e-eddd-4e3e-a328-46ddcffaaf21	2018-03-03 15:04:10.517815-06	2	[22231] 336	[4] DLarrabee	[21062] a	\N	\N
bda06c07-969f-45f5-9d0c-d727a2ad98ca	2018-03-03 15:05:14.514214-06	2	[22232] 337	[4] DLarrabee	[21062] a	\N	\N
10b03781-da4a-44c2-911c-53d0dde97a68	2018-03-03 15:06:03.489111-06	2	[22233] 338	[4] DLarrabee	[21062] a	\N	\N
a3eabc56-578c-468b-a2e4-4a797ed01fe1	2018-03-03 15:06:47.252486-06	2	[22234] 342	[4] DLarrabee	[21062] a	\N	\N
9c9c406d-fcf6-4f80-bb34-6ea62e80595d	2018-03-03 15:07:37.782539-06	2	[22235] 343	[4] DLarrabee	[21062] a	\N	\N
8eb623e3-bee1-4aa4-b2a4-9b57c3fe5b82	2018-03-03 15:08:35.518312-06	1	[22414] 343 Copy	[4] DLarrabee	[21062] a	\N	\N
c51ef7de-1c4d-4cc9-b115-d1c42cd4507c	2018-03-03 15:09:01.90095-06	2	[22414] 344	[4] DLarrabee	[21062] a	\N	\N
9f808d03-ae55-473e-bbb7-d0938762464b	2018-03-03 15:09:07.512511-06	1	[22415] 344 Copy	[4] DLarrabee	[21062] a	\N	\N
32c83263-42e2-4195-9f7c-15f593735ed4	2018-03-03 15:09:24.884248-06	2	[22415] 346	[4] DLarrabee	[21062] a	\N	\N
37e2696a-8ace-44a0-a8de-a008da83e5f1	2018-03-03 15:09:34.915251-06	1	[22416] 346 Copy	[4] DLarrabee	[21062] a	\N	\N
182157a8-afce-42fd-8b8d-9e6dff5a007a	2018-03-03 15:09:50.692829-06	2	[22416] 347	[4] DLarrabee	[21062] a	\N	\N
6e85bcde-186e-4477-ab0a-7640d3b4fc98	2018-03-03 15:10:02.689028-06	1	[22417] 347 Copy	[4] DLarrabee	[21062] a	\N	\N
195ef9be-ee82-48ff-98ff-0d54a48dd770	2018-03-03 15:10:19.70573-06	2	[22417] 348	[4] DLarrabee	[21062] a	\N	\N
6b1c8cf5-9571-413e-b95d-8cfe8c698060	2018-03-03 15:10:46.384397-06	1	[22418] 348 Copy	[4] DLarrabee	[21062] a	\N	\N
9f9347e8-0112-40d3-8a5f-d152387a31e5	2018-03-03 15:11:05.795338-06	2	[22418] 349	[4] DLarrabee	[21062] a	\N	\N
b45f9a6c-b539-4aaa-99d7-1a956ae401e5	2018-03-03 15:11:15.980357-06	1	[22419] 349 Copy	[4] DLarrabee	[21062] a	\N	\N
38ab8617-0155-4c50-aaa3-2f15d092ee69	2018-03-03 15:11:32.136972-06	2	[22419] 351	[4] DLarrabee	[21062] a	\N	\N
2f43f00e-d793-4874-95f1-a0bed765171a	2018-03-03 15:11:46.371395-06	1	[22420] 351 Copy	[4] DLarrabee	[21062] a	\N	\N
45d596e7-2be9-4755-85a2-ef8d89d0ea6e	2018-03-03 15:12:05.294287-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
0f143c0d-7e8d-494b-9d4f-b46e327055f8	2018-03-03 15:12:40.911849-06	1	[22421] 352 Copy	[4] DLarrabee	[21062] a	\N	\N
a304834f-83c5-4e45-a114-b765c339d6ac	2018-03-03 15:12:57.058463-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
33fd53e4-ae1d-4154-8daf-d3080f7c6ebf	2018-03-03 15:26:54.027569-06	1	[22422] 259	[4] DLarrabee	[21062] a	\N	\N
ca58ee38-2945-4b11-8374-c27e09c4bf11	2018-03-03 15:27:57.440569-06	2	[21216] Floorplan	[4] DLarrabee	[21062] a	\N	\N
a0be0a54-3ed7-4bae-a6f9-9fba4a642c7d	2018-03-03 16:18:44.997279-06	1	[22426] Area-C-Left SP.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
3d9ad5c4-e69e-4746-bba8-0e30ceb0330a	2018-03-03 16:18:47.140493-06	2	[22426] Area-C-Left SP.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
f14b4751-9d73-4c13-b861-4b9685807273	2018-03-03 16:19:19.982777-06	2	[22063] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
3e9ecd8e-a95f-44e3-a231-65b74dbc5e4e	2018-03-03 16:21:07.452523-06	1	[22427] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
0e196861-3c16-4487-be82-b39689ac2715	2018-03-03 16:21:38.461624-06	3	[22427] New	[21041] OSSI-DNOVAK	[293] master	\N	\N
a8e34575-a965-427e-a704-74c089f2a6fa	2018-03-03 16:22:31.522929-06	2	[21977] 248	[4] DLarrabee	[21062] a	\N	\N
3f8daea1-4080-494f-af50-5122bbdd6380	2018-03-03 16:22:46.376414-06	2	[21278] Area C Target  Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
495b4bad-dccd-4485-bf38-0adfd8d0de5f	2018-03-03 16:35:25.132282-06	1	[22427] arrow-right-6-32.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
53f250e2-4f79-478f-a79f-0225b585c0ce	2018-03-03 16:35:26.749444-06	2	[22427] arrow-right-6-32.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
83678daf-27a6-4b19-a194-b26f550957db	2018-03-03 16:38:22.646032-06	2	[22427] arrow-right-Lime	[21041] OSSI-DNOVAK	[293] master	\N	\N
98868d6c-6013-4d72-8a87-cec0e21da923	2018-03-03 16:38:31.440911-06	1	[22428] arrow-right-Red.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
70e4151c-7b40-48b1-9411-6910b7491732	2018-03-03 16:38:33.385106-06	2	[22428] arrow-right-Red.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
ed709edc-bb20-47f0-bf8b-4ea5f4312229	2018-03-03 16:43:46.05937-06	1	[22429] arrow-right-LBlue.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
19699422-8ad4-4f24-af94-be13ad5a66a6	2018-03-03 16:43:48.179582-06	2	[22429] arrow-right-LBlue.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
4f1336db-c863-40e4-abd8-94a7574d953a	2018-03-03 16:44:07.908555-06	1	[22430] arrow-right-Yellow.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
d852f1ba-0b0e-4f88-abdb-e51b802abd4a	2018-03-03 16:44:11.176882-06	2	[22430] arrow-right-Yellow.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
39407ae8-9475-49f6-9f96-4e5393458a54	2018-03-03 16:44:21.274891-06	1	[22431] arrow-right-White.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
cf5a59ff-8f8e-4035-b9d6-472855ceae47	2018-03-03 16:44:23.210085-06	2	[22431] arrow-right-White.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
43fcb183-3410-4148-afaf-8d3f91123b2e	2018-03-03 16:45:17.238487-06	2	[21278] Area C Target  Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
c00e35dc-8259-432f-9053-41f2cde04da4	2018-03-03 16:45:43.214084-06	2	[21278] Area C Target  Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
17ed480c-cd5d-435f-80f7-cd5801506908	2018-03-03 16:46:06.942457-06	2	[21278] Area C Target  Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
2e54d50f-2253-4090-8716-02b500380a10	2018-03-03 16:47:40.675829-06	2	[22215] IC 316B-OUT B	[4] DLarrabee	[21062] a	\N	\N
0c2c5d94-b73f-4708-9159-e193d07ad64a	2018-03-03 16:48:22.29099-06	2	[21278] Area C Target  Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
fe5023c5-5e64-43fd-b80f-b7cd3e1d66c9	2018-03-03 16:48:40.160777-06	2	[22216] IC 316B-2-in B 	[4] DLarrabee	[21062] a	\N	\N
85aa7419-8f10-478a-82cd-9f25bda15f98	2018-03-03 16:49:16.88745-06	2	[21278] Area C Target  Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
f6b2c80e-b8fe-48d6-8cff-d7f2dda2c73a	2018-03-03 16:49:51.433904-06	1	[22432] Area C Target  Right Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
ab00f043-0a64-44bc-aff8-dc6f67eaa090	2018-03-03 16:52:16.958455-06	2	[22217] IC 316B-2-Out B	[4] DLarrabee	[21062] a	\N	\N
09abfbfa-8e6c-45f2-8701-0d268ec41c43	2018-03-03 16:52:38.134572-06	2	[21149] C Left	[21041] OSSI-DNOVAK	[293] master	\N	\N
165bb4a0-0772-4f3c-9f77-c24a2776a9e4	2018-03-03 16:52:44.162175-06	1	[22433] 6	[21041] OSSI-DNOVAK	[293] master	\N	\N
0f48032b-2a23-493a-9329-685fc463fd9d	2018-03-03 16:52:55.655324-06	2	[22433] C Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
c520ec1d-0f43-4e4c-9ae1-ea58a88d1c54	2018-03-03 16:52:59.827741-06	1	[22434] 7	[21041] OSSI-DNOVAK	[293] master	\N	\N
57f52507-29d9-4931-a5af-97a19afde262	2018-03-03 16:53:09.01366-06	2	[22434] D Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
8947476d-6085-474a-a362-832a91dd9fd7	2018-03-03 16:53:19.969755-06	2	[21150] D Left	[21041] OSSI-DNOVAK	[293] master	\N	\N
5f8bbb4b-e3c0-4584-85e3-4767c67cb03e	2018-03-03 16:53:24.197178-06	2	[22216] IC 316B-2-in B 	[4] DLarrabee	[21062] a	\N	\N
f9371e70-5b54-4dff-800c-3b06743f6cc0	2018-03-03 16:53:25.540312-06	2	[22433] C Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
64660f24-bc96-41a4-b6ad-b21848bf201e	2018-03-03 16:53:55.126271-06	2	[21154] Area C Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
49bbc38f-a22b-4366-8b88-f63678678b2c	2018-03-03 16:54:18.829641-06	2	[21278] Area C Target  Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
a1b8454d-47b3-469c-8803-7c64d2b3d813	2018-03-03 16:54:35.498307-06	2	[22432] Area C Target  Right Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
1f4dc362-c549-46c1-86aa-fce737cf2e69	2018-03-03 16:55:55.301287-06	2	[22432] Area C Target  Right Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
6747a9f4-8821-4b5b-b32e-fc32d0a07634	2018-03-03 16:55:59.395696-06	3	[22427] arrow-right-Lime	[21041] OSSI-DNOVAK	[293] master	\N	\N
2dda7d06-e175-46e6-94e6-ac7639b3b218	2018-03-03 16:55:59.664723-06	2	[22428] arrow-right-Red.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
51e3f275-2e57-4911-b065-f41ac11d49d2	2018-03-03 16:55:59.668724-06	2	[22429] arrow-right-LBlue.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
e432f531-67aa-4970-a82f-a5ab452248a6	2018-03-03 16:55:59.675724-06	2	[22430] arrow-right-Yellow.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
86576163-b5a6-499a-b28f-3ffa8bd4f764	2018-03-03 16:55:59.679725-06	2	[22431] arrow-right-White.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
35b70448-b154-46a0-aaf1-e056e0a278c4	2018-03-03 16:55:59.686725-06	2	[21278] Area C Target  Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
88cb7038-7e53-4bbb-8bf9-a82632d6d30b	2018-03-03 16:55:59.695726-06	2	[22432] Area C Target  Right Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
480f26c9-5250-444f-9395-a9c8db94e5c1	2018-03-03 16:57:08.564613-06	1	[22427] arrow-right-6-32 (1).png	[21041] OSSI-DNOVAK	[293] master	\N	\N
d3fc578e-6a5e-423d-95fa-5e146e64bd0e	2018-03-03 16:57:10.424799-06	2	[22427] arrow-right-6-32 (1).png	[21041] OSSI-DNOVAK	[293] master	\N	\N
56eeefe6-0c3a-4f5d-9c47-7387e2520a46	2018-03-03 16:57:48.007556-06	2	[22432] Area C Target  Right Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
ec7375b2-0458-4442-89a2-fda837062269	2018-03-03 16:58:38.930648-06	2	[22213] Door 316B -2	[4] DLarrabee	[21062] a	\N	\N
7071643d-4d4d-45df-a5d9-1678b7fc9738	2018-03-03 16:59:07.359491-06	2	[22432] Area C Target  Right Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
d757e99f-8b15-4754-8d25-0ea496ce4f4f	2018-03-03 16:59:28.643619-06	2	[21278] Area C Target  Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
c6f44b44-3082-4ea0-95b4-cb808ffcff0a	2018-03-03 17:00:03.037058-06	2	[21278] Area C Target  Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
a287d821-9d57-4954-83ee-5d2476396ffa	2018-03-03 17:02:25.146268-06	2	[22432] Area C Target  Right Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
e279fe33-f2c0-4b7b-9347-622fd4d19d69	2018-03-03 17:02:40.960849-06	2	[21278] Area C Target  Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
7f4e80f5-367b-49a1-b368-cb6d42311eaf	2018-03-03 17:02:53.782131-06	2	[22432] Area C Target  Right Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
70128881-0d98-4043-a755-88c34e1e5ebb	2018-03-03 17:03:07.428495-06	2	[22432] Area C Target  Right Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
ba61f59e-fe3d-43dc-91d1-ff785378d371	2018-03-03 17:03:15.333286-06	2	[21278] Area C Target  Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
9d195de5-dbc0-4bc0-88aa-6bd3c9131d63	2018-03-03 17:06:30.963847-06	2	[22088] Door 307	[4] DLarrabee	[21062] a	\N	\N
3f734ec6-8ad0-491b-adf5-e4a8aad27146	2018-03-03 17:07:16.862436-06	2	[21155] Area D Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
24c7a7b4-2426-4e9d-a47c-aaf32fa17547	2018-03-03 17:07:24.918242-06	1	[22435] Area C Target  Right Copy Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
ec6b5a15-3a67-4b34-a774-0b52407f12e4	2018-03-03 17:08:04.734223-06	2	[22435] Area D Target Left	[21041] OSSI-DNOVAK	[293] master	\N	\N
17a01d5d-56b9-43cf-a935-22dee6bace4e	2018-03-03 17:09:02.772026-06	1	[22436] Area D Target Left Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
5e5a179c-39db-4f6d-b404-e1906e00ff18	2018-03-03 17:09:09.670716-06	3	[22436] Area D Target Left Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
31dfdc04-66ef-471d-bc87-0cf8db0f3892	2018-03-03 17:09:14.969246-06	1	[22436] Area C Target  Right Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
40571c87-1fcc-4861-80bc-57d5f4a87c44	2018-03-03 17:10:21.010849-06	2	[22436] Area D Target Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
6584087d-365c-40e6-b9d7-130bcc359295	2018-03-03 17:11:48.710618-06	2	[22435] Area D Target Left	[21041] OSSI-DNOVAK	[293] master	\N	\N
ced2270a-9b71-4bb5-87cf-ab8e096e1f28	2018-03-03 17:12:12.13196-06	2	[21155] Area D Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
05e3bef5-919f-41f4-99f5-9c97700acbac	2018-03-03 17:12:54.03215-06	2	[22436] Area D Target Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
0bed643f-5a0e-4387-8347-4844165b2d2c	2018-03-03 17:13:59.387685-06	2	[21092] Nav Map	[21041] OSSI-DNOVAK	[293] master	\N	\N
15b5aab1-0d71-4661-9c5f-bd1dfe96c912	2018-03-03 17:15:50.84783-06	2	[22089] Door 309	[4] DLarrabee	[21062] a	\N	\N
a870dbd6-76f6-4c1a-8418-4ee7f7900a4c	2018-03-03 17:19:10.806824-06	2	[22090] Door 314	[4] DLarrabee	[21062] a	\N	\N
048b5e45-9fcc-4e1f-8e4e-1dfef4053036	2018-03-03 17:22:32.545995-06	2	[22090] Door 314	[4] DLarrabee	[21062] a	\N	\N
f471623e-c802-4434-a4a3-fe0e4c798244	2018-03-03 17:28:27.269464-06	2	[21154] Area C Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
3f09f144-7b8e-4ee2-8029-a4a5112607e1	2018-03-03 17:28:41.275865-06	2	[21155] Area D Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
ff8197cb-1a80-4d3e-9465-4daa02489ac5	2018-03-03 18:01:39.8277-06	1	[22437] Area D Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
2d77be93-05d0-4591-be45-596f85f34472	2018-03-03 18:01:56.719389-06	2	[22437] Area D Left	[21041] OSSI-DNOVAK	[293] master	\N	\N
09ebcc8b-4a4c-4cbb-88cc-172d2b71e486	2018-03-03 18:02:42.646981-06	1	[22537] Area-D Left.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
611128c7-dec6-4001-b9a0-17a44223645e	2018-03-03 18:02:45.285245-06	2	[22537] Area-D Left.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
c7580653-f16d-4212-b60a-ae9440dbff42	2018-03-03 18:02:55.523269-06	1	[22538] Area-D Right.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
54d55f01-aac6-4a24-bc7d-f1f2d40a4f19	2018-03-03 18:02:57.485465-06	2	[22538] Area-D Right.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
c7f97143-edb6-448c-83c0-7c45c2240f73	2018-03-03 18:03:20.766793-06	2	[22440] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
a820ab0b-ef12-46e5-904d-74a20b9a24a1	2018-03-03 18:05:09.097625-06	2	[22239] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
fa3b1381-ed8b-4985-b2cf-dab38f9f9605	2018-03-03 18:06:20.910806-06	2	[22435] Area D Target Left	[21041] OSSI-DNOVAK	[293] master	\N	\N
c1d51aad-aabe-47bc-ac06-221caf7f8c4d	2018-03-03 18:06:37.062421-06	2	[21155] Area D Target	[21041] OSSI-DNOVAK	[293] master	\N	\N
3295eafb-44f2-4f7b-9d82-10d08d08ed08	2018-03-03 18:07:59.080622-06	1	[22539] Area D Left Copy	[21041] OSSI-DNOVAK	[293] master	\N	\N
e3e7387a-683f-49e0-9aa8-84e6108960db	2018-03-03 18:08:13.530066-06	2	[22539] Area D Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
cd437951-7340-4f66-ba68-6aadfc6b292f	2018-03-03 18:08:47.110424-06	2	[22542] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
7c2a6b07-f45d-44c3-8a1d-fb5e2d3cc29e	2018-03-03 18:09:20.221735-06	2	[22239] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
d0954b9f-b61f-44db-8858-02bc2aaaa8d1	2018-03-03 18:10:28.68258-06	2	[22436] Area D Target Right	[21041] OSSI-DNOVAK	[293] master	\N	\N
4d627a72-b60e-4525-99b6-8d4eb8ddfd9b	2018-03-03 19:58:13.264974-06	2	[22091] Door 322	[4] DLarrabee	[21062] a	\N	\N
4384daca-993f-4b95-9a59-2a1e8aee4241	2018-03-03 20:21:43.692003-06	1	[22639] OHDoors	[4] DLarrabee	[21062] a	\N	\N
cc006830-c76f-4d17-afc3-fc1447b947b9	2018-03-03 20:22:43.697002-06	1	[22640] OverheadDoorGreen.png	[4] DLarrabee	[21062] a	\N	\N
a48bc8a6-26c1-44a2-9432-c54ed4c3d1a9	2018-03-03 20:22:57.910424-06	2	[22640] OverheadDoorGreen.png	[4] DLarrabee	[21062] a	\N	\N
25c883ab-3216-44d4-9dbb-1e7b423e67e3	2018-03-03 20:23:08.213454-06	1	[22641] OverheadDoorRed.png	[4] DLarrabee	[21062] a	\N	\N
2abd3a9e-ee6f-41f3-9ed4-01e96c56f098	2018-03-03 20:23:23.060938-06	2	[22641] OverheadDoorRed.png	[4] DLarrabee	[21062] a	\N	\N
9580860e-aa85-4088-a323-4f6e0ffc6d72	2018-03-03 20:24:31.054737-06	2	[22085] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
8de323e3-2e82-4e11-956e-cc837f99df0a	2018-03-03 20:27:02.440874-06	2	[22082] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
e7f6e0ac-7812-4268-901d-5610d90460e7	2018-03-03 21:55:35.781155-06	1	[22642] OverheadDoorGreen-up-arrow.png	[4] DLarrabee	[21062] a	\N	\N
15b04fbc-62cc-48a6-827b-479a1b8b9b6b	2018-03-03 21:55:50.059583-06	1	[22643] OverheadDoorRed-down-arrow.png	[4] DLarrabee	[21062] a	\N	\N
84a84a47-b9b0-404c-98ec-cb7e52962ca7	2018-03-03 21:57:02.144791-06	2	[22085] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
2866d011-5663-47dd-9e9c-c66e8a6b8d82	2018-03-03 22:00:24.081982-06	2	[22085] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
7c354281-883d-47a1-95c9-00a732995195	2018-03-03 22:00:52.625836-06	2	[22085] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
40bbf1c1-7a04-464f-aab8-e252279dfa70	2018-03-03 22:05:33.028874-06	2	[22085] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
9111cc3e-f2ab-4d4f-869f-a6b6d45742ee	2018-03-03 22:06:25.086079-06	2	[22082] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
4fa5da25-c967-428a-bda8-9b5016cce61f	2018-03-03 22:06:34.218992-06	3	[22082] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
d8d40387-1c55-4666-b12f-4a489cda2dd6	2018-03-03 22:06:34.532024-06	2	[22083] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
2edbf629-59d9-4608-822f-8ce9182c8531	2018-03-03 22:06:34.550025-06	2	[22084] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
9f208146-7f99-490c-9e51-5c18210f497d	2018-03-03 22:06:34.565027-06	2	[22085] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
aa625bfd-3ca4-44e8-801f-6278efd7dc63	2018-03-03 22:06:34.579028-06	2	[22086] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
60903cd1-7052-4f11-8107-ccf51d906057	2018-03-03 22:06:34.59303-06	2	[22087] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
4f47f91f-45b1-421b-803d-542bd1a72503	2018-03-03 22:06:34.608031-06	2	[22092] Door 324A	[4] DLarrabee	[21062] a	\N	\N
4a176c8a-4ebc-4e87-b375-0fd734f49e76	2018-03-03 22:06:34.623033-06	2	[22093] Door 324B	[4] DLarrabee	[21062] a	\N	\N
24bf15b6-493f-4e30-a582-73209e2377d3	2018-03-03 22:06:34.640034-06	2	[22094] Door 324C	[4] DLarrabee	[21062] a	\N	\N
d6c5828f-0261-4d46-9a2c-3eb5ccf74887	2018-03-03 22:06:34.653036-06	2	[22095] Door 333	[4] DLarrabee	[21062] a	\N	\N
43e0c3ef-21ad-4ff5-8515-aa9ac0f7cb23	2018-03-03 22:06:34.668037-06	2	[22096] Door 330A	[4] DLarrabee	[21062] a	\N	\N
f1629e6f-fea4-47f2-8dde-6f1a936a3e55	2018-03-03 22:06:34.681039-06	2	[22097] Door 330B	[4] DLarrabee	[21062] a	\N	\N
0a2efe53-5b53-4ade-b1ac-a5b9a70dbe36	2018-03-03 22:06:34.69304-06	2	[22098] Door 378	[4] DLarrabee	[21062] a	\N	\N
5c26905f-0b4a-4230-b92a-f790f7bfe2af	2018-03-03 22:06:34.69704-06	2	[22099] Cameras	[4] DLarrabee	[21062] a	\N	\N
a30c3389-5432-43d2-a6aa-7e5d6307e98d	2018-03-03 22:08:37.568326-06	2	[22085] Door 323OHD OPEN/CLOSE	[4] DLarrabee	[21062] a	\N	\N
916fd13f-65af-4f89-955c-273fbd054e46	2018-03-03 22:25:07.176277-06	2	[22084] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
6eb68981-9847-4d68-a3b1-421c88df743c	2018-03-03 22:25:40.161575-06	2	[22084] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
8c29255e-6953-4326-9760-5a592353706a	2018-03-03 22:31:06.949251-06	2	[22086] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
62e95101-a966-4b39-9862-a1a4c02b3c6b	2018-03-03 22:31:22.4438-06	2	[22084] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
c9119ba2-7650-4c65-9f3f-66adaa947ac3	2018-03-03 22:31:28.706426-06	2	[22084] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
ccda5556-429e-483f-8002-86e365e4a96f	2018-03-03 22:31:43.918947-06	2	[22086] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
3c47e66a-6286-428c-984b-18503182a1f7	2018-03-03 22:32:21.971752-06	2	[22086] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
10f83026-bf3c-45ff-a6dd-589553052723	2018-03-03 22:33:13.644919-06	2	[22086] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
e1994093-bf21-44e8-8c85-aacbfe383766	2018-03-03 22:33:20.212576-06	2	[22084] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
db7e5806-38dc-4d49-b4b7-5837d45c4fbc	2018-03-03 22:33:48.390393-06	3	[22083] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
a6a0bb00-0573-4856-b91e-e1368d0d1347	2018-03-03 22:33:48.779432-06	2	[22084] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
c63d8805-4f2a-42f0-a53c-788b685715ee	2018-03-03 22:33:48.798434-06	2	[22086] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
ac716156-ca4c-4153-a4d2-6d0dcfec76ea	2018-03-03 22:33:48.813435-06	2	[22087] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
864c34ab-3ba9-4e28-b2e7-3ce3dbd0b15d	2018-03-03 22:33:48.831437-06	2	[22092] Door 324A	[4] DLarrabee	[21062] a	\N	\N
8378791c-b7f4-4e47-8974-fff2bd5eb999	2018-03-03 22:33:48.846439-06	2	[22093] Door 324B	[4] DLarrabee	[21062] a	\N	\N
7f52b8f8-4eae-485c-8fec-44cd26782a61	2018-03-03 22:33:48.85644-06	2	[22094] Door 324C	[4] DLarrabee	[21062] a	\N	\N
b8f92c16-5da9-49e4-9efa-dabdf22550f8	2018-03-03 22:33:48.866441-06	2	[22095] Door 333	[4] DLarrabee	[21062] a	\N	\N
b61abb4f-08f6-4bac-849e-8ffac5b0ef84	2018-03-03 22:33:48.877442-06	2	[22096] Door 330A	[4] DLarrabee	[21062] a	\N	\N
ddd6a37e-01bd-4316-af2f-0dd60703ee39	2018-03-03 22:33:48.891443-06	2	[22097] Door 330B	[4] DLarrabee	[21062] a	\N	\N
1a874eae-9e6d-470f-a9c7-5dcc7302f07d	2018-03-03 22:33:48.902444-06	2	[22098] Door 378	[4] DLarrabee	[21062] a	\N	\N
e7822b7c-fe2d-4229-aafa-3ee740aeec0a	2018-03-03 22:33:48.905445-06	2	[22099] Cameras	[4] DLarrabee	[21062] a	\N	\N
7299308f-caa3-48ab-bd22-1a8f93963930	2018-03-03 22:34:05.75613-06	3	[22087] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
20dd0600-b4c9-4bd1-b54f-6133a93ff49f	2018-03-03 22:34:06.024156-06	2	[22092] Door 324A	[4] DLarrabee	[21062] a	\N	\N
27cd705e-899f-46f1-ac73-ac501f97c34e	2018-03-03 22:34:06.034157-06	2	[22093] Door 324B	[4] DLarrabee	[21062] a	\N	\N
f77bb5e6-583e-46ff-ac80-7a91e7005cd0	2018-03-03 22:34:06.043158-06	2	[22094] Door 324C	[4] DLarrabee	[21062] a	\N	\N
0f57bea7-423d-4df0-844c-83fb6f893104	2018-03-03 22:34:06.06016-06	2	[22095] Door 333	[4] DLarrabee	[21062] a	\N	\N
73e3019a-f4a9-463c-bb8b-9cc66ee3a3d5	2018-03-03 22:34:06.074161-06	2	[22096] Door 330A	[4] DLarrabee	[21062] a	\N	\N
3243b550-941b-48aa-9667-64aa9c781309	2018-03-03 22:34:06.088163-06	2	[22097] Door 330B	[4] DLarrabee	[21062] a	\N	\N
9fb94dee-aefa-4c45-acdc-c92f13e1a5e0	2018-03-03 22:34:06.103164-06	2	[22098] Door 378	[4] DLarrabee	[21062] a	\N	\N
97d13eea-7659-497e-8199-5c2599d71ae8	2018-03-03 22:34:06.108165-06	2	[22099] Cameras	[4] DLarrabee	[21062] a	\N	\N
3c18a25e-1880-4c7c-8e0e-5c454256925c	2018-03-03 22:35:43.731926-06	2	[22084] Door 324OHDW OPEN/CLOSE	[4] DLarrabee	[21062] a	\N	\N
18e467c9-f1f0-4149-8daf-aa92ee74cfbf	2018-03-03 22:35:54.002953-06	2	[22086] Door 324OHDE OPEN/CLOSE	[4] DLarrabee	[21062] a	\N	\N
2718847f-f98c-4ead-a32e-eba59f88af59	2018-03-03 22:45:42.43279-06	2	[22186] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
86acc0fc-0a0c-41e9-8cd0-92b184e4314e	2018-03-03 22:49:32.05175-06	1	[22082] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
e8f2b074-f919-454c-ad19-017735af1de1	2018-03-03 22:50:13.363881-06	3	[22082] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
c35fc61d-08b9-40d0-b0fa-3a6c6ea52a69	2018-03-03 22:54:17.77932-06	1	[22082] IC 324B-InB Copy	[4] DLarrabee	[21062] a	\N	\N
20c6a930-b969-4a1d-9d60-feb7788a5011	2018-03-03 22:56:46.309171-06	2	[22082] IC 324B-OutB Copy	[4] DLarrabee	[21062] a	\N	\N
016a0855-f102-4f8d-a8d8-5ab9c0ca2c25	2018-03-03 22:57:04.143955-06	2	[22082] IC 324B-OutB	[4] DLarrabee	[21062] a	\N	\N
831a1b59-f06c-4dbf-9f77-6af00105b7df	2018-03-04 09:24:48.239049-06	2	[22085] Door 323OHD OPEN/CLOSE	[21041] OSSI-DNOVAK	[293] master	\N	\N
a4b0df48-ee57-407e-9cb4-08108964fadd	2018-03-04 09:26:37.772001-06	2	[22085] Door 323OHD OPEN/CLOSE	[21041] OSSI-DNOVAK	[293] master	\N	\N
db6d147a-9f6b-4d09-be0f-2524a221e69c	2018-03-04 09:27:05.341757-06	2	[22085] Door 323OHD OPEN/CLOSE	[21041] OSSI-DNOVAK	[293] master	\N	\N
94937cd1-5d56-4737-9b12-144d9785d200	2018-03-04 09:27:25.451852-06	2	[22085] Door 323OHD OPEN/CLOSE	[21041] OSSI-DNOVAK	[293] master	\N	\N
e38d24b3-3015-4241-85e5-8c06369bf12e	2018-03-04 09:57:06.961967-06	2	[22085] Door 323OHD OPEN/CLOSE	[21041] OSSI-DNOVAK	[293] master	\N	\N
a882c266-9282-4c0a-a6a2-ef8c229c1ad9	2018-03-04 10:01:27.849053-06	2	[22085] Door 323OHD OPEN/CLOSE	[21041] OSSI-DNOVAK	[293] master	\N	\N
b400746d-b923-4bc2-a1a4-41f235d88e40	2018-03-04 10:11:49.624225-06	2	[21686] A 1 MULTI-USE DINING 122 	[21041] OSSI-DNOVAK	[293] master	\N	\N
efbb5a2e-538e-418f-8a6b-1dbf7ba64ba4	2018-03-04 10:12:35.099772-06	2	[21687] A 2 MULTI-USE DINING 122	[21041] OSSI-DNOVAK	[293] master	\N	\N
6d3cd1ef-51de-4287-ac09-d9e6c3f6773a	2018-03-04 10:12:56.259888-06	2	[21687] A 2 MULTI-USE DINING 122	[21041] OSSI-DNOVAK	[293] master	\N	\N
09419374-eb3d-4d94-9f83-d4f78459d5c1	2018-03-04 10:14:55.281789-06	2	[21688] A 3 MULTI-USE DINING 123	[21041] OSSI-DNOVAK	[293] master	\N	\N
94dac3f7-ce12-48cc-aaf7-be084f05293f	2018-03-04 10:15:14.352695-06	2	[21689] A 4 MULTI-USE DINING 123	[21041] OSSI-DNOVAK	[293] master	\N	\N
099a9adf-79cf-46dd-b26b-51473a5e9c5b	2018-03-04 10:15:35.534813-06	2	[21689] A 4 MULTI-USE DINING 123	[21041] OSSI-DNOVAK	[293] master	\N	\N
5dd27ed8-9148-4248-b25a-9a13101ca679	2018-03-04 10:15:53.612621-06	2	[21045] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
fcc3a75f-c521-43d8-8462-ff96a453f761	2018-03-04 10:20:25.795837-06	2	[21045] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
095c1c7a-b49c-4d94-afa7-ddf1450e6b65	2018-03-04 10:20:45.778835-06	2	[21045] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
5936e901-1b99-4786-b8c0-abbed24d0556	2018-03-04 10:22:34.954751-06	2	[21045] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
658b0b3e-8e49-4594-8633-470aefd779ea	2018-03-04 10:24:22.198475-06	2	[21045] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
82e85dc7-bcec-41ab-9750-471065b8238a	2018-03-04 10:24:27.618016-06	2	[21045] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
9d3740ed-ecf1-481c-b213-3d7245011553	2018-03-04 10:25:10.694324-06	2	[21045] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
e8779cdd-58c8-48a8-8de1-e282cd82ab91	2018-03-04 10:28:02.516504-06	2	[291] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
95ebc712-2fd4-46a4-ac33-578306503ebe	2018-03-04 10:40:41.896435-06	2	[22102] C 3 INTAKE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
dcc1a047-aab4-455e-b0b8-aa4f38e7de15	2018-03-04 10:41:11.417386-06	2	[22102] C 3 INTAKE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
69020784-f07b-4599-9331-233805d99394	2018-03-04 10:41:20.945339-06	2	[22102] C 3 INTAKE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
eccbcd0c-8926-42a6-bc5c-716280cdde06	2018-03-04 10:42:01.297374-06	2	[22103] C 4 INTAKE	[21041] OSSI-DNOVAK	[293] master	\N	\N
cc5e502b-9cf6-412c-b557-561f7d60e906	2018-03-04 10:49:00.062246-06	2	[22100] C 1 VEHICLE SALLY PORT 324	[21041] OSSI-DNOVAK	[293] master	\N	\N
ea76f2e8-a310-413a-a427-5e715ffd8c90	2018-03-04 10:49:20.143254-06	2	[22100] C 1 VEHICLE SALLY PORT 324	[21041] OSSI-DNOVAK	[293] master	\N	\N
a4e442a2-5198-4b0b-9af4-88ad3ef4806f	2018-03-04 10:51:17.612-06	2	[22101] C 2 VEHICLE SALLY PORT 324	[21041] OSSI-DNOVAK	[293] master	\N	\N
98a04cb9-6778-4ea3-b563-616a7484d23f	2018-03-04 10:52:09.31717-06	2	[22100] C 1 VEHICLE SALLY PORT 324	[21041] OSSI-DNOVAK	[293] master	\N	\N
b2cd29cd-31fc-4302-9e95-808d75c50469	2018-03-04 10:53:26.162854-06	2	[22100] C 1 VEHICLE SALLY PORT 324	[21041] OSSI-DNOVAK	[293] master	\N	\N
1aa52805-3b53-4c4b-a6f1-2935edafbec5	2018-03-04 10:56:19.466182-06	2	[22104] C 5 INTAKE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e1ce8967-a704-4826-b6c4-3d051cbb06da	2018-03-04 10:57:02.338469-06	2	[22104] C 5 INTAKE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
31e00f8a-70a5-47f4-8709-847fe005d2c8	2018-03-04 10:57:53.597594-06	2	[22105] C 6 INTAKE	[21041] OSSI-DNOVAK	[293] master	\N	\N
c57175e6-4ddb-4b7b-96c2-73f8484d60a0	2018-03-04 10:59:04.477682-06	2	[22106] C 7 GROUP MALE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0e02243a-2eaf-4069-91a6-9af95057568d	2018-03-04 10:59:41.06234-06	2	[22107] C 8 GROUP FEMALE	[21041] OSSI-DNOVAK	[293] master	\N	\N
406d2e87-9960-47e4-9a75-cab981bf79d9	2018-03-04 11:00:12.957529-06	2	[22063] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
1c015427-d0b9-47a4-b55f-0e491a413b79	2018-03-04 11:01:22.793512-06	2	[22108] C 9 INTAKE SINGLE 343	[21041] OSSI-DNOVAK	[293] master	\N	\N
6707ac25-72fe-4058-91e8-70f484ca2083	2018-03-04 11:01:41.853418-06	2	[22108] C 9 INTAKE SINGLE 343	[21041] OSSI-DNOVAK	[293] master	\N	\N
7af6f9a8-fa98-4a61-b328-6c2795ba8ab0	2018-03-04 11:02:29.505182-06	2	[22109] C 10 INTAKE SINGLE 346	[21041] OSSI-DNOVAK	[293] master	\N	\N
a0833276-8def-4efd-94e2-f0e8f5806a54	2018-03-04 12:13:02.674457-06	2	[22110] C 11 YOUTH SHOWER 347 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6387fbd2-9fac-45db-90da-141b313fa6d3	2018-03-04 12:13:36.00579-06	2	[22111] C 12 YOUTH SHOWER 348 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7d3c97c2-3c7b-4341-88a7-1a5652946e2f	2018-03-04 12:13:55.528742-06	2	[22111] C 12 YOUTH SHOWER 348 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8bd8206f-9a30-47fd-be74-b24db19f0956	2018-03-04 12:15:19.1141-06	2	[22112] C 13 HALL 326	[21041] OSSI-DNOVAK	[293] master	\N	\N
cbe75290-950f-4a3e-bfe2-e20d5f741717	2018-03-04 12:15:46.560844-06	2	[22112] C 13 HALL 326	[21041] OSSI-DNOVAK	[293] master	\N	\N
04aac84b-277b-4109-acc0-dac40386ee9b	2018-03-04 12:15:48.867075-06	2	[22112] C 13 HALL 326	[21041] OSSI-DNOVAK	[293] master	\N	\N
f17b186d-b93a-4809-a8da-ea33fe8ebed9	2018-03-04 12:16:04.434631-06	2	[22112] C 13 HALL 326	[21041] OSSI-DNOVAK	[293] master	\N	\N
9d07f339-dd47-4659-9ac1-3aa04fce863e	2018-03-04 12:16:24.308618-06	2	[22112] C 13 HALL 326	[21041] OSSI-DNOVAK	[293] master	\N	\N
20b6863c-73b2-43de-8d04-6c9fd1c9b0b6	2018-03-04 12:17:24.067594-06	2	[22113] C 14 HALL 326 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b9f646e9-286f-4c62-96cc-7b1d03c6d62b	2018-03-04 12:19:56.439829-06	2	[22114] C 15 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a6be7578-e051-4415-9a8e-49560c2182f8	2018-03-04 12:20:15.44473-06	2	[22114] C 15 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
02bc85d2-165c-4b0d-a71b-38a92ca37925	2018-03-04 12:21:10.45023-06	2	[22115] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bc2d81a7-858c-4fb6-a586-a90093f9e7f6	2018-03-04 12:21:39.744159-06	2	[22115] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0459a1ec-0e19-497f-a2b6-71cfbba5ee0a	2018-03-04 12:22:07.643948-06	2	[22115] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
753cbdc8-67e2-4025-bc98-7d2db30a4e38	2018-03-04 12:23:37.203904-06	2	[22116] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
1d1d1ebe-7eef-4978-8fdf-baab05632a75	2018-03-04 12:26:00.708253-06	2	[22117] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
af3b8c3b-53f5-4b02-8ee6-138873a27ee9	2018-03-04 12:26:28.604042-06	2	[22118] C 19 CORRIDOR 308 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8473396a-053d-40aa-b98f-dfc20ba332bb	2018-03-04 12:27:04.213602-06	2	[22119] C 20 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
0f958cf5-8cd5-4dae-a25a-09803408d97a	2018-03-04 12:27:36.938875-06	2	[22119] C 20 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
347461a4-1fa3-4840-b674-ebda4c4571e5	2018-03-04 12:28:26.077788-06	2	[22121] C 22 CORRIDOR 352	[21041] OSSI-DNOVAK	[293] master	\N	\N
ff19c664-bcb5-4804-8310-72bf10b2f5e9	2018-03-04 12:29:41.699349-06	3	[22120] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d75d45eb-cc15-4c5b-8995-dc47c7d1d80c	2018-03-04 12:29:41.960376-06	2	[22121] C 22 CORRIDOR 352	[21041] OSSI-DNOVAK	[293] master	\N	\N
0b0ab1f3-0f1f-4da4-8134-f682da7158b2	2018-03-04 12:29:41.964376-06	2	[22122] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
43d71c4f-c469-47ea-802e-6c6a367fee61	2018-03-04 12:29:41.967376-06	2	[22123] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
25635157-cd92-40c1-a091-7c351a1a41f6	2018-03-04 12:29:41.970377-06	2	[22124] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fc7eb100-a081-4ff1-a84a-a0833cc26e3a	2018-03-04 12:29:41.974377-06	2	[22125] C 26 CORRIDOR 317 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ba20245b-d467-4fac-b3b0-bbfc61c57da8	2018-03-04 12:29:41.977377-06	2	[22126] C 27 CORRIDOR 317 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0c6a1da6-059b-4676-b7c6-d0d44b48d835	2018-03-04 12:29:41.979377-06	2	[22127] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
547f12b6-f8c3-46d5-b653-8952b38352b1	2018-03-04 12:31:30.485227-06	2	[22124] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5b4092f2-1ad2-4c0b-a6c1-d36741c6bce0	2018-03-04 12:31:56.180796-06	2	[22125] C 26 CORRIDOR 317 	[21041] OSSI-DNOVAK	[293] master	\N	\N
dcfb45e3-70d9-44d6-9594-ef5ee9abd728	2018-03-04 12:32:38.467024-06	2	[22126] C 27 CORRIDOR 317 	[21041] OSSI-DNOVAK	[293] master	\N	\N
577bc5bb-d9fa-4d34-9a4a-688b0e7c4cb5	2018-03-04 12:33:08.800057-06	2	[22126] C 27 CORRIDOR 317 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2965853f-6203-4dfc-b25c-ff1f07a54eea	2018-03-04 12:33:43.300507-06	2	[22125] C 26 CORRIDOR 317 	[21041] OSSI-DNOVAK	[293] master	\N	\N
129a7cd3-9ce1-40f5-becc-75423ae5d77a	2018-03-04 12:36:19.706146-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7be9e366-dad0-42cf-811a-0b651436447d	2018-03-04 12:43:08.711043-06	2	[22302] C 27 CORRIDOR 317 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8cfc2810-0b46-486d-b2a3-e023b45165c4	2018-03-04 12:43:12.88246-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bfcdece2-2781-4b0a-b58a-92c88ff3c4b7	2018-03-04 12:43:29.478119-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
94cb8f64-5af5-496a-a684-00c871c27cd5	2018-03-04 12:43:47.547926-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
efc92746-17a9-4d01-8f0f-20ecee3a8684	2018-03-04 12:44:22.861457-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
039ed8f8-bc2b-4df9-ba30-1f154ca5842f	2018-03-04 12:44:59.79215-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
29c40304-7b8f-4b19-b0a9-51e0bc0e717b	2018-03-04 12:45:14.048575-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c76d064d-f38c-4985-a040-160efb20a71d	2018-03-04 12:46:29.437113-06	3	[22303] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
93dd2d7b-08dc-49fa-afe8-74aa29461b59	2018-03-04 12:46:29.691139-06	3	[22302] C 27 CORRIDOR 317 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6b71fecc-ccf1-4973-a319-84802594f629	2018-03-04 12:46:29.929162-06	3	[22301] C 26 CORRIDOR 317 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e9035143-1b9c-47ba-a239-0f1aca41f6fd	2018-03-04 12:46:30.167186-06	3	[22294] C 19 CORRIDOR 308 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4e6ec7e2-6374-4d85-b7df-61543245d5ee	2018-03-04 12:46:30.40521-06	2	[22295] C 20 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
42ec49a5-470a-493c-9dbc-0f0ba378840b	2018-03-04 12:46:30.417211-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c59aac7a-bd4c-4f24-8897-6e34786693f5	2018-03-04 12:46:30.420211-06	2	[22297] C 22 CORRIDOR 352	[21041] OSSI-DNOVAK	[293] master	\N	\N
4d2310da-7e41-45bd-bf28-b5a7b7d7f4aa	2018-03-04 12:46:30.423212-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
763aba4a-1e29-4591-9a55-7e74f2ac9e87	2018-03-04 12:46:30.425212-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
22e1a3ab-9b8b-416d-90bd-268dbf1356f9	2018-03-04 12:46:30.428212-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f59c2a65-cb83-4800-951b-f8ef2a5ab84e	2018-03-04 12:46:30.431213-06	3	[22295] C 20 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
2f443e38-cbaa-4db1-8bc0-866d00b0a8f1	2018-03-04 12:46:30.669236-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5ee86bff-2733-4473-aca2-25976bf4e328	2018-03-04 12:46:30.673237-06	2	[22297] C 22 CORRIDOR 352	[21041] OSSI-DNOVAK	[293] master	\N	\N
321a08db-9cf5-4f71-a474-e63a6c5f361b	2018-03-04 12:46:30.675237-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cb845964-c52d-4f47-8709-a12f19f3b286	2018-03-04 12:46:30.678237-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
a04dc7d3-c820-4fd2-a12f-aba5063e5456	2018-03-04 12:46:30.680237-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9b0a63d5-26ba-4dcc-8341-630431c456e7	2018-03-04 12:46:30.682238-06	3	[22297] C 22 CORRIDOR 352	[21041] OSSI-DNOVAK	[293] master	\N	\N
818cd8d5-58a3-43aa-b7cf-9342e0c978b9	2018-03-04 12:46:30.927262-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4a1f5078-82f0-4a5b-811a-38993d11b3ff	2018-03-04 12:46:30.930262-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
a149c407-88cc-43da-9723-fde57dc2e3ec	2018-03-04 12:46:30.933263-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9edf1206-068d-4125-807b-f4c178de6fe8	2018-03-04 12:46:57.640933-06	3	[22289] C 14 HALL 326 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f6b3f360-bf04-4a8d-80b3-6585924c8c1d	2018-03-04 12:46:57.894959-06	2	[22290] C 15 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5d942656-dddd-48f4-9693-56b73a6e929a	2018-03-04 12:46:57.897959-06	2	[22291] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
04488a81-5cce-4202-825c-92da879971a2	2018-03-04 12:46:57.900959-06	2	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
7c7ef5b4-97b2-4bcd-a44f-91b5e6420043	2018-03-04 12:46:57.90396-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef0695e7-a1c2-4914-9ec9-99991b014455	2018-03-04 12:46:57.90596-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1dc288cb-0b36-4c65-bd0d-b88e48f5abbe	2018-03-04 12:46:57.90896-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d6e2199b-3ead-496d-93da-e1ecfa4c4ed2	2018-03-04 12:46:57.91096-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
2c1f20eb-6343-4964-b5ca-f0461cdf02bf	2018-03-04 12:46:57.913961-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2a31a386-fde2-468b-8189-9255f3450175	2018-03-04 12:46:57.914961-06	3	[22283] C 8 GROUP FEMALE	[21041] OSSI-DNOVAK	[293] master	\N	\N
dacb6945-bc8f-4c2b-9899-2a7bfdb7439b	2018-03-04 12:46:58.151984-06	2	[22284] C 9 INTAKE SINGLE 343	[21041] OSSI-DNOVAK	[293] master	\N	\N
50d7dd8a-4b59-48c5-8f96-9f40087a108a	2018-03-04 12:46:58.154985-06	2	[22285] C 10 INTAKE SINGLE 346	[21041] OSSI-DNOVAK	[293] master	\N	\N
a85fbcba-7b33-40b8-abc6-ac763bc2e570	2018-03-04 12:46:58.157985-06	2	[22286] C 11 YOUTH SHOWER 347 	[21041] OSSI-DNOVAK	[293] master	\N	\N
89462fe8-e6d4-4da0-a3cb-da0b92d627d4	2018-03-04 12:46:58.159985-06	2	[22287] C 12 YOUTH SHOWER 348 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2d93880e-6850-4554-9fe8-6c5074097476	2018-03-04 12:46:58.162985-06	2	[22288] C 13 HALL 326	[21041] OSSI-DNOVAK	[293] master	\N	\N
02328f68-c571-45f5-b28e-3b33876bf8fc	2018-03-04 12:46:58.165986-06	2	[22290] C 15 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6f2f3781-ba18-4d2e-8100-8e12d1c082c9	2018-03-04 12:46:58.167986-06	2	[22291] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
26f97a6f-40a9-479f-835d-1d36f8859c88	2018-03-04 12:46:58.170986-06	2	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
fffe5e6f-9bdd-4b01-b462-c93e25090c16	2018-03-04 12:46:58.172986-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
a0106dc2-99ea-4c8d-8212-f8aba3fd4552	2018-03-04 12:46:58.174987-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0f8ed556-76dd-4fd2-a1f0-1f3c649391b0	2018-03-04 12:46:58.177987-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5229690d-647e-42cc-b4b2-beb775248af3	2018-03-04 12:46:58.179987-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
d061ceda-fd83-4068-9e64-543b898b2410	2018-03-04 12:46:58.181987-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0274b33a-fd90-4c63-9c96-40ef4195ccd5	2018-03-04 12:46:58.184988-06	3	[22277] C 2 VEHICLE SALLY PORT 324	[21041] OSSI-DNOVAK	[293] master	\N	\N
0d9cc804-3d43-46b9-9e9d-152b40ca9a34	2018-03-04 12:46:58.430012-06	2	[22278] C 3 INTAKE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4b6eda1f-d98d-415d-a5df-e9e4d619b6d8	2018-03-04 12:46:58.433012-06	2	[22279] C 4 INTAKE	[21041] OSSI-DNOVAK	[293] master	\N	\N
b354a321-7cce-400e-a0a7-0eb7ac0ea4b5	2018-03-04 12:46:58.436013-06	2	[22280] C 5 INTAKE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ebe77663-8ce4-492c-98bb-9c496d64a506	2018-03-04 12:46:58.439013-06	2	[22281] C 6 INTAKE	[21041] OSSI-DNOVAK	[293] master	\N	\N
7ce548be-a2b7-4b70-ab19-e73fe066fed4	2018-03-04 12:46:58.441013-06	2	[22282] C 7 GROUP MALE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
01557d90-2521-4bca-9f45-7d0ccf71da5d	2018-03-04 12:46:58.443013-06	2	[22284] C 9 INTAKE SINGLE 343	[21041] OSSI-DNOVAK	[293] master	\N	\N
c80cbbdc-5262-49e4-a861-a3492a7038ee	2018-03-04 12:46:58.446014-06	2	[22285] C 10 INTAKE SINGLE 346	[21041] OSSI-DNOVAK	[293] master	\N	\N
2c9aa728-b1d3-4162-8c92-f91326bf1800	2018-03-04 12:46:58.448014-06	2	[22286] C 11 YOUTH SHOWER 347 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2e64f7bd-cb1f-4abe-9570-91ee4ab5b463	2018-03-04 12:46:58.450014-06	2	[22287] C 12 YOUTH SHOWER 348 	[21041] OSSI-DNOVAK	[293] master	\N	\N
edbbc960-b17c-47b6-ace8-cecce8e6ac67	2018-03-04 12:46:58.453014-06	2	[22288] C 13 HALL 326	[21041] OSSI-DNOVAK	[293] master	\N	\N
a98c03cd-0403-40b3-a63b-003b9ed69e77	2018-03-04 12:46:58.455015-06	2	[22290] C 15 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a79940ae-f6c1-43b6-a261-05032cd40ace	2018-03-04 12:46:58.458015-06	2	[22291] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
be959497-7f23-47e9-b223-10817808788c	2018-03-04 12:46:58.460015-06	2	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
0698dc07-83fe-423f-8079-bfc131283899	2018-03-04 12:46:58.463015-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
9df35fc6-ae46-49d1-9fa2-39824336acaa	2018-03-04 12:46:58.465016-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8d30840a-3067-4db5-95ea-d528ec7a5b27	2018-03-04 12:46:58.468016-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e360aca0-93d8-40bd-b96b-270673e038b7	2018-03-04 12:46:58.470016-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
73979db4-2f5b-405f-8fc1-158a5be6e760	2018-03-04 12:46:58.473016-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8f31be5c-26a2-467a-88af-a90098e82d00	2018-03-04 12:46:58.474017-06	3	[22276] C 1 VEHICLE SALLY PORT 324	[21041] OSSI-DNOVAK	[293] master	\N	\N
bdb1b542-f564-4e28-a481-1d920768097b	2018-03-04 12:46:58.717041-06	2	[22278] C 3 INTAKE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8f085968-001b-43ed-ba81-996e7ceb3673	2018-03-04 12:46:58.720041-06	2	[22279] C 4 INTAKE	[21041] OSSI-DNOVAK	[293] master	\N	\N
59d5c7fa-9711-4e30-8e75-b3c658a879ce	2018-03-04 12:46:58.723041-06	2	[22280] C 5 INTAKE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
40aee783-bb40-4f0a-a796-2ad354696b06	2018-03-04 12:46:58.725042-06	2	[22281] C 6 INTAKE	[21041] OSSI-DNOVAK	[293] master	\N	\N
b94822ad-ac2e-4be9-8dd8-4d611818b407	2018-03-04 12:46:58.727042-06	2	[22282] C 7 GROUP MALE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bc6dcb30-5103-473f-8ffb-744a37d4d932	2018-03-04 12:46:58.730042-06	2	[22284] C 9 INTAKE SINGLE 343	[21041] OSSI-DNOVAK	[293] master	\N	\N
0000907f-acf7-46b5-a4bc-829c59dd3aac	2018-03-04 12:46:58.734043-06	2	[22285] C 10 INTAKE SINGLE 346	[21041] OSSI-DNOVAK	[293] master	\N	\N
648658c1-7ec7-4a95-8ca4-0931fac414eb	2018-03-04 12:46:58.736043-06	2	[22286] C 11 YOUTH SHOWER 347 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2352ba2f-56a0-465b-a986-515d320cbcb5	2018-03-04 12:46:58.739043-06	2	[22287] C 12 YOUTH SHOWER 348 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e91b844b-4a6a-4809-b799-f0bf07a330cd	2018-03-04 12:46:58.741043-06	2	[22288] C 13 HALL 326	[21041] OSSI-DNOVAK	[293] master	\N	\N
323bc341-d8d6-4bd9-a3dc-c92acb8fa165	2018-03-04 12:46:58.743043-06	2	[22290] C 15 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4a7e23c9-f05c-461c-8e26-787698bc91ad	2018-03-04 12:46:58.746044-06	2	[22291] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a2d3c1ba-09de-4256-87a6-a4d63aa0e193	2018-03-04 12:46:58.748044-06	2	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
16440c14-b183-4f9f-ae6a-2e12158cb4d4	2018-03-04 12:46:58.750044-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
22b0510c-842f-4dbd-9e3c-5038cae33f53	2018-03-04 12:46:58.753044-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
dcc9b8eb-3ac7-4fb0-8b79-119ea453bced	2018-03-04 12:46:58.756045-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1da0613e-10fd-480e-a881-37656b51ef12	2018-03-04 12:46:58.759045-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
ec4e68a2-c2ba-48fe-a81a-22374ad3dfd4	2018-03-04 12:46:58.761045-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a9f0bffb-f2ec-4fe9-8080-efc6f3905107	2018-03-04 12:46:58.763045-06	3	[22282] C 7 GROUP MALE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0626e6f9-fc94-40b1-9d95-4242e3b9c1d7	2018-03-04 12:46:58.999069-06	2	[22284] C 9 INTAKE SINGLE 343	[21041] OSSI-DNOVAK	[293] master	\N	\N
16f2ebc2-c1bb-4bb8-9d60-c5c6f962e8ab	2018-03-04 12:46:59.002069-06	2	[22285] C 10 INTAKE SINGLE 346	[21041] OSSI-DNOVAK	[293] master	\N	\N
22679c7d-8528-4cc8-a4d5-d94dd8a96d11	2018-03-04 12:46:59.00507-06	2	[22286] C 11 YOUTH SHOWER 347 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5064b700-c9cb-4ef0-913e-ed96753f77db	2018-03-04 12:46:59.00707-06	2	[22287] C 12 YOUTH SHOWER 348 	[21041] OSSI-DNOVAK	[293] master	\N	\N
78de53c9-7b18-4f72-90ee-703540b68d9b	2018-03-04 12:46:59.01007-06	2	[22288] C 13 HALL 326	[21041] OSSI-DNOVAK	[293] master	\N	\N
996eef1e-5bc5-43b1-affc-54d3af25ea84	2018-03-04 12:46:59.01207-06	2	[22290] C 15 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c10104f4-73bd-44de-af91-b4992cdde47d	2018-03-04 12:46:59.015071-06	2	[22291] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5841b80c-8f31-4ec3-bfbd-adda0a78e7ca	2018-03-04 12:46:59.017071-06	2	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
2b08ecfa-d767-43f7-bf4c-6cfcac3a06cb	2018-03-04 12:46:59.020071-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
a051c997-2405-41b6-a059-9d0915c33335	2018-03-04 12:46:59.022071-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b893b571-a749-4f28-a3d5-53e619b94b5a	2018-03-04 12:46:59.025072-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
da2849a3-2ccf-448e-aa58-86f079d3f84c	2018-03-04 12:46:59.027072-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
94f75752-2dba-46cc-9b35-9847e9566613	2018-03-04 12:46:59.029072-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
05b2bdf8-c302-4a37-8e72-f312e317c790	2018-03-04 12:46:59.031072-06	3	[22288] C 13 HALL 326	[21041] OSSI-DNOVAK	[293] master	\N	\N
51dbb0f1-9793-49d4-afcf-b4f028f5a45d	2018-03-04 12:46:59.272096-06	2	[22290] C 15 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5e94221e-166b-4364-8cbd-e06fb2b7114b	2018-03-04 12:46:59.276097-06	2	[22291] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
89856529-c826-4638-b30f-2b9401bae44d	2018-03-04 12:46:59.278097-06	2	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
a5ddf121-f978-4dce-9739-3205be21a094	2018-03-04 12:46:59.281097-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
4d18a1f9-30ea-42e8-8933-bee34f9792e2	2018-03-04 12:46:59.283097-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
be8b4640-1b9a-4c12-94fd-663f33aba22d	2018-03-04 12:46:59.286098-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ad942866-8b03-438d-9b22-663703f71558	2018-03-04 12:46:59.288098-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
d6b9b145-cc7d-42ae-8379-3e7786871932	2018-03-04 12:46:59.291098-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e9e04997-a983-42a0-967c-ddc6b50a0373	2018-03-04 12:47:26.978867-06	3	[22290] C 15 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4bf0a116-d134-40f4-bb63-13616f2e6e4f	2018-03-04 12:47:27.217891-06	2	[22291] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d803728c-c573-4be5-808d-57ed3b9bed63	2018-03-04 12:47:27.220891-06	2	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
f04f51e5-794d-4af2-9068-203b9d5f2000	2018-03-04 12:47:27.222891-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
cc4b444d-5d16-4792-9dde-6ecfbd3879b0	2018-03-04 12:47:27.225891-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cf5b03f1-f663-44f0-b791-e68c6732cd01	2018-03-04 12:47:27.227892-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6557a460-99e9-419f-9dd6-f53b54bd25d9	2018-03-04 12:47:27.230892-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
3f12ac61-9f67-4c4f-a196-ee81f80ab14a	2018-03-04 12:47:27.232892-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
44b5de2b-b5c4-4647-925b-a3641fcffc35	2018-03-04 12:47:27.234892-06	3	[22284] C 9 INTAKE SINGLE 343	[21041] OSSI-DNOVAK	[293] master	\N	\N
6764ef7b-42ce-4df1-b299-a469ca80d6e2	2018-03-04 12:47:27.470916-06	2	[22285] C 10 INTAKE SINGLE 346	[21041] OSSI-DNOVAK	[293] master	\N	\N
5472dab9-a0a4-4d5e-9582-c9e979891d2d	2018-03-04 12:47:27.473916-06	2	[22286] C 11 YOUTH SHOWER 347 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5d39ff81-21e2-4463-92a0-83bfb1b787e1	2018-03-04 12:47:27.476917-06	2	[22287] C 12 YOUTH SHOWER 348 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e271c69b-d277-4dc3-a474-84f506e5e2df	2018-03-04 12:47:27.478917-06	2	[22291] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b50772ef-c172-45ef-b1f3-a6fa855e8a4d	2018-03-04 12:47:27.481917-06	2	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
eabed7d8-7d96-4fe6-b27c-c813638a1bad	2018-03-04 12:47:27.483917-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
ff303ce9-4388-41b7-88df-a0675003f157	2018-03-04 12:47:27.486918-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
eb4ea5b9-4ace-4322-81fa-566c9fdf386c	2018-03-04 12:47:27.488918-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
55b81153-4940-44ce-9831-9db107b6af79	2018-03-04 12:47:27.490918-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
eae85ac5-b0ea-4854-80db-49af724bec76	2018-03-04 12:47:27.493918-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
78f72e44-a851-4c5a-9337-1c044c90b3e2	2018-03-04 12:47:27.494918-06	3	[22278] C 3 INTAKE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6fc80d54-33de-4f51-80b8-1144ee51b2fe	2018-03-04 12:47:27.735942-06	2	[22279] C 4 INTAKE	[21041] OSSI-DNOVAK	[293] master	\N	\N
66f01b2a-abb6-4669-8454-0708d8a4a9fe	2018-03-04 12:47:27.738943-06	2	[22280] C 5 INTAKE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3d826024-cfda-4296-92b3-1beb63cad330	2018-03-04 12:47:27.741943-06	2	[22281] C 6 INTAKE	[21041] OSSI-DNOVAK	[293] master	\N	\N
2e30050b-42c5-4dd5-98fb-fad4e7cbe4bd	2018-03-04 12:47:27.744943-06	2	[22285] C 10 INTAKE SINGLE 346	[21041] OSSI-DNOVAK	[293] master	\N	\N
fede6d72-685b-44e3-8b51-9bbf796eed45	2018-03-04 12:47:27.746944-06	2	[22286] C 11 YOUTH SHOWER 347 	[21041] OSSI-DNOVAK	[293] master	\N	\N
dc208c47-6c61-4039-8006-cf4a64e501f7	2018-03-04 12:47:27.749944-06	2	[22287] C 12 YOUTH SHOWER 348 	[21041] OSSI-DNOVAK	[293] master	\N	\N
43a4318b-8ebb-452d-9597-441dcd751b09	2018-03-04 12:47:27.751944-06	2	[22291] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c237e48c-9d8d-4e4c-a0b1-4a972dfab3ae	2018-03-04 12:47:27.754944-06	2	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
7c7656c4-e98a-4a22-bd40-c555109729e2	2018-03-04 12:47:27.756945-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
98b4f216-8626-4b46-965a-1bc14ad2f01d	2018-03-04 12:47:27.758945-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
77a3cdf0-2eb8-4b78-8f95-3958ed0cc48e	2018-03-04 12:47:27.761945-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d2d0dd75-0a7e-4b16-85f2-e5902be1f39c	2018-03-04 12:47:27.763945-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
8eaed333-fab4-4a5a-a6ad-584e1d6dfc10	2018-03-04 12:47:27.765945-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8e049fdd-e203-488e-919f-653290066038	2018-03-04 12:47:27.767946-06	3	[22279] C 4 INTAKE	[21041] OSSI-DNOVAK	[293] master	\N	\N
2f8a8bf7-1101-4a7c-83cb-3349f661f983	2018-03-04 12:47:28.004969-06	2	[22280] C 5 INTAKE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7bb3bf1f-9aa5-42c4-a9c2-97eda46193f3	2018-03-04 12:47:28.00797-06	2	[22281] C 6 INTAKE	[21041] OSSI-DNOVAK	[293] master	\N	\N
045c2334-5de4-4b9e-879a-36f8a763f5af	2018-03-04 12:47:28.01097-06	2	[22285] C 10 INTAKE SINGLE 346	[21041] OSSI-DNOVAK	[293] master	\N	\N
441c8136-3d4d-4397-820d-afd7be49780c	2018-03-04 12:47:28.01397-06	2	[22286] C 11 YOUTH SHOWER 347 	[21041] OSSI-DNOVAK	[293] master	\N	\N
06ad0c93-111e-4a3b-9adf-8b32521a1d6d	2018-03-04 12:47:28.01597-06	2	[22287] C 12 YOUTH SHOWER 348 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5f4d0df4-8245-4ca8-acfd-6f680abedc87	2018-03-04 12:47:28.018971-06	2	[22291] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f651a316-e7f8-4b6a-a5a9-8b48ddc9052e	2018-03-04 12:47:28.020971-06	2	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
356d3b64-8bc9-4cb4-89ed-c2a9b265db82	2018-03-04 12:47:28.022971-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
3f181f03-957b-47c2-a81d-4706519e98dc	2018-03-04 12:47:28.025971-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ee42df2a-df8c-468f-be1e-ef9804e64496	2018-03-04 12:47:28.027972-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5e3dac0f-6a5d-49a9-a78b-f87cb93b1126	2018-03-04 12:47:28.030972-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
adead829-a18b-4479-94ef-1642a2a31d0e	2018-03-04 12:47:28.033972-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
36767da1-288d-48a5-8a3c-8a7ca3ffd9b1	2018-03-04 12:47:28.034972-06	3	[22280] C 5 INTAKE 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0f308d2b-8c19-497d-a2e3-22c56eeb7f57	2018-03-04 12:47:28.273996-06	2	[22281] C 6 INTAKE	[21041] OSSI-DNOVAK	[293] master	\N	\N
b96e541a-0df0-4dc6-9c32-e560e3d9c8c5	2018-03-04 12:47:28.276997-06	2	[22285] C 10 INTAKE SINGLE 346	[21041] OSSI-DNOVAK	[293] master	\N	\N
16bf6ab5-274e-40d5-ac63-b2750112713d	2018-03-04 12:47:28.279997-06	2	[22286] C 11 YOUTH SHOWER 347 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9e44ce6b-fcda-47f6-8119-7b20f583846e	2018-03-04 12:47:28.281997-06	2	[22287] C 12 YOUTH SHOWER 348 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c990e43d-a168-4577-b764-d4d418375332	2018-03-04 12:47:28.284997-06	2	[22291] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c9748a94-5560-43f5-8af8-84cb1dd5372e	2018-03-04 12:47:28.286998-06	2	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
ee176a94-4fae-4b85-8361-61e214bb99fd	2018-03-04 12:47:28.288998-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
4e3b33e4-11f6-4a91-bbc6-d9823a758438	2018-03-04 12:47:28.291998-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9fa50ec9-ed63-471c-889d-96c8b877ee7d	2018-03-04 12:47:28.293998-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e982ad99-4d0c-4eaa-967c-ac18b988e2a3	2018-03-04 12:47:28.296999-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
cb95bd37-4fcd-42f0-9cf4-688699662c78	2018-03-04 12:47:28.298999-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d3202860-bca9-4d80-839f-4140eb0153cd	2018-03-04 12:47:28.300999-06	3	[22281] C 6 INTAKE	[21041] OSSI-DNOVAK	[293] master	\N	\N
a6a856f9-db53-4cd1-82f8-de77c95f470f	2018-03-04 12:47:28.543023-06	2	[22285] C 10 INTAKE SINGLE 346	[21041] OSSI-DNOVAK	[293] master	\N	\N
ff7d1e3c-af0a-449c-81a9-f56a0a9087a8	2018-03-04 12:47:28.546023-06	2	[22286] C 11 YOUTH SHOWER 347 	[21041] OSSI-DNOVAK	[293] master	\N	\N
855ddfb9-991f-4d2f-819a-2b89debc34a0	2018-03-04 12:47:28.549024-06	2	[22287] C 12 YOUTH SHOWER 348 	[21041] OSSI-DNOVAK	[293] master	\N	\N
be4a7f3f-e4f9-4829-95d8-b3291e4ac2f6	2018-03-04 12:47:28.551024-06	2	[22291] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b6839435-180c-4af9-b50b-9513f88b3587	2018-03-04 12:47:28.553024-06	2	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
932baf8b-eccc-4aef-9355-e499d621b3ff	2018-03-04 12:47:28.556024-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
3a57e145-bffe-4baf-ab34-828f262a8de8	2018-03-04 12:47:28.558025-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ab1241b6-b8df-48ff-be69-82b2962f4a97	2018-03-04 12:47:28.560025-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c30eb8af-854b-4f50-9b53-c8e88dcba80d	2018-03-04 12:47:28.563025-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
c4e6581e-6da0-430b-aa4b-efd940f2f7b0	2018-03-04 12:47:28.565025-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
94269759-5ae1-4dc9-82d4-8d6d33b8c59d	2018-03-04 12:47:28.567026-06	3	[22287] C 12 YOUTH SHOWER 348 	[21041] OSSI-DNOVAK	[293] master	\N	\N
07826b75-992b-42b4-a92f-f50ec58f5ca6	2018-03-04 12:47:28.805049-06	2	[22291] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f50de8dd-b9f0-4d98-99ea-e320d292eebd	2018-03-04 12:47:28.80805-06	2	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
dbb3c1e4-df1f-40a9-9987-084bcff334af	2018-03-04 12:47:28.81205-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
6ac61cab-ac66-4c7f-b639-0b5264617adb	2018-03-04 12:47:28.81505-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bc554fef-67e1-4618-89ef-5a3fff8aa632	2018-03-04 12:47:28.817051-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a4f0a18b-33bc-4d4f-bdaf-ed8182808afd	2018-03-04 12:47:28.819051-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
70bf09fa-7292-4982-a922-c6b2e49518cd	2018-03-04 12:47:28.822051-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
deb478e4-4194-4c99-9abc-16e49bd5f3ed	2018-03-04 12:47:28.823051-06	3	[22286] C 11 YOUTH SHOWER 347 	[21041] OSSI-DNOVAK	[293] master	\N	\N
106e101c-623f-4cca-8189-32b519dd714f	2018-03-04 12:47:29.063075-06	2	[22291] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d40bad00-ba86-4a4b-99a0-32a1ec156458	2018-03-04 12:47:29.066075-06	2	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
d3c00312-20c9-4902-ac35-8f55c8a756da	2018-03-04 12:47:29.069076-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
063e2628-8a73-4a57-839d-0a76c5f28313	2018-03-04 12:47:29.071076-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
70aef435-89af-4f4a-8e76-cf49ecd2e8ea	2018-03-04 12:47:29.074076-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
98e3a064-c50d-407d-b8d5-7a4a37a2c0b9	2018-03-04 12:47:29.076076-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
77d71501-bae8-4b60-959a-f2f9cdb97469	2018-03-04 12:47:29.078077-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8b34a823-01e0-44bb-9a7c-946791ec1731	2018-03-04 12:47:29.080077-06	3	[22285] C 10 INTAKE SINGLE 346	[21041] OSSI-DNOVAK	[293] master	\N	\N
06ea73ce-ce5f-4a4e-b0b7-f4dd4f853028	2018-03-04 12:47:29.319101-06	2	[22291] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
433ceeb4-4305-46cc-8621-2651e49f2f4d	2018-03-04 12:47:29.322101-06	2	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
c16d720f-94e9-402a-b452-1eedc43087f0	2018-03-04 12:47:29.325101-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
83e62add-7741-4ddf-b561-9fbdf5f29e0c	2018-03-04 12:47:29.327102-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
18be34ee-9870-427a-bb33-1a627b059983	2018-03-04 12:47:29.330102-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3e40f2f8-74e0-42d3-a6d2-d85c53e46c4a	2018-03-04 12:47:29.332102-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
bae6f825-5380-4ad5-aca9-115a8fde1fd7	2018-03-04 12:47:29.335102-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
77594439-6f80-494c-9626-97f1dc34ebc7	2018-03-04 12:47:29.337103-06	3	[22291] C 16 CORRIDOR 327 	[21041] OSSI-DNOVAK	[293] master	\N	\N
adbe976b-5215-4dd8-8677-44a4374eae58	2018-03-04 12:47:29.572126-06	2	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
6e863f35-580f-49b6-8717-c52c3433925e	2018-03-04 12:47:29.576126-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
21110413-3784-45a5-97f7-fff5ce6e60ca	2018-03-04 12:47:29.578127-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f92a8561-ebf3-4b67-b0a1-643cbdd222f9	2018-03-04 12:47:29.581127-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9b5c9db8-cbbf-4662-a674-ebc73f36e1a0	2018-03-04 12:47:29.584127-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
c75d06b8-eaf6-4044-84bf-79930978d0a3	2018-03-04 12:47:29.586127-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
85cf98bd-b81a-414c-a4cd-68a764ea8b47	2018-03-04 12:47:29.588128-06	3	[22292] C 17 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
38d2ab5c-e996-489d-9a98-acc620030611	2018-03-04 12:47:29.825151-06	2	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
9e74e95b-7602-4994-834f-d6fe10772c4c	2018-03-04 12:47:29.829152-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
29f1f0e9-f2ec-4e7a-9bbd-4bf7fe77fbcc	2018-03-04 12:47:29.831152-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c304253c-1962-4401-a228-ca322aae7d94	2018-03-04 12:47:29.834152-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
8ec5bfa4-9dbf-482f-8049-c2d35ec1f0fd	2018-03-04 12:47:29.837153-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3b79f2f6-61a6-4091-a607-d40746885cda	2018-03-04 12:47:29.838153-06	3	[22293] C 18 CORRIDOR 308	[21041] OSSI-DNOVAK	[293] master	\N	\N
50832247-0ffc-427d-808e-3699ce49e4c3	2018-03-04 12:47:30.075176-06	2	[22296] C 21 CORRIDOR 352 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7680fc07-3a1b-41c2-9bc2-e755126645ff	2018-03-04 12:47:30.079177-06	2	[22298] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
efe6a4c2-2061-4ce7-928d-8dc36fd41c5a	2018-03-04 12:47:30.081177-06	2	[22299] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
f2dc98ed-262d-461e-813c-ff984e238fd7	2018-03-04 12:47:30.084177-06	2	[22300] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e5c56eb7-1bf5-40e4-b75b-4040d41f4aec	2018-03-04 12:52:13.974563-06	2	[22440] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
4d8291c6-968a-4e7b-8e48-1540e7f97408	2018-03-04 12:52:54.179584-06	2	[22473] D 8 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0bb6938a-7f9a-4079-bfc8-5e6c46936ec8	2018-03-04 12:54:46.391804-06	2	[22473] D 8 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ce1ba798-a446-4a2b-b9a0-bf57bcbd7413	2018-03-04 12:55:30.577222-06	2	[22474] D 9 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
045c52eb-c9f7-4a7f-9178-9f8f39d253ce	2018-03-04 12:55:59.485112-06	2	[22475] D 10 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a83fe39d-4183-4ec6-b8a5-8c6ef88c7139	2018-03-04 12:56:54.177581-06	2	[22476] D 11 CLASSROOM 415 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3e18b3cf-b85d-4e55-a98e-f7e12c23b16f	2018-03-04 12:57:17.512914-06	2	[22476] D 11 CLASSROOM 415 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef64ebd8-4df0-47e3-a45d-961f42d89ed6	2018-03-04 12:57:43.46851-06	2	[22477] D 12 CLASSROOM 415	[21041] OSSI-DNOVAK	[293] master	\N	\N
7e24143c-b74c-402e-bc05-c8807dc2f132	2018-03-04 12:59:20.376199-06	2	[22478] D 13 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
fbeca906-468e-4741-a2cd-eda27460be17	2018-03-04 12:59:46.631825-06	2	[22478] D 13 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
337d8f93-e8a0-434e-9761-481787a011df	2018-03-04 13:00:22.142375-06	2	[22479] D 14 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
7e18b47e-56b3-40f1-b60b-527413e9f404	2018-03-04 13:02:17.568917-06	2	[22480] D 15 VESTIBULE 422 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7d7afbd8-36b0-4f30-86ef-b15f0a8dbfd9	2018-03-04 13:02:52.788438-06	2	[22481] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
4299d40d-3717-4200-92ec-35c7bd6cfe8b	2018-03-04 13:03:11.60232-06	2	[22480] D 15 VESTIBULE 422 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c9732845-309c-4ff3-ab66-2dee6f83cc89	2018-03-04 13:23:30.742221-06	2	[22482] D 17 WORK ALCOVE 423 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0b7e1f98-e687-442a-9623-f5ce032d79ec	2018-03-04 13:24:00.598207-06	2	[22482] D 17 WORK ALCOVE 423 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d5903d2d-4d4b-41b3-8d29-083f597a859e	2018-03-04 13:24:32.508397-06	2	[22483] D 18 CLASSROOM 425	[21041] OSSI-DNOVAK	[293] master	\N	\N
e8657f9f-2795-4040-bce9-bd28ae51384e	2018-03-04 13:25:06.474794-06	2	[22484] D 19 CLASSROOM 425 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4c9794cc-40d0-46c4-a5a7-73b179a63845	2018-03-04 13:25:37.602906-06	2	[22485] D 20 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c47f81a7-b5c6-4525-a993-7dae8612bcdb	2018-03-04 13:26:16.434789-06	2	[22486] D 21 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a69c4e1e-db72-44f1-8b78-430f58d69295	2018-03-04 13:30:11.774321-06	2	[22471] D 6 CORRIDOR 414 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c12811f5-d932-45de-accf-07997a5e2520	2018-03-04 13:33:30.533195-06	2	[22467] D 2 CORRIDOR 437 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8221bc89-90d3-4382-9026-1e3e7bef705c	2018-03-04 13:33:53.341475-06	2	[22467] D 2 CORRIDOR 437 	[21041] OSSI-DNOVAK	[293] master	\N	\N
775e2c5c-2ca2-40f1-9856-740422a1e980	2018-03-04 13:34:43.19846-06	2	[22469] D 4 CORRIDOR 437 	[21041] OSSI-DNOVAK	[293] master	\N	\N
16c1eaf0-996e-46df-a070-570d0611ebbf	2018-03-04 13:38:22.685407-06	2	[22466] D 1 CORRIDOR 437 	[21041] OSSI-DNOVAK	[293] master	\N	\N
902e32d2-621d-4723-9ea7-2d6a1b316033	2018-03-04 13:42:24.702606-06	2	[22470] D 5 CORRIDOR 437	[21041] OSSI-DNOVAK	[293] master	\N	\N
ebd7f9d9-7af5-4f2b-8898-186d47b4b325	2018-03-04 13:42:53.506486-06	2	[22440] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
723d79de-9544-4806-a535-24a6f92466b6	2018-03-04 13:43:42.954431-06	2	[22487] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fd613ff2-94df-4ca0-b348-22e28fc842c5	2018-03-04 13:44:06.593794-06	2	[22487] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2de2478d-e0aa-40fd-a6f5-f9df36bb05ad	2018-03-04 13:45:34.685603-06	2	[22488] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
5f698efe-1f46-4efa-838d-0c2e399638da	2018-03-04 13:46:37.418875-06	2	[22489] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fd6c17d3-69d9-4848-9a28-a46c3d7ab103	2018-03-04 13:46:59.051038-06	2	[22490] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
67ba6440-fbd4-45ca-aaed-6532bd559bcc	2018-03-04 13:47:30.445177-06	2	[22491] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
a9011406-275e-4d4e-a207-4983bd66bd98	2018-03-04 13:53:27.444874-06	2	[22492] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c5bccb42-c1e9-4680-ad84-63d1fea3590d	2018-03-04 13:53:52.503379-06	2	[22492] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c34b38a4-f15d-4dce-a228-74ce6db8f86a	2018-03-04 13:55:18.92302-06	2	[22493] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
298ecf36-fe34-4335-baaa-38a24d2c764a	2018-03-04 13:56:18.547982-06	2	[22494] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
41bc9e9c-c188-4e55-95e0-326af180dd7e	2018-03-04 13:59:50.094135-06	2	[22498] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6603f3ce-6ce1-42c5-b5aa-27e4cde81929	2018-03-04 14:00:30.34716-06	2	[22497] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
4b16803f-80dd-459f-a3e9-947af5ce9ae8	2018-03-04 14:00:46.586784-06	2	[22497] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
65e55396-b171-40a4-aeb6-bf3885fac400	2018-03-04 14:03:37.062829-06	2	[22499] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e97fb2fb-a621-4b0e-910b-23113c55305b	2018-03-04 14:06:08.305952-06	2	[22500] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
802e6a6e-7220-4029-91d2-98bd33038b2e	2018-03-04 14:06:44.68459-06	2	[22501] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6470fe98-251d-47b7-a431-631cc0e9bbe5	2018-03-04 14:07:12.415363-06	2	[22502] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
48a00a66-4636-485f-94ec-2c505b4bfb38	2018-03-04 14:07:31.126233-06	2	[22502] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2660ded9-be75-452f-b279-e0f5cad7dce2	2018-03-04 14:08:25.236644-06	2	[22503] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
cb587699-9107-4f13-9af0-3e34f06e9d52	2018-03-04 14:08:55.047625-06	2	[22504] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ea481fa6-f75e-4705-b899-9b7fb5fb782f	2018-03-04 14:09:27.039824-06	2	[22504] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2a2050c6-5af8-45d2-a135-bb2fa9c9a060	2018-03-04 14:09:42.847404-06	2	[22504] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6a8f501b-9243-4434-b020-2051c831664e	2018-03-04 14:12:39.443062-06	2	[22505] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b9c9a08c-5b32-4a3c-befa-1a6335b1e287	2018-03-04 14:12:56.898807-06	2	[22505] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
55e0f696-bffd-4daf-aeee-6ac81940ef6b	2018-03-04 14:13:47.486866-06	2	[22506] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
576aac67-6aee-4b73-90e5-51dbed61e01a	2018-03-04 14:14:19.603077-06	2	[22507] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
da3c6118-4e71-4f4c-8081-f2edab422200	2018-03-04 14:14:38.787995-06	2	[22507] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
1f6af256-16fd-475b-8c32-5dac60460600	2018-03-04 14:15:53.411457-06	2	[22508] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
45f20462-0460-4919-8f7a-a7387497786b	2018-03-04 14:17:01.940309-06	2	[22509] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e71135b1-34b6-49c6-948e-f0c9ca30dc64	2018-03-04 14:18:29.25404-06	2	[22514] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fcfea8a4-010c-4bf6-9826-881eb139b2af	2018-03-04 14:19:48.36195-06	3	[22495] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0266454e-ed9e-4c2f-9b34-bb9025d0acec	2018-03-04 14:19:48.619975-06	2	[22496] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
1ac80bb8-026a-48c1-9a7c-cf734b40452a	2018-03-04 14:19:48.622976-06	2	[22497] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
fedb1b2a-cd87-4c18-a1e7-9abc15fa21b2	2018-03-04 14:19:48.626976-06	2	[22498] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3c52c0d7-e02f-4ec3-a770-922ee28f9f1a	2018-03-04 14:19:48.628976-06	2	[22499] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4e0d7a90-b0d9-4941-a7d4-c4398d572675	2018-03-04 14:19:48.631977-06	2	[22500] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c2eaff1b-54f4-4a95-b750-b800b519adca	2018-03-04 14:19:48.634977-06	2	[22501] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c4efeeb2-e1bb-48c6-b561-df784835cb7f	2018-03-04 14:19:48.637977-06	2	[22502] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9b1cf764-5a4a-4b99-901e-55a4edbec5af	2018-03-04 14:19:48.639977-06	2	[22503] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
3f19743d-fbb6-455e-81ee-8e63692d936f	2018-03-04 14:19:48.642978-06	2	[22504] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a8f362d1-b5dd-41f3-b9b0-1ab613aa9b8e	2018-03-04 14:19:48.645978-06	2	[22505] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
03d2df68-39d6-48cc-8cd0-6335d53af208	2018-03-04 14:19:48.647978-06	2	[22506] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
30fdbd3d-1ddf-46eb-807b-979284b280ec	2018-03-04 14:19:48.649978-06	2	[22507] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
9238e1d3-5dec-4b28-8432-a0440402609c	2018-03-04 14:19:48.652979-06	2	[22508] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cb51c9df-fbb2-4070-8a57-fd915eba13a6	2018-03-04 14:19:48.654979-06	2	[22509] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
260a9c00-3ea7-4324-abff-78b791335d3e	2018-03-04 14:19:48.657979-06	2	[22510] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c050ccbf-c5ed-41d5-b314-64220ed62561	2018-03-04 14:19:48.659979-06	2	[22511] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1ffae9ea-6c6d-410c-9b9b-0220b535cb7b	2018-03-04 14:19:48.66298-06	2	[22512] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
06b7f445-6337-4a7c-af7d-1ed04244bda9	2018-03-04 14:19:48.66498-06	2	[22513] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
64f67668-f16f-49c9-ba96-002383300882	2018-03-04 14:19:48.66798-06	2	[22514] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3eb23826-f64e-45bd-b59e-4374c25a5d7f	2018-03-04 14:19:48.670981-06	2	[22515] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
ad910cd6-32a2-49a0-882d-13899623bf65	2018-03-04 14:19:48.673981-06	2	[22516] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
76eace1c-c24f-41b9-8237-45c04974cfaf	2018-03-04 14:19:48.675981-06	2	[22517] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ad58ccc7-1d05-4bae-b7f0-d304011185e6	2018-03-04 14:19:48.677981-06	2	[22518] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
adbc364d-30fc-4260-9d37-ecb4c334e5cd	2018-03-04 14:19:48.680982-06	2	[22519] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9fce1336-44ad-4c52-a06e-0a2a1bf8f32b	2018-03-04 14:19:48.682982-06	2	[22520] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5900f600-b187-47e3-bb61-f44f7f79dd58	2018-03-04 14:19:48.685982-06	2	[22521] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
7914290b-5016-43f0-8c6c-195350a8a3a7	2018-03-04 14:19:48.687982-06	2	[22522] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
990d52e9-3f1b-4d80-a3a8-343261580baa	2018-03-04 14:19:48.690983-06	2	[22523] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
c92f7b26-77b6-47ee-b40b-82cfe2a6295b	2018-03-04 14:19:48.692983-06	2	[22524] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
6f3ebcc5-c6ad-46a2-b780-6a98e0bdd6d6	2018-03-04 14:19:48.694983-06	2	[22525] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
44741b75-0bff-4535-a15f-1424c9b5881c	2018-03-04 14:19:48.696983-06	3	[22496] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
5a7b24ad-722c-4ef6-9eeb-da311b2d28f3	2018-03-04 14:19:48.935007-06	2	[22497] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
996cdfec-4003-40d4-8445-ed2adba7a7a8	2018-03-04 14:19:48.941008-06	2	[22498] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1cd4c731-b303-4af7-914d-d4df0af1e2d4	2018-03-04 14:19:48.944008-06	2	[22499] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8417dbed-487d-4f3d-81db-29f6f0ea7627	2018-03-04 14:19:48.946008-06	2	[22500] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2a2d1ee0-5fd8-4ba8-8ffe-df4284ccff04	2018-03-04 14:19:48.949008-06	2	[22501] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2c49851a-1799-4c47-a151-d81a5a6f51fe	2018-03-04 14:19:48.951009-06	2	[22502] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
20bb614b-6f63-4569-9636-f1fe38b4c00e	2018-03-04 14:19:48.953009-06	2	[22503] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
79b80dc6-106b-4fef-a3dd-54e208594087	2018-03-04 14:19:48.957009-06	2	[22504] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
45d415c8-01b6-4e65-ae98-d72fc0cf8483	2018-03-04 14:19:48.959009-06	2	[22505] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
71878d3c-736c-4efe-99e1-11a9ccf8d5e1	2018-03-04 14:19:48.96101-06	2	[22506] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d881fe25-b091-4a25-af7e-cf4675da14fb	2018-03-04 14:19:48.96401-06	2	[22507] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef2dc3c0-a4f8-4e64-a401-0f2ec3b34591	2018-03-04 14:19:48.96601-06	2	[22508] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
530765ba-2702-4763-abd1-bfe09a49043a	2018-03-04 14:19:48.96901-06	2	[22509] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bc20b488-4427-4591-9ee8-67cf8659e226	2018-03-04 14:19:48.971011-06	2	[22510] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
79d4b89f-82a5-4077-9516-c3e263f11d99	2018-03-04 14:19:48.974011-06	2	[22511] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
95dd26b5-14c1-4c74-8fcd-8ca57b44c8be	2018-03-04 14:19:48.976011-06	2	[22512] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e63f8734-e302-42e6-97a3-98345be27126	2018-03-04 14:19:48.979011-06	2	[22513] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
112afb19-1428-47df-8bae-fbc1b43b7ccf	2018-03-04 14:19:48.982012-06	2	[22514] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5c785171-695a-4549-9efc-01dfe8adf0a0	2018-03-04 14:19:48.984012-06	2	[22515] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
db19f18c-fc50-4c75-9aab-aa5245a95588	2018-03-04 14:19:48.986012-06	2	[22516] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
68fe5469-b231-49aa-acff-dec556b810a4	2018-03-04 14:19:48.989012-06	2	[22517] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
07129935-d204-4a34-8917-ded2af9eb917	2018-03-04 14:19:48.991013-06	2	[22518] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f1367566-b5c1-49ac-a917-8d14cf7ee4dd	2018-03-04 14:19:48.994013-06	2	[22519] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
78c9e0ff-f79b-4dac-a977-efe83af33fbd	2018-03-04 14:19:48.996013-06	2	[22520] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4bbb2e91-f9d7-41e6-b54a-c0ee191dfe4d	2018-03-04 14:19:48.998013-06	2	[22521] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
67780185-67fc-46d9-ae2d-64fa488d69d0	2018-03-04 14:19:49.001014-06	2	[22522] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
45eb96b8-13b0-4f1e-b30c-e6a910334142	2018-03-04 14:19:49.003014-06	2	[22523] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
3d55bab5-6115-4a33-ba94-08e53ff2ae13	2018-03-04 14:19:49.007014-06	2	[22524] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
5bc4cc1c-7d4b-4958-bdc5-fa1b2157fa3f	2018-03-04 14:19:49.009014-06	2	[22525] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
86758d4d-c161-41a0-a669-aa5052d00cd1	2018-03-04 14:19:49.011015-06	3	[22510] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7e6e5285-d3a7-44a1-a2ae-6ea96393ae70	2018-03-04 14:19:49.26304-06	2	[22511] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f4f414c9-bad7-46f7-b2ef-e07e26ec74ea	2018-03-04 14:19:49.278041-06	2	[22512] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b783ad32-f1d8-4775-b54a-08aee6e8bb01	2018-03-04 14:19:49.281042-06	2	[22513] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
ecfb53d9-4d3b-46fa-a4f6-8c36cfd3f306	2018-03-04 14:19:49.284042-06	2	[22514] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c6074aa5-3eab-4506-a33d-ed22343bb698	2018-03-04 14:19:49.286042-06	2	[22515] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
5edc2bec-0c55-44f5-9b29-5185edfee674	2018-03-04 14:19:49.288042-06	2	[22516] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
75facb89-98f2-49f8-839d-75000b5d4df8	2018-03-04 14:19:49.291043-06	2	[22517] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cf84b646-e0ac-44ce-a9d5-a21c97e88ae6	2018-03-04 14:19:49.293043-06	2	[22518] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bb93842a-9111-4379-9b44-153f8619bf5d	2018-03-04 14:19:49.296043-06	2	[22519] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ac1cb08c-03d0-40bf-8ea1-a02059de42fb	2018-03-04 14:19:49.298043-06	2	[22520] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
76374c67-5b45-46f2-81c3-a2297eb7ca30	2018-03-04 14:19:49.301044-06	2	[22521] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
bbc6ce36-186e-45bd-a79a-1c8d8115c323	2018-03-04 14:19:49.303044-06	2	[22522] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
82eb79ae-11e9-4e42-9ca8-8837e7287c30	2018-03-04 14:19:49.305044-06	2	[22523] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
e538d2ef-af52-461e-af28-b93676eb293e	2018-03-04 14:19:49.308044-06	2	[22524] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
172373b0-ac53-4bc1-acc9-176b224022e8	2018-03-04 14:19:49.310044-06	2	[22525] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
c76196f1-9aba-4206-a7d4-58b596f5df2e	2018-03-04 14:19:49.312045-06	3	[22512] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
67f55a28-8cbc-4e8c-9537-d1f7de07d730	2018-03-04 14:19:49.551069-06	2	[22513] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
8ccb7c0c-b59e-4e92-a397-4e0a2fa7c1bf	2018-03-04 14:19:49.56807-06	2	[22514] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4314d1d1-1194-44d8-8fbc-043785509f3f	2018-03-04 14:19:49.57007-06	2	[22515] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
c800a850-30e6-461e-ac12-915fe64893da	2018-03-04 14:19:49.573071-06	2	[22516] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a79dbdf9-8f96-4b49-b200-bae43faf6750	2018-03-04 14:19:49.575071-06	2	[22517] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
83055c86-76f2-41aa-bc4d-495f271aaf4b	2018-03-04 14:19:49.578071-06	2	[22518] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1a0452bb-247b-4e3c-9665-96a21afef03b	2018-03-04 14:19:49.581072-06	2	[22519] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
be3cb530-b77f-4393-8fe4-04a5201ab2b4	2018-03-04 14:19:49.583072-06	2	[22520] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
dc1d5495-dbc2-4ca3-a3ae-51b681f33849	2018-03-04 14:19:49.586072-06	2	[22521] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
5adca65b-85e4-4905-82f9-9fc41111a3a0	2018-03-04 14:19:49.588072-06	2	[22522] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
212a6f1a-8110-493f-9d7c-4f51a75caf30	2018-03-04 14:19:49.590072-06	2	[22523] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
3abbe902-36b7-484d-852b-731f448e595b	2018-03-04 14:19:49.593073-06	2	[22524] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
624aff1f-37f9-4ff9-8c0d-e0e348782bb7	2018-03-04 14:19:49.595073-06	2	[22525] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
dff8409e-f4f2-4295-9f06-a10edbf00c5f	2018-03-04 14:19:49.597073-06	3	[22513] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
d86b1378-35b2-422a-a6ac-64d720feb6ac	2018-03-04 14:19:49.836097-06	2	[22514] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
94167b2c-4195-400e-85c4-fe91aa029c3f	2018-03-04 14:19:49.847098-06	2	[22515] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
fec6d16b-bef4-454a-9d57-13b6c26e6868	2018-03-04 14:19:49.850098-06	2	[22516] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ac71b305-4fd3-4f6c-a98b-e596169d26fa	2018-03-04 14:19:49.853099-06	2	[22517] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3828380d-f8b5-4ae7-89f8-52d93f8bd13d	2018-03-04 14:19:49.855099-06	2	[22518] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7eb44f0a-6112-443a-8f51-2d3e8d3b4478	2018-03-04 14:19:49.858099-06	2	[22519] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7b0546c1-56f5-4f2d-9b59-5b2a489a5b8c	2018-03-04 14:19:49.860099-06	2	[22520] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
84f3028f-ac42-4913-b42d-ccd5691f7569	2018-03-04 14:19:49.8631-06	2	[22521] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
1243e200-a681-402b-92ef-0a51a419a7f6	2018-03-04 14:19:49.8651-06	2	[22522] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
89460b5f-46b4-48ca-8050-082b5766684d	2018-03-04 14:19:49.8671-06	2	[22523] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
0141ceaa-97f1-42e2-9894-1864cda0e1bf	2018-03-04 14:19:49.8691-06	2	[22524] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
3424df91-4f78-457c-88b0-c6dedb54ffca	2018-03-04 14:19:49.872101-06	2	[22525] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
629d6513-f75a-44bc-8098-2c619ee08d35	2018-03-04 14:19:49.873101-06	3	[22515] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
bebb39df-5c3f-4495-ab80-8dc25cbfa406	2018-03-04 14:19:50.111125-06	2	[22516] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
67f0b153-8a2b-4707-9200-833e15f5c37f	2018-03-04 14:19:50.114125-06	2	[22517] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fe903303-7592-4fd3-9d96-35e0a31e568d	2018-03-04 14:19:50.117125-06	2	[22518] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
65fede42-9ed7-4f65-a1c0-cc1b99f9ceb9	2018-03-04 14:19:50.119125-06	2	[22519] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
928731db-de19-463f-a3a9-8971a1831ac3	2018-03-04 14:19:50.122126-06	2	[22520] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5ad399f5-29cd-49b2-8e21-a82f15f0262f	2018-03-04 14:19:50.124126-06	2	[22521] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
0d9c6bd0-60f2-4efc-993e-add9e3481fcd	2018-03-04 14:19:50.126126-06	2	[22522] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cb3cb66a-9a5c-4ff9-847e-bb2cd7f4ef8b	2018-03-04 14:19:50.129126-06	2	[22523] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
2136943f-b3c0-42ed-8480-266339f64fdd	2018-03-04 14:19:50.131127-06	2	[22524] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
b2cd3b37-66a7-4a24-b7b1-91f336c51c65	2018-03-04 14:19:50.134127-06	2	[22525] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
849ffe4d-0596-4915-aa34-9879c91264fd	2018-03-04 14:19:50.137127-06	3	[22516] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
827ad49a-047c-4e55-865a-5b387458052c	2018-03-04 14:19:50.390152-06	2	[22517] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9f7c4dda-7ec5-4ddc-beda-fcd057fd1917	2018-03-04 14:19:50.394153-06	2	[22518] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8e72ee04-1f49-47ae-a0e5-4c04aa6eff26	2018-03-04 14:19:50.397153-06	2	[22519] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
71debd4b-c1db-4488-8824-f55f4a6b66e5	2018-03-04 14:19:50.400153-06	2	[22520] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8548db11-0b65-43ea-a6d6-45d4672c1736	2018-03-04 14:19:50.402154-06	2	[22521] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
568d60de-0ea7-4ba7-8740-cf56edc5d02c	2018-03-04 14:19:50.405154-06	2	[22522] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8773e847-13e8-4222-be23-b3c1e3cb8b86	2018-03-04 14:19:50.409154-06	2	[22523] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
23afdba7-3c8b-4b5a-b8c1-5c7e55ad39ff	2018-03-04 14:19:50.412155-06	2	[22524] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
fa75ff3d-cf1b-4ab6-bfdb-95a2d392f3f0	2018-03-04 14:19:50.414155-06	2	[22525] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
7090d3d9-c6f6-4f03-abe0-fc3570ee11cb	2018-03-04 14:19:50.417155-06	3	[22517] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
91acc537-9689-47fa-bf9d-ec4f56b814c3	2018-03-04 14:19:50.66318-06	2	[22518] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
558d0cd7-8645-46eb-9458-4213284f2d73	2018-03-04 14:19:50.678181-06	2	[22519] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b9dda074-264b-4db1-af1c-a3c063d1043c	2018-03-04 14:19:50.681182-06	2	[22520] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ab5ab0e6-1f5a-4187-b71e-660a805325bd	2018-03-04 14:19:50.685182-06	2	[22521] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
f6c3649e-9a01-4e26-9ff1-f86b08af66dd	2018-03-04 14:19:50.688182-06	2	[22522] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
09538d1f-8e4a-4e22-9306-3a75f109efa1	2018-03-04 14:19:50.692183-06	2	[22523] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
577f4f76-e44c-4e0d-9531-ec3025101f86	2018-03-04 14:19:50.694183-06	2	[22524] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
62a659a0-ea88-4f16-832c-733f2c75251c	2018-03-04 14:19:50.697183-06	2	[22525] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
87f61727-6645-451f-80ec-7f8d6b40f1d1	2018-03-04 14:19:50.699183-06	3	[22518] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
312b0b27-3d57-4650-b66a-7bef836f3a38	2018-03-04 14:19:50.936207-06	2	[22519] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
20e7f434-609a-40de-b721-1f7770beeb9b	2018-03-04 14:19:50.944208-06	2	[22520] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3a55a903-9c6c-44d1-8a25-eec48c6ea702	2018-03-04 14:19:50.946208-06	2	[22521] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
15495e35-2483-498a-aa01-5855f56a3360	2018-03-04 14:19:50.949208-06	2	[22522] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5d4b2963-f85e-489d-a4c2-5e935e6456fa	2018-03-04 14:19:50.951209-06	2	[22523] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
6c0cc793-c5a7-4755-80fa-337f575560a2	2018-03-04 14:19:50.953209-06	2	[22524] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
09998be4-f4aa-4ca0-bb70-e36560addd52	2018-03-04 14:19:50.956209-06	2	[22525] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
0677caf4-1d72-4ea3-bf75-56cf04b6496f	2018-03-04 14:19:50.958209-06	3	[22523] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
6235b065-74b8-4018-8c4d-062a0a435861	2018-03-04 14:19:51.198233-06	2	[22524] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
42ba3aaa-ef56-4362-83e9-5b05c8ecc0ba	2018-03-04 14:19:51.230236-06	2	[22525] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
d2693132-6b37-420f-9a2a-1ebfcec708b5	2018-03-04 14:19:51.232237-06	3	[22524] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
6b5c7130-e002-4269-b841-0253b58e552c	2018-03-04 14:19:51.46726-06	2	[22525] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
88d8189e-48f7-4410-a84f-ea3df1430709	2018-03-04 14:19:51.511265-06	3	[22525] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
f8668950-334b-49f0-9cf9-9314abb837aa	2018-03-04 14:20:14.409554-06	3	[22511] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
220d8fbc-dc2d-4892-aeb8-1ee3a1648e20	2018-03-04 14:20:14.656579-06	2	[22514] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ab500b3e-205b-484e-8ae4-8ad64ea6f6cd	2018-03-04 14:20:14.659579-06	2	[22519] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7459af69-4b31-4048-b7fc-4b3d365f7071	2018-03-04 14:20:14.661579-06	2	[22520] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bc4e68cd-ae24-444b-88f1-33f6d9052404	2018-03-04 14:20:14.66458-06	2	[22521] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
89b5541d-087f-4ae1-b493-c3d3599d230f	2018-03-04 14:20:14.66658-06	2	[22522] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ff609aa0-b94e-4bbb-bee4-cc2a479192d6	2018-03-04 14:20:14.66858-06	3	[22519] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5a91ae45-843a-4c52-ad72-71799bdcff9d	2018-03-04 14:20:14.908604-06	2	[22520] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
36ee86b3-7632-4ad7-bdc2-9829f89f1564	2018-03-04 14:20:14.914605-06	2	[22521] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
9b1a62e6-32f8-4e1c-b500-d61c59507bfb	2018-03-04 14:20:14.935607-06	2	[22522] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
645e66e8-83dd-470e-9cdf-de67d394b5cf	2018-03-04 14:20:14.937607-06	3	[22520] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d74b9134-6809-4b4c-8500-99bcf41e2ff1	2018-03-04 14:20:15.176631-06	2	[22521] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
8d525887-3a2e-40b9-885a-1d722ecc315e	2018-03-04 14:20:15.185632-06	2	[22522] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3e19f0fa-58ee-4a96-9ed8-1113488de702	2018-03-04 14:20:15.187632-06	3	[22521] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
fe421332-0033-40b8-a652-c29ed9d3648d	2018-03-04 14:20:15.426656-06	2	[22522] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
df4905a1-f7e1-4c21-a953-5d2a801c233f	2018-03-04 14:20:15.453659-06	3	[22522] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
21293aa0-255c-4014-bb5b-00b24a19631a	2018-03-04 14:31:07.090816-06	3	[22568] D 1 CORRIDOR 437 	[21041] OSSI-DNOVAK	[293] master	\N	\N
905ef6c7-32ac-4007-92c8-6eecd97c1835	2018-03-04 14:31:07.389846-06	2	[22569] D 2 CORRIDOR 437 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d0fb0600-8627-4f8c-8b1a-49060343c223	2018-03-04 14:31:07.393846-06	2	[22570] D 3 CORRIDOR 437	[21041] OSSI-DNOVAK	[293] master	\N	\N
b828e789-43e1-4902-9194-0c9c326815e4	2018-03-04 14:31:07.396846-06	2	[22571] D 4 CORRIDOR 437 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1f1f7d0a-702b-410c-9de6-1ced4a8f6bf8	2018-03-04 14:31:07.399847-06	2	[22572] D 5 CORRIDOR 437	[21041] OSSI-DNOVAK	[293] master	\N	\N
8f8103f5-a468-4658-bea7-73d7d94998cd	2018-03-04 14:31:07.401847-06	2	[22573] D 6 CORRIDOR 414 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9eda7dfa-6502-4545-aef0-67ad12efd784	2018-03-04 14:31:07.404847-06	2	[22574] D 7 CORRIDOR 414 	[21041] OSSI-DNOVAK	[293] master	\N	\N
08e927d9-7e26-4a79-9197-ac3dc377ba7d	2018-03-04 14:31:07.406847-06	2	[22575] D 8 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
011f2c1a-74d0-4800-bed9-2aabf085fafd	2018-03-04 14:31:07.411848-06	2	[22576] D 9 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4f8926f1-b190-454d-9f30-491873c59a5b	2018-03-04 14:31:07.414848-06	2	[22577] D 10 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e15cf3a9-4167-40d7-a148-96c96ac57174	2018-03-04 14:31:07.416848-06	2	[22578] D 11 CLASSROOM 415 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b9ef43f4-0a53-4d09-aeb1-ef971cb4fa9a	2018-03-04 14:31:07.419849-06	2	[22579] D 12 CLASSROOM 415	[21041] OSSI-DNOVAK	[293] master	\N	\N
b291d8f0-93af-4db3-a080-f465f20a4265	2018-03-04 14:31:07.421849-06	2	[22580] D 13 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
624677f3-fbb7-4e18-9d84-162c03c5360a	2018-03-04 14:31:07.424849-06	2	[22581] D 14 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
fa5b79f6-a5fc-425e-9df2-884ff22db3a7	2018-03-04 14:31:07.426849-06	2	[22582] D 15 VESTIBULE 422 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b310d6be-15ce-46c3-8bca-bf78a37985c7	2018-03-04 14:31:07.42985-06	2	[22583] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
99a57a0c-6471-45dd-ab52-6679c461447c	2018-03-04 14:31:07.43185-06	2	[22584] D 17 WORK ALCOVE 423 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c8c59622-5f30-4559-861a-96c719db952d	2018-03-04 14:31:07.43385-06	2	[22585] D 18 CLASSROOM 425	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef1c9de5-3c61-4d59-8da5-7c0cf9e728e8	2018-03-04 14:31:07.438851-06	2	[22586] D 19 CLASSROOM 425 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4742230d-0f7e-4c16-83a6-4d50721cd92b	2018-03-04 14:31:07.440851-06	2	[22587] D 20 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
eb9101b5-2334-4134-a023-f021c08f251d	2018-03-04 14:31:07.443851-06	2	[22588] D 21 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
45bf6ad4-37db-46d6-9313-44456631746e	2018-03-04 14:31:07.445851-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ba5c5145-e393-49f6-a97b-58806ce900c0	2018-03-04 14:31:07.448852-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
6c8e1240-4a48-4c54-bdfc-7b191aa06ed7	2018-03-04 14:31:07.450852-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a34a3712-75ba-4208-b082-5d7555287ad9	2018-03-04 14:31:07.453852-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
87e6d386-f273-41e4-82ff-241551484949	2018-03-04 14:31:07.455852-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
7bf9f76e-a66e-4e3b-9d25-5975a57a3cfd	2018-03-04 14:31:07.458853-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2f42e850-9a8e-4a84-80c4-2812ac7467ee	2018-03-04 14:31:07.460853-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c419f294-a3a8-4393-9937-60709ec36abe	2018-03-04 14:31:07.464853-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3723a6c0-e793-4d13-b2fa-450e65cb6794	2018-03-04 14:31:07.468854-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
73d54093-d4fd-4f05-bbfb-f65f3392952a	2018-03-04 14:31:07.471854-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
a796e61e-2c33-4e02-97a6-5401252dc12f	2018-03-04 14:31:07.474854-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
12d5dc72-669d-4b1f-b983-27efa73bf815	2018-03-04 14:31:07.476854-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1165fa38-7fc9-48f2-9a2a-e97f0c6f701e	2018-03-04 14:31:07.479855-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef1017f6-f101-497d-a40e-1e2e4e1bfd02	2018-03-04 14:31:07.481855-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7ab1166e-6822-48e0-a7ba-0fc742a12a65	2018-03-04 14:31:07.484855-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7ce9d1fd-7779-43b2-87e2-0f9b4d4471a0	2018-03-04 14:31:07.486855-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d921cdc1-3ea5-4aa9-89c4-649053c8bd2b	2018-03-04 14:31:07.488856-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
48c2eebe-1ca3-4402-b220-e672c0e754e9	2018-03-04 14:31:07.492856-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a5ce33f3-006f-4b7a-bfba-4c1afb868e0f	2018-03-04 14:31:07.495856-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3a2d4718-e33a-4f74-a6f9-21c6266f9385	2018-03-04 14:31:07.498857-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6e72698a-6d17-481f-bcf1-a4cba764dd56	2018-03-04 14:31:07.500857-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
fdcc0aaa-05cf-4ee9-b93c-b3714cbfc819	2018-03-04 14:31:07.503857-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4ccec113-5626-44f0-a0fd-5d0dca4ccb23	2018-03-04 14:31:07.505857-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8943c938-5a83-4e43-acea-a5ed99e3453d	2018-03-04 14:31:07.508858-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6e6a6554-07eb-444c-bf2f-408530b7353f	2018-03-04 14:31:07.510858-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c93d7f9c-e383-499e-8911-9b05d4a4b24d	2018-03-04 14:31:07.512858-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a667d7c7-d1a3-47e5-8f51-64a74fc11877	2018-03-04 14:31:07.515858-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef6cd7ca-c307-45f2-8bae-d5b9992b0669	2018-03-04 14:31:07.517858-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
efdb0132-ecdc-4b19-acaf-4239d0ce82b3	2018-03-04 14:31:07.519859-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
6affbb37-d9bd-4ac2-ad15-51636c322b83	2018-03-04 14:31:07.523859-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
50b0c56c-3dae-44bb-9801-7723403b4485	2018-03-04 14:31:07.525859-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
56e440c0-8547-4c6f-8834-679a2201cc1a	2018-03-04 14:31:07.52886-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
211ac637-2d8b-4948-a631-7c173a9dbb47	2018-03-04 14:31:07.53086-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c68995c9-053f-4e00-b428-df1b4dc9f439	2018-03-04 14:31:07.53286-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1d187063-18df-4beb-a7eb-4e7b954e2e54	2018-03-04 14:31:07.53586-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
6290b6d2-f07f-45a4-87a7-9df2a07b514f	2018-03-04 14:31:07.53786-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1e9d8610-6c5c-4257-b0ec-3e22a9457b2d	2018-03-04 14:31:07.539861-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
ee1f171d-8b2c-49d1-9422-0cc9cc9999de	2018-03-04 14:31:07.542861-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
75821a4f-9e80-4c3e-9f71-d7030886dff1	2018-03-04 14:31:07.544861-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
208c4ab3-99b6-4aba-ab3b-591ee2ca108e	2018-03-04 14:31:07.546861-06	3	[22576] D 9 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
05bceee6-5de1-47b7-a6e0-1d77f33323a1	2018-03-04 14:31:07.786885-06	2	[22577] D 10 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
233bdc28-5d6f-47fd-b14c-70c75cdf1f0a	2018-03-04 14:31:07.791886-06	2	[22578] D 11 CLASSROOM 415 	[21041] OSSI-DNOVAK	[293] master	\N	\N
aaf46dcd-0397-4a66-8543-5eb14fc6b440	2018-03-04 14:31:07.794886-06	2	[22579] D 12 CLASSROOM 415	[21041] OSSI-DNOVAK	[293] master	\N	\N
60d1724f-4ea6-43bb-a277-ac0132442335	2018-03-04 14:31:07.796886-06	2	[22580] D 13 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
94a77fb3-b359-40f9-8503-6b32329bbbd6	2018-03-04 14:31:07.799887-06	2	[22581] D 14 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
5098f717-85d2-491d-bcfa-e25ba1da45c7	2018-03-04 14:31:07.801887-06	2	[22582] D 15 VESTIBULE 422 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7924c023-baee-483b-a4dc-5fa9ae4d2754	2018-03-04 14:31:07.804887-06	2	[22583] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
97fa5da9-5d0c-42d5-b561-058aa8187774	2018-03-04 14:31:07.806887-06	2	[22584] D 17 WORK ALCOVE 423 	[21041] OSSI-DNOVAK	[293] master	\N	\N
eca125ad-cf95-4a18-98fb-16af72550f78	2018-03-04 14:31:07.808888-06	2	[22585] D 18 CLASSROOM 425	[21041] OSSI-DNOVAK	[293] master	\N	\N
58467ff3-7c5e-4fc6-9340-73e8cbd40492	2018-03-04 14:31:07.811888-06	2	[22586] D 19 CLASSROOM 425 	[21041] OSSI-DNOVAK	[293] master	\N	\N
288fcde5-1850-4ea8-a7d2-81ee945cc6b2	2018-03-04 14:31:07.813888-06	2	[22587] D 20 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4465059a-86cc-46e7-84f3-afb02e196e06	2018-03-04 14:31:07.816888-06	2	[22588] D 21 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
21d22a64-be1d-420a-8bbd-758075c46381	2018-03-04 14:31:07.819889-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
46850084-f995-4d90-b14d-8a5296fa5213	2018-03-04 14:31:07.822889-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
deee6b13-8921-429b-9eaa-15288667ac98	2018-03-04 14:31:07.824889-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cce36ff1-a136-494a-9d98-0543c5beb206	2018-03-04 14:31:07.826889-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ba42f795-8211-472f-bbdf-91549917935b	2018-03-04 14:31:07.82989-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
b118280c-e75f-49ea-9ba9-a9ce59b32bd8	2018-03-04 14:31:07.83189-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d75eb10d-737d-4f4c-94b9-2a685624cbc4	2018-03-04 14:31:07.83389-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0e9d47eb-1813-4b91-b4f4-91d79c02f848	2018-03-04 14:31:07.83689-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c52abef2-a8f2-4107-9bdd-7f47dd3c227f	2018-03-04 14:31:07.839891-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
73bae364-2eeb-4f45-b44a-eae8a4b00016	2018-03-04 14:31:07.841891-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
0a4243b3-e49c-4658-b3fb-b36d1ba61695	2018-03-04 14:31:07.846891-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
d5866665-8dac-462b-b88d-41a9184478dd	2018-03-04 14:31:07.849892-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f8d248f6-12b3-42a8-9e3d-e84debe89e20	2018-03-04 14:31:07.851892-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bf36117f-3107-44b4-8cb9-925dce88c225	2018-03-04 14:31:07.854892-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f1c89626-2773-42c0-80b9-888dcafcad4e	2018-03-04 14:31:07.856892-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
839c4b6d-fea1-4679-8411-6974e25197f9	2018-03-04 14:31:07.858893-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2f4bf73f-5f2c-4503-8d7a-bd3da2e9d79b	2018-03-04 14:31:07.861893-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
09aa2f4e-2b35-4aed-a46b-6deda02174c5	2018-03-04 14:31:07.863893-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
377d78ec-30e3-40b7-a459-f18cee1bfe71	2018-03-04 14:31:07.866893-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
76d6402f-089e-493a-b38b-5f42c92e0a60	2018-03-04 14:31:07.868894-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
04119680-328e-4458-b3f9-164eb045fb41	2018-03-04 14:31:07.870894-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
63409dcd-26cf-47ec-a3c3-9e21ee6bb9dc	2018-03-04 14:31:07.874894-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d49a0715-270c-4ed8-8b24-a91f9714f62c	2018-03-04 14:31:07.876894-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3b0c062b-d8ea-4444-bd77-a868c81bdf86	2018-03-04 14:31:07.879895-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8e69d9d5-b0d9-4a52-b8ca-35cfc4d7aae8	2018-03-04 14:31:07.881895-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
faa0b6e6-d906-4208-9328-810c1a0963b2	2018-03-04 14:31:07.884895-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cee58308-05c1-4a1e-97c8-400c6ef795e4	2018-03-04 14:31:07.886895-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
de6c1f9c-cd4c-4ac1-b658-7d78e7f8539e	2018-03-04 14:31:07.889896-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
25c0fa8d-e90b-42d8-b877-0c10f06741df	2018-03-04 14:31:07.891896-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
dec5e72b-3079-405f-81b5-38c2db6110ea	2018-03-04 14:31:07.893896-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ec2474d9-bbe5-4c84-b61b-b5f3394df00b	2018-03-04 14:31:07.896896-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ff2c4c56-ccba-49a8-aace-e5e105f6b7db	2018-03-04 14:31:07.899897-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3e79c106-e4ac-4a3d-963f-44dda0b23ff7	2018-03-04 14:31:07.902897-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c8389d90-e400-451f-be17-17bcbe79828e	2018-03-04 14:31:07.904897-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c5debe5b-ae81-4e18-b81c-22ca75d3153b	2018-03-04 14:31:07.906897-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
80b2f612-dc82-4138-9d10-74189aeff055	2018-03-04 14:31:07.909898-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1c59fbee-1c5b-462a-8370-7e6a85dbddd0	2018-03-04 14:31:07.911898-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
d234f59a-fc74-4364-acfb-505d07716cd7	2018-03-04 14:31:07.913898-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
c685adae-394e-4900-8e4d-6af3ff849995	2018-03-04 14:31:07.916898-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
be58828e-2a9d-4d85-adcb-39f80bdd11f6	2018-03-04 14:31:07.917898-06	3	[22584] D 17 WORK ALCOVE 423 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9bfa99a3-53e4-4c16-9612-ea150836c186	2018-03-04 14:31:08.161923-06	2	[22585] D 18 CLASSROOM 425	[21041] OSSI-DNOVAK	[293] master	\N	\N
ee5e832d-5ce7-4a58-b5b8-1f3915090827	2018-03-04 14:31:08.164923-06	2	[22586] D 19 CLASSROOM 425 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b64bad71-9494-4475-b774-7910a76f5bca	2018-03-04 14:31:08.166923-06	2	[22587] D 20 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
eefcb18d-a476-49cf-b3c1-159d325e4e81	2018-03-04 14:31:08.170924-06	2	[22588] D 21 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
75c1e59b-cd50-4bf8-95e8-4336b019b8c2	2018-03-04 14:31:08.173924-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b84137b2-4c0b-4521-b9ea-b1ffc3e44739	2018-03-04 14:31:08.176924-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
d8b81f55-5391-48a8-864d-3d772fa104c7	2018-03-04 14:31:08.178925-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
63e1ecaa-17d1-413c-a0af-2dc2b5ed3122	2018-03-04 14:31:08.180925-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
07823f1f-c770-434d-9c5a-b2aff6ee4d4d	2018-03-04 14:31:08.183925-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
8ed58c83-3fcd-4d5c-ba42-f0ab2459a323	2018-03-04 14:31:08.185925-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d5c752f0-680a-48b2-ae33-4053e40b487a	2018-03-04 14:31:08.188926-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a32122fd-c034-4a4e-9f28-387310641071	2018-03-04 14:31:08.190926-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
971921b9-2db9-4eaa-b9e5-86d69f281327	2018-03-04 14:31:08.192926-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d83ea8dd-a69c-4096-978f-abdf1fc3cd83	2018-03-04 14:31:08.195926-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
c7ab8f78-6260-4a75-85e6-60d3d10a3064	2018-03-04 14:31:08.198927-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
40ade3b5-9fb7-44be-a25c-ea72be9a61ce	2018-03-04 14:31:08.201927-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8f702a87-ed0d-47f1-a3ec-5762d90e5939	2018-03-04 14:31:08.203927-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
25c65c6e-87eb-42c5-82d6-5bc91cbf3032	2018-03-04 14:31:08.206927-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6632e995-16b7-491b-9fec-acd04a530408	2018-03-04 14:31:08.208928-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e0084624-5fad-4779-a9ee-2ac1c18e8fd8	2018-03-04 14:31:08.211928-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ea923ff5-8ce5-4b1a-94ce-1e29df5284f1	2018-03-04 14:31:08.213928-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
21d79edb-e8c3-4612-930c-3e4fd00e8a90	2018-03-04 14:31:08.215928-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d30bc474-00a9-422b-94ec-188f83d3fc5f	2018-03-04 14:31:08.218929-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e8c935f5-fb6a-4a00-8e94-a7474f60ee72	2018-03-04 14:31:08.220929-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3ae37dd6-5eb1-4114-805a-88a0e4e8c3ac	2018-03-04 14:31:08.224929-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
b366b936-1c56-4721-a858-93540553e91e	2018-03-04 14:31:08.226929-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8d4ad9cc-7f0d-4a8c-8cb3-5effb0ce1b47	2018-03-04 14:31:08.22993-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
10b7d478-81e9-4de9-aade-86c034d19641	2018-03-04 14:31:08.23193-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7ff9fd4a-535e-4cd6-a23f-b0797746ae23	2018-03-04 14:31:08.23393-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1d953cc2-351e-4da4-be25-6e447d290b88	2018-03-04 14:31:08.23693-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ccca7854-e640-47bf-9bed-3d778f19eb77	2018-03-04 14:31:08.238931-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
cc905de7-a774-41f4-bcfd-327a3d7ba685	2018-03-04 14:31:08.241931-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6ada2ba2-7125-4a82-8dc4-52be87bb14b2	2018-03-04 14:31:08.243931-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
7acd733f-2c4e-48f8-89d8-bcd8c335d539	2018-03-04 14:31:08.245931-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4a7e8683-c4af-41d2-a6f3-878304b3a1bb	2018-03-04 14:31:08.248932-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8cd6c44b-7881-45c1-aaea-c349437d9b85	2018-03-04 14:31:08.251932-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a4c231a0-103b-4dd5-ba36-03e137fe3146	2018-03-04 14:31:08.254932-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b8f1eb6e-1248-4909-8b04-bcea055a960c	2018-03-04 14:31:08.256932-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c4fee5f3-8808-44bd-8999-e4ba143895b7	2018-03-04 14:31:08.260933-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
7162aa00-18b7-4de1-9893-5850791f8b82	2018-03-04 14:31:08.262933-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7589d26d-9f4e-4a81-99a4-baa2fa560ddc	2018-03-04 14:31:08.264933-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
1051608b-b89f-431e-b0de-5b22507ed527	2018-03-04 14:31:08.267933-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
e8e258e9-317e-422e-bd72-72712f72e8e0	2018-03-04 14:31:08.269934-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
abf2eaeb-b7aa-4ca4-86ea-85064f783ecc	2018-03-04 14:31:08.270934-06	3	[22569] D 2 CORRIDOR 437 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f889175c-b45c-478c-8e2f-93c3649ef5f9	2018-03-04 14:31:08.513958-06	2	[22570] D 3 CORRIDOR 437	[21041] OSSI-DNOVAK	[293] master	\N	\N
73ad1894-83d0-4b43-a5e3-7fc37e7f80aa	2018-03-04 14:31:08.516958-06	2	[22571] D 4 CORRIDOR 437 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4224afe3-233f-40a7-9fcd-c67df5f4e229	2018-03-04 14:31:08.519959-06	2	[22572] D 5 CORRIDOR 437	[21041] OSSI-DNOVAK	[293] master	\N	\N
6bb5bc6c-68dc-43aa-bcad-859d241827ee	2018-03-04 14:31:08.523959-06	2	[22573] D 6 CORRIDOR 414 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1dce8c8d-1c3b-4443-bc51-fa8de7183d78	2018-03-04 14:31:08.525959-06	2	[22574] D 7 CORRIDOR 414 	[21041] OSSI-DNOVAK	[293] master	\N	\N
722b1042-e8b3-4cc5-a9f8-0720253b8aac	2018-03-04 14:31:08.52896-06	2	[22575] D 8 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8164cd37-96a5-4944-b089-a0ddc9313ce0	2018-03-04 14:31:08.53096-06	2	[22577] D 10 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
426b2e7a-db8d-419e-88bd-60afb8694bbd	2018-03-04 14:31:08.53296-06	2	[22578] D 11 CLASSROOM 415 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ed10683e-cd62-476c-b7e1-a936161ab0d5	2018-03-04 14:31:08.53596-06	2	[22579] D 12 CLASSROOM 415	[21041] OSSI-DNOVAK	[293] master	\N	\N
14d0dc94-ac9b-464e-89a1-59c55d655e3e	2018-03-04 14:31:08.53796-06	2	[22580] D 13 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
d21ef8df-e6f0-47c8-9841-711b55a3c0e0	2018-03-04 14:31:08.540961-06	2	[22581] D 14 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
fffb5b03-ff10-4ba3-a97c-4d8569acb137	2018-03-04 14:31:08.542961-06	2	[22582] D 15 VESTIBULE 422 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5854dcad-122b-4a3a-bfee-06dc82108597	2018-03-04 14:31:08.544961-06	2	[22583] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
1f0231c9-bc35-46f6-8c96-32e7c6fe5e23	2018-03-04 14:31:08.548962-06	2	[22585] D 18 CLASSROOM 425	[21041] OSSI-DNOVAK	[293] master	\N	\N
32e5e5c8-5833-4b84-ae21-d3060eacad12	2018-03-04 14:31:08.550962-06	2	[22586] D 19 CLASSROOM 425 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c87d7594-9d62-4faa-8b87-5a657162928a	2018-03-04 14:31:08.553962-06	2	[22587] D 20 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
77a64b78-53a0-44f9-9b93-f43a9efce1d2	2018-03-04 14:31:08.555962-06	2	[22588] D 21 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6665b66c-4c80-4a1f-b515-6df57b3930e9	2018-03-04 14:31:08.558963-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f53f6a5b-f182-43f8-ae3e-9ce0c22ff64e	2018-03-04 14:31:08.560963-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
ccd51302-be22-46e1-a70d-a52a868bd61f	2018-03-04 14:31:08.562963-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
50e1a5da-7fc4-48e0-b180-82bcc8f307b9	2018-03-04 14:31:08.565963-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
83564bdd-fcd7-4ed9-9a70-f6af79461000	2018-03-04 14:31:08.567963-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
bcaf156a-d3a1-4ff6-91d0-1093cba2e491	2018-03-04 14:31:08.569964-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
08eaddda-eb15-4a81-a01d-cd62497c666f	2018-03-04 14:31:08.572964-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b9b36f8f-97ed-448d-8ee4-098497cd9b0e	2018-03-04 14:31:08.575964-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1402bb33-f429-4ba0-96ed-3ce9250f8cf0	2018-03-04 14:31:08.578965-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e7547b45-cf43-47d6-b9de-3e94aee4abe5	2018-03-04 14:31:08.580965-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
461fe0c3-218d-4fe0-acdc-f31e2c336066	2018-03-04 14:31:08.583965-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
2510cdc0-7e7f-4689-82e3-e9cff67636aa	2018-03-04 14:31:08.585965-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7ebd50d0-55ef-43b9-a383-92842ea2c96c	2018-03-04 14:31:08.588966-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
959cc20f-55c5-4b86-a735-2d07445c2bcb	2018-03-04 14:31:08.590966-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7b15d053-3685-4509-8bc3-c946a66b08c0	2018-03-04 14:31:08.593966-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d09997c3-e3f1-4a22-a3e4-3e68477968cf	2018-03-04 14:31:08.595966-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bfafc87f-d644-40a5-9d94-e43c7b3fdbaf	2018-03-04 14:31:08.597966-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
6a642d46-2894-4824-a3c8-7e3ab8dc6a69	2018-03-04 14:31:08.601967-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5ea49209-08ac-43e4-b8a5-bca4a622975d	2018-03-04 14:31:08.603967-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bb51cb99-282c-4ae9-ae71-3b61951a693e	2018-03-04 14:31:08.606967-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
59e0b8c8-586c-4129-a48e-7f3cb6480a45	2018-03-04 14:31:08.608968-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
1610c55a-44ab-4f7c-86a2-7750120a5b49	2018-03-04 14:31:08.611968-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3a180e6f-dbb1-4818-a96a-5088efc646e5	2018-03-04 14:31:08.613968-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b6f8dea3-4e6b-42e9-ab74-484a913d1048	2018-03-04 14:31:08.616968-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
397d4517-285a-4db4-bd19-709afe9fda92	2018-03-04 14:31:08.618969-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a230c06a-75eb-4ab6-bfa3-74acfb3cd8a5	2018-03-04 14:31:08.620969-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d66442b4-2ebc-4cb0-9fff-df6dc4ece2ec	2018-03-04 14:31:08.623969-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
9eb939ac-99a8-41f8-8bbb-c526885f271d	2018-03-04 14:31:08.625969-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
41754ff1-b2aa-49ab-b2a2-3f754132ec75	2018-03-04 14:31:08.62997-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
28cc9892-0126-4155-9517-555ce9115551	2018-03-04 14:31:08.63197-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d721de77-7503-44a2-8e96-826a90afd0e7	2018-03-04 14:31:08.63397-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5abc05d1-5bcc-450e-aef2-7dd52497fcc5	2018-03-04 14:31:08.63697-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d545d042-f174-4728-a107-2013a471706a	2018-03-04 14:31:08.638971-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a251ee2f-728a-4b35-83c3-eaf070c802bc	2018-03-04 14:31:08.640971-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9d4bef54-c2ef-4b9e-b9a7-81751413f741	2018-03-04 14:31:08.643971-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
8093dcc2-02d0-4d7b-b1cb-f3f47fd0ecf9	2018-03-04 14:31:08.645971-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
05f19de9-7a3c-449d-82e5-09fa9709d819	2018-03-04 14:31:08.647971-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
d5482762-4f64-44d7-9089-cfa0c6e90532	2018-03-04 14:31:08.650972-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
ebde87c6-751d-48bd-8792-8d385e49f741	2018-03-04 14:31:08.652972-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
d77b141f-5679-43b8-bf76-f83af68c97e2	2018-03-04 14:31:08.655972-06	3	[22577] D 10 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6966d2d7-0b6b-4b29-865a-8a6847d610f1	2018-03-04 14:31:08.897996-06	2	[22578] D 11 CLASSROOM 415 	[21041] OSSI-DNOVAK	[293] master	\N	\N
95f2c4da-15dc-4928-b8bb-2fa8e0eed528	2018-03-04 14:31:08.900997-06	2	[22579] D 12 CLASSROOM 415	[21041] OSSI-DNOVAK	[293] master	\N	\N
3aedd065-7cd3-4067-b7f3-1fb9599a58b0	2018-03-04 14:31:08.903997-06	2	[22580] D 13 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
d2dc6269-9eb2-4c39-87b8-223fe60ce197	2018-03-04 14:31:08.905997-06	2	[22581] D 14 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
307be916-42b3-4547-ae60-c39704bf1ae3	2018-03-04 14:31:08.908998-06	2	[22582] D 15 VESTIBULE 422 	[21041] OSSI-DNOVAK	[293] master	\N	\N
111195b7-3449-43cd-8e59-5c4b98029632	2018-03-04 14:31:08.910998-06	2	[22583] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
6b95066c-3705-40a7-af46-47fb941840c3	2018-03-04 14:31:08.912998-06	2	[22585] D 18 CLASSROOM 425	[21041] OSSI-DNOVAK	[293] master	\N	\N
e5db880d-861c-4e06-aba3-4b8bcce089d7	2018-03-04 14:31:08.915998-06	2	[22586] D 19 CLASSROOM 425 	[21041] OSSI-DNOVAK	[293] master	\N	\N
47cdebeb-41f5-41eb-8f73-005b09e6d0e4	2018-03-04 14:31:08.917998-06	2	[22587] D 20 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ed79b649-82b1-4540-8cbc-153bf15e357a	2018-03-04 14:31:08.919999-06	2	[22588] D 21 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
efd30109-c537-47a7-94a2-4b4d3f205f87	2018-03-04 14:31:08.923999-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0b82b059-486e-4f0c-99f4-b3fb8c9c9d8b	2018-03-04 14:31:08.926999-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
6c5da3b1-9f44-4e16-8f5e-b0f5743a1661	2018-03-04 14:31:08.93-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
69a52b94-e78e-4211-8682-eb4b13d57382	2018-03-04 14:31:08.932-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
00d74fee-4fee-4879-9830-f1e17f04034f	2018-03-04 14:31:08.934-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
378e4877-47e2-467f-936a-d02187657bb0	2018-03-04 14:31:08.937-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7f907ba0-c882-4769-9069-fb3a4b468790	2018-03-04 14:31:08.939001-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
dbae8e86-be25-44b3-8357-3146bb26815a	2018-03-04 14:31:08.941001-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
51ef870d-e2dd-4102-88f5-b30c91ddd3fb	2018-03-04 14:31:08.944001-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
62f8a532-9b73-491d-b8c6-540bb817fa54	2018-03-04 14:31:08.947001-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
f9e4d4f9-9012-4722-95f8-dd21a2c051df	2018-03-04 14:31:08.950002-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
b3b0d985-aba5-420e-b882-f694deabe75e	2018-03-04 14:31:08.953002-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c12447e4-d2f3-4f6c-a2ff-a7b6d944c1c4	2018-03-04 14:31:08.956002-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cd28e200-bfd0-4846-836c-f3664054ff00	2018-03-04 14:31:08.958002-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
67aabfdc-c68b-4134-acf3-5093e1c4bb53	2018-03-04 14:31:08.961003-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d260e96a-f9f6-45b1-b1fa-3647112311b8	2018-03-04 14:31:08.963003-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
846c4614-ca0d-4478-846c-b4fc8e269635	2018-03-04 14:31:08.965003-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
9a899781-9739-42ea-bcaf-b53c13b1b8b2	2018-03-04 14:31:08.968003-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b4be23bc-05d2-4050-a28b-26ac88e44028	2018-03-04 14:31:08.970004-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
24e88b56-a932-48be-936c-81311603746e	2018-03-04 14:31:08.972004-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d44c7463-3344-4e11-b5d8-181456d86213	2018-03-04 14:31:08.974004-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
d3a2c898-2e44-40ef-b6ac-9264d4f6f7be	2018-03-04 14:31:08.977004-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3816d72f-2f56-48cd-add8-a348656edb69	2018-03-04 14:31:08.980005-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e1d37f5c-dc11-4d7b-a293-010d2282572b	2018-03-04 14:31:08.983005-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
45fa8a96-feff-4e93-9781-cb50eb703d48	2018-03-04 14:31:08.985005-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0f3b9594-9a8e-4d8c-b025-78e464a8e07e	2018-03-04 14:31:08.988005-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
451242b6-a72b-4a40-93bb-704dff2ad8fd	2018-03-04 14:31:08.990006-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
97ff270b-7a2d-46da-b3b5-064219e71610	2018-03-04 14:31:08.993006-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
56828704-e6d0-4581-a48e-2ee2f04ef33d	2018-03-04 14:31:08.995006-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
fcc0114d-8f37-4314-b8f9-a4103844580d	2018-03-04 14:31:08.997006-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2dca6386-1bd3-4069-8d6c-ace066ecc551	2018-03-04 14:31:08.999007-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7ad7ee73-3c97-42ef-ae99-8ac2bad53585	2018-03-04 14:31:09.002007-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
109072b7-8bce-4bd7-aea3-0972c2c8631c	2018-03-04 14:31:09.005007-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e9c570a0-b118-44b9-80c6-4737925f1925	2018-03-04 14:31:09.008007-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2ea26ddc-5cf2-49fc-8cd4-8e907468fa66	2018-03-04 14:31:09.010008-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
3f6dfe66-fcc7-45e0-9765-1b888af826c4	2018-03-04 14:31:09.012008-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0433939c-1990-4b60-9719-51edc9ffe610	2018-03-04 14:31:09.014008-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
46af3614-4170-441d-ab0d-c0b010dac7d4	2018-03-04 14:31:09.017008-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
f718c5d4-772d-4d44-b43e-cd633280fec5	2018-03-04 14:31:09.019009-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
cf763516-cfa9-4c68-ad1d-8567c570d1d5	2018-03-04 14:31:09.021009-06	3	[22585] D 18 CLASSROOM 425	[21041] OSSI-DNOVAK	[293] master	\N	\N
46b414f6-3da1-4a80-ac7d-65248ae8c78a	2018-03-04 14:31:09.262033-06	2	[22586] D 19 CLASSROOM 425 	[21041] OSSI-DNOVAK	[293] master	\N	\N
aeda9a2f-2bc3-4c00-8101-c1e2a2bd21b6	2018-03-04 14:31:09.265033-06	2	[22587] D 20 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5838f97b-f3b3-4ba2-a385-69dbef373958	2018-03-04 14:31:09.268033-06	2	[22588] D 21 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b697a93b-63e9-4eae-b72f-61cbf0939a53	2018-03-04 14:31:09.270034-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e83fc20d-dbdb-4801-8733-da10859872d1	2018-03-04 14:31:09.274034-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
f11909fd-2173-47d8-9f9d-6bea05261508	2018-03-04 14:31:09.277034-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
64d8c462-4144-45d6-965a-84971e1d36f0	2018-03-04 14:31:09.279035-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
612f715e-8eda-430d-8673-d0413ced6173	2018-03-04 14:31:09.282035-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
e89cf1e0-2a10-4951-839b-5d8bb014822c	2018-03-04 14:31:09.285035-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8e86b642-4953-4514-bb0c-f4f1655ac9fd	2018-03-04 14:31:09.288035-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
071b5178-2437-4a2e-ade3-3876ef907c40	2018-03-04 14:31:09.290036-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
60e3bee0-0ca8-4463-a120-16a7a82d6275	2018-03-04 14:31:09.293036-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4bfaa3df-aa7c-4abd-b578-49f3531c52b5	2018-03-04 14:31:09.295036-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
a0f2cd43-a1f3-41c7-9d2f-42c77286ad5e	2018-03-04 14:31:09.297036-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
6024acba-a7e4-40e1-838e-cc3a353fee22	2018-03-04 14:31:09.300037-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6c0890be-0352-4a22-96fb-eb9a6586f448	2018-03-04 14:31:09.303037-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b21c81a2-8ff2-49b1-a6c5-4c7adfb7534b	2018-03-04 14:31:09.306037-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2ad4b48f-cfb0-4c25-9d10-3840d48d2c44	2018-03-04 14:31:09.309038-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5a127c06-a6d4-4c88-a42b-e52563e26702	2018-03-04 14:31:09.311038-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
263ceda2-ac3d-434f-9384-8b3ac6d66bd6	2018-03-04 14:31:09.313038-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
560f9184-ed3b-481f-b00e-2739e7e272b4	2018-03-04 14:31:09.316038-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c1d7534a-400c-4a96-a72e-1c02efeeda1b	2018-03-04 14:31:09.318038-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
11e1ebbf-5998-4632-aee6-66c499e49bc5	2018-03-04 14:31:09.320039-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
42fe0041-b26e-4aba-b0c6-86f84c6b8e0b	2018-03-04 14:31:09.323039-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
3efa5b58-a56d-484a-968d-0d4ed8df7567	2018-03-04 14:31:09.325039-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
92f3a199-9f40-4b56-b1f6-f48fb7082f15	2018-03-04 14:31:09.32904-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f5669042-fdec-4798-ab4c-78ea415d87fc	2018-03-04 14:31:09.33104-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c65e05cc-40f2-4043-a219-89150d02af34	2018-03-04 14:31:09.33404-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6f606840-ef8f-48ef-a94d-7a66ffecac7d	2018-03-04 14:31:09.33604-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6a335a24-cfcb-4ee0-bd04-6ec097019013	2018-03-04 14:31:09.33804-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
68adefbd-be15-4a41-afdd-f41d496b68cd	2018-03-04 14:31:09.341041-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bf67d2ae-4bd9-48f4-b3c6-9b2099032154	2018-03-04 14:31:09.343041-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
19d78b54-f03f-4185-9d1a-b884c66edc00	2018-03-04 14:31:09.345041-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
53be98b9-ad2a-4576-8c60-5bf4c0a69278	2018-03-04 14:31:09.348041-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
eb7a050d-15ff-4e89-bcaf-6c733ad6ead3	2018-03-04 14:31:09.350042-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e1be8706-d77f-4f7d-853a-e15f6a39800d	2018-03-04 14:31:09.352042-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1b06c89a-b606-4ee7-b2e4-8df91c6698f9	2018-03-04 14:31:09.356042-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c008b452-fde3-447d-b3cb-6e5ee8545aa4	2018-03-04 14:31:09.358042-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
f4a3f30c-49ab-483c-812d-edec97842d42	2018-03-04 14:31:09.361043-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fb638d2c-1081-4e11-a7de-e765aa1df19e	2018-03-04 14:31:09.363043-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
3f6d7c58-dfb5-49af-bc09-6593151d4045	2018-03-04 14:31:09.365043-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
40ae61a6-beed-4000-a7d2-4d40e8d42c37	2018-03-04 14:31:09.368043-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
acbd8a7e-cd49-416d-8dd9-88cb765252a3	2018-03-04 14:31:09.370044-06	3	[22570] D 3 CORRIDOR 437	[21041] OSSI-DNOVAK	[293] master	\N	\N
7192f191-05d1-40b0-bdb8-0240995574fb	2018-03-04 14:31:09.610068-06	2	[22571] D 4 CORRIDOR 437 	[21041] OSSI-DNOVAK	[293] master	\N	\N
77698326-ca3c-4dd6-88c6-afa51a67172d	2018-03-04 14:31:09.614068-06	2	[22572] D 5 CORRIDOR 437	[21041] OSSI-DNOVAK	[293] master	\N	\N
26c50362-d90d-47a1-b7f3-558c13db47c0	2018-03-04 14:31:09.616068-06	2	[22573] D 6 CORRIDOR 414 	[21041] OSSI-DNOVAK	[293] master	\N	\N
83ce4efd-ad3f-4dd5-92c7-20bf61b66f03	2018-03-04 14:31:09.619069-06	2	[22574] D 7 CORRIDOR 414 	[21041] OSSI-DNOVAK	[293] master	\N	\N
12ac9f19-d77d-4ece-b617-78a36720c9d4	2018-03-04 14:31:09.621069-06	2	[22575] D 8 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
85f64b92-e7db-4ed6-9277-e5e6e4a24b1b	2018-03-04 14:31:09.625069-06	2	[22578] D 11 CLASSROOM 415 	[21041] OSSI-DNOVAK	[293] master	\N	\N
39ee2c27-4663-4914-ab5a-85e38ac914af	2018-03-04 14:31:09.628069-06	2	[22579] D 12 CLASSROOM 415	[21041] OSSI-DNOVAK	[293] master	\N	\N
bb8447e7-bae8-4768-88d1-929c91820ad1	2018-03-04 14:31:09.63007-06	2	[22580] D 13 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
6182f337-5d61-46e0-a1d2-6de47a0c5c56	2018-03-04 14:31:09.63207-06	2	[22581] D 14 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
88471de1-8f03-468e-a892-cf9ac35ad8b2	2018-03-04 14:31:09.63507-06	2	[22582] D 15 VESTIBULE 422 	[21041] OSSI-DNOVAK	[293] master	\N	\N
289fc6f5-7a52-497d-88f0-7bdfecd1271d	2018-03-04 14:31:09.63707-06	2	[22583] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
5b6cdb5e-cfe8-4b9e-a01a-d999743473bb	2018-03-04 14:31:09.640071-06	2	[22586] D 19 CLASSROOM 425 	[21041] OSSI-DNOVAK	[293] master	\N	\N
62fafd90-6011-4f88-93d3-65ffdce3f172	2018-03-04 14:31:09.642071-06	2	[22587] D 20 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5a2a2e1a-3fb2-4a4f-b4c9-519b6cf3e869	2018-03-04 14:31:09.644071-06	2	[22588] D 21 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
379a8d3e-e4d3-41fc-a358-cde9eb8828b4	2018-03-04 14:31:09.647071-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c60045cc-b1b1-4b57-b6cd-0f67d0956eb2	2018-03-04 14:31:09.650072-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
84a7df39-4858-4120-96b0-76d670785217	2018-03-04 14:31:09.653072-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
04c4a924-f9bb-4bf7-9e3e-c548b86e668b	2018-03-04 14:31:09.655072-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b603a9f6-2180-465d-8c91-ecedc0dbeeae	2018-03-04 14:31:09.657072-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
e410b932-2cd7-4d15-9620-2c5d6ebc7e38	2018-03-04 14:31:09.660073-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0acaa29f-11ba-425f-aa7c-ea61027767ff	2018-03-04 14:31:09.662073-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c87efb83-4b9b-40c9-a571-96a7734266c5	2018-03-04 14:31:09.664073-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
da66ce28-6add-4029-9ef4-5802f915b04d	2018-03-04 14:31:09.667073-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5a71f7e0-f580-44bf-af2f-41e216750b07	2018-03-04 14:31:09.669074-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
e8489754-e7f1-4d85-bfd5-1fc4801e2404	2018-03-04 14:31:09.672074-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
62f4d5f6-f4f0-48b3-9c7d-6bb1b289608a	2018-03-04 14:31:09.675074-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
58e86733-9e9c-437f-8170-6c3aa2e85519	2018-03-04 14:31:09.678074-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
20c62a03-7ea5-487c-9729-7bf5215e68b5	2018-03-04 14:31:09.681075-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a08f8cc4-5f26-447a-a636-1260aefd4615	2018-03-04 14:31:09.683075-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
63decb02-9103-4dc3-a6c4-e725fb6d61a1	2018-03-04 14:31:09.686075-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
251ae908-8ef8-4ad7-b02e-ae260b1adfdb	2018-03-04 14:31:09.688075-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
c4005098-d47c-40b7-91ac-52263b766f82	2018-03-04 14:31:09.690076-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
046cab97-f112-4eaf-986b-a21668697e83	2018-03-04 14:31:09.693076-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6e145849-c962-4c04-9de6-c5e96ef2cc0e	2018-03-04 14:31:09.695076-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f4d0e362-bf9d-4ba5-b15a-8cd7c99144ed	2018-03-04 14:31:09.697076-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
49d43c7c-cb76-420d-870f-7e90ac7a3fd1	2018-03-04 14:31:09.700077-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9bf287d2-ee1f-483e-95df-901e486d7226	2018-03-04 14:31:09.702077-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
28901dbc-81bf-43b7-8ece-90ff63fc4816	2018-03-04 14:31:09.706077-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7f837894-9b88-4df9-ba09-138e5fec7dbd	2018-03-04 14:31:09.708077-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bd29cc34-0c1a-42f0-a384-149e592e2aff	2018-03-04 14:31:09.711078-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4abe0c56-4041-450c-ad6d-1442baf38496	2018-03-04 14:31:09.713078-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
ebd46740-a732-4f44-85b9-89ed8674a284	2018-03-04 14:31:09.715078-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
044aecea-39e0-42b4-b598-4380f6c54ed1	2018-03-04 14:31:09.718078-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
aa4b5e99-cfc7-4b6e-92cc-06b92d2097b3	2018-03-04 14:31:09.720079-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
af4d1db7-88ad-4202-8f46-1ea5971a7d04	2018-03-04 14:31:09.722079-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f0c4f619-a8d9-4d4f-9abe-80139c8eda7b	2018-03-04 14:31:09.725079-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d8b15b43-42c3-492d-a00f-afbb545e5505	2018-03-04 14:31:09.727079-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3168640d-8335-4d2b-a5e0-2c2447dfeb1e	2018-03-04 14:31:09.73108-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8263237a-9d08-4bb9-b90e-08b8912dea94	2018-03-04 14:31:09.73308-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
f8c7f867-752e-4745-803c-a516ea0d6efa	2018-03-04 14:31:09.73608-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c48db830-54cf-4a40-a23e-a355b4b2dc72	2018-03-04 14:31:09.739081-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
90346846-4d45-4031-8551-98ff317e66c9	2018-03-04 14:31:09.741081-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
543f477b-d47f-4422-883e-c14ec7b8b7dd	2018-03-04 14:31:09.743081-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
0dc78c71-624d-4b5f-bee1-4ed74d913c38	2018-03-04 14:31:09.745081-06	3	[22578] D 11 CLASSROOM 415 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e5b0ff32-2367-48ff-ac47-6f9362629679	2018-03-04 14:31:09.985105-06	2	[22579] D 12 CLASSROOM 415	[21041] OSSI-DNOVAK	[293] master	\N	\N
53fa3564-797a-49c3-a689-31d552370864	2018-03-04 14:31:09.988105-06	2	[22580] D 13 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
0a9306ff-d76e-4a4d-b183-0601331ff6b5	2018-03-04 14:31:09.991106-06	2	[22581] D 14 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
491e1d8e-dafe-46b4-963b-392318affd9f	2018-03-04 14:31:09.993106-06	2	[22582] D 15 VESTIBULE 422 	[21041] OSSI-DNOVAK	[293] master	\N	\N
013a9576-bc1b-48ad-bfdb-e30b03fa15de	2018-03-04 14:31:09.996106-06	2	[22583] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
084b05e8-c65e-4dbd-b782-30c4dd6463d6	2018-03-04 14:31:09.999107-06	2	[22586] D 19 CLASSROOM 425 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9ac3bc4b-d31f-4e03-9e01-81233303ad21	2018-03-04 14:31:10.002107-06	2	[22587] D 20 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3a5887e5-bc9e-48b3-919d-bb98b9fbaeae	2018-03-04 14:31:10.005107-06	2	[22588] D 21 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f549bc66-0782-489e-b419-c6c8c674fe22	2018-03-04 14:31:10.007107-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8ca193c9-6028-4135-bccc-784c5b981412	2018-03-04 14:31:10.009108-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
53b8898b-e4d1-4d87-87e2-849626e70f10	2018-03-04 14:31:10.011108-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6b790ad9-e30f-4436-be19-86b3e524bea2	2018-03-04 14:31:10.014108-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
83fb4e27-11c9-4d50-aa1f-dbb0a1c90056	2018-03-04 14:31:10.017108-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
cedc48de-c317-4e86-9543-74d189cb86a4	2018-03-04 14:31:10.019109-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
751f18d9-c0c9-4b75-8643-f5909576e865	2018-03-04 14:31:10.021109-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
92a4a6a6-6570-4d01-a291-30ff00a29b3a	2018-03-04 14:31:10.024109-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b40bfd25-4f63-4934-a77d-d172420f372b	2018-03-04 14:31:10.027109-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9594180e-1e06-424b-9b35-1a956a83f27e	2018-03-04 14:31:10.03011-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
8e428318-6747-4de3-bf1e-cb54945aa99f	2018-03-04 14:31:10.03211-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
175a90d4-591d-406e-ba39-0a3d5edb75a8	2018-03-04 14:31:10.03511-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b363f2e8-2b19-4774-81d4-7afea6b976f5	2018-03-04 14:31:10.03711-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
76d29654-3f7d-4c09-8527-ffe71c39df05	2018-03-04 14:31:10.040111-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ee6dc230-3bae-48ea-93da-a67db422cfc0	2018-03-04 14:31:10.042111-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
baa61e58-7848-4dfc-b930-92a59a509aa7	2018-03-04 14:31:10.045111-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3e9d666f-506a-4cf5-b05f-6a4c0857f7c4	2018-03-04 14:31:10.047111-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
e70c924b-5365-45ee-b744-446bf561027c	2018-03-04 14:31:10.049112-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1b11ef46-439b-4ede-9c0f-a3eea19abeb5	2018-03-04 14:31:10.053112-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1635227a-31ac-4061-9d78-ff8b33146230	2018-03-04 14:31:10.055112-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f57a2180-7ab9-4a54-9e47-38d72944c6b1	2018-03-04 14:31:10.058112-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
77bf1cb6-c9dc-4189-aa1d-db1288c538ea	2018-03-04 14:31:10.060113-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9c2e1219-32e2-4276-8ad1-e2a0395d04de	2018-03-04 14:31:10.063113-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4cc1cdd1-6da8-40a7-8292-9b99c4461bbd	2018-03-04 14:31:10.065113-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d9ca3fbf-db13-476a-9269-0a657dfbb616	2018-03-04 14:31:10.068113-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ae19ba20-d556-4fa7-8631-00240e631545	2018-03-04 14:31:10.070114-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
02ed2c4e-2a3a-4eb0-a672-df81e2465d57	2018-03-04 14:31:10.072114-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
62bee441-91be-4195-b513-0147f2d96276	2018-03-04 14:31:10.075114-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d9ffa098-1c3c-4cff-a5fc-1f4adfd73085	2018-03-04 14:31:10.077114-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
77459722-846c-4e55-a1f5-d7021686a002	2018-03-04 14:31:10.081115-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c5ab9f00-e717-4605-87eb-6b7c0389e13a	2018-03-04 14:31:10.083115-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7970d6a7-b79c-4fdf-8412-1c7db2cd8b8b	2018-03-04 14:31:10.086115-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6e7c7edc-87bb-47d9-bac0-9295a8845668	2018-03-04 14:31:10.088115-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
999372fe-305a-4e56-815d-34cdf7068023	2018-03-04 14:31:10.090116-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c6ea2e44-b06e-485e-902d-adc23d3fc4bc	2018-03-04 14:31:10.093116-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
aead848b-8dcf-47bd-91c3-a00a95334eaa	2018-03-04 14:31:10.095116-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ae93a01c-a7b2-4413-ab11-22cc65492122	2018-03-04 14:31:10.097116-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
0a6b9387-1047-4a51-aaa7-4c7a48a28f21	2018-03-04 14:31:10.100117-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
aadcebcc-a614-4b45-a1c6-6d657572c8ae	2018-03-04 14:31:10.102117-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
5ea26252-a54f-4fab-b766-d14d2931e45b	2018-03-04 14:31:10.104117-06	3	[22586] D 19 CLASSROOM 425 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f8d7f1d0-2cfe-4dfe-be52-140a0f966854	2018-03-04 14:31:10.359143-06	2	[22587] D 20 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6f344478-bb26-4dc4-aaf6-715e34cd6917	2018-03-04 14:31:10.363143-06	2	[22588] D 21 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1bc88966-2222-4da4-9170-83113ca929f7	2018-03-04 14:31:10.366143-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0babd467-2b81-4398-a89d-90f39ab7e35e	2018-03-04 14:31:10.368143-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
93b4b91c-728d-434b-bb9c-e377ef2c1d82	2018-03-04 14:31:10.371144-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9cf2152a-1745-4cb2-b8dd-30a1ddfff5c3	2018-03-04 14:31:10.373144-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0ab6961f-e257-402d-be8b-409c919d33a8	2018-03-04 14:31:10.375144-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
298b3934-5bbb-4338-9e3e-3e098d5e6db1	2018-03-04 14:31:10.378144-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e6f9b9a0-cab3-4b5e-8ebf-26820dbf3b29	2018-03-04 14:31:10.380145-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ae798bd8-382f-4d56-8b05-d629d3520c22	2018-03-04 14:31:10.382145-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
420f4f23-a374-4786-bf19-04879d7911e7	2018-03-04 14:31:10.385145-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9bc47814-5b92-49ec-9d35-2ee1782b9c1d	2018-03-04 14:31:10.388145-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
1dfd90a6-e7e8-46fc-9519-adab23db92e2	2018-03-04 14:31:10.392146-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
0a559e44-7239-4fa4-bf6e-06859dd589d3	2018-03-04 14:31:10.394146-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cda28ff7-237a-411f-9260-27f100c2547e	2018-03-04 14:31:10.397146-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
652a58e9-4d7d-4bcf-937f-743eef4e7c08	2018-03-04 14:31:10.399147-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
dd724b90-96c9-4b48-b358-f5fabee1a25b	2018-03-04 14:31:10.416148-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d69f2f8e-a3fa-4190-914a-5c51ae8e8551	2018-03-04 14:31:10.418148-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
dcbd7c85-f133-454b-a6e8-b7dd7e4bf69d	2018-03-04 14:31:10.421149-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
a5792cbb-ed2c-40bb-82a7-3676cfded2b1	2018-03-04 14:31:10.423149-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1c637c41-30c3-4c89-9b01-e535cc8b6ca2	2018-03-04 14:31:10.425149-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bb66f04d-ea19-4433-a960-150aff222819	2018-03-04 14:31:10.428149-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
658539fe-c031-4159-87b8-7b3e44461119	2018-03-04 14:31:10.43115-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
cb566e0f-dd02-45af-ae51-fac409446959	2018-03-04 14:31:10.43415-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
308d53dc-66df-4061-8b27-7ea4cfdc5bd6	2018-03-04 14:31:10.43715-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
54d368b7-4325-43cf-afd4-fe8df67c6136	2018-03-04 14:31:10.440151-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f47ee765-3fd3-4655-bd6f-3f148f9b72c1	2018-03-04 14:31:10.442151-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a04c3d91-09e0-42b3-be7c-fcdfd5ffe6b7	2018-03-04 14:31:10.444151-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5c6a3d09-be83-4f3a-9680-0a2f3d2e160a	2018-03-04 14:31:10.447151-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
e5caec7e-eae9-4353-9640-5221c7ef49f0	2018-03-04 14:31:10.449152-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0274ed99-8530-406d-ab56-69e88d6d8867	2018-03-04 14:31:10.451152-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
dfe34666-d764-4497-966a-f8e7e914c986	2018-03-04 14:31:10.454152-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
18b47360-3f09-43fd-8962-967182cfda64	2018-03-04 14:31:10.457152-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6e119ced-3f2a-4c77-a603-84c74726390e	2018-03-04 14:31:10.460153-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e5509838-1479-4d42-89c5-8cd8f8bb1553	2018-03-04 14:31:10.462153-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8b4df2f3-baae-475c-98a6-d6cff6b3943f	2018-03-04 14:31:10.465153-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3206c054-65ea-4e29-80e0-cf9cc5bbd0b5	2018-03-04 14:31:10.467153-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
9f3b82d5-121f-4495-b649-146ee6061b26	2018-03-04 14:31:10.469154-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bebdb657-77f7-4a8d-b7ca-574a9ac99b6e	2018-03-04 14:31:10.472154-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
1b46f068-f3ea-4a59-8a2f-ddec9540b280	2018-03-04 14:31:10.475154-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
2d50aac4-b187-4717-86e4-f65b57e40635	2018-03-04 14:31:10.477154-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
f5534afd-9d3f-4953-9662-b5cae8939c5f	2018-03-04 14:31:10.479155-06	3	[22571] D 4 CORRIDOR 437 	[21041] OSSI-DNOVAK	[293] master	\N	\N
27140760-ad3c-4aa4-badd-247e10ec75ed	2018-03-04 14:31:10.724179-06	2	[22572] D 5 CORRIDOR 437	[21041] OSSI-DNOVAK	[293] master	\N	\N
3ba214a3-96d4-4825-ac43-8419d9ee1bd0	2018-03-04 14:31:10.728179-06	2	[22573] D 6 CORRIDOR 414 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c2533300-d6c7-4fdf-8fd5-61e7b6921ffe	2018-03-04 14:31:10.73118-06	2	[22574] D 7 CORRIDOR 414 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f23d2a2e-d813-46c2-baf6-ad0a4823a1dd	2018-03-04 14:31:10.73418-06	2	[22575] D 8 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
803cfdf1-61f1-4210-80cb-3624176ec05c	2018-03-04 14:31:10.73718-06	2	[22579] D 12 CLASSROOM 415	[21041] OSSI-DNOVAK	[293] master	\N	\N
b5ae6ae9-c32b-4e75-a77c-ff1a90204c23	2018-03-04 14:31:10.739181-06	2	[22580] D 13 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
787a1c12-12e8-4595-9e2f-1a9645c7be58	2018-03-04 14:31:10.742181-06	2	[22581] D 14 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
cbf3d9c4-9514-414e-945d-40129459d1a2	2018-03-04 14:31:10.744181-06	2	[22582] D 15 VESTIBULE 422 	[21041] OSSI-DNOVAK	[293] master	\N	\N
298748b9-65c6-48bb-ae5c-562fd340fea1	2018-03-04 14:31:10.747181-06	2	[22583] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
83f3d371-e921-4899-a371-7a2932d449f0	2018-03-04 14:31:10.749182-06	2	[22587] D 20 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c6786367-6484-41bf-8cc2-beaffdab5908	2018-03-04 14:31:10.752182-06	2	[22588] D 21 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3ed0d6b9-d29f-434f-ac95-13afbddab22d	2018-03-04 14:31:10.754182-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
55197cea-017c-45c1-b568-ddaf467ff217	2018-03-04 14:31:10.756182-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
efef5502-2406-427d-b618-161fc9a8516a	2018-03-04 14:31:10.760183-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e8e61591-adf3-4fd5-a308-bd2eb8efde85	2018-03-04 14:31:10.763183-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
16c941c7-982f-458d-9f9b-55f008808423	2018-03-04 14:31:10.765183-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
ba46a1b9-dca9-4d65-bd40-b217f4ca2c65	2018-03-04 14:31:10.767183-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e70f839d-4f2a-4aad-82b8-958873395984	2018-03-04 14:31:10.770184-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f543c8bd-1eed-48b3-aac7-ad224f477a69	2018-03-04 14:31:10.772184-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
918ba260-41c6-4da1-abbf-d68ab6307625	2018-03-04 14:31:10.774184-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ee819c0c-97bf-4f58-98ed-85468403b099	2018-03-04 14:31:10.777184-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
e71770e0-f30c-427b-aef9-aa3c422030a5	2018-03-04 14:31:10.779185-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
e7527609-7063-4461-9ecd-09144dea88ca	2018-03-04 14:31:10.781185-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
72a0b659-b33e-46a4-95db-85edd188b3ea	2018-03-04 14:31:10.785185-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
48ff2fc8-cce1-4f5c-99c9-5d039452972c	2018-03-04 14:31:10.788185-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d9e9ed3e-963c-4381-8bc0-df3200b1a5f1	2018-03-04 14:31:10.790186-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5e1b50b0-647a-4228-8b7a-617a4408b91f	2018-03-04 14:31:10.793186-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d58440e0-4709-4138-84f9-b2b7fee7f949	2018-03-04 14:31:10.795186-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
4368275a-1fc6-4757-a4f1-efb524fce921	2018-03-04 14:31:10.798186-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
03ddb4c0-6d5b-4199-b625-e4bf2e96e2ae	2018-03-04 14:31:10.800187-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6ead924f-73c0-4d78-b1df-cf0bb9547d82	2018-03-04 14:31:10.802187-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
55fce3e8-a03f-4dcb-848a-b86d5ad98bb0	2018-03-04 14:31:10.805187-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
a195d1fd-7647-4a4b-ba75-e8caa91573e7	2018-03-04 14:31:10.807187-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
239f6d03-eaa6-4f16-8938-48f452e57308	2018-03-04 14:31:10.809188-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
940b7415-db58-4666-85ca-5b71bf166a3e	2018-03-04 14:31:10.813188-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ea113bc5-7a55-46bb-9347-346c8dafb8bd	2018-03-04 14:31:10.816188-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d4b114e9-ca7b-4512-a09e-0adad59d3362	2018-03-04 14:31:10.818188-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1172378a-4e7c-4e57-afb6-62643a7dbec5	2018-03-04 14:31:10.820189-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
05716c0a-209e-44da-b241-653861b68d09	2018-03-04 14:31:10.823189-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9623f580-e2ec-409d-999d-ad213749f216	2018-03-04 14:31:10.825189-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
0d85856f-7f6f-48da-bdde-a381d4db4af0	2018-03-04 14:31:10.828189-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
376d04a8-7f8e-46f1-8356-c219fc0e906e	2018-03-04 14:31:10.83019-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7693590b-516b-4c21-8fb6-95f7d4d7cfc1	2018-03-04 14:31:10.83319-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2afb772c-47c6-4432-8383-b03c7f93f5f5	2018-03-04 14:31:10.83519-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f05719a5-680e-45d0-b1e9-b269d26f00c5	2018-03-04 14:31:10.83819-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
30f5eb80-f14b-4cbe-a432-a163104a5a06	2018-03-04 14:31:10.842191-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
0d385d2a-9a45-4a3d-b3ec-b926e2c6c9d3	2018-03-04 14:31:10.845191-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f64e6a9a-a586-4de8-9dfa-a81f85db5f00	2018-03-04 14:31:10.847191-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
0affebbd-93a0-4f2e-9206-b8587c3de6ae	2018-03-04 14:31:10.850192-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
9d8acc65-1a9c-4abf-b02e-b4ff2e1ef541	2018-03-04 14:31:10.852192-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
1d7a2776-e055-4209-b4da-176c67d909de	2018-03-04 14:31:10.854192-06	3	[22579] D 12 CLASSROOM 415	[21041] OSSI-DNOVAK	[293] master	\N	\N
f27f846d-9f27-422b-9ff4-b799bc0d3c2e	2018-03-04 14:31:11.094216-06	2	[22580] D 13 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
56f43fe2-8289-4eef-b17b-85bc4e94c043	2018-03-04 14:31:11.097216-06	2	[22581] D 14 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
14a4d93d-779d-4e20-b7b5-5ec905724e85	2018-03-04 14:31:11.100217-06	2	[22582] D 15 VESTIBULE 422 	[21041] OSSI-DNOVAK	[293] master	\N	\N
28a55019-5ac4-45e3-b80f-4145bd06f1f9	2018-03-04 14:31:11.102217-06	2	[22583] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
b99eca1f-e0f4-43e0-b89e-0358ab7cf46a	2018-03-04 14:31:11.105217-06	2	[22587] D 20 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
005653c6-99fb-41b4-957e-c72b1b3c89f2	2018-03-04 14:31:11.109218-06	2	[22588] D 21 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
84e9fa8e-eb87-4119-b456-8fae04f99c4f	2018-03-04 14:31:11.112218-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
da36ffdd-ac5f-4748-adfa-314e9b19b4c8	2018-03-04 14:31:11.114218-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
e4ba2d52-968e-4834-b4b6-e448e674f837	2018-03-04 14:31:11.117218-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
344b7572-40c3-4fa4-a4e7-41031a104628	2018-03-04 14:31:11.119219-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a2dbf4ab-1c70-4781-92fc-7dba3792ff53	2018-03-04 14:31:11.121219-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
a538f4ed-734d-413d-ba65-2a8a033c9a8a	2018-03-04 14:31:11.124219-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a8081971-4501-44c2-a75c-11a88c843e93	2018-03-04 14:31:11.126219-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8bbf95d5-f910-4932-8510-e8abd24bad71	2018-03-04 14:31:11.12922-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8da3f094-af50-4c96-9104-b5039c473549	2018-03-04 14:31:11.13122-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
40b534e4-686f-46a3-b852-67546109045a	2018-03-04 14:31:11.13322-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
dae69cec-26e6-4b60-b348-41d813b47eca	2018-03-04 14:31:11.13722-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
8cb480fa-ce93-43d6-9e1f-f79572d381b4	2018-03-04 14:31:11.139221-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7617e3c4-12ba-4ac3-ac6f-79dac14da858	2018-03-04 14:31:11.142221-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e967ff17-413c-4f8d-803a-635cb1a01d95	2018-03-04 14:31:11.144221-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
993c8495-50c1-4476-b9c6-fedc87f7c2b1	2018-03-04 14:31:11.149222-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f513af01-0369-4fc7-8d81-6825b8130ec2	2018-03-04 14:31:11.152222-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
eb5440b0-d1db-4828-9d84-7319105e6ec9	2018-03-04 14:31:11.154222-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
ec96600a-152d-4ede-b6d8-747440f72c50	2018-03-04 14:31:11.157222-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4ff110bd-643f-469d-84be-f316027fbfaa	2018-03-04 14:31:11.159223-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ff17d33a-3d1a-4475-906b-7a153b527a36	2018-03-04 14:31:11.161223-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
73dfe853-a916-481f-ad53-635fac7f77ad	2018-03-04 14:31:11.165223-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
23697530-efbc-4827-a26b-68dbf98c63e7	2018-03-04 14:31:11.168223-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
18baaec9-c302-449e-8cdf-be727a97ef1b	2018-03-04 14:31:11.170224-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fbe9df02-999d-488d-90e4-0f6858f8c12d	2018-03-04 14:31:11.173224-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f0311eef-7162-4c89-b2df-75f145fae342	2018-03-04 14:31:11.176224-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4aa55273-bb7c-4dfa-9e3c-7bf822430515	2018-03-04 14:31:11.178224-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9a401563-95ff-4542-b80b-a7615a7a37fe	2018-03-04 14:31:11.181225-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
5da7961c-06d9-41ad-b63f-ebfeb7ba082c	2018-03-04 14:31:11.183225-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a19f76b5-a697-4666-a712-ba98b95a02a7	2018-03-04 14:31:11.186225-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
b5ae6d34-d04f-47ed-bd7b-40c58902f42f	2018-03-04 14:31:11.188225-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bf124bc9-bf1b-43b8-8147-6b4e95d3a67c	2018-03-04 14:31:11.190226-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8265d7c3-ffdd-4f6a-99c0-82a6add9e4a8	2018-03-04 14:31:11.194226-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
87b25aef-bd77-40e3-ba3c-2ca6325fdab2	2018-03-04 14:31:11.196226-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0afd7833-8b10-481a-bb0a-76d6ae858865	2018-03-04 14:31:11.199227-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0e218252-1caf-443d-a696-220c7d75650a	2018-03-04 14:31:11.201227-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
adfd3682-7acb-4374-8231-d82ce3abee31	2018-03-04 14:31:11.203227-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
90a90cbd-7b23-40f7-8c18-eee07db9cacd	2018-03-04 14:31:11.205227-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
70e6c50c-d525-48c7-90df-75daa6870e71	2018-03-04 14:31:11.208227-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
69ee25da-97e3-40fa-8155-ea55e88f46f7	2018-03-04 14:31:11.210228-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
d59001b2-01b6-4d14-ab87-1abe6bb37bac	2018-03-04 14:31:11.212228-06	3	[22587] D 20 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a35b4b08-595b-4da5-ac05-37369a7c7b22	2018-03-04 14:31:11.458252-06	2	[22588] D 21 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ea96ec30-7998-4dd8-afb9-695ce70e1e83	2018-03-04 14:31:11.461253-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
746882eb-98ae-48bc-a082-6e707a581e06	2018-03-04 14:31:11.464253-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
5faa27f8-da42-4329-9daa-3e590aa26f1e	2018-03-04 14:31:11.468253-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5954d524-2aad-4c81-9f7a-616a427f4688	2018-03-04 14:31:11.471254-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ca88f664-b0e8-409b-964e-be9cecbf19ce	2018-03-04 14:31:11.473254-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
6ae5b4de-b5e1-404c-87b4-44dd568510fd	2018-03-04 14:31:11.476254-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2ba7bf11-16b5-4a09-b499-ed04351b8bf2	2018-03-04 14:31:11.478254-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
076246ba-2b2c-4afe-8082-7152de7cf9be	2018-03-04 14:31:11.480255-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
11460d21-8b61-4a84-bf43-02c6f564be7b	2018-03-04 14:31:11.483255-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f07a258f-90d2-4493-810f-98deb6e4c277	2018-03-04 14:31:11.485255-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
4a45f7c7-bff2-402e-9fb8-22d36d6228e5	2018-03-04 14:31:11.488255-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
9650ccfd-7515-4818-8d6f-2d9b738f06ab	2018-03-04 14:31:11.490256-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f1f1f69a-5e05-46ae-afc4-0cdbd7cf26c7	2018-03-04 14:31:11.494256-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7c25401c-f689-464a-912d-8cd1f45d65b7	2018-03-04 14:31:11.496256-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cb389cf5-a655-4510-a457-006fca2f724f	2018-03-04 14:31:11.499257-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4ce592f7-718f-4433-9635-7913d192b8fd	2018-03-04 14:31:11.501257-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b8c30eac-076a-413f-9241-293e19590511	2018-03-04 14:31:11.504257-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
2dde5fa8-ea74-4674-b805-9ec261037830	2018-03-04 14:31:11.506257-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9a2e4f98-2969-4857-a2e4-1ce01d16f4d1	2018-03-04 14:31:11.508257-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f8ee7056-21a6-4b21-99af-7e425a240c88	2018-03-04 14:31:11.511258-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
930949b3-b395-49ca-aa50-de8d38fe8cc9	2018-03-04 14:31:11.513258-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
2814b8b8-469b-42ed-9651-1cb2d6936f38	2018-03-04 14:31:11.515258-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4b7ae155-23ad-440f-bd15-cfab37874ffd	2018-03-04 14:31:11.518258-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
11604f2c-4a25-45c2-97a0-f94ca64d8c4f	2018-03-04 14:31:11.522259-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
82c8ba91-06c0-41a8-bec8-70f09e37c837	2018-03-04 14:31:11.524259-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b3c1d711-0d9f-4421-b130-efe18ca6b673	2018-03-04 14:31:11.527259-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c4a581d4-8c35-4d9b-a007-a6f4482cad34	2018-03-04 14:31:11.52926-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
9ef3a61e-e836-4f17-9dc4-e8bb27901bed	2018-03-04 14:31:11.53126-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bfde9a99-528b-4df5-9be9-5da6819318e1	2018-03-04 14:31:11.53426-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
6c6e1c12-126d-408e-9307-7406df611d44	2018-03-04 14:31:11.53626-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f313bdf4-2e94-4ed4-b7db-170d9d7c7cc3	2018-03-04 14:31:11.53826-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0bfda4fc-fad7-47cf-81b3-6b5d01e2a1aa	2018-03-04 14:31:11.541261-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9e729477-d77c-4f6f-8e1f-cbc4b1dfae76	2018-03-04 14:31:11.543261-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
52830e37-9a0c-498a-ba6b-23a7faa21b0d	2018-03-04 14:31:11.547261-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
46fe7fff-fab7-487a-9e60-53db84b209e3	2018-03-04 14:31:11.549262-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
2fb71ee5-3f91-4082-8fe6-3d8e895156d2	2018-03-04 14:31:11.552262-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3de50418-0b6a-4730-9697-7a4c9d92981b	2018-03-04 14:31:11.554262-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
13f0cb8a-faf9-483f-8cef-ab0202820a71	2018-03-04 14:31:11.557262-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
ebfde565-0133-4a39-ac2b-9628b623fd9b	2018-03-04 14:31:11.559263-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
b7102e13-ed4e-4d24-b3bc-648db730641b	2018-03-04 14:31:11.561263-06	3	[22572] D 5 CORRIDOR 437	[21041] OSSI-DNOVAK	[293] master	\N	\N
27b49dc3-1e12-4a0d-860c-f50a3643a538	2018-03-04 14:31:11.805287-06	2	[22573] D 6 CORRIDOR 414 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b1cead1c-55c8-4a99-a165-6a66c6c2a202	2018-03-04 14:31:11.809288-06	2	[22574] D 7 CORRIDOR 414 	[21041] OSSI-DNOVAK	[293] master	\N	\N
320aa16e-87ca-4950-b9dc-e241b79a96de	2018-03-04 14:31:11.812288-06	2	[22575] D 8 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
41ff48d2-df05-4f71-8c64-ba1eb9d088aa	2018-03-04 14:31:11.816288-06	2	[22580] D 13 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
aa0253d2-c1fe-448d-9567-2c11e255714c	2018-03-04 14:31:11.820289-06	2	[22581] D 14 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
a5b0e6f9-1ff5-4689-8fdd-8df83e2395d9	2018-03-04 14:31:11.825289-06	2	[22582] D 15 VESTIBULE 422 	[21041] OSSI-DNOVAK	[293] master	\N	\N
aa514944-85a2-4ae5-9adb-4b813d79cddd	2018-03-04 14:31:11.828289-06	2	[22583] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
771645b0-bad4-43d8-a375-8b67d96d096d	2018-03-04 14:31:11.83129-06	2	[22588] D 21 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
06942a3c-d491-43f7-ad92-5b84e43c54ae	2018-03-04 14:31:11.83429-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
88f9fe6e-c6d6-4319-aabe-7beb9e36e4b9	2018-03-04 14:31:11.83729-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
77c7c0ae-db3c-4e06-9ed6-e63316f2ac4b	2018-03-04 14:31:11.840291-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4c770874-e59f-4f06-b500-26ec3245e66f	2018-03-04 14:31:11.842291-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
339d65ec-e600-4863-9320-384e4bb72b6b	2018-03-04 14:31:11.845291-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
524bce49-d635-4b1d-aeee-9fc02d7f08b7	2018-03-04 14:31:11.847291-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
65e2b306-2e47-43b2-9fb3-cdeb1a38f2c8	2018-03-04 14:31:11.850292-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9a812ec0-ae41-43ae-a49f-106f9a67ade0	2018-03-04 14:31:11.852292-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6c0c0407-7f40-475d-9fcd-ad60ad36cf9e	2018-03-04 14:31:11.855292-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3a00827d-d710-4a1d-885b-b093c1a5ddb0	2018-03-04 14:31:11.858292-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
573ea079-42e7-4ed6-9a7e-888934824c48	2018-03-04 14:31:11.860293-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
1616c391-e552-4be7-9319-8460ed4a4382	2018-03-04 14:31:11.863293-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
981ebe8c-794e-40a2-89f1-dcc1c932417d	2018-03-04 14:31:11.865293-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6fdc70df-4c3b-4d3e-9a15-3ac2dbc56ab9	2018-03-04 14:31:11.867293-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3365a30b-af9d-4307-b620-3006fea8f4ea	2018-03-04 14:31:11.870294-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7c606f6d-cadc-48af-a497-91ff36feb88f	2018-03-04 14:31:11.872294-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8be2121b-1aea-4cfc-82ec-0cb55f1c97c0	2018-03-04 14:31:11.874294-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
984feb96-1975-4ca0-8501-8778344c9256	2018-03-04 14:31:11.876294-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
84e0ea6f-2686-4429-84f8-9d31aab7069b	2018-03-04 14:31:11.880295-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
19a0f71b-9258-4271-9236-fcdfd2341d45	2018-03-04 14:31:11.883295-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
13927fc2-e83d-4168-bda9-94e3b7fb2b5e	2018-03-04 14:31:11.886295-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
201ad55c-43ca-4a22-a0ea-8363d0ecd91c	2018-03-04 14:31:11.888295-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
801af34b-5873-48c4-b567-16432f8e4d79	2018-03-04 14:31:11.891296-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
43508009-afcc-48ae-aa3f-ece7f4eb8452	2018-03-04 14:31:11.893296-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
893dcde3-c22d-4c33-aa83-becd7e11bf8b	2018-03-04 14:31:11.895296-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e5840732-711b-44c3-8c8d-9c4e03b18e45	2018-03-04 14:31:11.898296-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
eea9f835-8bd2-4a80-8c8e-fb3a57307fae	2018-03-04 14:31:11.900297-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
795877ff-1c77-43ba-8ce1-033182c64bf5	2018-03-04 14:31:11.902297-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ba970dec-e126-45f7-9d90-34054abc4414	2018-03-04 14:31:11.905297-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
ee9db0f8-1bdd-40f4-aa00-a540c24cfe4d	2018-03-04 14:31:11.909298-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6b64ded8-c99d-4be9-9e8a-93e1f770048e	2018-03-04 14:31:11.911298-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
eee5421e-5fb3-47ca-8f6b-edaa67aa8bee	2018-03-04 14:31:11.913298-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a7da0c1f-7fa8-4a76-82cb-c7798be7632a	2018-03-04 14:31:11.916298-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
69e81c1d-9315-402d-8642-018e4aca1847	2018-03-04 14:31:11.918298-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
107da70b-163c-4ee8-b753-282645cb431e	2018-03-04 14:31:11.920299-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
715a49fe-237a-4566-88c1-15a92467fdcd	2018-03-04 14:31:11.923299-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c8ae90d8-d40a-4cd3-a0d0-77c4323d67c9	2018-03-04 14:31:11.925299-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
40d02e7d-c077-47c1-a672-5554685169a2	2018-03-04 14:31:11.927299-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
e659bbcd-0fed-4fc6-942e-a0277a779763	2018-03-04 14:31:11.9303-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
bc49f4ac-87b1-4cf0-ac49-06e18d85bd49	2018-03-04 14:31:11.9313-06	3	[22580] D 13 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
6a6c9f7b-68c7-4f7c-a0b7-61802fe37c73	2018-03-04 14:31:12.171324-06	2	[22581] D 14 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
9eff101a-9be2-4de5-bea7-1b63e448e176	2018-03-04 14:31:12.176324-06	2	[22582] D 15 VESTIBULE 422 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4c1baec2-7ce9-4cba-8b36-b4084b3348f8	2018-03-04 14:31:12.179325-06	2	[22583] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
30afd8d1-8f30-44a8-a260-65df3de5391e	2018-03-04 14:31:12.181325-06	2	[22588] D 21 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f826cc4b-7e0c-4f12-93fb-7eefd68c6e8f	2018-03-04 14:31:12.184325-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
04e2879c-0322-486f-9298-b4bd733a9e66	2018-03-04 14:31:12.186325-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
a7fa794a-86db-4cfc-bc7d-d56dbbaba20d	2018-03-04 14:31:12.189326-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f2e0fdb0-c1a8-4676-b341-4c92b47de9d6	2018-03-04 14:31:12.191326-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0a11b38c-bdf8-466a-ab12-8d61fadf277d	2018-03-04 14:31:12.193326-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
2642ffc0-cd9a-4b3c-ad74-35196c9cefd6	2018-03-04 14:31:12.196326-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5f94e8ee-f96a-4c5d-bdd7-ea37e96ae0bc	2018-03-04 14:31:12.199327-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
860c4ab7-e30a-4eb5-9004-1d13e276ac35	2018-03-04 14:31:12.203327-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6a764ca9-87c6-499a-89fc-b5eca318d6ee	2018-03-04 14:31:12.205327-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ba3aafa1-459f-4e2b-ad5d-157a96c9624f	2018-03-04 14:31:12.208327-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
dddd187b-ceeb-4f0e-9dd0-e0b05597162b	2018-03-04 14:31:12.211328-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
e393873a-2a81-4394-8798-43b8ee594aaf	2018-03-04 14:31:12.213328-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ee076be1-8e7b-471c-873c-0395a95ba136	2018-03-04 14:31:12.216328-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
45e32167-ba39-440e-bb1c-ea94d3633571	2018-03-04 14:31:12.218328-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
86192f4a-1c2e-48bc-93dc-0ba24cae8313	2018-03-04 14:31:12.221329-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6d1bc0fe-373d-48d0-99e3-c66cd68cc111	2018-03-04 14:31:12.223329-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7fafac9b-1f45-464c-b417-1cdb04f6ee5b	2018-03-04 14:31:12.225329-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
dd99204c-3af9-482e-9f25-1298db34a3b7	2018-03-04 14:31:12.228329-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d96ed91e-a60b-4ccd-a34a-b25aeef81809	2018-03-04 14:31:12.23133-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
15d6a184-f27d-4bf4-932f-a8b51573062d	2018-03-04 14:31:12.23433-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9b3a229e-f764-4242-b8d8-42636c3d26d4	2018-03-04 14:31:12.23633-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
9ca3ad09-cd71-459a-8770-db952f4d1efc	2018-03-04 14:31:12.239331-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
77ad0b47-5768-4230-a4f4-916051c45fe5	2018-03-04 14:31:12.241331-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7f3f483d-88e0-4e8d-a36d-3e97350cf7c4	2018-03-04 14:31:12.243331-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a6092ba2-e413-4ebc-957c-56fa4d6ef066	2018-03-04 14:31:12.246331-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
275b0e5f-391d-4200-81a6-dc7b94ebbd69	2018-03-04 14:31:12.248331-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5a25aefb-6d1a-428e-ac66-47815f6dec28	2018-03-04 14:31:12.250332-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
663626bf-9677-4023-bfa5-2f814b44c456	2018-03-04 14:31:12.253332-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
61d331af-aeac-4aa0-819b-4db9eaec5a2f	2018-03-04 14:31:12.255332-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
dcb80c06-e867-430c-80b8-18ac09f4db1f	2018-03-04 14:31:12.259333-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
812b4cb5-4411-476a-8915-76d0c68e0d25	2018-03-04 14:31:12.261333-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
eac316e1-adf2-4b11-9ba3-22abf05c5e49	2018-03-04 14:31:12.264333-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8fc81f39-a9b2-4f5d-b666-dbd8d6b2c372	2018-03-04 14:31:12.266333-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c92c75ec-d0b6-48d8-875c-c0760de5ce21	2018-03-04 14:31:12.268333-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0628de52-c3dc-40c7-a750-4b8f72f70b7c	2018-03-04 14:31:12.271334-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
a3e13ab0-5b8a-4bce-95db-ef9940719788	2018-03-04 14:31:12.273334-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
68b69cd1-d0e6-4963-a36a-de45b72de185	2018-03-04 14:31:12.275334-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
a612af4d-3c8f-4a62-9a44-afddea2cba32	2018-03-04 14:31:12.278334-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
a8e8f7cc-82d6-49c5-a06a-b8f7abb57cc3	2018-03-04 14:31:12.280335-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
a8349571-e240-4c3c-88a5-cdc1b6ea7bea	2018-03-04 14:31:12.282335-06	3	[22588] D 21 CLASSROOM 428 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bd2c0903-3fd8-41e6-b4d5-01ef5ee5ecd0	2018-03-04 14:31:12.524359-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
deb28fba-2300-4377-b430-9f2fe8516ef5	2018-03-04 14:31:12.528359-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
69696722-6e8c-4db7-839b-eae9f6d2d789	2018-03-04 14:31:12.53036-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2c9a3d77-62f6-430b-9f1c-cbcdaa8ecd3c	2018-03-04 14:31:12.53336-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7f08ff9f-f46b-418d-9e14-92e220d65641	2018-03-04 14:31:12.53536-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
4daf63c6-ca26-424b-903d-0cfa5dbe61d5	2018-03-04 14:31:12.53736-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b248b32c-e337-4b04-ad91-7b9f2834ceef	2018-03-04 14:31:12.540361-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
00bd8a4d-fc2a-4e16-a645-8e6dfa88b2cd	2018-03-04 14:31:12.542361-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d2cd8a19-189c-433d-8846-d07c59b101dc	2018-03-04 14:31:12.544361-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
999ef42b-df18-408b-bff6-b99009001e1b	2018-03-04 14:31:12.547361-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
a3a7e490-94ce-409b-9370-131b36ba3b1f	2018-03-04 14:31:12.549362-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
5c424e44-b629-4b72-996b-2ca66c4c0f7a	2018-03-04 14:31:12.553362-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0e559570-5962-4535-9e89-b4a4b1a46738	2018-03-04 14:31:12.555362-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3e41cfa7-982b-44f9-b6fc-6f1b364801b4	2018-03-04 14:31:12.557362-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ff4bfa89-4c5b-432c-adca-7014a679a654	2018-03-04 14:31:12.560363-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
505034a4-6174-48a4-818d-1262468a4c76	2018-03-04 14:31:12.562363-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
52aadb38-138d-4dbb-bd4f-17ea092a2f67	2018-03-04 14:31:12.564363-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
e70631f8-4c7b-4e7f-b2dc-93f7978be5b8	2018-03-04 14:31:12.567363-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d9ca7c77-6cf7-4d89-981e-ca0e2690ca30	2018-03-04 14:31:12.569364-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
090abdc8-7270-4dfc-b5f2-094866b9896f	2018-03-04 14:31:12.572364-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d7547ce8-4a59-4296-980d-52697a29198a	2018-03-04 14:31:12.574364-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
7131d32e-4036-41a9-ae85-07ef30537e21	2018-03-04 14:31:12.576364-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ddc01a3b-5a28-4ac4-8e5c-0ed411f7eb3b	2018-03-04 14:31:12.592366-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
aee0ef75-9f42-4ca6-941d-34ba6cd944d7	2018-03-04 14:31:12.594366-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
dfeb3330-5118-4171-95d9-56aab8c0b435	2018-03-04 14:31:12.597366-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
40b869f2-5665-4000-b0e9-f74dba0f6563	2018-03-04 14:31:12.599367-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7bae5eaa-bd9c-4207-9c0c-13a477b70e54	2018-03-04 14:31:12.602367-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
08d3dff9-ffd4-4e7e-8a7c-00faecfe81b0	2018-03-04 14:31:12.604367-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5efc328e-e2ce-4464-84cb-b420d374883a	2018-03-04 14:31:12.608367-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
a7bcbfa4-f9bb-45f0-a1bd-3b896691d618	2018-03-04 14:31:12.610368-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
aca92a3b-c64b-4d9a-a3b0-689f19f436a1	2018-03-04 14:31:12.612368-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c8d82207-f863-48ce-a306-e33a9ce80620	2018-03-04 14:31:12.615368-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
18919dce-fd9b-4831-a666-cdc59b43317f	2018-03-04 14:31:12.618368-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
96d27234-9d76-4aba-b630-8e32adcb403a	2018-03-04 14:31:12.621369-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
823e23fa-c8d4-4434-8e87-c69e4421894c	2018-03-04 14:31:12.624369-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
c275c9a2-b05f-4512-876c-f807bdc1275c	2018-03-04 14:31:12.626369-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ba8f7d9c-e9ee-4bfc-8c80-a70d97ea6fef	2018-03-04 14:31:12.628369-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
983107ff-6c3f-49d0-8406-3011174a14c8	2018-03-04 14:31:12.63137-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
42d8ae5c-9c46-4b90-ad71-988345624054	2018-03-04 14:31:12.63337-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
a279ca82-70c8-43ef-a98b-60a36b083518	2018-03-04 14:31:12.63437-06	3	[22573] D 6 CORRIDOR 414 	[21041] OSSI-DNOVAK	[293] master	\N	\N
712cd842-48ad-4a83-8ac7-0e3d6d2f25af	2018-03-04 14:31:12.888395-06	2	[22574] D 7 CORRIDOR 414 	[21041] OSSI-DNOVAK	[293] master	\N	\N
72ce0894-51ae-4065-9b18-5a214e5f1d55	2018-03-04 14:31:12.890396-06	2	[22575] D 8 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
996083a7-fa7c-4e0c-b57e-0b657d2bdb63	2018-03-04 14:31:12.893396-06	2	[22581] D 14 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
f2f68fc0-f719-49ae-940a-f834e7ab09fa	2018-03-04 14:31:12.896396-06	2	[22582] D 15 VESTIBULE 422 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5b8e74a1-a648-4b7e-8d70-b585dfd38669	2018-03-04 14:31:12.899397-06	2	[22583] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
953a3ef4-3305-4ab3-9c27-dff84804ff3b	2018-03-04 14:31:12.902397-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8a0d5d5f-2aa8-49bc-b48a-e5f1c3c636e6	2018-03-04 14:31:12.905397-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
81ff456f-1b0a-4887-8612-38a559192439	2018-03-04 14:31:12.907397-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e04c875b-1df9-4b7b-86f0-4f1a4e3f4eae	2018-03-04 14:31:12.910398-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3dccd7d6-f260-477f-a86f-ed0df7c6da4e	2018-03-04 14:31:12.912398-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
1cfb6a28-e2d0-4dff-a206-9084e18cf548	2018-03-04 14:31:12.914398-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
35ab7630-af49-4ec3-baea-7947604a35d0	2018-03-04 14:31:12.917398-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
12d99191-0e32-48b8-9f1b-352433ec0df6	2018-03-04 14:31:12.919399-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
245d5f94-aa9d-49a9-89c6-9c442aad246f	2018-03-04 14:31:12.922399-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f3e60148-01c1-4106-868f-3494ae42a5d8	2018-03-04 14:31:12.925399-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
b3e90d0e-70e2-4d6a-92e1-81c3cc21c265	2018-03-04 14:31:12.928399-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
dcb975d6-ff34-40b3-975c-6b944b6c9f3e	2018-03-04 14:31:12.9314-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
49180c0c-0157-4fd8-b1dd-43ce77bb7c27	2018-03-04 14:31:12.9344-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8c937a0b-db70-482c-9fdc-fc6310caeb46	2018-03-04 14:31:12.9364-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
03ce1739-57f6-4b16-b384-c90d7b3b7e3b	2018-03-04 14:31:12.9384-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a66be4fa-cc4a-43bc-ae1f-31e89ef26055	2018-03-04 14:31:12.941401-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ec53bbf1-0cad-4f26-8abb-748773cb0cf2	2018-03-04 14:31:12.943401-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
7f7b9200-82c0-4484-9029-f49d6aef073a	2018-03-04 14:31:12.945401-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3ed2bdb9-711f-4761-8693-704f5b3ba492	2018-03-04 14:31:12.948401-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1961b1c2-ae16-4661-92ad-ce113dbdc38b	2018-03-04 14:31:12.951402-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e3b30dc5-3991-47a5-89c6-8f7b88764e86	2018-03-04 14:31:12.954402-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
b52dc0dd-1c70-429e-be95-947583e73478	2018-03-04 14:31:12.956402-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ed84874a-0653-4f3c-a48a-730308917f80	2018-03-04 14:31:12.959403-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
73c8e54f-da9b-4a30-b6a3-bf794f40b6b5	2018-03-04 14:31:12.961403-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8d4af176-d0a1-4836-a4f6-f5fd6096b335	2018-03-04 14:31:12.964403-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5766a88e-038d-4732-aba4-3f08679e7792	2018-03-04 14:31:12.966403-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f786639c-5919-46f1-845d-98ca694243f2	2018-03-04 14:31:12.968403-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
2a626f4c-ea94-4b39-a4bf-7e4b81ee0d7b	2018-03-04 14:31:12.971404-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7992fb1e-fef4-4e0c-a932-71972d7d7dd5	2018-03-04 14:31:12.973404-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
f7ffb380-b2b6-421f-a276-cbaee7a96ca8	2018-03-04 14:31:12.975404-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
28af2178-1955-4883-986e-c0dca7a3ad8f	2018-03-04 14:31:12.978404-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
46d3ec53-0a89-48e7-b24c-e4121087f4a8	2018-03-04 14:31:12.981405-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5e68af5e-93f8-4dfb-aea5-68d8cbe05ae2	2018-03-04 14:31:12.984405-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a762da1f-3105-4b6a-87ba-8fa9132f2037	2018-03-04 14:31:12.986405-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f589a7e9-a72d-4fee-8eed-264a44ea2b3d	2018-03-04 14:31:12.988405-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
677ab94a-37d2-4504-afa1-eb07a8d7b223	2018-03-04 14:31:12.991406-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ce98520e-1f11-4669-8c77-937072827ff0	2018-03-04 14:31:12.993406-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
208394c6-a9d8-48d2-96ae-96ab53d4df2c	2018-03-04 14:31:12.996406-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
894d4d5a-db4d-449a-a414-1c93d044ea05	2018-03-04 14:31:12.998406-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
a2aeae08-4519-46d3-8951-44312319a6ff	2018-03-04 14:31:13.000407-06	3	[22581] D 14 CLASSROOM 418	[21041] OSSI-DNOVAK	[293] master	\N	\N
de8aaee3-831e-4635-92e8-8ab475842308	2018-03-04 14:31:13.23743-06	2	[22582] D 15 VESTIBULE 422 	[21041] OSSI-DNOVAK	[293] master	\N	\N
192c99ec-f426-41b1-8535-9d1408c5fb79	2018-03-04 14:31:13.241431-06	2	[22583] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
59c6168d-290f-4ec1-a0f7-df019ce183d4	2018-03-04 14:31:13.243431-06	2	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a5828032-5075-410f-8c66-71f49bc27226	2018-03-04 14:31:13.247431-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
8300ce40-346b-46d4-81e8-06caba2909fd	2018-03-04 14:31:13.250432-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7fbd1429-d566-449c-a07c-845878928b57	2018-03-04 14:31:13.253432-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
57569fe9-d27a-4d8f-8f01-caa95dd7a49a	2018-03-04 14:31:13.255432-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
2aff0e92-5ba1-45b6-bb54-c5c6da7564e1	2018-03-04 14:31:13.258432-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4ef04b14-f5ac-4ac1-a064-7adc0000982c	2018-03-04 14:31:13.260433-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f7dbda83-4d27-4975-8a77-c8c80a289544	2018-03-04 14:31:13.262433-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
59edd7f6-aa62-421c-bfd1-ab75014768cf	2018-03-04 14:31:13.265433-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f66feca6-a418-4cfd-8ec4-cd80e69642c6	2018-03-04 14:31:13.267433-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
4646e436-a17a-4eb4-8565-bc0c8b4d2180	2018-03-04 14:31:13.270434-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
2b7e4b06-d9b9-4fa5-8271-398b8c4179c3	2018-03-04 14:31:13.273434-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
58323066-6768-4cbe-b4ca-56c7df7feec8	2018-03-04 14:31:13.276434-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
aceea811-1fc5-4a27-afeb-116d01054d95	2018-03-04 14:31:13.278434-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
53a5b35f-fde7-4c6f-9349-f622fda7e8d2	2018-03-04 14:31:13.280435-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e90d83c8-990e-4358-9cbb-d8f3fb583517	2018-03-04 14:31:13.282435-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6d3b692b-136d-4d1f-99f7-4992f9aa1bae	2018-03-04 14:31:13.285435-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
66c242b0-4d5e-4a25-b072-895323dddf77	2018-03-04 14:31:13.288435-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b0527b0e-22bb-4bf5-bd23-ca1d176a5d38	2018-03-04 14:31:13.290436-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1488510a-3617-464e-8795-ea8a18322cf4	2018-03-04 14:31:13.293436-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9f6733ac-9c84-456d-a368-5dbc14781a14	2018-03-04 14:31:13.295436-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
29fd1905-4276-4870-89b2-f9059b982065	2018-03-04 14:31:13.297436-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
faaf81ce-bcc5-45be-af04-e27801ef7dbf	2018-03-04 14:31:13.301437-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
41827846-bcd1-4a16-9abb-48f173abf3fc	2018-03-04 14:31:13.303437-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ae1be5f7-4895-4716-8d5c-f46dc03fe2a3	2018-03-04 14:31:13.306437-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0a2d94e1-4eb7-40cb-b648-437289817acb	2018-03-04 14:31:13.308437-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1f58e6c1-97b8-4e45-b0b0-66f4098d3d84	2018-03-04 14:31:13.310438-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
476c2d35-2b57-4c5b-af2d-74b27ea1bc8c	2018-03-04 14:31:13.313438-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e6ef41e0-cedd-4318-8da7-585a3fb0941c	2018-03-04 14:31:13.315438-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
19ee1bb4-e0b3-412f-9c69-47c9730217fb	2018-03-04 14:31:13.317438-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
68d3670d-3fe2-4521-b7b8-fd93e0a1bb3a	2018-03-04 14:31:13.320439-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d25fa513-e7d2-45ed-8d56-d811a34296d7	2018-03-04 14:31:13.322439-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6f91aeb0-60e8-46b2-a78b-0a713de32e1a	2018-03-04 14:31:13.325439-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
399eaf95-6f70-4b28-a6d6-0709fa3ddfa9	2018-03-04 14:31:13.328439-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9d5700e2-4711-46f8-b254-b1f4a50fde37	2018-03-04 14:31:13.33044-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
3151d499-855d-4d21-a050-ff9157f1a33b	2018-03-04 14:31:13.33344-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
dcbc9670-621a-406d-bac7-d8b541939291	2018-03-04 14:31:13.33544-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
5586c3f5-83be-4fdc-bc81-4cac74793d03	2018-03-04 14:31:13.33844-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
5ddb0f2a-43d8-43ea-8728-84a03f0dc93f	2018-03-04 14:31:13.340441-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
f88c8466-e71b-4ecb-9946-ac5730346756	2018-03-04 14:31:13.342441-06	3	[22589] D 22 VESTIBULE 444 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bc82fb44-d137-4cc6-8985-7147c6d929a0	2018-03-04 14:31:13.580465-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
606b7f4c-39c8-4e9a-9091-bdb440f0d0c7	2018-03-04 14:31:13.584465-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
45748486-37e1-42c5-9669-c50dbf018088	2018-03-04 14:31:13.587465-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9ed8aed8-2a15-4c2d-afa3-36612a439cc3	2018-03-04 14:31:13.590466-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
40c3497e-a062-4cfe-bbe6-498cd564711c	2018-03-04 14:31:13.593466-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2bd67a3e-e2ec-4d03-b2a0-d771077f246b	2018-03-04 14:31:13.597466-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
be6558e1-75b2-45a6-b90b-ed7318afa07f	2018-03-04 14:31:13.599467-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
20e4a318-dadb-41e6-8726-02da1730e367	2018-03-04 14:31:13.601467-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0e62babb-3f38-4f44-ad18-4470d9a95ab8	2018-03-04 14:31:13.604467-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
24d66afa-2e48-4293-923d-e494068c836b	2018-03-04 14:31:13.606467-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
0a83fc18-4262-451a-be71-3c4ca241b6ca	2018-03-04 14:31:13.609468-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f33187f1-935a-4b53-8e58-a35ce7cfacf7	2018-03-04 14:31:13.611468-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4e906d42-3f4b-4406-96e8-2e7c30c05df5	2018-03-04 14:31:13.613468-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5176660b-546b-4c13-9916-aa67eee1ef52	2018-03-04 14:31:13.616468-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e145f988-16ed-49f7-9c4c-06925142ab2a	2018-03-04 14:31:13.618468-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b9e70c77-3ba4-4c31-991f-2bb5744f8ffa	2018-03-04 14:31:13.622469-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
b40e194e-7be9-46dd-a201-94257c4d1a46	2018-03-04 14:31:13.624469-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6810d77a-2fd4-4282-8d39-9fda1e4cf096	2018-03-04 14:31:13.627469-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
43bf0fee-e12f-47ec-a05e-69f4c8953903	2018-03-04 14:31:13.62947-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
35a67e3b-67b5-4413-9425-54544d752e15	2018-03-04 14:31:13.63147-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
12621b23-73fb-4273-8741-c6c8fc28005b	2018-03-04 14:31:13.63447-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a51842d2-ed27-4009-be7b-5d6f2ae2039c	2018-03-04 14:31:13.63647-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
79a8a712-8741-4f5a-889a-102116ff88c4	2018-03-04 14:31:13.639471-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f3b982c2-9c5c-413e-830f-1afc708f71bd	2018-03-04 14:31:13.641471-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e455d4f5-7d5b-46c7-8798-638662714584	2018-03-04 14:31:13.643471-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5b0ff03f-6ab7-4625-998d-1df89e09ffe7	2018-03-04 14:31:13.647471-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
f397653f-d4e4-4fcc-b690-f88338ed9096	2018-03-04 14:31:13.649472-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6c31c86d-87a0-48a8-b957-d21e39db6ad7	2018-03-04 14:31:13.652472-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
6b73891f-64bc-43ff-b3ce-f9bf201f0762	2018-03-04 14:31:13.654472-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cad226f3-4fd7-4305-8cde-cf235dd85c23	2018-03-04 14:31:13.657472-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
aceea824-22fa-4e3b-92ab-a2588a27c6cb	2018-03-04 14:31:13.659473-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cf162058-4382-4117-a6ea-2242febdae8a	2018-03-04 14:31:13.661473-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8818c295-b625-4fda-bec6-f41c5b68ad85	2018-03-04 14:31:13.664473-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
55a521e5-842c-4bd2-b95d-90447cb9e07e	2018-03-04 14:31:13.666473-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
819e5918-249b-4138-b501-d9d7d52de7cc	2018-03-04 14:31:13.669474-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b2df3532-c23c-4369-a94d-d64839cd1b66	2018-03-04 14:31:13.671474-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
b15b1727-7bce-478d-a479-84cd388d56ac	2018-03-04 14:31:13.675474-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
d81763db-6d09-4087-9125-7535a14898c9	2018-03-04 14:31:13.677474-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
e9d38df8-de13-4172-8933-16db2b58e295	2018-03-04 14:31:13.679475-06	3	[22574] D 7 CORRIDOR 414 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bf842db7-c8b6-4833-88a7-630ac8fd42fa	2018-03-04 14:31:13.920499-06	2	[22575] D 8 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7c1c89a5-221c-4a16-afeb-304c4b22ceba	2018-03-04 14:31:13.923499-06	2	[22582] D 15 VESTIBULE 422 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1c792e85-a6c3-4358-abca-1d521111ad64	2018-03-04 14:31:13.926499-06	2	[22583] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
9c5d6cee-4889-4c45-9168-a466666fc007	2018-03-04 14:31:13.928499-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
125f0966-9f1b-4df4-88fd-826a44ea14a7	2018-03-04 14:31:13.9315-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7358a9f4-d049-4ca9-bca3-88d1709cac09	2018-03-04 14:31:13.9345-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8bbec58d-21a2-42df-a790-f235c8ce512a	2018-03-04 14:31:13.9365-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
f47293a0-0f74-4146-b324-6f4cd87d5887	2018-03-04 14:31:13.939501-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0c916357-dd38-47ed-b5c7-ef853c4d7b70	2018-03-04 14:31:13.941501-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c6d09767-8919-4593-852b-b85550158ae1	2018-03-04 14:31:13.945501-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c33fa6e2-5837-458d-bfde-51f20f07161d	2018-03-04 14:31:13.948501-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9d46b445-9d41-4b0e-be22-619ea683b181	2018-03-04 14:31:13.950502-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
72044c21-259a-4330-bc5f-e0ed63176da8	2018-03-04 14:31:13.953502-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
2310b8c7-4c7e-4d38-bad1-29bbb9fa36fe	2018-03-04 14:31:13.955502-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
958636ab-3a14-4795-8ef3-de3887942e10	2018-03-04 14:31:13.958502-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
498d7ebb-5126-4880-add6-b5d1436a40f7	2018-03-04 14:31:13.960503-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
44c0bf09-cf7e-44e0-8345-66adaac3e040	2018-03-04 14:31:13.962503-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
30259b5b-9821-4213-9907-3068d3f3cb27	2018-03-04 14:31:13.965503-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
13486e82-85d6-4acc-8367-de3c668f2bff	2018-03-04 14:31:13.967503-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
52e49035-9eb2-4758-9ca9-fe94498f9fe2	2018-03-04 14:31:13.970504-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6bc9ca6a-87f6-4c87-bf28-7cc9d240b6cf	2018-03-04 14:31:13.973504-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fa4955da-9dda-437f-9f34-b29b284f1add	2018-03-04 14:31:13.975504-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5f6c4591-7700-4bc6-8b0b-82d849638f51	2018-03-04 14:31:13.978504-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
52de552a-de09-4900-9e05-70b78f669662	2018-03-04 14:31:13.980505-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
570e259d-b512-4ab2-a018-42622e62d852	2018-03-04 14:31:13.983505-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0ea1581b-542f-418d-9f81-419be9f36f4c	2018-03-04 14:31:13.985505-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e35fd588-4541-413e-801f-25b280f837e9	2018-03-04 14:31:13.987505-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3308e05a-67f3-4081-8eb7-d6ee2ec05a11	2018-03-04 14:31:13.990506-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a46c97e6-e597-4e76-bfa8-b37c819fce82	2018-03-04 14:31:13.992506-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
b9a80d2e-43a4-4413-9461-ced2d8f90a5f	2018-03-04 14:31:13.994506-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b5897039-23dd-48eb-a237-7bde7e311a0c	2018-03-04 14:31:13.998506-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
82f1b7a9-aa04-4b7b-a000-30b4c4171150	2018-03-04 14:31:14.001507-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a191b278-cba7-4b3b-b865-24386a366eef	2018-03-04 14:31:14.003507-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6eedc79c-1dee-420f-b9ab-1d19376fcdad	2018-03-04 14:31:14.005507-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
18bdd65a-a7be-470f-bf9d-6203e1dd02e4	2018-03-04 14:31:14.008507-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e738e082-d0e4-4c9c-8f5b-0a3e9ad0287f	2018-03-04 14:31:14.010508-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
be1a23a8-7dd2-493c-8542-3ee8d9921695	2018-03-04 14:31:14.012508-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
2993e7ad-a970-48f1-9a81-511d8e3d67bc	2018-03-04 14:31:14.015508-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
98a99d52-df0f-4ee6-90f8-0938dd6dda2d	2018-03-04 14:31:14.017508-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
b44b11be-6f12-4abc-9862-dc40e6a7c1b0	2018-03-04 14:31:14.019509-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
49aab0fc-3efe-4767-b71d-3dd0df356595	2018-03-04 14:31:14.022509-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
6d25a623-80b5-46eb-841f-8c44c4b276d6	2018-03-04 14:31:14.025509-06	3	[22582] D 15 VESTIBULE 422 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b0da4853-0ff6-4953-a482-1b0b47bec4ce	2018-03-04 14:31:14.266533-06	2	[22583] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
de0557e6-e9f1-46d1-b9f9-3f0f645e1116	2018-03-04 14:31:14.270534-06	2	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
e4b0ec0f-614e-4996-aeb5-d6a6599f398c	2018-03-04 14:31:14.272534-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1d219d61-f933-4436-9aa2-3b49f3f57e40	2018-03-04 14:31:14.275534-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
20849bf4-65d7-4caa-8589-859edc96da88	2018-03-04 14:31:14.277534-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
3cc0bdac-aed4-4df1-bafd-64e1adee799a	2018-03-04 14:31:14.280535-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4780ae65-e33c-470d-9ba7-10b94f64a98a	2018-03-04 14:31:14.282535-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
08748c03-c7de-4209-8964-3f21dbfd22c8	2018-03-04 14:31:14.284535-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fa934da2-12de-42d6-adc3-cdf3c6f3ec74	2018-03-04 14:31:14.287535-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0daf7997-8ef5-4235-a7a9-a97945e60398	2018-03-04 14:31:14.289536-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
4cd40e83-7e89-4648-ac2d-0204dab11c40	2018-03-04 14:31:14.293536-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
b07b42f3-6c92-47d7-a915-fcdfca449f32	2018-03-04 14:31:14.296536-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ca0d37ec-ed71-4a0f-8c3c-1b8d3fcc2b24	2018-03-04 14:31:14.298536-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5533107d-bd2d-4e8e-a841-f068ba463fc8	2018-03-04 14:31:14.301537-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1e1b3aeb-863b-4ec4-b443-7dee1116d38a	2018-03-04 14:31:14.303537-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4f5148ff-e712-4551-81ea-db54e584f340	2018-03-04 14:31:14.306537-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c7d778d9-04b2-4da4-b691-6cb7845510d4	2018-03-04 14:31:14.308537-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
14e141e9-e7eb-42d1-8ffd-6f960add7505	2018-03-04 14:31:14.310538-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
13145ddd-531b-409e-a9fe-0986bf1410e2	2018-03-04 14:31:14.313538-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f430981f-a552-47c3-951e-2b8249f216a2	2018-03-04 14:31:14.315538-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
140d4d73-c774-4793-a4f2-107f91afbfd2	2018-03-04 14:31:14.317538-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
de23a103-d9bc-4271-8191-ccaa42be560a	2018-03-04 14:31:14.321539-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ac50b066-0c53-4281-a323-65673724fd95	2018-03-04 14:31:14.325539-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e55a28a5-2d07-478f-b3b1-f7356a33b86e	2018-03-04 14:31:14.327539-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ddf528e8-ff2f-4f98-804c-b521fd0369b1	2018-03-04 14:31:14.32954-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9bf1dc4c-988f-4ef7-9c2a-fff14adfed5a	2018-03-04 14:31:14.33254-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7f8b2076-86f3-4858-a8f3-9486bfd0cff8	2018-03-04 14:31:14.33454-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
673d7031-7f8d-4c52-a8bc-2f7631128adb	2018-03-04 14:31:14.33754-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3f424fd7-ff1c-408c-a89d-7ee1d1646b71	2018-03-04 14:31:14.339541-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
8bbf8e41-f920-4957-a32e-555dffbb3040	2018-03-04 14:31:14.342541-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
abdd1f3e-f7d2-492b-ade1-47d9da6b9e3c	2018-03-04 14:31:14.344541-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b416b75d-49b8-423c-9671-413b2bba6836	2018-03-04 14:31:14.347541-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
77ce8538-f706-4896-a556-c43fdd4df5bd	2018-03-04 14:31:14.350542-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
17196044-4fe4-40ae-bfa9-ceb69ad8dd67	2018-03-04 14:31:14.353542-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d7653021-cb3c-415c-9588-cc0f1bc1d26e	2018-03-04 14:31:14.355542-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
f475ba4d-c505-44bf-a5e9-9149dc10a998	2018-03-04 14:31:14.358542-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f1271f7f-b689-45b7-a587-c7669cfabe96	2018-03-04 14:31:14.360543-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
602a9aa1-8c48-4b8c-b928-f5eb6326891d	2018-03-04 14:31:14.362543-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
19888161-6f85-465d-b4cd-6b709d58850b	2018-03-04 14:31:14.365543-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
be51c659-ad1e-44e7-be25-bbd11c2bcbb5	2018-03-04 14:31:14.366543-06	3	[22590] D 23 DETENTION HEARING 443	[21041] OSSI-DNOVAK	[293] master	\N	\N
9e413875-f1d6-4c7e-a469-5f7ce37c9a7e	2018-03-04 14:31:14.607567-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
47194197-94e0-403b-852b-f6a3d8e6377e	2018-03-04 14:31:14.610568-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ad49de76-555f-47f6-ba7b-5560cfad4d8e	2018-03-04 14:31:14.613568-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
75a4585c-5f6d-4357-9350-121617705387	2018-03-04 14:31:14.615568-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
822e5341-48c7-4bae-b86e-5e6a09eb0716	2018-03-04 14:31:14.620569-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2cad951c-6ea4-4043-a2d2-8c2d8bddab27	2018-03-04 14:31:14.622569-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5365aded-bfc0-4e92-b187-c1c629fa54fd	2018-03-04 14:31:14.624569-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c108fa9b-f49c-4de4-9229-bb59bb531164	2018-03-04 14:31:14.627569-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
5db9c858-9a35-4550-9ea3-b6f7d161be75	2018-03-04 14:31:14.63057-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
78ab19cc-f9ee-4cf1-9b07-fd946b453e55	2018-03-04 14:31:14.63257-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ebb46be9-bafa-4a8c-aed7-83b1be391500	2018-03-04 14:31:14.63557-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b18bd764-7923-42f5-b7b8-829ee2ae666f	2018-03-04 14:31:14.63757-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
274f8c5f-d733-4568-a6ff-688c9e8e99b5	2018-03-04 14:31:14.639571-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a21c98a5-9c92-4151-b320-6b13237cddf0	2018-03-04 14:31:14.642571-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e8da6d0a-82f7-4032-a709-33aab93c4c99	2018-03-04 14:31:14.645571-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
5e096f5d-1992-4795-a6f8-6a83d0dde15b	2018-03-04 14:31:14.648571-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f6cba1d2-b410-441a-98ac-5af003d3099b	2018-03-04 14:31:14.650572-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0ab12917-ed19-4044-9f21-1c6298915881	2018-03-04 14:31:14.652572-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c62ccad6-3484-4f08-8265-d8608d1fd850	2018-03-04 14:31:14.655572-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
a8e4b6ee-01b1-442a-b16c-c50e49673044	2018-03-04 14:31:14.657572-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
88811339-f66b-4dc5-ba77-7b0146e318b4	2018-03-04 14:31:14.659573-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
24d9ad61-f6b9-4cb9-bdf0-46c9557021ba	2018-03-04 14:31:14.662573-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d911345b-6d8a-4188-b322-11fbf7dd883e	2018-03-04 14:31:14.664573-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7161673f-a5f1-400d-9e95-a3bdb6760755	2018-03-04 14:31:14.667573-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a1e7ab14-ccce-4049-8749-6088102a763f	2018-03-04 14:31:14.669574-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
31ef2835-2020-4d3e-8630-1522f0435cae	2018-03-04 14:31:14.672574-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ce97e108-9cd0-438e-acfe-ee1af3d9d892	2018-03-04 14:31:14.675574-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
792ced4f-50f3-4017-a5e8-d3642adc6d87	2018-03-04 14:31:14.677574-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0bfa40ea-2d93-4b4f-89a3-4615e97ce7da	2018-03-04 14:31:14.680575-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1832bbd9-235b-4d4c-9607-007dae1689ad	2018-03-04 14:31:14.682575-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
eeca5e59-6598-40dd-8295-fe68f218df64	2018-03-04 14:31:14.685575-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0d6e1d12-5673-4bf1-a949-7a7bc532a4a3	2018-03-04 14:31:14.687575-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
804a1b4c-f9c3-4f09-9b04-d95fcdf3de97	2018-03-04 14:31:14.689576-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
12f5509b-b32e-487e-a613-9b7e23fe2098	2018-03-04 14:31:14.692576-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
dbfcf5ac-b5a7-48e5-ab61-8b0d45a26b9d	2018-03-04 14:31:14.694576-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
5f41a820-9a09-4cde-b82b-41d63efdd490	2018-03-04 14:31:14.697576-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
5afb21b5-8bce-4dc8-a05f-5481aeff47c2	2018-03-04 14:31:14.700577-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
10eef871-8d01-4b77-bc6c-773dfec71ab0	2018-03-04 14:31:14.702577-06	3	[22575] D 8 MA 410 	[21041] OSSI-DNOVAK	[293] master	\N	\N
48c8d1bc-3a12-46fe-8443-8b2095c18772	2018-03-04 14:31:14.941601-06	2	[22583] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
47038615-8d34-4803-b690-71a7bfcb61d5	2018-03-04 14:31:14.944601-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cf7fda7d-1eba-4b8b-aee9-955ede80fdbf	2018-03-04 14:31:14.947601-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4f19b424-ba68-4bfd-ab4b-a374d342b683	2018-03-04 14:31:14.950602-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
93ea11c7-36a8-4f29-828e-a2a2a3cc841d	2018-03-04 14:31:14.952602-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a2bbc388-e9d8-4d2c-8d8f-a9b40f532d1f	2018-03-04 14:31:14.954602-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5c1fc41f-d72f-4646-aef0-b666ae4a2df9	2018-03-04 14:31:14.957602-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
400a1e2f-a955-4048-befa-1adc3bab70a7	2018-03-04 14:31:14.959603-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c6bc9d9b-dc74-4d25-afcb-46b8845ea3ab	2018-03-04 14:31:14.961603-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
9509f72c-916b-4fc1-aed4-ec5b76665b70	2018-03-04 14:31:14.965603-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
21c21ab0-ceda-43a3-84f1-d97aed67d9f4	2018-03-04 14:31:14.968603-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
513abac2-8478-4975-b5d9-fc58e406e390	2018-03-04 14:31:14.971604-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fc94ab47-1cb0-4130-9b15-69a369ae48b1	2018-03-04 14:31:14.973604-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
25c4d59d-2ce2-44ae-9597-c86369a8ac93	2018-03-04 14:31:14.975604-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
08b447c0-1586-444a-882d-a206df7e33e1	2018-03-04 14:31:14.978604-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
953930cf-f612-48ed-baf5-98bf42f97c33	2018-03-04 14:31:14.980605-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
89106070-cdf7-4dc7-a6c1-549be1962074	2018-03-04 14:31:14.982605-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d834fdcf-8aef-4d78-b5d1-4578cd9dbbd6	2018-03-04 14:31:14.984605-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6e32b6e8-8aca-4001-8fe2-82015808672b	2018-03-04 14:31:14.987605-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c0b69d6d-c5c5-49bc-ac5f-23e3c4ff7345	2018-03-04 14:31:14.989606-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
a690eab3-cab2-4051-9450-735a65b49b6a	2018-03-04 14:31:14.993606-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0451f32a-2fe5-4b39-8d45-f9f8d66e631d	2018-03-04 14:31:14.995606-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
80645509-31b0-4a86-bb82-20c0729a2dea	2018-03-04 14:31:14.998606-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7e52a544-8742-4702-8390-3f0a2efde732	2018-03-04 14:31:15.000607-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cadda358-f8c9-476b-b8cc-af5582d5db12	2018-03-04 14:31:15.002607-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0b4b3dd0-d64a-4347-a0f4-f3133f811b07	2018-03-04 14:31:15.005607-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
af16aa4e-6af0-4f07-b518-8132f362f110	2018-03-04 14:31:15.007607-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
18d6ddc9-6044-4826-85e2-f7fe4f1488a2	2018-03-04 14:31:15.009608-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
16b7ed33-6568-4f19-a239-1cfca52031d2	2018-03-04 14:31:15.012608-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ad315cb8-e235-4bc3-9614-0fdc86a8a898	2018-03-04 14:31:15.014608-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4dd543ec-a6e5-4ab7-82e8-98e2eba097fd	2018-03-04 14:31:15.017608-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
86effcaf-043f-421a-b586-f4dcd8821749	2018-03-04 14:31:15.020609-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5d3f6442-0db6-4f6d-beb4-87fbe069f4c8	2018-03-04 14:31:15.022609-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
908e9ab3-1e28-4be1-b199-4a40080d2c9f	2018-03-04 14:31:15.025609-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
f6e91ce0-d57c-45de-97f7-45a20dee6f4e	2018-03-04 14:31:15.027609-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ca634b02-2989-4264-8933-0ffedcf05bed	2018-03-04 14:31:15.03061-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
ab012656-0036-4c06-8133-fb30925579ec	2018-03-04 14:31:15.03261-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
0cd5b70d-fd68-45aa-9c22-92a2ad529d20	2018-03-04 14:31:15.03461-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
92d85282-5b62-493f-ac21-e07bc41a91a2	2018-03-04 14:31:15.03761-06	3	[22583] D 16 WORK ALCOVE 423	[21041] OSSI-DNOVAK	[293] master	\N	\N
1e533fa7-31a3-45b0-8a8f-5b8fc7ec69ab	2018-03-04 14:31:15.280635-06	2	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
997bbdbc-9009-4e30-b422-0ec69df3966e	2018-03-04 14:31:15.284635-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
eb21c57a-f151-4019-bad8-0c06f1215243	2018-03-04 14:31:15.288635-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
240bf7e0-5456-47f2-9d1a-2efeb28acc96	2018-03-04 14:31:15.292636-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
369f79e6-7c3c-4fbe-bc40-0383e853161f	2018-03-04 14:31:15.294636-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5e413895-a9c6-49a2-8905-a093c86c45ed	2018-03-04 14:31:15.297636-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f48afb33-09f8-4a74-9690-5f50ddb67859	2018-03-04 14:31:15.300637-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b35313af-8231-488c-af2b-a0f5123001bf	2018-03-04 14:31:15.302637-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
243ced05-b2c2-4e08-be68-0d88542d6f27	2018-03-04 14:31:15.305637-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
b2f61aee-a1a8-4888-b64d-1bb0e0fd2477	2018-03-04 14:31:15.307637-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1e3e7ada-6cc1-4078-8aaa-756c05c8859b	2018-03-04 14:31:15.309638-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2f3959db-fedf-451f-bf56-326da4d4d0f1	2018-03-04 14:31:15.312638-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
93e28913-7d4d-4df7-b5bc-928750e69671	2018-03-04 14:31:15.314638-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
52b30e32-cbcd-4a79-af83-6ba4d116b363	2018-03-04 14:31:15.316638-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0c641a68-3877-4ba0-b037-1e3edb25d017	2018-03-04 14:31:15.320639-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
777ea603-e577-481c-a84b-a5eb1298d89f	2018-03-04 14:31:15.322639-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
01678908-baba-41d9-96ed-bf390a700dd3	2018-03-04 14:31:15.325639-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9019d3bb-ccc1-4ab3-aae0-27f53691d9c5	2018-03-04 14:31:15.327639-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9234764c-0c96-4386-99c0-b20d08d7fcaa	2018-03-04 14:31:15.32964-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
8379f8f3-0286-4525-82c2-120409443287	2018-03-04 14:31:15.33264-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b3e3c491-dc1a-4a77-bd6d-37d8da4ddc28	2018-03-04 14:31:15.33464-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
17b6daf9-f67d-4e6c-b041-3c90339a1d56	2018-03-04 14:31:15.33764-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
255f7949-8ae4-4120-aafd-d7ef82501e45	2018-03-04 14:31:15.339641-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
485f9c85-7a17-475e-b570-7989157f33cc	2018-03-04 14:31:15.341641-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7e2b6c2a-3bd3-41f3-9940-373094040943	2018-03-04 14:31:15.344641-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
67be0fd3-2313-493f-8ca0-8c536644a998	2018-03-04 14:31:15.347641-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
57b00b1a-e527-40e0-b568-e99803c21301	2018-03-04 14:31:15.350642-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
73878287-df4f-4a0b-8d6f-e2b672e87960	2018-03-04 14:31:15.352642-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2bda4614-83a4-4ff7-abe4-4f4330467ba7	2018-03-04 14:31:15.354642-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f850246c-6819-4d38-b5e2-a56d18ebc5fa	2018-03-04 14:31:15.357642-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
18475b9b-85f4-4ed7-bf3f-e80dad54f296	2018-03-04 14:31:15.359643-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d2ce4d1a-0c03-4a82-b881-d8d1be0badcd	2018-03-04 14:31:15.361643-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4b8faee8-e784-4df3-948b-5ab996ef6174	2018-03-04 14:31:15.364643-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
ccb299fb-285c-42dd-bd66-f21fba5fae43	2018-03-04 14:31:15.366643-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
abfcd20b-2d66-45fd-8da8-9e3c2e4509dc	2018-03-04 14:31:15.368643-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
dfaf6822-74bd-4a3f-9cd6-e1f791c0e849	2018-03-04 14:31:15.372644-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
a976f2a2-c721-4dd7-92bf-2cd14154bb5f	2018-03-04 14:31:15.374644-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
3bf1a9ba-10db-4f9c-80ea-8fa5bb7f1003	2018-03-04 14:31:15.376644-06	3	[22591] D 24 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
db1e187d-e84e-490f-80e0-d6e2cd1ce3e2	2018-03-04 14:31:15.615668-06	2	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
38867ecb-d229-4255-ad09-cf962d5b9ebe	2018-03-04 14:31:15.619669-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
b3a2ce21-57c4-4d22-b33c-6a53a37fb5be	2018-03-04 14:31:15.621669-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e493e25d-34b3-41a7-8dea-03397a284b83	2018-03-04 14:31:15.624669-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0888db7c-e4c6-42f7-9e63-6ed9a32d5a8f	2018-03-04 14:31:15.626669-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a8357add-3f07-47d0-ac3d-709a3ac7fc0b	2018-03-04 14:31:15.628669-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2bf9acdf-5ace-42dd-8c06-b5d958894085	2018-03-04 14:31:15.63167-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
e1db9066-205b-4719-8457-4bd7a02f12e5	2018-03-04 14:31:15.63367-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
73c0f4b6-32d8-430c-a2a4-e174217f178f	2018-03-04 14:31:15.63567-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
13dfa1a8-0768-497c-a1d0-c2fb4753f19f	2018-03-04 14:31:15.639671-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
03d2dd1c-17ce-446c-9dd5-1f9a051b167f	2018-03-04 14:31:15.642671-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
023289df-7e02-40a1-a886-98eae0aed2bc	2018-03-04 14:31:15.645671-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0a792f26-4f49-4081-9164-c900a7dc1db7	2018-03-04 14:31:15.647671-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
49eb2a8e-0042-4525-a3a9-0ddda6ce654b	2018-03-04 14:31:15.649672-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
37fd39b2-d3c7-4d8b-81fc-f1f9586d9ba1	2018-03-04 14:31:15.652672-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
459e5f8b-706b-41a4-b505-593df573c7e2	2018-03-04 14:31:15.654672-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5d5d2258-3c56-4c30-b02a-85f3ad179e77	2018-03-04 14:31:15.658672-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c2d5b3dd-64c8-45ce-b018-046b033865a9	2018-03-04 14:31:15.660673-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
ea942f5c-b161-4fba-a4a9-2d09f250f573	2018-03-04 14:31:15.662673-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4c257977-9957-4757-9801-1659980018d4	2018-03-04 14:31:15.665673-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bac08a64-7411-4178-b4f6-ae5b9935eecb	2018-03-04 14:31:15.668673-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
93ae5051-9746-4e1f-9c1b-5838c4f9d78f	2018-03-04 14:31:15.671674-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
08679984-707e-44e5-a1e8-b23ac435a013	2018-03-04 14:31:15.673674-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
89c7b89d-5755-4242-8723-bef57aa9f1a3	2018-03-04 14:31:15.675674-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
a1b22b66-79fc-424f-bece-00ea66d20f11	2018-03-04 14:31:15.678674-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e9a6dc3c-b8a5-4e45-adbf-044ac3e3f389	2018-03-04 14:31:15.680675-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
f8da44ab-a18a-46af-aae0-3ae2b57cfb58	2018-03-04 14:31:15.684675-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a6c2c933-2364-43bc-932f-0beb098b7ee4	2018-03-04 14:31:15.686675-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c119f4a3-2ea8-4974-8100-f84df1f82f20	2018-03-04 14:31:15.689676-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9bd7c2c9-83d7-44ba-9b81-5f17454bda5e	2018-03-04 14:31:15.691676-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2f567492-a968-4c94-ae4c-d27471b9d32c	2018-03-04 14:31:15.694676-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8c1e9731-02c9-4b81-b0e5-9f17bbe0f9b0	2018-03-04 14:31:15.697676-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
93650aac-8e68-47c4-8a87-37f8e0a8ff29	2018-03-04 14:31:15.699677-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
58e5553a-1628-44a1-b667-c39d8ab21ba2	2018-03-04 14:31:15.702677-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
657f1d1b-2395-4110-b6e3-edfb618c1623	2018-03-04 14:31:15.704677-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
be3e8651-137c-43a8-8171-61bd0026e3d5	2018-03-04 14:31:15.706677-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
c3263399-2ca6-4f7c-a5a3-3ff1b35edf70	2018-03-04 14:33:12.64937-06	3	[22592] D 25 CLASSROOM 463 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a722958f-754d-4921-992a-182fc4e1e357	2018-03-04 14:33:12.901396-06	2	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
1b226a79-21d3-46e9-9549-6f218a99a08c	2018-03-04 14:33:12.904396-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f7c8d5c4-c62d-4328-8e39-4b0b339fe7a4	2018-03-04 14:33:12.906396-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c65cc21a-e568-4749-a63c-319a7bb8a142	2018-03-04 14:33:12.911397-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
643ea39a-ee9f-47da-ab94-14c7cfefc477	2018-03-04 14:33:12.915397-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d4b62c82-b93b-4d2d-9f8a-f5991066f91e	2018-03-04 14:33:12.917397-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
080118cb-e1c4-4984-9c9c-291b579a4b61	2018-03-04 14:33:12.920397-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
067e2959-1f72-4d21-af55-94d4a0efb47d	2018-03-04 14:33:12.922398-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c6325025-546b-40ac-b8db-51ce23cf55cb	2018-03-04 14:33:12.924398-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
85536e4c-6bea-4505-9d53-db635f95f64e	2018-03-04 14:33:12.927398-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
499f3478-beb7-45a9-945e-a881e24708ad	2018-03-04 14:33:12.929398-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4bbc2fa3-b560-4779-a99c-ba1fb13756d2	2018-03-04 14:33:12.931399-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
abb0b559-ae29-4544-b0de-dcc0e5ca9cda	2018-03-04 14:33:12.934399-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
86573e15-1bed-46be-8070-216a81594be1	2018-03-04 14:33:12.936399-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
dd177eb3-348f-4be0-9566-38288dda382f	2018-03-04 14:33:12.938399-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0cc48d37-9646-457a-89aa-c3563c47f79c	2018-03-04 14:33:12.9424-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b0f3cefd-1119-42fe-8cb0-fbf6c32cef5d	2018-03-04 14:33:12.9454-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
47050e29-94ba-4e9e-9699-e097f8acea06	2018-03-04 14:33:12.9474-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f8db6351-6717-417e-9ee6-7f4b19bc7e16	2018-03-04 14:33:12.9494-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c69534f5-ef19-4f95-b763-d674c34877fb	2018-03-04 14:33:12.952401-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7857d68d-769c-4632-b20a-159b2e1532c0	2018-03-04 14:33:12.956401-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e307656f-b3d1-4903-8392-4427ceddebc5	2018-03-04 14:33:12.958401-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
65563625-506e-40d6-b94a-31e6310dbd8f	2018-03-04 14:33:12.960401-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
268d353b-e840-4d12-98b6-1c2077fadbff	2018-03-04 14:33:12.963402-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
31240a86-fd24-4131-814c-fa3ee3b60791	2018-03-04 14:33:12.965402-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
aef9ef0b-1be4-4885-8894-952ecc6c40f1	2018-03-04 14:33:12.969402-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
11679b6e-371b-4f80-85eb-5b0be621eefa	2018-03-04 14:33:12.971403-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7631da4a-fe4f-4d73-a8b3-1f2ddce31f3f	2018-03-04 14:33:12.974403-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9e1914f0-1bc0-4165-9dc4-37891b4a310c	2018-03-04 14:33:12.976403-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a3554d9f-575a-4757-9151-0390c22a1a98	2018-03-04 14:33:12.979403-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b5706031-3494-47fb-a9e2-44b446c882f7	2018-03-04 14:33:12.981404-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
c43a190e-4b6f-41c5-bb5e-0b610da9237b	2018-03-04 14:33:12.984404-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fa87ba24-58d1-42c5-97b7-c0d582abe5e5	2018-03-04 14:33:12.986404-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
4bf2a920-4ec1-41cf-bd9c-5675a6000acf	2018-03-04 14:33:12.988404-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
8af98c66-3714-44e6-84be-ee9f7efab621	2018-03-04 14:33:12.991405-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
f6dad20b-ba79-417c-b8c6-ad602ee57d91	2018-03-04 14:33:12.992405-06	3	[22593] D 26 CLASSROOM 465	[21041] OSSI-DNOVAK	[293] master	\N	\N
739fa976-412f-4dc0-a1d8-b995cec93ccf	2018-03-04 14:33:13.235429-06	2	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4acb7591-01fc-44a4-b455-761b9a0e6c11	2018-03-04 14:33:13.240429-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a48ea1b6-4ba9-477a-9090-42f3cbc065a7	2018-03-04 14:33:13.24243-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
dae94fc4-512c-4682-9610-e5b1ecc7c002	2018-03-04 14:33:13.24543-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2796b39f-9df4-4f6a-862f-2c02c876d561	2018-03-04 14:33:13.24743-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
e5e6aa73-8eb7-4f30-9f44-2030f9b7dac0	2018-03-04 14:33:13.25043-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
002b94c1-b04f-4f26-93d1-4fcea072c425	2018-03-04 14:33:13.252431-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c0bd95af-b9ea-423a-b570-0347f1257bbb	2018-03-04 14:33:13.254431-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
072fed8f-b590-4da1-a4d4-7f2bff93bee4	2018-03-04 14:33:13.257431-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6fc8d23a-dbb4-440b-bbb0-10f2c59cd721	2018-03-04 14:33:13.259431-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
676e204a-9a99-40d4-89f6-f77c1af0f02e	2018-03-04 14:33:13.261432-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a1703ca0-8e13-4bee-8d3b-00e5e65caf1d	2018-03-04 14:33:13.263432-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
77a02179-e760-44c7-affa-972c41c9f1ed	2018-03-04 14:33:13.267432-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
844d38ec-59b9-4869-baa6-bb03789530f9	2018-03-04 14:33:13.270432-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ce98ab3e-e3f5-456b-8c46-501ee4b411b8	2018-03-04 14:33:13.273433-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2dfe1fdb-f60b-4ab0-bc46-e126340245d3	2018-03-04 14:33:13.276433-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
54d6a16e-717e-4cdb-a984-ac68d0291a71	2018-03-04 14:33:13.278433-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1688777a-8d70-4573-82d6-e7796ad25ba4	2018-03-04 14:33:13.281434-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fe9159da-c521-41b1-8363-b58493573350	2018-03-04 14:33:13.283434-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
079fbc7a-458d-413d-a02a-323f83da2b3e	2018-03-04 14:33:13.285434-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
99b1ef3b-ee24-4ef1-b953-129e4bccf2a0	2018-03-04 14:33:13.288434-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1ed69acc-0d55-4d02-beae-dfa96c0f2256	2018-03-04 14:33:13.290434-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
7a4fd86c-e3e1-4238-a2aa-98167b8bbae3	2018-03-04 14:33:13.294435-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
505100de-c86d-4c16-9f87-cb79f775c1e6	2018-03-04 14:33:13.296435-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
da799b34-7e56-427c-bd8a-b6434c8860d0	2018-03-04 14:33:13.299435-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cccea48d-b256-467b-8a4a-34059de1cee5	2018-03-04 14:33:13.301436-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d9206c15-68b9-4df3-9e04-931f8e590e6a	2018-03-04 14:33:13.303436-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b82f0d68-7602-48c8-aad8-9990a6b18b14	2018-03-04 14:33:13.306436-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c2304a45-9e39-4e4b-879f-fe945d466a4d	2018-03-04 14:33:13.309436-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4341be91-89b0-4436-9cf5-e1ec74f0e1a5	2018-03-04 14:33:13.311437-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
60ce0263-efee-4de8-bcef-7148e586591f	2018-03-04 14:33:13.313437-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7360f696-c3af-4638-831e-5b38faf689d9	2018-03-04 14:33:13.316437-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
6048d944-d5c8-416c-97a2-65c9c863c130	2018-03-04 14:33:13.318437-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
01ed1ea8-0f78-4f00-a4b5-755188804192	2018-03-04 14:33:13.322438-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
42b872e6-c3d1-46a8-870a-c3232b5d38a2	2018-03-04 14:33:13.324438-06	3	[22594] D 27 CLASSROOM 465 	[21041] OSSI-DNOVAK	[293] master	\N	\N
73cb4d57-4db4-4835-9fde-033937cbc98b	2018-03-04 14:33:13.564462-06	2	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
16be7bbb-2143-431a-a49e-b87b3a867562	2018-03-04 14:33:13.568462-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
84d5aa37-8108-4733-9d53-00b3c64aef11	2018-03-04 14:33:13.570462-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3a1b4cc6-13ae-445a-9ed2-e904b132a233	2018-03-04 14:33:13.573463-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
8f42243b-b352-4234-96dd-4ac7f9c175e5	2018-03-04 14:33:13.575463-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
4f291c40-1b0e-408b-9493-79d23879793d	2018-03-04 14:33:13.578463-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
be586d76-7b2f-4112-a0ec-cd9b78755b23	2018-03-04 14:33:13.581464-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b2c8da39-2d67-4b7d-9132-068167ba9db6	2018-03-04 14:33:13.583464-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
075c9108-c879-4b14-af0f-5e1ef12e4fbe	2018-03-04 14:33:13.586464-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5cf2286c-7729-4826-8443-94ccd40569c0	2018-03-04 14:33:13.588464-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3e4f4b35-bc30-4a83-a4e9-80a59878ae47	2018-03-04 14:33:13.592465-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
79f9977c-263f-4689-a6f6-787969bb53cd	2018-03-04 14:33:13.595465-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef0cce3b-5848-424d-ad47-2ef5557827d8	2018-03-04 14:33:13.597465-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
979fa85f-41a6-42a2-8e41-6cc2b9068fdf	2018-03-04 14:33:13.600465-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
caad287c-3e5d-4e54-8532-2f176d8217d2	2018-03-04 14:33:13.602466-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
5636a3c8-f085-4476-8f91-3be74e984886	2018-03-04 14:33:13.604466-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d3741de0-d945-447d-b139-30333cea4064	2018-03-04 14:33:13.607466-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
01b33fb0-208c-41ab-96f1-b95c5bcb6deb	2018-03-04 14:33:13.609466-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5ae4c493-fd25-45d7-a816-431f67ae17fe	2018-03-04 14:33:13.611467-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b0a67d76-4e25-4f60-8023-d919e84f8855	2018-03-04 14:33:13.614467-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0bfb7e69-2253-4b3b-b1fd-93a28dcbf2a9	2018-03-04 14:33:13.617467-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
3305e9d1-2818-47a1-b53a-d1a6806d8479	2018-03-04 14:33:13.620467-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0f9d225e-cd55-4639-9622-31c4d75f7ee3	2018-03-04 14:33:13.622468-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
09d2f75b-8cc3-49be-be84-8c29298b0a37	2018-03-04 14:33:13.625468-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a73b7652-23d9-4d77-a36a-e3b3269f2889	2018-03-04 14:33:13.628468-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fb569283-fbfa-414e-ae0d-da20478ab1be	2018-03-04 14:33:13.630468-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4fd4b231-6cf2-47b1-85fb-abcfd5fd0f57	2018-03-04 14:33:13.632469-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a52f55bc-4341-4a9a-a5eb-5578d35026e6	2018-03-04 14:33:13.635469-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
da50f725-86b1-4ca0-aac7-f69ee754e1fd	2018-03-04 14:33:13.637469-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
b3c2fa23-1108-49a0-b380-b3117f9d0ef5	2018-03-04 14:33:13.640469-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6a9ff8b5-cc2c-4674-bef2-74612c7867c9	2018-03-04 14:33:13.64247-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
57071442-ebeb-4f4e-bf14-fae1cb2abebd	2018-03-04 14:33:13.64647-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
ad4335d5-6d58-4f03-9a9f-de1d1598bfe8	2018-03-04 14:33:13.64847-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
ecbaf6d1-2abe-447a-bafa-09e02f435be5	2018-03-04 14:33:13.65047-06	3	[22595] D 28 CORRIDOR 461 	[21041] OSSI-DNOVAK	[293] master	\N	\N
739ac71a-641f-4bbc-be62-cd56672855bf	2018-03-04 14:33:13.891495-06	2	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
12212338-9d0b-4dce-8053-b012134cefdd	2018-03-04 14:33:13.894495-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c6224997-7aea-4f3a-9580-3b42af2d252f	2018-03-04 14:33:13.897495-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
88330cfb-2f7e-449b-82d8-de5aef407626	2018-03-04 14:33:13.899495-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
590d1efc-c9e3-42d0-9386-80b1f78c4f2f	2018-03-04 14:33:13.902496-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
df560958-e5f1-4eec-b72a-d26a120f2ba3	2018-03-04 14:33:13.904496-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b12d7d5a-a12c-49cd-87e4-511f17b733b5	2018-03-04 14:33:13.907496-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7135460a-a0c3-4a5d-bf56-0a3cc6015be1	2018-03-04 14:33:13.909496-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d3c4af5c-2ecf-498a-8b0b-e1dc55d104f2	2018-03-04 14:33:13.912497-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7e7c00cd-e094-4944-9cca-d38c0f8c1dd3	2018-03-04 14:33:13.915497-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
aff923b3-9ce1-405c-88ef-70521002a83b	2018-03-04 14:33:13.918497-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
06b6062b-2298-4114-88c8-8ef75f1453c5	2018-03-04 14:33:13.921498-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b72a7a6c-d566-4325-8bfd-0961b6bc6495	2018-03-04 14:33:13.923498-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bde6d36e-be12-46e1-acdf-683144ee9c10	2018-03-04 14:33:13.925498-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
c18f0206-d1ee-4ef6-bed9-569fb796988f	2018-03-04 14:33:13.928498-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2ce5d831-944e-47d9-9dfe-96022e656266	2018-03-04 14:33:13.930498-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
36bb98a0-6987-4448-ad8d-01a06cb0e8af	2018-03-04 14:33:13.933499-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4dc3266a-cb75-410d-b52e-736a7d211348	2018-03-04 14:33:13.935499-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
08f52443-8eb3-4444-81c7-8aec335dd8ce	2018-03-04 14:33:13.937499-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
96bcf2dc-900d-4ee1-9dca-a40017bfd87c	2018-03-04 14:33:13.9415-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
cbc70fc0-d180-44c1-8b38-4c9aec5cd8d2	2018-03-04 14:33:13.9435-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bd2a3a64-82e7-4eac-8758-d996c39ae2ae	2018-03-04 14:33:13.9465-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
51e5c31d-5446-4516-bca7-713452ba4884	2018-03-04 14:33:13.9485-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
80ea9e5c-33a1-4810-a472-e1c3627f99e8	2018-03-04 14:33:13.9505-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0ca8d1b0-b492-4bc9-b19e-1aa06d7c14e5	2018-03-04 14:33:13.952501-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
674bc214-fa25-4bdf-9b7d-05eaa2d6c185	2018-03-04 14:33:13.955501-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1e2b9a38-027f-49eb-938c-8136f34bf1ef	2018-03-04 14:33:13.957501-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
10fd4cb2-a568-4641-9644-83c9219b6bda	2018-03-04 14:33:13.959501-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
f36a0bb6-0334-4af7-ab54-4287b887b5d3	2018-03-04 14:33:13.962502-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
be7287e9-90f0-4278-8b2d-313704317b5b	2018-03-04 14:33:13.964502-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
d6c08931-5d4e-48d1-8d44-095e59eb0051	2018-03-04 14:33:13.968502-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
ae930e7d-cb31-4fe9-b6d0-14ce6033708f	2018-03-04 14:33:13.970502-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
69253cd1-0d46-44fc-a1c1-09ef5474fee5	2018-03-04 14:33:13.972503-06	3	[22596] D 29 CALMING ROOM 456 	[21041] OSSI-DNOVAK	[293] master	\N	\N
27f72a9a-2fa2-489d-b811-967201d5dce2	2018-03-04 14:33:14.215527-06	2	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0e408c69-68df-4d84-914d-72007bd2641a	2018-03-04 14:33:14.218527-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
9c432b34-e448-4f0d-b2df-2ec587ad3e7a	2018-03-04 14:33:14.221528-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
249f26f7-1951-4bb8-8865-5ad4c497890b	2018-03-04 14:33:14.223528-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b114adec-d624-4795-b153-971068302769	2018-03-04 14:33:14.226528-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ec424cb6-7f18-462d-af5a-e5b1072e7344	2018-03-04 14:33:14.228528-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3c590d57-91d7-4f0c-8e01-5a549f499704	2018-03-04 14:33:14.231529-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
411764e8-fa9c-4b10-97f5-f0f87bbd9eab	2018-03-04 14:33:14.233529-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
20cc4021-eb18-465d-8e5c-d1ed8d0d36e6	2018-03-04 14:33:14.236529-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
acfcdfe2-df11-4c13-8a56-1c60e25a1042	2018-03-04 14:33:14.239529-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fa5dac43-c9fe-47bb-b728-e1ea10f59bb5	2018-03-04 14:33:14.24253-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5fbcb309-ca8a-4833-9470-860c84ea6dc7	2018-03-04 14:33:14.24553-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f1a68183-5b6a-408e-bca4-0869afd2a090	2018-03-04 14:33:14.24753-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
df897ad6-58d5-4977-bb6c-cdd48e560d15	2018-03-04 14:33:14.25053-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8ce305ed-2693-4f88-a690-4351c312a8c0	2018-03-04 14:33:14.252531-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8254c0bb-05aa-4875-a862-b4ed0a3e1cc5	2018-03-04 14:33:14.254531-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
574845a1-a3c6-4c21-aaaf-fc2fd0e36a81	2018-03-04 14:33:14.257531-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
70c42011-82fe-4483-8d8f-328a804bf81a	2018-03-04 14:33:14.259531-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
87ff264c-61ef-4927-ad06-2962aa7d0cc3	2018-03-04 14:33:14.261532-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
d23caacd-5946-4f83-a8e3-b355b0809eab	2018-03-04 14:33:14.265532-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
63db4c14-3caf-43f5-a443-8657b5cf84c9	2018-03-04 14:33:14.268532-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
03c33c58-819a-42ee-9a8d-f4a40c87272c	2018-03-04 14:33:14.271533-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d5c3df67-5dbb-4f3e-8636-51d1604520b1	2018-03-04 14:33:14.273533-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
128994c7-b5b4-4331-8e20-410961b97f80	2018-03-04 14:33:14.276533-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5608c524-8acb-4e1b-8849-a4adc9bf5c38	2018-03-04 14:33:14.278533-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ab52a2e8-eb00-4a8c-933d-9f4607ba6f1b	2018-03-04 14:33:14.281534-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e0123660-390a-435f-be9f-e3b49963ff1e	2018-03-04 14:33:14.283534-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
2babab5c-6404-43aa-96bf-fb7f8c8ec08f	2018-03-04 14:33:14.285534-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
04eeac75-fa42-4965-9768-a3c733c3aec4	2018-03-04 14:33:14.288534-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
c070e378-d1f0-4a5d-bc8f-799e3a840b18	2018-03-04 14:33:14.290534-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
22c6b5ef-7c28-458c-8ef1-66023a044027	2018-03-04 14:33:14.294535-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
9ce626ad-f216-4fe3-8678-712af655934e	2018-03-04 14:33:14.296535-06	3	[22597] D 30 CALMING ROOM 438 	[21041] OSSI-DNOVAK	[293] master	\N	\N
41d0765a-fea4-4cac-9012-8b58ed589dfe	2018-03-04 14:33:14.538559-06	2	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
8f8726dd-d5f4-48d3-be27-2cf9e1ae7904	2018-03-04 14:33:14.54156-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
038e789c-9097-44fa-917e-c8ac7c730f05	2018-03-04 14:33:14.54456-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7a041c82-832c-4435-988b-31e21a348d67	2018-03-04 14:33:14.54656-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
54a1e15e-1154-4677-9a97-2369cfa42d05	2018-03-04 14:33:14.54956-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f3e7bb37-75ad-40a6-aadf-f55c0d9ff95c	2018-03-04 14:33:14.551561-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9b80467e-95c7-422d-9563-96028d193be2	2018-03-04 14:33:14.553561-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9788e9b6-3602-461b-a2ce-9f925afa1a89	2018-03-04 14:33:14.556561-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
7750963a-5c7e-4b2c-b8ce-5429071bad58	2018-03-04 14:33:14.558561-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
82d78eda-4d09-4646-8ac2-816953e5be66	2018-03-04 14:33:14.560561-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
745834a8-4fee-4fee-91b7-606913b02e12	2018-03-04 14:33:14.564562-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
19ec4753-50d8-4285-af67-58b47c9a9cca	2018-03-04 14:33:14.567562-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
fd2d327e-5015-4222-a5d0-f9acc6d99b45	2018-03-04 14:33:14.570562-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
acd37d07-ba03-42c4-a08c-f9f394cbb41e	2018-03-04 14:33:14.572563-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cb003c6e-1e0e-4714-90f8-85a0d41b8b2f	2018-03-04 14:33:14.575563-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7b6df4d8-d8ab-47d8-98bc-1d61f565bb8b	2018-03-04 14:33:14.577563-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
735a4e0f-525d-4d20-baac-5d26c5024762	2018-03-04 14:33:14.579563-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4cec2879-8799-46c9-9973-9f385eb7f1a7	2018-03-04 14:33:14.582564-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
5eb8e5ae-cb72-4a73-be55-d7fb2c53d8e7	2018-03-04 14:33:14.584564-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4f73683a-8fe7-4af7-a813-703a51675477	2018-03-04 14:33:14.587564-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
7b6531cf-b096-4511-b9f3-bc19d8300fc8	2018-03-04 14:33:14.590564-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f2dea2ea-37e9-4b0e-89b4-28f49e14e0fc	2018-03-04 14:33:14.593565-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a9cbe4ed-7eb2-4883-88a2-6b5e886f992b	2018-03-04 14:33:14.595565-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e4eca76d-a3a8-4a02-9e84-08ae56e1143d	2018-03-04 14:33:14.598565-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4829af09-21d5-41a2-b6fa-39714d60e7f6	2018-03-04 14:33:14.600565-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3a893580-c80c-408a-b671-f2ea03df6ea4	2018-03-04 14:33:14.602566-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
57cdde73-b3b4-4eaa-b8f6-3f4b6a87eedd	2018-03-04 14:33:14.605566-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
09b88df9-8597-46f2-a202-776d4501d931	2018-03-04 14:33:14.607566-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
f4a251cb-d9e8-41d3-a17f-da24a5256035	2018-03-04 14:33:14.610566-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
0ca0f90a-0053-47e6-a517-3b0fa5ddbe13	2018-03-04 14:33:14.612567-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
c9ca2a5d-e0b9-48f6-9a70-c76f07caacbf	2018-03-04 14:33:14.614567-06	3	[22598] D 31 CALMING ROOM 439	[21041] OSSI-DNOVAK	[293] master	\N	\N
a3051ec4-5fee-4b5a-887b-7fd5f4c97423	2018-03-04 14:33:14.857591-06	2	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
39b15c17-9973-45b8-8361-f6af959a6093	2018-03-04 14:33:14.861592-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b674a0e7-9fb9-4a71-acb7-a723cea5bb63	2018-03-04 14:33:14.864592-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5210be6a-2f77-425a-8ce9-f04dc334563b	2018-03-04 14:33:14.867592-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c592511a-86db-494b-a5af-dc45a78578a8	2018-03-04 14:33:14.869592-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b383fca7-8caa-4570-92e1-fadc804f96d5	2018-03-04 14:33:14.872593-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
83a83e29-7bbd-4d99-8371-2d35284ab250	2018-03-04 14:33:14.874593-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
3505d81c-9ab4-4f93-a844-33c35805bdf5	2018-03-04 14:33:14.876593-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c3e807bc-d767-4a44-aebe-a10ce5fde76e	2018-03-04 14:33:14.879593-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0de4dfdd-eee9-4bfb-a9b1-38416613f09a	2018-03-04 14:33:14.881594-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
61880454-8ca0-46ae-b724-6b109c165c4a	2018-03-04 14:33:14.883594-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
8c7e52d8-cf6f-4cc9-b308-a6c4e78cca70	2018-03-04 14:33:14.886594-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ce787a51-6ff8-4843-a087-b8accbf5371a	2018-03-04 14:33:14.890594-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8f448613-b82b-4853-bcdf-4b430e0bc3d6	2018-03-04 14:33:14.892595-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b77386c0-9911-4ffe-ace3-3ff1d9d28bda	2018-03-04 14:33:14.894595-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
824be427-16e7-4cec-b8f0-960f758dd0fc	2018-03-04 14:33:14.897595-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a5e2e8df-2d83-4f16-b29a-a44e7a37907d	2018-03-04 14:33:14.899595-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
8d05d000-1e28-47ae-8817-1407b22485c8	2018-03-04 14:33:14.902596-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d470b930-abfa-4e3c-9dec-97eb2a032715	2018-03-04 14:33:14.904596-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
c0cc9e93-86de-4964-9f9a-202f0f0a35fc	2018-03-04 14:33:14.906596-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2219e638-398b-41c0-bb31-bfd72a1fdffe	2018-03-04 14:33:14.909596-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8f4005c9-1cc3-44fc-85b7-1be627a9efc6	2018-03-04 14:33:14.911597-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d8bb7b57-864c-4930-8293-f65515e31d3d	2018-03-04 14:33:14.915597-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0d178942-ed3e-4143-b02f-a799cec228e1	2018-03-04 14:33:14.917597-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b6e28893-3941-41ba-a2d2-49dd5b4806b5	2018-03-04 14:33:14.920597-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
83cff63b-6a10-40f5-b91a-539864f58aed	2018-03-04 14:33:14.922598-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
eba0473f-0dd3-4019-a32d-18f5e1556093	2018-03-04 14:33:14.924598-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
63f90161-9f79-4a1b-8114-7ddea45711a8	2018-03-04 14:33:14.926598-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
2e541fb4-2bc2-4f8e-86a8-6f3470af36b5	2018-03-04 14:33:14.929598-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
281aa16e-f090-4121-a359-af0905a63314	2018-03-04 14:33:14.930598-06	3	[22599] D 32 GYM 455	[21041] OSSI-DNOVAK	[293] master	\N	\N
7c8f8398-b8d1-4609-9001-bfb6be31cb05	2018-03-04 14:33:15.172623-06	2	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8ee35169-004d-44ef-8b5b-4e499ba64271	2018-03-04 14:33:15.175623-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
be476289-05fb-4557-b681-05705dc2069e	2018-03-04 14:33:15.178623-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
366a3a65-a416-48d3-84ca-e67196c8707f	2018-03-04 14:33:15.180623-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1b92a5bb-2337-45d0-ad0b-3fc8e00e89f0	2018-03-04 14:33:15.184624-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
857078cb-7ba4-48b9-8ca8-3e10841c82e3	2018-03-04 14:33:15.187624-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
da4283b2-5dd1-4b3c-b31f-a7963c9a1b1f	2018-03-04 14:33:15.190624-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7e077bf1-02b1-4561-9337-3e24b3737b7b	2018-03-04 14:33:15.192625-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
87bc9ca4-9e16-4f5a-b4ff-0489895d04c5	2018-03-04 14:33:15.194625-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ac3b2bca-ea34-4300-b9f4-d088f96bd65b	2018-03-04 14:33:15.197625-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
421bf5e1-f0f6-43af-bf7d-b6948f51c5dc	2018-03-04 14:33:15.199625-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
279b5261-eda8-459c-92cb-3c6a9610176d	2018-03-04 14:33:15.202626-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c264681d-6d3d-4fba-af80-edaab9567b9d	2018-03-04 14:33:15.204626-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fbbf05c1-ec39-4bcf-8025-e5789257ab2a	2018-03-04 14:33:15.206626-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
372db8e9-1202-4bef-9b04-89661e71a4e9	2018-03-04 14:33:15.209626-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0900aff5-2368-44ed-a328-ccceed3c68e3	2018-03-04 14:33:15.212627-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
80bd9e01-f679-47dc-b014-642d279b512e	2018-03-04 14:33:15.215627-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ad66bcab-6d5d-41dd-b4ec-c5f8e6165e23	2018-03-04 14:33:15.217627-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
2f18b702-7283-4e8e-b2ab-1556d3469875	2018-03-04 14:33:15.220627-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e86d4dc9-09a5-4b9a-bf4f-77b197096f42	2018-03-04 14:33:15.222628-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
11a4c31d-007c-46c1-9d5d-a01e5cd15665	2018-03-04 14:33:15.224628-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7101c12d-36e9-430a-a7ed-76b1a0ccda02	2018-03-04 14:33:15.227628-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
32606dca-6fcf-49bf-be39-01262d2d79f0	2018-03-04 14:33:15.229628-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c1907875-3958-467c-a385-cfdd48b05166	2018-03-04 14:33:15.232629-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
36fda171-7a6d-4893-bf24-d2d3b572e002	2018-03-04 14:33:15.234629-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
39743d6f-b2b3-4c94-a398-d55c7a274e8a	2018-03-04 14:33:15.237629-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
9eba37dd-f7e2-4653-bc14-fd1cbed9cb6b	2018-03-04 14:33:15.240629-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
41011ee9-cadf-4e87-98a8-69169c3b4284	2018-03-04 14:33:15.24363-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
18671ddb-d21d-4cb7-b5ef-be0204dc4303	2018-03-04 14:33:15.24563-06	3	[22600] D 33 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0a177c64-ca3a-4180-9b47-c62755e3e204	2018-03-04 14:33:15.486654-06	2	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5c456cc1-562d-4a64-9a9a-5b490d5f745c	2018-03-04 14:33:15.490654-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9eba0926-78f8-4197-9546-d5bc280810bd	2018-03-04 14:33:15.493655-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5424426f-ebb2-46ec-a336-0e299b37a8b3	2018-03-04 14:33:15.495655-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0adcdcec-5cdf-424a-9b6e-e876da8e3e6f	2018-03-04 14:33:15.498655-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
84d73b78-2f32-4491-b54a-d75fd8973ddb	2018-03-04 14:33:15.500655-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
227e40ce-52da-452f-a4c5-9bd0a31358a7	2018-03-04 14:33:15.503656-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3b0b9409-c885-4ef1-9791-09bf06a93c62	2018-03-04 14:33:15.505656-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4ee44871-a419-406f-a3a4-ebea5928b4ed	2018-03-04 14:33:15.509656-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
53b9c8f5-06c9-4c0d-af3c-ea4b4d816fea	2018-03-04 14:33:15.512657-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2d6d2d6d-b3e2-47d2-a616-9d515d3f3201	2018-03-04 14:33:15.514657-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
332c2cde-79a6-4f57-8ba6-5f026d0b6e18	2018-03-04 14:33:15.517657-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
01f60d65-8f4a-43c9-b216-07f7e80b9e45	2018-03-04 14:33:15.520657-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
37c9391b-91d4-47f0-a657-c250dc5e0cb3	2018-03-04 14:33:15.522658-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
aea38069-a175-4eb1-933b-2ba020ed27bc	2018-03-04 14:33:15.524658-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
9f31de0c-96b1-4a8b-9f6f-94b2a38aaa2b	2018-03-04 14:33:15.527658-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
29ec8495-8138-40db-a749-1601aab05192	2018-03-04 14:33:15.529658-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
2f6a5dec-926c-46e5-9276-c1259d866ccb	2018-03-04 14:33:15.532659-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f23968d6-c6e3-4231-b830-b7bcc0c10b48	2018-03-04 14:33:15.534659-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ec7b244f-4fee-48ce-ba96-599ff2ec8f67	2018-03-04 14:33:15.538659-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ca695119-22e6-4089-bca8-06c566ad2324	2018-03-04 14:33:15.540659-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6dd8471f-7c8d-4221-8cf4-5d49bc88e7b6	2018-03-04 14:33:15.54366-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
479495bd-49a4-4324-9d64-ff9693cf1a4f	2018-03-04 14:33:15.54566-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
65ac36ff-64cd-40a7-829d-89a85a0151ef	2018-03-04 14:33:15.54866-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5eb0d6ec-9cb9-4bec-9818-87be9f20459e	2018-03-04 14:33:15.55066-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
1fbff3d5-226d-4306-a837-bb399b85cbf1	2018-03-04 14:33:15.552661-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
68047243-7dc2-4f23-ab2c-7d853427db02	2018-03-04 14:33:15.555661-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
165db3aa-9f13-40d2-b18f-033bc2de5033	2018-03-04 14:33:15.556661-06	3	[22601] D 34 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
731156a0-1c81-4990-980f-64dd268f433f	2018-03-04 14:33:15.796685-06	2	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6b40cd2d-5c13-4e50-92cf-e6bf082fa282	2018-03-04 14:33:15.799685-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
356e8e7c-a3a0-425a-978f-cd2f20ca8e07	2018-03-04 14:33:15.802686-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
89fb4e5f-7f17-4a79-a0ac-4973736ca179	2018-03-04 14:33:15.806686-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
abd37ed6-9c82-4006-803b-56dcae77bccf	2018-03-04 14:33:15.809686-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1f8b086d-2f59-4a86-a3f0-920bd4fe335b	2018-03-04 14:33:15.811687-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1c101c43-4415-4dd1-81f8-a4b59d211142	2018-03-04 14:33:15.814687-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3e35dcca-c54e-4fba-80f2-67df2adaaa0b	2018-03-04 14:33:15.816687-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
10fe12d7-18d1-45af-bd3e-e95c4a757409	2018-03-04 14:33:15.819687-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e5fe684a-2192-423c-9454-e47e83425765	2018-03-04 14:33:15.822688-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5216cfcd-a793-4348-8c1a-eed37147ea67	2018-03-04 14:33:15.824688-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
652351ee-2d2a-4922-b228-3ba14a6929f1	2018-03-04 14:33:15.827688-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5e56ceae-f306-46d2-89bf-0dd97711f61e	2018-03-04 14:33:15.829688-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4adae969-53cd-44df-ad07-10ad45224e20	2018-03-04 14:33:15.831689-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
c8ab0d37-0e9c-476e-9c35-3f651a5a7935	2018-03-04 14:33:15.835689-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bb8e1024-ff3a-422c-bc15-2cfe2e92a867	2018-03-04 14:33:15.838689-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
74f89700-25a5-4fea-8f51-35c5a8751388	2018-03-04 14:33:15.840689-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
271c41f0-2f9e-46b7-affb-84f5a1862510	2018-03-04 14:33:15.84369-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d69e1b80-8727-4ae2-bf54-cee599a235fa	2018-03-04 14:33:15.84569-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
23701441-5ac5-49f7-8ab5-d0b9983c12c9	2018-03-04 14:33:15.84869-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e93bec07-5a47-4a18-b81c-682a954f422e	2018-03-04 14:33:15.85069-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d08e37ef-c3ba-4b87-a08b-156c4f93904a	2018-03-04 14:33:15.853691-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
db44fbc3-f406-408a-aa3a-e24fd9583351	2018-03-04 14:33:15.855691-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a79996dc-0b80-4e4a-a4cb-5277d08b665d	2018-03-04 14:33:15.857691-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
1d617609-1187-40ad-b61e-196943038377	2018-03-04 14:33:15.861692-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
400c3d03-653c-4871-b66a-e30e466cc235	2018-03-04 14:33:15.864692-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
aeb47b5a-ded7-4836-9d27-67d85d040a1e	2018-03-04 14:33:15.865692-06	3	[22602] D 35 GYM 455 	[21041] OSSI-DNOVAK	[293] master	\N	\N
de825a01-ef91-457b-b637-dfeb14e831c4	2018-03-04 14:33:16.102716-06	2	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6649c02b-62fe-4482-9904-5c6e6f5739fb	2018-03-04 14:33:16.105716-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
35dd9294-d8e9-4a6d-a8e4-65f585fe20b8	2018-03-04 14:33:16.108716-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
901788ef-5e2f-42de-b211-cbeb1718549b	2018-03-04 14:33:16.110716-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8958285b-5e20-49a2-a85f-005842aec247	2018-03-04 14:33:16.113717-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6d843d2d-bc74-4944-8b8c-1c73a0b3fa6b	2018-03-04 14:33:16.115717-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1265b850-343b-401b-8662-e590ed20774b	2018-03-04 14:33:16.118717-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
e93be8f7-21c8-47fa-86e5-02091cf43a02	2018-03-04 14:33:16.120717-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
249b46d3-4a1b-48e9-99b3-98fee105f703	2018-03-04 14:33:16.122718-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ab1cb0d0-806a-49a8-86c0-4da527f37e22	2018-03-04 14:33:16.126718-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4de8bba5-b1d1-410d-989d-3c7dd9836563	2018-03-04 14:33:16.129718-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
96660f4a-16a9-4bfa-8e9a-a857935a3395	2018-03-04 14:33:16.131719-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f8c4a64d-d1d5-4449-962c-cfff3ef0d041	2018-03-04 14:33:16.134719-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
8a7d3c36-f415-4901-9a27-be94ac6eabf2	2018-03-04 14:33:16.136719-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e035b39b-616d-4b27-b920-1173717ca6a4	2018-03-04 14:33:16.139719-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
a52be99e-ff53-4afc-9824-a99ddab97ac0	2018-03-04 14:33:16.14172-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cca9978c-fd6a-4b5a-93f9-42c248814fb4	2018-03-04 14:33:16.14372-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5c51a6f5-febe-4ec0-a5a9-bc1b8b87ab74	2018-03-04 14:33:16.14672-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d4f66998-25a3-480f-b95c-2a292985e106	2018-03-04 14:33:16.14872-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8d2b0a96-80b2-4732-81ff-2b22dd3a31ef	2018-03-04 14:33:16.15072-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9b578221-891b-4d8e-bcda-405e8db52e12	2018-03-04 14:33:16.154721-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
4b3d5a3e-69c3-4258-898e-37275ce774ed	2018-03-04 14:33:16.157721-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2fc6e9f1-3c09-406f-b304-57a1afe23862	2018-03-04 14:33:16.159721-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
90d3b7a7-23bf-43e8-aa9e-3efbbd762848	2018-03-04 14:33:16.162722-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
585dfac6-a03a-4b0a-a885-a192c32ba1e2	2018-03-04 14:33:16.165722-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
9b533742-61fc-4856-8fb6-7d6f787244cd	2018-03-04 14:33:16.167722-06	3	[22603] D 36 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7c99a7be-5514-4261-9f6f-6cd52f7186aa	2018-03-04 14:33:16.407746-06	2	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cedaab5d-4d34-49b5-96fc-6403fb5d01f1	2018-03-04 14:33:16.410746-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
4cfea636-96f5-48c0-abd8-2f1c09fbd31f	2018-03-04 14:33:16.413747-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1dea8966-1248-4fba-a438-88f146c00e83	2018-03-04 14:33:16.416747-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
104d820c-39f2-4ce8-8622-23d3dbc0e117	2018-03-04 14:33:16.418747-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c09b7fc0-bc99-43a9-b2d7-49ad92f8df90	2018-03-04 14:33:16.422748-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
6be6a9b6-4447-4805-9109-e97635abe5a3	2018-03-04 14:33:16.425748-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
144d53df-dcee-47f2-9af9-4f8ae347f503	2018-03-04 14:33:16.427748-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b83d7952-6349-4d08-bd58-664bc0ab4df1	2018-03-04 14:33:16.430748-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cc194024-5c76-4631-b96c-8a0f17625f64	2018-03-04 14:33:16.432749-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
50abcae9-24ca-4944-ab38-800ce4653806	2018-03-04 14:33:16.434749-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6d7148ab-8f4c-487c-b53d-be8bfa3794a1	2018-03-04 14:33:16.437749-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
a4049c7a-7bb3-4b97-b2e7-d917f29fd632	2018-03-04 14:33:16.439749-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5c2e1be2-34db-4e1d-ba62-1b88c5b6e6e4	2018-03-04 14:33:16.44175-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
d8394f5e-3348-4848-8c4c-5f0e112016c0	2018-03-04 14:33:16.44475-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e2fdde8f-1090-4a76-a7bd-f8dfe738c437	2018-03-04 14:33:16.44675-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d3f80df2-c891-44df-a5d6-949c47f1d07d	2018-03-04 14:33:16.45075-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
faf71cb1-ac22-497b-94ca-777c47c424dd	2018-03-04 14:33:16.452751-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b10f2b42-1206-4394-9dbf-ac6fcf6bc61b	2018-03-04 14:33:16.455751-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b913ff8c-c5f9-45a4-a53a-f7c453416b69	2018-03-04 14:33:16.457751-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
77546fae-fd16-492b-b99e-be8ef5c548e3	2018-03-04 14:33:16.459751-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c9afd169-67cf-4c99-885b-5232412e96e2	2018-03-04 14:33:16.462752-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
a872a239-83e0-4a0f-8d24-cf912679ac73	2018-03-04 14:33:16.464752-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
c050b1a4-8aea-49c3-ade0-1782c13843c9	2018-03-04 14:33:16.467752-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
7adafb41-8f53-4a2b-b014-9c04af220ec0	2018-03-04 14:33:16.468752-06	3	[22604] D 37 FITNESS 452 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a0ae2588-09cf-4745-96ee-1ca7295241e2	2018-03-04 14:33:16.723778-06	2	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
930fd058-8613-4643-988c-86194d588414	2018-03-04 14:33:16.727778-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7f219735-39c2-45ca-9768-1b26498a70f2	2018-03-04 14:33:16.729778-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e8e8c826-3f78-4848-9f79-e270efc18ba8	2018-03-04 14:33:16.733779-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8a420d98-8001-49a1-a40e-e4c3248ba25d	2018-03-04 14:33:16.736779-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
7dbe651e-9d01-4f20-b97f-370d13494edb	2018-03-04 14:33:16.739779-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
261b788a-57c6-4d45-a563-933c15d6241b	2018-03-04 14:33:16.74278-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b70ba287-9222-432b-b9de-76581eb799ff	2018-03-04 14:33:16.74478-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d3e4bee9-f6f6-46e2-8c60-a178e7b19be1	2018-03-04 14:33:16.74678-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
313f0c4e-7747-487c-92a1-fb9e38aeacff	2018-03-04 14:33:16.74978-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e55309d5-2c9a-4e13-a838-0370b046c96a	2018-03-04 14:33:16.751781-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
a408cba4-f113-4274-9a79-a59252317733	2018-03-04 14:33:16.753781-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1e110033-49ab-49de-89f0-69e8ce1dfcbf	2018-03-04 14:33:16.756781-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
70b49def-d163-42f6-9097-22deb673bb93	2018-03-04 14:33:16.759781-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e70fd085-1059-42d0-97c5-e399cdb8d186	2018-03-04 14:33:16.762782-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
813e8e8b-8406-4fa1-99bb-8c5ed97e6eee	2018-03-04 14:33:16.764782-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1b91b18d-767e-429c-b364-f2f8723c2543	2018-03-04 14:33:16.767782-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4f9a2773-ce78-4fcb-a915-1abc45b4ca06	2018-03-04 14:33:16.769782-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
de2ace15-5780-4405-b78e-b5fc52773ddf	2018-03-04 14:33:16.771783-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
07b62536-1d25-4e20-b98c-4bc9a67d2de9	2018-03-04 14:33:16.774783-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7b6f5b66-d02a-4b5c-94ae-ec18d411c76f	2018-03-04 14:33:16.776783-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
127fd80b-0706-4390-b6b1-32535a13fb8d	2018-03-04 14:33:16.779783-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
342e34b4-8292-4b02-af76-5ae4cd192565	2018-03-04 14:33:16.781784-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
87772553-3126-4620-8519-67e5c965727b	2018-03-04 14:33:16.783784-06	3	[22605] D 38 COURTYARD 451	[21041] OSSI-DNOVAK	[293] master	\N	\N
c7e9799b-d72d-4903-a14d-2e1b828835ef	2018-03-04 14:33:17.024808-06	2	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
219ab314-5f15-45e5-94f7-199f458a5820	2018-03-04 14:33:17.028808-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bec1fb5d-49ac-4fba-923c-3dfecad84a0b	2018-03-04 14:33:17.031809-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
58fd5b5f-67a2-4d32-b11c-898786158dbb	2018-03-04 14:33:17.034809-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
4ad22fbd-20d1-40b8-bc6a-fc4da40808b5	2018-03-04 14:33:17.036809-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
03eda458-c462-4992-a8c7-c4b5082ef0f6	2018-03-04 14:33:17.039809-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
01fdd5d6-d412-46a1-9a3d-228554816f38	2018-03-04 14:33:17.04181-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f15cbf00-0265-4c49-b1a7-76bbf6450dd8	2018-03-04 14:33:17.04481-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
64245b89-6507-4558-be27-4c5cf1477cb1	2018-03-04 14:33:17.04681-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ec950a8f-b229-4ae0-a78c-ffead582fa60	2018-03-04 14:33:17.04881-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
df82fb29-646c-423c-b776-0ad3454fb158	2018-03-04 14:33:17.05081-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
144fc510-bdc3-474d-b39b-1a86f05c9f54	2018-03-04 14:33:17.053811-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
7caef1cc-f674-40ab-9cb0-ffcd829de7ff	2018-03-04 14:33:17.057811-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
774c472f-7b6b-4baf-983c-b5a24a1dd398	2018-03-04 14:33:17.059811-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8792abfd-1497-4c7a-9de9-ac758d03742b	2018-03-04 14:33:17.061812-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
52fa4014-ffdc-4733-a8f2-b703d4cdefb2	2018-03-04 14:33:17.064812-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
72b3d960-43e4-458f-bd4f-8123114a773a	2018-03-04 14:33:17.066812-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cfbb3114-a1d1-4720-b213-4f9a9aa7aacc	2018-03-04 14:33:17.068812-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
0701bb3c-e63b-48ff-9279-5a502920c289	2018-03-04 14:33:17.071813-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4402f609-1778-4a3e-be6b-5ad3b607dc43	2018-03-04 14:33:17.073813-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
0712981b-cc45-4801-9d2b-0bc0a049e2c8	2018-03-04 14:33:17.076813-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
68c2efb7-985a-44c8-b91a-5b4e87883c08	2018-03-04 14:33:17.078813-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
f3208850-63d1-417f-a04d-68f6d1530244	2018-03-04 14:33:17.079813-06	3	[22606] D 39 COURTYARD 451 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cf02233e-da86-4549-ac2b-946ce93a50a1	2018-03-04 14:33:17.322838-06	2	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c627947b-9da6-49a8-b6d9-c5efc80ecb43	2018-03-04 14:33:17.327838-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
786e25db-9ce8-4969-ad05-fb853f319f5f	2018-03-04 14:33:17.329838-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
9d345105-453e-4df3-9437-8146300725df	2018-03-04 14:33:17.332839-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fa59f3f3-032e-4591-90e5-51492bd962fe	2018-03-04 14:33:17.334839-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
80d31970-e606-4646-b239-c387e7f98798	2018-03-04 14:33:17.336839-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7cb9fd2c-6247-454e-ab08-6df3afbb73e5	2018-03-04 14:33:17.338839-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c65ef142-dfe5-4009-888d-144657bd2d8f	2018-03-04 14:33:17.34184-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8a662033-3dea-499f-a40f-df90b8712209	2018-03-04 14:33:17.34384-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
3666fa6c-97de-4fd8-8528-a03d1024a9fc	2018-03-04 14:33:17.34584-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b5d35da9-7326-4be3-825c-7a429a99f962	2018-03-04 14:33:17.34784-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
4e683e92-82aa-4098-bc98-d3c865ea2ea8	2018-03-04 14:33:17.351841-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4904dcf7-9fd4-46ea-ad20-29c751fb7d7c	2018-03-04 14:33:17.353841-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
703ef51d-f014-41ff-ab2f-75f59ce8364a	2018-03-04 14:33:17.356841-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
29057325-a6b0-4d3d-a9b2-6cb9ff46f2ba	2018-03-04 14:33:17.358841-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
39eb0408-574e-4c67-8bfc-7722abb068b8	2018-03-04 14:33:17.360841-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a31f6d3b-655f-4172-b290-dd528349a97a	2018-03-04 14:33:17.362842-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
21ba2f45-f942-411d-a6bf-39dfe3905dbb	2018-03-04 14:33:17.365842-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f0ef1d04-211c-4bf5-aca4-96df0889725a	2018-03-04 14:33:17.367842-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
94c0f98c-dd52-4a05-8eed-f07ea2dbe212	2018-03-04 14:33:17.369842-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
f4164056-ec57-4778-984f-07911b1a732b	2018-03-04 14:33:17.371843-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
d85c5fd0-cdb3-45c6-afe1-20c17f1355ce	2018-03-04 14:33:17.373843-06	3	[22607] D 40 VISITING 448 	[21041] OSSI-DNOVAK	[293] master	\N	\N
95d7c84a-5492-4be3-b219-4b16db283ac8	2018-03-04 14:33:17.616867-06	2	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7295b9e7-87a3-43fc-8275-0b27eddb9d23	2018-03-04 14:33:17.621868-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
9e4579a1-6154-49a2-8cf2-fdb9e24eba43	2018-03-04 14:33:17.624868-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f1ff373e-c707-4067-a331-979ae95c3233	2018-03-04 14:33:17.626868-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2929c61f-f030-49bc-9d54-abb208741967	2018-03-04 14:33:17.628868-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
75da5830-70b8-47bc-acf2-34f083845aec	2018-03-04 14:33:17.631869-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
20685858-b5f4-4d2a-b869-c1193aa82d28	2018-03-04 14:33:17.633869-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
25140e40-c605-4e70-9854-9aac93b220fc	2018-03-04 14:33:17.636869-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
b87420f6-0c0d-46a1-89f9-a10491cf6461	2018-03-04 14:33:17.638869-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
dcfaa057-09b4-4efa-8b89-2e16fd06780c	2018-03-04 14:33:17.640869-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
84b807b0-14d6-40a1-bc36-10763e6d7a98	2018-03-04 14:33:17.64387-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bef2678d-f6b8-43dc-aca7-829f5554e35b	2018-03-04 14:33:17.64587-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
faa17508-b551-4c8c-b470-083adf7f02cb	2018-03-04 14:33:17.64987-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7018efe3-89e2-4300-8a3b-12358ec78308	2018-03-04 14:33:17.651871-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
2e8ecff8-f992-4a0f-a229-3bee0683803c	2018-03-04 14:33:17.654871-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
561be647-f1fe-41e3-b800-4883e2c3a6c5	2018-03-04 14:33:17.656871-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
2dfb6b61-04da-482b-8ea4-725f62312021	2018-03-04 14:33:17.659871-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
30e6c4ab-e5ff-4c2a-af2a-cbdd6a9a2f8e	2018-03-04 14:33:17.661872-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
6bd22de3-f4de-4f87-9d48-561e3978ff10	2018-03-04 14:33:17.663872-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
8f47a415-7395-41a8-92d8-40aa52b8b771	2018-03-04 14:33:17.666872-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
761b1e00-8cbd-478e-b4c4-38d88522502e	2018-03-04 14:33:17.667872-06	3	[22608] D 41 VISITING 445 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3baf16ee-e64b-42d6-8d86-00ffb12df142	2018-03-04 14:33:17.910896-06	2	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
5adeab6a-19df-4c3a-9873-bafe20b2b8aa	2018-03-04 14:33:17.913897-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0abad513-f33e-44ea-97c1-e072e153bbdc	2018-03-04 14:33:17.915897-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
61767ee3-05e5-40ac-b774-66303ef556f7	2018-03-04 14:33:17.919897-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1c6fff28-34a7-425e-a747-cc20199e8ff4	2018-03-04 14:33:17.922898-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
07a98ba1-1ccb-4e21-ae82-6e0601d85f23	2018-03-04 14:33:17.925898-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5a78aa58-8a07-4a4a-a837-9ab1ea6a1cb1	2018-03-04 14:33:17.927898-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
b5c411bf-ff90-4f68-a28c-50b157dfcdfd	2018-03-04 14:33:17.930898-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
be9b0585-7881-476c-bec7-1be0400e56e2	2018-03-04 14:33:17.932899-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
e7616c74-3fe0-46bc-8b89-5e1cc60ff883	2018-03-04 14:33:17.934899-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c20946fa-ae6e-48dc-a6f1-7d85815969c0	2018-03-04 14:33:17.937899-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
26c308cc-1d8a-45d7-a777-527b7a9b78bd	2018-03-04 14:33:17.939899-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ab11dc80-49cf-4aea-8f3d-4c171b4a4b4b	2018-03-04 14:33:17.9429-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
111ffe32-d9d4-4e4c-8b01-659c30d75745	2018-03-04 14:33:17.9469-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8ce8ad49-a3da-420a-9938-27f79bfb17c1	2018-03-04 14:33:17.9489-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
12663a5d-a7e5-47b5-9596-894fcef0c0e3	2018-03-04 14:33:17.9509-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
cc86d1f0-b2a0-4d7e-929d-a12da6c3db66	2018-03-04 14:33:17.954901-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
1795dae5-b973-4315-93ec-1c7c5624f0a3	2018-03-04 14:33:17.956901-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
09943bb9-eaff-43ee-b5ed-384aff2ed1a9	2018-03-04 14:33:17.959901-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
cbf11d76-0090-48ba-9f81-ec035a79787a	2018-03-04 14:33:17.961902-06	3	[22609] D 42 VISITING 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
cd65628c-8a69-4fd5-baf8-024acdfc9b80	2018-03-04 14:33:18.201926-06	2	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e4eaf1d7-7486-4f58-8707-186d5503241f	2018-03-04 14:33:18.205926-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
59393f72-f604-42e0-ba38-c60f4afb67be	2018-03-04 14:33:18.207926-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5b866d3b-867a-4616-aa7e-7e8ae25e6dba	2018-03-04 14:33:18.210926-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
473b78ea-b03c-4771-be65-6b4d63683881	2018-03-04 14:33:18.212927-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9ead074c-7399-4e47-a070-8e1b30dc1345	2018-03-04 14:33:18.216927-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
b110c908-7315-4972-87dc-23ff30a61533	2018-03-04 14:33:18.219927-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
027275d7-df3c-48e7-86ac-5c95d97e7d3e	2018-03-04 14:33:18.222928-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
0e3ff472-a928-49de-adb8-9ef4f4709559	2018-03-04 14:33:18.224928-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
00ffaabb-8107-4887-9984-3a7f4b654335	2018-03-04 14:33:18.227928-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
63839119-3dde-439e-aac0-c26ae3e77d0d	2018-03-04 14:33:18.229928-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f5f4c5b6-9a55-4ae4-90c0-7bc1398fcffb	2018-03-04 14:33:18.231929-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7f1e8315-8515-42ab-9b19-10cc5b0d2866	2018-03-04 14:33:18.234929-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0c686cdf-79f7-42e8-adec-b64fd1bd377d	2018-03-04 14:33:18.236929-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
24c79835-0494-491a-9308-c6ff3a8aa513	2018-03-04 14:33:18.239929-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
3faa6422-047a-481e-942f-f5d6bd40623e	2018-03-04 14:33:18.24193-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
246d2eb0-1e13-4165-b921-0f7efafaea32	2018-03-04 14:33:18.24593-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
6af551a7-116c-45d2-9db3-67665b896d1e	2018-03-04 14:33:18.24793-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
9ae8cd88-2040-44a8-8f70-b0574f0d75a7	2018-03-04 14:33:18.24993-06	3	[22610] D 43 VISITING 446 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d9e2b934-4adb-45f2-9c63-a11921764970	2018-03-04 14:33:18.490954-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c390d084-c50d-4e5b-8a66-f4fd8264d600	2018-03-04 14:33:18.493955-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8c00a08c-ac9b-41fa-999a-74d459125d19	2018-03-04 14:33:18.495955-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4d356b24-c046-4ab6-8b8b-f6c89bddbca8	2018-03-04 14:33:18.498955-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9d0d6863-e2ca-4c11-99ef-ded962ed5be7	2018-03-04 14:33:18.500955-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
85017918-fc3c-4186-ae68-72c11dbb1dc7	2018-03-04 14:33:18.503956-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7a7c48e0-b61d-4cef-9f30-b106706548f2	2018-03-04 14:33:18.505956-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
85d274b4-f2e8-47df-a354-677043900a89	2018-03-04 14:33:18.507956-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1a03d625-e3a9-4044-bdc1-b22f67fe1916	2018-03-04 14:33:18.510956-06	2	[22619] D 52 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
58c7be69-ab3c-459f-ab37-0f2c924a9b57	2018-03-04 14:33:18.513957-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
c6dfdc3a-e9ab-4e21-a23b-afce31e45b9c	2018-03-04 14:33:18.516957-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
5113e445-2325-49ae-9e7b-42f8025f9bfa	2018-03-04 14:33:18.518957-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a0c12415-7ba1-46f6-ab78-43d582fb75b1	2018-03-04 14:33:18.521958-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
92cabe30-135f-43ed-b6e3-3a82f3c3b591	2018-03-04 14:33:18.523958-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d54221e7-9bb1-4eea-921e-307a993c1c65	2018-03-04 14:33:18.525958-06	2	[22625] D58 VISITING ROOM 445	[21041] OSSI-DNOVAK	[293] master	\N	\N
c1095e26-f60d-49af-8a63-9ac06be06232	2018-03-04 14:33:18.528958-06	2	[22626] D59 MEDS STORAGE 401	[21041] OSSI-DNOVAK	[293] master	\N	\N
e5b5af77-4a55-4137-8379-0b80bf90c80d	2018-03-04 14:33:18.530958-06	2	[22627] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
0a558f5c-65f7-4ffe-afad-772aac36b13a	2018-03-04 14:38:15.968699-06	2	[22085] Door 323OHD OPEN/CLOSE	[4] DLarrabee	[21062] a	\N	\N
74bfe213-51e4-4e37-84b6-6055911812e3	2018-03-04 14:38:25.47665-06	2	[22084] Door 324OHDW OPEN/CLOSE	[4] DLarrabee	[21062] a	\N	\N
72234af9-0191-4c0f-bad7-113c0fbfeea5	2018-03-04 14:39:08.522954-06	2	[22611] D 44 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7cb9b326-ed0e-4f27-a59d-7edd637fea81	2018-03-04 14:39:14.989601-06	2	[22091] Door 322	[4] DLarrabee	[21062] a	\N	\N
cae0bc9a-96c2-4330-9882-34259051e1d1	2018-03-04 14:40:42.69037-06	2	[22085] Door 323OHD OPEN/CLOSE	[4] DLarrabee	[21062] a	\N	\N
94c5ebd2-236a-4087-aabb-507ab9da7398	2018-03-04 14:43:04.194519-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9a658757-9323-4dcc-ad2a-802745916ca3	2018-03-04 14:43:24.250524-06	2	[22612] D 45 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
8b6c1c3b-3f4b-4925-a394-b0d80121ac87	2018-03-04 14:43:52.750374-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e41dd27b-f870-4727-b1bb-17c68a23d888	2018-03-04 14:44:30.204119-06	2	[22613] D 46 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
54af2758-57db-4ebe-85a5-7dc55b826d1f	2018-03-04 14:47:30.684165-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
95019d35-cf9c-4132-9170-4a64f1358f39	2018-03-04 14:47:53.352432-06	2	[22614] D 47 WAITING 382 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4a533c5c-b652-437f-8fc6-718d508458d1	2018-03-04 14:49:10.275123-06	2	[22615] D 48 VENDING 492	[21041] OSSI-DNOVAK	[293] master	\N	\N
7151e381-6a80-4572-a560-957607a14d10	2018-03-04 14:51:49.345029-06	2	[22064] Door 326A	[4] DLarrabee	[21062] a	\N	\N
af04dbfc-7574-448c-9881-947cba00a992	2018-03-04 14:53:36.096703-06	2	[22616] D 49 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
fb3c83b1-4985-467d-8bb4-30fcecbcc568	2018-03-04 14:54:00.640157-06	2	[22617] D 50 CORRIDOR 484	[21041] OSSI-DNOVAK	[293] master	\N	\N
b70baeba-c183-4cc1-9ec7-0017762fd71f	2018-03-04 14:54:36.728765-06	2	[22618] D 51 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
724b1388-ca1c-402f-96ee-6f6c8c8091a9	2018-03-04 14:56:44.066498-06	2	[22065] Door 327A 	[4] DLarrabee	[21062] a	\N	\N
e78b1c4f-2c6b-47cd-aff5-c07d5ec8f809	2018-03-04 14:57:16.683759-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4cbb6bc0-a92c-4b72-9ad5-7e4b6a371b9c	2018-03-04 14:57:33.643455-06	2	[22620] D 53 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e5560bdf-4817-45de-8009-a37bc2fdbb2c	2018-03-04 14:58:19.060996-06	2	[22621] D 54 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6c2a3b5d-8311-4735-8962-fedb2dc80224	2018-03-04 14:58:47.881878-06	2	[22622] D 55 INTERVIEW 466 	[21041] OSSI-DNOVAK	[293] master	\N	\N
bc2c8820-a334-4799-a096-55ec0d0fcc9f	2018-03-04 14:59:06.352725-06	2	[22210] Door 306	[4] DLarrabee	[21062] a	\N	\N
886b1bdb-406b-4c1d-ae3e-7e9c2dcf976d	2018-03-04 14:59:12.113301-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
206d6be0-884b-4b89-a568-9d4b16697597	2018-03-04 14:59:29.193009-06	2	[22623] D 56 MEETING 467	[21041] OSSI-DNOVAK	[293] master	\N	\N
e04f10c7-33d6-4325-8ce7-73bce6666db7	2018-03-04 15:01:13.367425-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e6795fd3-d3df-4d28-80a0-4014d39c4014	2018-03-04 15:01:30.01809-06	2	[22624] D 57 CORRIDOR 484 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a7a6f5ec-4845-48c7-a5fd-289c8c8438df	2018-03-04 15:10:55.962679-06	1	[22083] IC 306B-InB	[4] DLarrabee	[21062] a	\N	\N
269dc4e2-1bb3-43ea-9f66-c79abc956b7a	2018-03-04 15:11:03.337416-06	1	[22087] IC 306B-OutB	[4] DLarrabee	[21062] a	\N	\N
85b01b08-2d5f-4218-909f-c9be20440232	2018-03-04 15:12:13.344416-06	2	[21268] Door 306	[4] DLarrabee	[21062] a	\N	\N
bf12a5a9-b159-4c2e-8db9-82d0ea1e7890	2018-03-04 15:13:37.574839-06	2	[21915] E 1 HALL 544 	[21041] OSSI-DNOVAK	[293] master	\N	\N
678b3fbe-7f09-4cdc-a828-8e3a5ec18a95	2018-03-04 15:14:29.124993-06	2	[21916] E 2 HALL 544 	[21041] OSSI-DNOVAK	[293] master	\N	\N
10707a73-2132-4fd9-a71a-c3dce3dbdeee	2018-03-04 15:14:49.959076-06	2	[21916] E 2 HALL 544 	[21041] OSSI-DNOVAK	[293] master	\N	\N
a19f627a-832a-41a3-befc-c7ae418bf8b6	2018-03-04 15:15:19.825063-06	2	[21917] E 3 HALL 544 	[21041] OSSI-DNOVAK	[293] master	\N	\N
24314c74-a8a7-44e2-89aa-e199d40e6882	2018-03-04 15:15:28.913971-06	2	[22210] Door 306	[4] DLarrabee	[21062] a	\N	\N
500fd449-a3ba-4b5f-b952-507d9fc8c968	2018-03-04 15:15:43.595439-06	2	[21917] E 3 HALL 544 	[21041] OSSI-DNOVAK	[293] master	\N	\N
b0b42c0b-ae1c-43c2-8f9c-0645c5ffa70d	2018-03-04 15:16:05.736653-06	2	[21260] PODs 3X Drop sd.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
91abe313-656b-4639-ad86-b9bb9ca1e18e	2018-03-04 15:16:12.862366-06	2	[22065] Door 327A 	[4] DLarrabee	[21062] a	\N	\N
06f970da-b890-4fbf-9e43-af7a8c9e3449	2018-03-04 15:16:49.180997-06	2	[21918] E 4 LIVING ROOM 529 	[21041] OSSI-DNOVAK	[293] master	\N	\N
993efd4a-d6bf-45a8-8e22-096675d89495	2018-03-04 15:17:28.237903-06	2	[21920] E 6 LIVING ROOM 529 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4e61299f-cdce-42d7-a769-4202d5685fe8	2018-03-04 15:17:46.955774-06	2	[21920] E 6 LIVING ROOM 529 	[21041] OSSI-DNOVAK	[293] master	\N	\N
f4d2da56-570d-4d35-aab6-e1636a4d48d4	2018-03-04 15:18:32.308309-06	2	[21921] E 7 LIVING ROOM 529 	[21041] OSSI-DNOVAK	[293] master	\N	\N
57024346-f7d7-4813-a41d-c5b375e352b1	2018-03-04 15:18:44.290507-06	2	[21921] E 7 LIVING ROOM 529 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6e9e2bd4-ba22-4d33-b7b1-6177825422e6	2018-03-04 15:18:55.448623-06	2	[21921] E 7 LIVING ROOM 529 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9950e334-5e5f-40dd-aef4-1c7e4b8ada1a	2018-03-04 15:19:26.750753-06	2	[21922] E 8 LIVING ROOM 529 	[21041] OSSI-DNOVAK	[293] master	\N	\N
09a9f157-dd75-43da-b810-c47705378b69	2018-03-04 15:20:05.119589-06	2	[21923] E 9 DINING 515	[21041] OSSI-DNOVAK	[293] master	\N	\N
24e431eb-bff0-4827-87ea-b6c5aa8c450b	2018-03-04 15:20:24.219499-06	2	[21923] E 9 DINING 515	[21041] OSSI-DNOVAK	[293] master	\N	\N
30dc3846-f25f-456f-a30f-aa1ce6cdfb2b	2018-03-04 15:21:00.294106-06	2	[21924] E 10 DINING 515	[21041] OSSI-DNOVAK	[293] master	\N	\N
783f5dee-8d66-4af2-849d-dcd6eee0cc60	2018-03-04 15:21:15.539631-06	2	[21924] E 10 DINING 515	[21041] OSSI-DNOVAK	[293] master	\N	\N
6cd43731-748c-44cd-9643-bac87de4d7f4	2018-03-04 15:21:29.625039-06	2	[21924] E 10 DINING 515	[21041] OSSI-DNOVAK	[293] master	\N	\N
64a2a72b-b7be-4b43-aad7-0f5dde7e3193	2018-03-04 15:22:00.120088-06	2	[21925] E 11 LIVING ROOM 514 	[21041] OSSI-DNOVAK	[293] master	\N	\N
e48c9d03-1adb-4fec-9e98-c136b8fd27b5	2018-03-04 15:22:26.016678-06	2	[21922] E 8 LIVING ROOM 529 	[21041] OSSI-DNOVAK	[293] master	\N	\N
89a43aca-954a-4668-aed6-79fa936a68c1	2018-03-04 15:22:52.881364-06	2	[21926] E 12 LIVING ROOM 514	[21041] OSSI-DNOVAK	[293] master	\N	\N
dc13e0e1-5ed7-417a-9490-9c77eab661cb	2018-03-04 15:23:18.978973-06	2	[21926] E 12 LIVING ROOM 514	[21041] OSSI-DNOVAK	[293] master	\N	\N
dd7d37de-0dcd-40e6-84c2-753d9490789c	2018-03-04 15:23:42.014277-06	2	[21926] E 12 LIVING ROOM 514	[21041] OSSI-DNOVAK	[293] master	\N	\N
46b502c1-ddda-4d35-b2ef-12e1c881011d	2018-03-04 15:24:24.027477-06	2	[21927] E 13 LIVING ROOM 514	[21041] OSSI-DNOVAK	[293] master	\N	\N
1a70984a-5ace-450e-92f2-5cfd8b3075d2	2018-03-04 15:25:29.747049-06	2	[21928] E 14 LIVING ROOM 514 	[21041] OSSI-DNOVAK	[293] master	\N	\N
69e322e6-b00f-4499-ac63-9ab4b6372c63	2018-03-04 15:27:13.291402-06	2	[22066] Door 329A	[4] DLarrabee	[21062] a	\N	\N
3f6e3088-15f4-47e9-8876-7688a222c707	2018-03-04 15:27:37.598833-06	2	[22067] Door 329B	[4] DLarrabee	[21062] a	\N	\N
102631c2-2d20-4a38-8bc1-906541921033	2018-03-04 15:28:53.267399-06	2	[21931] E17 SINGLE SLEEPING 509	[21041] OSSI-DNOVAK	[293] master	\N	\N
c841bfac-6e9b-4cca-94dc-5bd6ed98abe0	2018-03-04 15:29:21.2862-06	2	[21931] E17 SINGLE SLEEPING 509	[21041] OSSI-DNOVAK	[293] master	\N	\N
29d6c1e8-bf35-4031-ac76-173abf5610f9	2018-03-04 15:29:47.210793-06	2	[21932] E18 ADA SLEEPING 513	[21041] OSSI-DNOVAK	[293] master	\N	\N
fcdac56f-4936-4852-94cf-49cc70ed851d	2018-03-04 15:30:08.011872-06	2	[21932] E18 ADA SLEEPING 513	[21041] OSSI-DNOVAK	[293] master	\N	\N
7ec7cf53-103b-490c-a7cb-c865e57db04e	2018-03-04 15:30:22.631334-06	2	[21932] E18 ADA SLEEPING 513	[21041] OSSI-DNOVAK	[293] master	\N	\N
06071d3f-b66b-4734-948f-fbef00c3a17f	2018-03-04 15:31:26.048675-06	2	[21933] E19 ADA SLEEPING 518	[21041] OSSI-DNOVAK	[293] master	\N	\N
63940e96-e48c-45ef-9b1a-dab0710ebcb1	2018-03-04 15:32:03.384409-06	3	[21935] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
16cd77b3-d65f-4b63-8e9d-2b044c16cf61	2018-03-04 15:32:53.275397-06	2	[22096] Door 330A	[4] DLarrabee	[21062] a	\N	\N
20052172-32ba-4316-8fc3-d9259ba1e3a8	2018-03-04 15:34:14.727542-06	2	[22097] Door 330B	[4] DLarrabee	[21062] a	\N	\N
7acbdf01-830f-435d-b30e-0246bd5a7a01	2018-03-04 15:37:39.484015-06	2	[21929] E 15 CALMING ROOM 535	[21041] OSSI-DNOVAK	[293] master	\N	\N
ccf8c514-4a67-44ae-b090-5fe6f39de384	2018-03-04 15:50:27.282787-06	1	[21935] 330 Copy	[4] DLarrabee	[21062] a	\N	\N
7d1f91ee-20fa-4dd3-a006-7ba8d9bedc22	2018-03-04 15:51:59.039962-06	2	[21935] 330 IC-IN	[4] DLarrabee	[21062] a	\N	\N
78811a2e-756a-455f-8b96-643c7c1f4a7a	2018-03-04 15:52:31.067165-06	2	[21935] 330 IC-IN	[4] DLarrabee	[21062] a	\N	\N
a84a63c7-a20a-4c42-acee-95ddb210f524	2018-03-04 15:52:38.660924-06	2	[21935] 330 IC-IN	[4] DLarrabee	[21062] a	\N	\N
f5b8f6a3-24b8-4cce-b5a2-65107973de4c	2018-03-04 15:53:15.572615-06	2	[21935] 330 IC-IN	[21041] OSSI-DNOVAK	[293] master	\N	\N
cbd43e27-4ce7-44be-97d1-0a9de1e783d6	2018-03-04 15:53:21.705228-06	2	[21935] 330 IC-IN	[4] DLarrabee	[21062] a	\N	\N
48ad0000-edfe-4c7e-a6d0-8f5b121c3382	2018-03-04 15:53:40.338091-06	2	[21935] 330 IC-IN	[21041] OSSI-DNOVAK	[293] master	\N	\N
90c98875-5fdc-44f3-9d0f-3b61e9e97602	2018-03-04 15:54:07.738831-06	1	[22120] 330 IC-IN Copy	[4] DLarrabee	[21062] a	\N	\N
11b1a3c4-4f83-42f3-940c-0639f33c0eb4	2018-03-04 15:54:16.543711-06	2	[22227] 330	[21041] OSSI-DNOVAK	[293] master	\N	\N
a6353ec4-366a-4ca5-8669-2a7f831eeaae	2018-03-04 15:54:20.014058-06	2	[22061] Fill.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
146d1355-6eb8-4fa1-b508-13882148561f	2018-03-04 15:55:04.522509-06	2	[22120] 330 IC-OUT	[4] DLarrabee	[21062] a	\N	\N
33eb260d-6d5b-4298-993b-c93ce9236a98	2018-03-04 15:55:31.957252-06	1	[22276] 330 IC-IN Copy	[4] DLarrabee	[21062] a	\N	\N
101c4236-717f-4df3-8c10-8d649805a0a3	2018-03-04 15:55:44.934549-06	1	[22277] 330 IC-OUT Copy	[4] DLarrabee	[21062] a	\N	\N
b2a79386-9541-4060-8d37-c0174621b5f1	2018-03-04 15:56:16.071663-06	2	[22276] 330A IN	[4] DLarrabee	[21062] a	\N	\N
f238d6cf-e055-4fec-a81f-c431c2ac5896	2018-03-04 15:56:44.176473-06	2	[22277] 330A OUT	[4] DLarrabee	[21062] a	\N	\N
332a4143-6e41-4900-a78d-ad693ffc5db6	2018-03-04 15:58:28.867941-06	2	[22097] Door 330B	[4] DLarrabee	[21062] a	\N	\N
284c745d-6be9-44aa-b08b-0f992680bd60	2018-03-04 15:58:36.55671-06	3	[22123] C 24 HALL 378	[21041] OSSI-DNOVAK	[293] master	\N	\N
f24b7976-1c78-4696-a674-b6de7e0051f4	2018-03-04 15:58:36.801734-06	2	[22124] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
69757952-a13e-4b3d-b059-014f67532676	2018-03-04 15:58:36.806735-06	2	[22125] C 26 CORRIDOR 317 	[21041] OSSI-DNOVAK	[293] master	\N	\N
91cd52d5-22aa-46d0-ad08-f47cb22861a4	2018-03-04 15:58:36.816736-06	2	[22126] C 27 CORRIDOR 317 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4cc46e10-f511-4d2b-bf1c-1dce7455b914	2018-03-04 15:58:36.818736-06	2	[22127] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
0f8fc920-00f2-4d78-a940-98794c3869d5	2018-03-04 15:58:36.820736-06	3	[22122] C 23 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
4c6541ca-a1f2-47b9-978b-dd2c640a695c	2018-03-04 15:58:37.098764-06	2	[22124] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef211bdc-0d25-4dfc-bf3c-f80e6e4f77b6	2018-03-04 15:58:37.103765-06	2	[22125] C 26 CORRIDOR 317 	[21041] OSSI-DNOVAK	[293] master	\N	\N
6373e4c3-1b48-4c1c-bcf1-c3d16d97f1a8	2018-03-04 15:58:37.108765-06	2	[22126] C 27 CORRIDOR 317 	[21041] OSSI-DNOVAK	[293] master	\N	\N
9aaa7d25-c354-47ac-9ad2-4cb7d84cb727	2018-03-04 15:58:37.112765-06	2	[22127] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
4c07ccae-e77b-411f-8f03-58a5684e07a8	2018-03-04 15:58:37.115766-06	3	[22124] C 25 HALL 378 	[21041] OSSI-DNOVAK	[293] master	\N	\N
498d3753-b5a3-4cee-899f-c35195f66f67	2018-03-04 15:58:37.435798-06	2	[22125] C 26 CORRIDOR 317 	[21041] OSSI-DNOVAK	[293] master	\N	\N
d726f6b5-8fc6-4993-8e70-e8081dc385b5	2018-03-04 15:58:37.439798-06	2	[22126] C 27 CORRIDOR 317 	[21041] OSSI-DNOVAK	[293] master	\N	\N
14923ce3-9255-4bdf-bbc7-dbb57cd2465a	2018-03-04 15:58:37.444799-06	2	[22127] None	[21041] OSSI-DNOVAK	[293] master	\N	\N
b840235a-db64-441c-ab2a-68404287ce2b	2018-03-04 16:05:21.905241-06	2	[21935] 330B IC-IN	[4] DLarrabee	[21062] a	\N	\N
cf9ce565-b642-4a26-ae56-402857b1c710	2018-03-04 16:05:35.553605-06	2	[22120] 330B IC-OUT	[4] DLarrabee	[21062] a	\N	\N
48806a22-4229-4d2d-9352-464d9fd10057	2018-03-04 16:05:50.421092-06	2	[22276] 330A IC-IN	[4] DLarrabee	[21062] a	\N	\N
b7813f33-29d4-4d51-9595-41ac59738fb7	2018-03-04 16:06:04.448495-06	2	[22277] 330A IC-OUT	[4] DLarrabee	[21062] a	\N	\N
a7ee85fa-4b4b-4937-b960-359526f13200	2018-03-04 16:07:07.526802-06	2	[22096] Door 330A	[4] DLarrabee	[21062] a	\N	\N
53a1efdd-c536-425e-89a1-d7aa7a8f334d	2018-03-04 16:07:20.758125-06	2	[22097] Door 330B	[4] DLarrabee	[21062] a	\N	\N
e40437da-0828-4a3d-a738-b23f20d28d97	2018-03-04 16:27:32.394276-06	2	[22189] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
14400342-ffff-4621-acd5-0e4a4073ba0d	2018-03-04 16:29:41.133149-06	2	[22188] IC 324C-InB	[4] DLarrabee	[21062] a	\N	\N
71c9bded-eca0-4132-b1a9-8835c77df6c6	2018-03-04 16:30:23.75341-06	2	[22187] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
15c95f4d-66f3-4cd2-9075-1861a33ac382	2018-03-04 16:33:06.831717-06	2	[22190] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
fff7d6c3-ce65-475c-8dca-179a4133cbbe	2018-03-04 16:33:47.021735-06	2	[22191] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
f90bf4dd-140b-4fcc-9106-a58e9b690581	2018-03-04 16:34:43.123345-06	3	[22189] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
e7a008d7-9121-42ce-a6f1-899ea7713505	2018-03-04 16:34:43.417374-06	2	[22190] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
79906cbd-51c9-4270-b59f-d9c239c35306	2018-03-04 16:34:43.422375-06	2	[22191] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
c2fa8fb6-8d65-4141-8cb3-2f3f6414bde9	2018-03-04 16:34:43.428375-06	2	[22196] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
50766f74-2ddf-4423-a38b-d2444820b99e	2018-03-04 16:34:43.435376-06	2	[22197] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
de61a2f4-255d-4801-9b92-59e1bf7021e0	2018-03-04 16:34:43.440377-06	2	[22198] 259	[4] DLarrabee	[21062] a	\N	\N
d7720234-7326-49b3-8116-1cd9086bd031	2018-03-04 16:34:43.444377-06	2	[22202] 301	[4] DLarrabee	[21062] a	\N	\N
4746f53c-b745-4491-8bb9-7325c642bbaa	2018-03-04 16:34:43.448377-06	2	[22209] 306	[4] DLarrabee	[21062] a	\N	\N
e64f5245-832d-41b6-81db-69d90639eeee	2018-03-04 16:34:43.452378-06	2	[22218] 307	[4] DLarrabee	[21062] a	\N	\N
cd74e935-2a8e-46cc-ab2a-d585fe68b693	2018-03-04 16:34:43.456378-06	2	[22219] 309	[4] DLarrabee	[21062] a	\N	\N
e5c8c6de-19b6-4835-ae58-ad6e86c412f2	2018-03-04 16:34:43.460379-06	2	[22220] 314	[4] DLarrabee	[21062] a	\N	\N
a2a2b48c-b6a7-4841-b3c5-b7162e08346e	2018-03-04 16:34:43.464379-06	2	[22211] 316	[4] DLarrabee	[21062] a	\N	\N
eeec9380-afc2-4ffb-8d18-95db7951e0af	2018-03-04 16:34:43.468379-06	2	[22221] 322	[4] DLarrabee	[21062] a	\N	\N
24fa2f2a-c0e6-424c-9661-1b7b48cd80d1	2018-03-04 16:34:43.47238-06	2	[22222] 323	[4] DLarrabee	[21062] a	\N	\N
4468e6bc-a467-45cd-afd2-f5c1a54abdc0	2018-03-04 16:34:43.47638-06	2	[22223] 324	[4] DLarrabee	[21062] a	\N	\N
352ea1b6-35a3-4dd4-9217-815b7899c11d	2018-03-04 16:34:43.47938-06	2	[22224] 326	[4] DLarrabee	[21062] a	\N	\N
e41b26dc-a890-439d-93cc-6d05a41d8cff	2018-03-04 16:34:43.486381-06	2	[22225] 327	[4] DLarrabee	[21062] a	\N	\N
ca3d748d-eadf-47a1-b751-ed73b2430575	2018-03-04 16:34:43.490382-06	2	[22226] 329	[4] DLarrabee	[21062] a	\N	\N
81f2fd70-294e-4f88-90e0-b2cbee5f4f65	2018-03-04 16:34:43.493382-06	2	[22227] 330	[4] DLarrabee	[21062] a	\N	\N
5608f5aa-4cbe-476c-b77a-3352121c5906	2018-03-04 16:34:43.498382-06	2	[22228] 333	[4] DLarrabee	[21062] a	\N	\N
8cfe5b4f-22ff-413a-93ae-ee7c518d0b82	2018-03-04 16:34:43.501383-06	2	[22229] 334	[4] DLarrabee	[21062] a	\N	\N
5d5b9aaa-3152-4026-84f8-7ff3a87c9ee6	2018-03-04 16:34:43.505383-06	2	[22230] 335	[4] DLarrabee	[21062] a	\N	\N
19b5f7b8-1608-4f73-a305-b6f13e1aebf8	2018-03-04 16:34:43.508383-06	2	[22231] 336	[4] DLarrabee	[21062] a	\N	\N
7d6f1716-ae60-469c-a333-b501fad11dab	2018-03-04 16:34:43.512384-06	2	[22232] 337	[4] DLarrabee	[21062] a	\N	\N
980b41ef-11da-4611-8697-8627f7c3a918	2018-03-04 16:34:43.515384-06	2	[22233] 338	[4] DLarrabee	[21062] a	\N	\N
65309cd5-2f06-4c77-b904-5a0469e7e591	2018-03-04 16:34:43.519384-06	2	[22234] 342	[4] DLarrabee	[21062] a	\N	\N
c5c45b58-6e2b-4ea5-a92e-38db778aa29d	2018-03-04 16:34:43.522385-06	2	[22235] 343	[4] DLarrabee	[21062] a	\N	\N
516bcee8-f9ee-4dd1-b38d-196daa0cc8d2	2018-03-04 16:34:43.527385-06	2	[22414] 344	[4] DLarrabee	[21062] a	\N	\N
dbd00d22-8473-49bc-bb6f-2686997402ab	2018-03-04 16:34:43.529385-06	2	[22415] 346	[4] DLarrabee	[21062] a	\N	\N
7d6bffff-371b-48ac-b6b4-57ea70aa6e5d	2018-03-04 16:34:43.534386-06	2	[22416] 347	[4] DLarrabee	[21062] a	\N	\N
1de3375a-991c-4852-934c-812ffeaadb4a	2018-03-04 16:34:43.537386-06	2	[22417] 348	[4] DLarrabee	[21062] a	\N	\N
712e6999-7f90-46b9-b5f4-951dab25c0e6	2018-03-04 16:34:43.542387-06	2	[22418] 349	[4] DLarrabee	[21062] a	\N	\N
b47d9786-185b-4f7a-8ea7-fb5d7fbcb4af	2018-03-04 16:34:43.545387-06	2	[22419] 351	[4] DLarrabee	[21062] a	\N	\N
3a07fc56-fc9a-4a91-8305-4bcb6338d02f	2018-03-04 16:34:43.548387-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
ebfe60e0-ade4-4b80-b492-9b141e176cc1	2018-03-04 16:34:43.551388-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
2e890534-937e-4d20-8f47-35cd3ffa6c3c	2018-03-04 16:34:43.562389-06	2	[22081] Door 352A	[4] DLarrabee	[21062] a	\N	\N
0c218192-17cd-4bd4-9f3a-907b3215ce78	2018-03-04 16:35:21.251157-06	2	[21779] B 1 LIVING ROOM 211 Copy (1)	[21041] OSSI-DNOVAK	[293] master	\N	\N
63eba79d-10c2-4f85-b1e7-6407b0153cc5	2018-03-04 16:36:37.105742-06	2	[21781] B 1 LIVING ROOM 211 Copy (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
d40ea1af-cb73-4c07-8011-c0751df4a6fb	2018-03-04 16:36:55.014533-06	2	[21781] B 1 LIVING ROOM 211 Copy (3)	[21041] OSSI-DNOVAK	[293] master	\N	\N
57ed9c9f-8f15-4aeb-8e1d-6d2ef1745842	2018-03-04 16:38:08.063837-06	2	[21790] B 1 LIVING ROOM 211 Copy (5)	[21041] OSSI-DNOVAK	[293] master	\N	\N
d08cff01-78c5-4602-9858-f1087815d585	2018-03-04 16:38:28.79691-06	2	[22095] Door 333	[4] DLarrabee	[21062] a	\N	\N
6a7e8612-ef6e-42a7-9e54-89ac573e36b3	2018-03-04 16:38:33.706401-06	2	[21791] B 1 LIVING ROOM 211 Copy (6)	[21041] OSSI-DNOVAK	[293] master	\N	\N
44cbf09c-5178-4d11-9c50-4a15acd7f9b7	2018-03-04 16:39:56.712701-06	2	[21789] B 1 LIVING ROOM 211 Copy (4)	[21041] OSSI-DNOVAK	[293] master	\N	\N
b107dcfa-5dc4-4300-972d-c2f8a27aef29	2018-03-04 16:40:21.377167-06	2	[21216] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
175a2fbb-adb3-4b2f-ad18-ecefd7ee0fd4	2018-03-04 16:41:17.11774-06	2	[22095] Door 333	[4] DLarrabee	[21062] a	\N	\N
466f74f6-4610-4955-afd3-d87ba2b463ee	2018-03-04 16:41:46.511679-06	1	[22122] 334 Copy	[4] DLarrabee	[21062] a	\N	\N
48b296e0-b343-4145-a9f8-02192260bf37	2018-03-04 16:43:39.386966-06	2	[21797] B 1 LIVING ROOM 211 Copy (12)	[21041] OSSI-DNOVAK	[293] master	\N	\N
8142291b-76f3-4e25-8cde-14df45e183f7	2018-03-04 16:44:01.513178-06	2	[22068] Door 334A	[4] DLarrabee	[21062] a	\N	\N
95f8d286-09e1-4f59-b24d-f3fb9f1b2d68	2018-03-04 16:44:07.414768-06	2	[21798] B 1 LIVING ROOM 211 Copy (13)	[21041] OSSI-DNOVAK	[293] master	\N	\N
ef41a37b-670f-4582-80a6-d59790d85466	2018-03-04 16:44:37.266753-06	2	[21797] B 1 LIVING ROOM 211 Copy (12)	[21041] OSSI-DNOVAK	[293] master	\N	\N
1bace505-a957-45cb-80b8-bc33e022a516	2018-03-04 16:45:00.107037-06	2	[21798] B 1 LIVING ROOM 211 Copy (13)	[21041] OSSI-DNOVAK	[293] master	\N	\N
e4195154-23e2-4366-b6eb-397de09a7405	2018-03-04 16:46:08.751901-06	2	[21795] B 1 LIVING ROOM 211 Copy (10)	[21041] OSSI-DNOVAK	[293] master	\N	\N
e7b178eb-3541-4c43-8b75-8dd126d365b8	2018-03-04 16:46:46.890714-06	2	[21796] B 1 LIVING ROOM 211 Copy (11)	[21041] OSSI-DNOVAK	[293] master	\N	\N
db5c8372-adfa-4606-bdbd-9cb3e34d2765	2018-03-04 16:47:34.619487-06	2	[21792] B 1 LIVING ROOM 211 Copy (7)	[21041] OSSI-DNOVAK	[293] master	\N	\N
f4fb318e-24f2-468e-b1de-b9a11946daed	2018-03-04 16:48:12.608285-06	2	[21793] B 1 LIVING ROOM 211 Copy (8)	[21041] OSSI-DNOVAK	[293] master	\N	\N
c47d6e2f-deca-4ec9-bd89-b3d49368d7c9	2018-03-04 16:48:35.35856-06	2	[21794] B 1 LIVING ROOM 211 Copy (9)	[21041] OSSI-DNOVAK	[293] master	\N	\N
bc87f5a8-adb6-4f9d-abc2-fa1711b8204f	2018-03-04 16:49:03.545378-06	2	[21799] B 1 LIVING ROOM 211 Copy (14)	[21041] OSSI-DNOVAK	[293] master	\N	\N
f1907d07-aeb8-40e7-b9ca-21ab6ccdafad	2018-03-04 16:50:00.538077-06	2	[21799] B 1 LIVING ROOM 211 Copy (14)	[21041] OSSI-DNOVAK	[293] master	\N	\N
9eccba1c-8484-445d-a14d-e8912228437c	2018-03-04 16:51:09.929016-06	2	[21801] B 1 LIVING ROOM 211 Copy (16)	[21041] OSSI-DNOVAK	[293] master	\N	\N
e712f93d-6e2f-431e-b430-5d410777875d	2018-03-04 16:52:18.833905-06	2	[22068] Door 334A	[4] DLarrabee	[21062] a	\N	\N
cc3d2fce-4800-4476-9c4f-eefc64e4e564	2018-03-04 16:52:28.945916-06	2	[21802] B 1 LIVING ROOM 211 Copy (17)	[21041] OSSI-DNOVAK	[293] master	\N	\N
b2222388-7079-424b-9f40-b92132057187	2018-03-04 16:53:06.173639-06	2	[21803] B 1 LIVING ROOM 211 Copy (18)	[21041] OSSI-DNOVAK	[293] master	\N	\N
c23f5297-ac81-453c-82a3-82879bbee8ab	2018-03-04 16:55:53.181338-06	2	[21804] B 1 LIVING ROOM 211 Copy (19)	[21041] OSSI-DNOVAK	[293] master	\N	\N
d6107261-451a-42a2-ad4b-e9eddb168c61	2018-03-04 16:57:13.032322-06	2	[22069] Door 335A	[4] DLarrabee	[21062] a	\N	\N
b9dc7982-16a8-4f67-b756-60517d6c62c9	2018-03-04 17:03:16.591675-06	2	[22122] 334	[4] DLarrabee	[21062] a	\N	\N
288ee747-5239-4420-a834-48d9faaa77a3	2018-03-04 17:06:32.491263-06	1	[22123] Door 335A	[4] DLarrabee	[21062] a	\N	\N
60db9888-ea1d-4472-be09-0a07b62b85b3	2018-03-04 17:10:42.444255-06	1	[22124] Door 335A	[4] DLarrabee	[21062] a	\N	\N
a9a8174f-7d9b-400f-9c65-dc3294380421	2018-03-04 17:15:05.279536-06	3	[22069] Door 335A	[4] DLarrabee	[21062] a	\N	\N
530c8ad6-e893-4086-9bcd-b359657d8ed1	2018-03-04 17:15:05.579566-06	2	[22149] IC 335A	[4] DLarrabee	[21062] a	\N	\N
34b30eb2-17d4-4482-a988-da68466940bc	2018-03-04 17:15:05.584567-06	2	[22150] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
c49bb830-50b5-45c3-b436-fcb3661d1df9	2018-03-04 17:16:45.085516-06	3	[22149] IC 335A	[4] DLarrabee	[21062] a	\N	\N
6bd8a886-6efe-45b0-a55c-f8dba706e70c	2018-03-04 17:16:45.367544-06	2	[22150] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
cc45d62d-cec4-4915-9981-3cbc5e2c9b52	2018-03-04 17:16:45.386546-06	2	[21102] Door 335A	[4] DLarrabee	[21062] a	\N	\N
fbb58362-e94d-4fc5-aef2-4103db14b6de	2018-03-04 17:16:51.62817-06	3	[22150] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
fba3d7b4-c498-41fa-88f3-cfc2b4c6c04a	2018-03-04 17:16:51.905198-06	2	[21102] Door 335A	[4] DLarrabee	[21062] a	\N	\N
181999c7-cffb-49ec-a0fb-6a4803888777	2018-03-04 17:17:30.965103-06	1	[22069] IC 335A	[4] DLarrabee	[21062] a	\N	\N
ac10a38d-a57d-4473-bd64-1d9d5b35c331	2018-03-04 17:17:40.652072-06	1	[22124] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
5506a8b7-6e98-4885-86cb-8f7a2c0d7add	2018-03-04 17:22:25.45955-06	2	[21102] Door 335A	[4] DLarrabee	[21062] a	\N	\N
e4071710-9ebc-47e9-bd28-aaf0bf75bf49	2018-03-04 17:24:10.136016-06	2	[22070] Door 336A	[4] DLarrabee	[21062] a	\N	\N
63412a5a-6bb0-42f2-91fb-fcbc131c23f9	2018-03-04 17:24:24.296432-06	2	[21102] Door 335A	[4] DLarrabee	[21062] a	\N	\N
49a33c3e-0a83-41d5-8b6c-0fbe9e5567de	2018-03-04 17:29:52.482248-06	2	[22070] Door 336A	[4] DLarrabee	[21062] a	\N	\N
e9577f7a-fef9-4125-ad29-3176063ca114	2018-03-04 17:32:39.174915-06	2	[22071] Door 337A	[4] DLarrabee	[21062] a	\N	\N
0518e9aa-466e-49e2-9224-54d4ce26dc8d	2018-03-04 17:36:57.257721-06	2	[22071] Door 337A	[4] DLarrabee	[21062] a	\N	\N
d5467751-abb3-4c15-9b25-451c11438e63	2018-03-04 17:39:18.422836-06	2	[22072] Door 338A	[4] DLarrabee	[21062] a	\N	\N
b158944d-a51e-4af1-baf4-0576f7ae4dc2	2018-03-04 17:43:07.397731-06	2	[22073] Door 343A	[4] DLarrabee	[21062] a	\N	\N
a1c45696-4c4e-4ec8-8cb2-4e4340fceed8	2018-03-04 17:43:20.481039-06	2	[22073] Door 343A	[4] DLarrabee	[21062] a	\N	\N
ce30d46c-9a38-418e-af93-4fa2ab712f7f	2018-03-04 17:46:34.062396-06	1	[22149] Door 346A Copy	[4] DLarrabee	[21062] a	\N	\N
e66899b5-abe9-431b-a542-e824dc9cdf7c	2018-03-04 17:53:33.55234-06	2	[21045] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
87ea676c-e77b-401b-a169-83605f2520d1	2018-03-04 17:53:38.835869-06	2	[21045] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
173a3e56-8bf1-4123-981e-a91614468d59	2018-03-04 17:56:08.749859-06	2	[22149] Door 342	[4] DLarrabee	[21062] a	\N	\N
cdf9eb3c-d3d0-46b4-ae15-3099a232250b	2018-03-04 17:58:58.296812-06	2	[22149] Door 342	[4] DLarrabee	[21062] a	\N	\N
82db1587-d246-41ad-a95a-55478f536414	2018-03-04 18:00:21.838165-06	3	[22123] Door 335A	[4] DLarrabee	[21062] a	\N	\N
c6a9c16e-9c52-4e12-8f8c-0999461384b7	2018-03-04 18:15:09.407913-06	2	[22213] Door 316B -2	[4] DLarrabee	[21062] a	\N	\N
01a1123f-36e5-43e6-95b8-e094773485eb	2018-03-04 18:18:17.960766-06	2	[21690] A 5 LIVING ROOM 113	[21041] OSSI-DNOVAK	[293] master	\N	\N
a53be2db-07be-4ed7-a832-f4cd799970c6	2018-03-04 18:20:04.90346-06	2	[21690] A 5 LIVING ROOM 113	[21041] OSSI-DNOVAK	[293] master	\N	\N
7ffc4b2f-e08f-493e-bed4-6796298213a7	2018-03-04 18:21:29.171886-06	2	[21692] A 7 LIVING ROOM 113 	[21041] OSSI-DNOVAK	[293] master	\N	\N
7486934d-9179-4a6f-8c43-146b560d6776	2018-03-04 18:22:04.255394-06	3	[22122] 334	[4] DLarrabee	[21062] a	\N	\N
e84be144-efdb-4906-9ae1-174d979414bc	2018-03-04 18:22:06.150583-06	2	[21693] A 8 LIVING ROOM 113	[21041] OSSI-DNOVAK	[293] master	\N	\N
12839369-330d-43a1-afb1-62c80ad04ffe	2018-03-04 18:22:26.230591-06	2	[21693] A 8 LIVING ROOM 113	[21041] OSSI-DNOVAK	[293] master	\N	\N
74242259-7065-43c9-bba8-a5d417db8fd0	2018-03-04 18:24:09.213888-06	2	[21694] A 9 COURTYARD 114	[21041] OSSI-DNOVAK	[293] master	\N	\N
2c40106e-ee4f-4759-a00c-b1ef0a670b7b	2018-03-04 18:25:26.83865-06	2	[21695] A 10 LIVING ROOM 133	[21041] OSSI-DNOVAK	[293] master	\N	\N
cd0d811e-5efd-462c-a74e-92cd320871c5	2018-03-04 18:26:00.283994-06	2	[21696] A 11 LIVING ROOM 133	[21041] OSSI-DNOVAK	[293] master	\N	\N
c9f2ee72-d82c-4434-b767-6eee1370079c	2018-03-04 18:26:39.569922-06	2	[21696] A 11 LIVING ROOM 133	[21041] OSSI-DNOVAK	[293] master	\N	\N
9f90cc84-c2e7-4a0c-8dca-49bf6c9fd8b1	2018-03-04 18:26:45.294495-06	2	[21698] A 13 LIVING ROOM 133 	[21041] OSSI-DNOVAK	[293] master	\N	\N
aa597a91-5c8a-4032-9235-ff972efda836	2018-03-04 18:26:52.866252-06	2	[21698] A 13 LIVING ROOM 133 	[21041] OSSI-DNOVAK	[293] master	\N	\N
0a02b1f4-2dac-4846-98fb-d379aa85bc3b	2018-03-04 18:28:03.189283-06	2	[21698] A 13 LIVING ROOM 133 	[21041] OSSI-DNOVAK	[293] master	\N	\N
1959582b-7796-40f1-885d-791b14eeb037	2018-03-04 18:29:24.814445-06	2	[21699] A 14 COURTYARD 134 	[21041] OSSI-DNOVAK	[293] master	\N	\N
17c9eea2-1507-463e-8ad8-dfdb7d5b379e	2018-03-04 18:32:48.634825-06	2	[22074] Door 344A	[4] DLarrabee	[21062] a	\N	\N
2ec837a3-416d-4e6d-824e-2a3095f31ead	2018-03-04 18:38:27.798101-06	2	[22075] Door 346A	[4] DLarrabee	[21062] a	\N	\N
e3ff1322-b137-46a9-9f89-21490f0700ab	2018-03-04 18:38:38.223016-06	2	[22074] Door 344A	[4] DLarrabee	[21062] a	\N	\N
fff4fc73-4432-489a-b128-00b3759e34ba	2018-03-04 18:41:13.076039-06	2	[22076] Door 347A	[4] DLarrabee	[21062] a	\N	\N
dfbe3d88-84f5-43c8-b0c0-a514450ec326	2018-03-04 18:45:19.914888-06	2	[21702] A 17 CORRIDOR 154	[21041] OSSI-DNOVAK	[293] master	\N	\N
0f1ebfa6-b635-45d6-bfc7-9db4aa43a586	2018-03-04 18:45:32.030888-06	2	[21702] A 17 CORRIDOR 154	[21041] OSSI-DNOVAK	[293] master	\N	\N
5d28009c-91ae-4082-bb02-47d00adab8f3	2018-03-04 18:45:46.349888-06	2	[21702] A 17 CORRIDOR 154	[21041] OSSI-DNOVAK	[293] master	\N	\N
52bfb576-1b2f-49be-ae2a-c810dc4fab16	2018-03-04 18:47:00.679888-06	2	[21704] A 19 CORRIDOR 154	[21041] OSSI-DNOVAK	[293] master	\N	\N
f11d0001-9681-4738-9725-16fba158b1a7	2018-03-04 18:47:15.281888-06	2	[21704] A 19 CORRIDOR 154	[21041] OSSI-DNOVAK	[293] master	\N	\N
48c4c6e1-94c4-4555-a64f-ac63edd3475e	2018-03-04 18:47:57.116888-06	2	[21704] A 19 CORRIDOR 154	[21041] OSSI-DNOVAK	[293] master	\N	\N
f35026db-62f1-479a-99c6-bb26f5a3f870	2018-03-04 18:49:30.232888-06	2	[22077] Door 348A	[4] DLarrabee	[21062] a	\N	\N
67bf33b9-8116-41a9-8015-f2e5546b9a07	2018-03-04 18:50:47.695888-06	2	[21713] A28 CALMING ROOM 146	[21041] OSSI-DNOVAK	[293] master	\N	\N
a992cdb3-7e71-4e47-a749-2de37257a5f1	2018-03-04 18:51:45.451888-06	2	[21709] A24 ADA SLEEPING 119	[21041] OSSI-DNOVAK	[293] master	\N	\N
e242c5f0-42d7-49d3-a99a-19fd0ca2a711	2018-03-04 18:52:22.817888-06	2	[22077] Door 348A	[4] DLarrabee	[21062] a	\N	\N
7bcb5adf-da48-4eb1-bb8f-74dad969b56a	2018-03-04 18:52:41.889888-06	2	[21708] A23 ADA SLEEPING 125	[21041] OSSI-DNOVAK	[293] master	\N	\N
3e8bebb8-2fbb-4085-855b-99e97fb334d7	2018-03-04 18:53:12.819888-06	2	[21712] A27 SINGLE SLEEPING 103	[21041] OSSI-DNOVAK	[293] master	\N	\N
980ec63e-910e-4182-9d2e-7f57dd92ec56	2018-03-04 19:18:14.072403-06	1	[22122] Door 327A 	[4] DLarrabee	[21062] a	\N	\N
310ae7f4-b239-4f8b-82d5-a1f7480c82b9	2018-03-04 19:18:25.312527-06	1	[22123] IC 327A	[4] DLarrabee	[21062] a	\N	\N
da82bf15-d260-4b7a-a0ef-5b36e3ccce0c	2018-03-04 19:18:31.060101-06	1	[22150] IC 327A-outB	[4] DLarrabee	[21062] a	\N	\N
99cbb001-2ece-4e50-a4dc-12aaeef457f3	2018-03-04 19:22:29.228916-06	3	[22142] IC 327A-outB	[4] DLarrabee	[21062] a	\N	\N
2564d5c3-19d5-4ca2-a076-0c0ff735c663	2018-03-04 19:22:35.244517-06	3	[22141] IC 327A	[4] DLarrabee	[21062] a	\N	\N
8151af94-213b-45b3-a3d6-88914cfac6cf	2018-03-04 19:22:41.103103-06	3	[22065] Door 327A 	[4] DLarrabee	[21062] a	\N	\N
7d3607aa-07b5-4e2f-ae21-87539f97ca70	2018-03-04 19:24:06.147607-06	2	[22122] Door 327A 	[4] DLarrabee	[21062] a	\N	\N
80b35b5f-b34f-485c-896b-99d7ae402af0	2018-03-04 19:24:58.192811-06	2	[22122] Door 327A 	[4] DLarrabee	[21062] a	\N	\N
2d670b8f-109a-46da-a84b-1e778826f8d7	2018-03-04 19:25:48.621853-06	2	[22122] Door 327A 	[4] DLarrabee	[21062] a	\N	\N
c41e056b-6515-41a4-9482-f4bb1ebc6190	2018-03-04 19:29:38.283817-06	2	[22084] Door 324OHDW OPEN/CLOSE	[4] DLarrabee	[21062] a	\N	\N
d0471962-2039-4585-9a43-6a94abcc466c	2018-03-04 19:31:46.746662-06	2	[22085] Door 323OHD OPEN/CLOSE	[4] DLarrabee	[21062] a	\N	\N
ac6f3e60-e1e7-4811-a57a-f446e1f61feb	2018-03-04 19:35:23.941379-06	2	[22078] Door 349A	[4] DLarrabee	[21062] a	\N	\N
9cf0b372-427f-44fe-a667-bc64677268a7	2018-03-04 19:41:19.505932-06	2	[22084] Door 324OHDW OPEN/CLOSE	[21041] OSSI-DNOVAK	[293] master	\N	\N
789744df-ed23-4935-825e-287c5aaacbb5	2018-03-04 19:41:52.869268-06	2	[22084] Door 324OHDW OPEN/CLOSE	[21041] OSSI-DNOVAK	[293] master	\N	\N
3934d6c1-b5e2-4e50-9d47-21e62451b98b	2018-03-04 19:43:11.264107-06	2	[22079] Door 351A	[4] DLarrabee	[21062] a	\N	\N
9d9bca7c-d7d0-48f8-b0e0-44fae2ab9dac	2018-03-04 19:43:33.702351-06	2	[22080] Door 351B	[4] DLarrabee	[21062] a	\N	\N
068a7611-1c4c-4c55-99d6-8ec6e7793053	2018-03-04 19:43:43.377318-06	2	[22078] Door 349A	[4] DLarrabee	[21062] a	\N	\N
33659a66-86e0-46c8-a39b-ce672d045770	2018-03-04 19:44:12.311211-06	2	[22086] Door 324OHDE OPEN/CLOSE	[21041] OSSI-DNOVAK	[293] master	\N	\N
5bb11ca4-ad02-4bee-af38-4eced189a3dd	2018-03-04 19:46:54.738452-06	1	[22065] 330B IC-IN Copy	[4] DLarrabee	[21062] a	\N	\N
92a8e4c1-06ce-414b-8b06-120c6348e203	2018-03-04 19:47:24.761454-06	1	[22141] 330A IC-OUT Copy	[4] DLarrabee	[21062] a	\N	\N
53fa9993-60ed-44f4-8b7d-606ee69495ac	2018-03-04 19:47:51.773155-06	1	[22142] 330A IC-OUT Copy	[4] DLarrabee	[21062] a	\N	\N
646a9c57-5b30-4a22-85cd-51445b1ee951	2018-03-04 19:48:00.690047-06	3	[22142] 330A IC-OUT Copy	[4] DLarrabee	[21062] a	\N	\N
2bb20356-ee50-4733-bbea-042a21ac4ea3	2018-03-04 19:48:09.437921-06	1	[22142] 351 Copy	[4] DLarrabee	[21062] a	\N	\N
377cd0af-8bc9-4e4c-a9dd-0ffcce6f9683	2018-03-04 19:49:20.740051-06	2	[22065] 351A+B IC-IN	[4] DLarrabee	[21062] a	\N	\N
2c910a11-b233-4c07-8f89-69d51c551cf6	2018-03-04 19:49:47.204697-06	2	[22141] 351A+B IC-OUT	[4] DLarrabee	[21062] a	\N	\N
ec0fd239-a87e-42ee-99eb-0f2a2d223192	2018-03-04 19:50:11.958172-06	2	[22142] 351A 	[4] DLarrabee	[21062] a	\N	\N
784726ab-630a-49fd-8363-5934863f6aed	2018-03-04 19:51:17.715747-06	1	[22189] 351A  Copy	[4] DLarrabee	[21062] a	\N	\N
4562199c-5e1c-4513-9284-bc2e939ba79f	2018-03-04 19:52:26.265602-06	2	[22142] 351A 	[4] DLarrabee	[21062] a	\N	\N
38efebb7-985f-42e5-9182-f980600bf54a	2018-03-04 19:52:52.497224-06	2	[22189] 351A  Copy	[4] DLarrabee	[21062] a	\N	\N
d49b3584-d833-460d-8ae5-915093ab6e35	2018-03-04 19:57:24.859458-06	2	[22189] 351B	[4] DLarrabee	[21062] a	\N	\N
e3ee4f74-d30e-4e53-b288-ca6b76dcdc9e	2018-03-04 19:59:33.49332-06	2	[22065] 351A+B IC-IN	[4] DLarrabee	[21062] a	\N	\N
228d3ee3-1037-4a1c-acc2-084744334797	2018-03-04 20:05:34.089376-06	3	[22081] Door 352A	[4] DLarrabee	[21062] a	\N	\N
43b90c0e-28bb-4585-884f-89caa81ebaf2	2018-03-04 20:05:34.390406-06	2	[22098] Door 378	[4] DLarrabee	[21062] a	\N	\N
92cbe346-7149-46d6-b7cb-8e9492ffb2fb	2018-03-04 20:05:54.263393-06	3	[22098] Door 378	[4] DLarrabee	[21062] a	\N	\N
7a982389-9995-4d7f-a104-d96bc99883e6	2018-03-04 20:09:00.187984-06	3	[22173] IC 352A	[4] DLarrabee	[21062] a	\N	\N
b2c090e9-2cd3-4553-b8d9-d462a073036e	2018-03-04 20:09:00.477013-06	2	[22174] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
588b5802-3b88-4f32-bba2-bfcf1ce9c206	2018-03-04 20:09:00.482013-06	2	[22196] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
437a2ac2-5ea7-47f7-8175-788e7e1375cf	2018-03-04 20:09:00.487014-06	2	[22197] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
262dbb28-8b04-4f91-907c-2e6192a6a11b	2018-03-04 20:09:00.491014-06	2	[22198] 259	[4] DLarrabee	[21062] a	\N	\N
3140dcea-df3c-44f0-803d-3471db8da04b	2018-03-04 20:09:00.500015-06	2	[22202] 301	[4] DLarrabee	[21062] a	\N	\N
0c5e3a97-9d49-41c1-8cc8-b9135bc83607	2018-03-04 20:09:00.506016-06	2	[22209] 306	[4] DLarrabee	[21062] a	\N	\N
acd6ee28-98b7-4d3f-8b8e-161e248da10b	2018-03-04 20:09:00.509016-06	2	[22218] 307	[4] DLarrabee	[21062] a	\N	\N
0039b6d3-5824-4239-8346-fd6baa63919e	2018-03-04 20:09:00.513016-06	2	[22219] 309	[4] DLarrabee	[21062] a	\N	\N
a3e4e6c5-7223-46fe-aaef-d8eb98d2ac89	2018-03-04 20:09:00.517017-06	2	[22220] 314	[4] DLarrabee	[21062] a	\N	\N
7fbf5025-0854-4317-bb1b-fcfaf1af673c	2018-03-04 20:09:00.520017-06	2	[22211] 316	[4] DLarrabee	[21062] a	\N	\N
1ee8b122-9c51-4d67-9f94-ff93dc23ee81	2018-03-04 20:09:00.523017-06	2	[22221] 322	[4] DLarrabee	[21062] a	\N	\N
09bc2f52-b5a6-429d-a821-1c3a0d40533b	2018-03-04 20:09:00.527018-06	2	[22222] 323	[4] DLarrabee	[21062] a	\N	\N
3bb2cb61-b962-4ac8-8461-1c8938a2f520	2018-03-04 20:09:00.532018-06	2	[22223] 324	[4] DLarrabee	[21062] a	\N	\N
3b4dc533-94ea-454c-88e7-18681a74ffdd	2018-03-04 20:09:00.536019-06	2	[22224] 326	[4] DLarrabee	[21062] a	\N	\N
8ea00c97-785f-4467-9a24-59b2f228ef8c	2018-03-04 20:09:00.540019-06	2	[22225] 327	[4] DLarrabee	[21062] a	\N	\N
2515ee0f-09f6-435c-8b37-669bd5db8298	2018-03-04 20:09:00.54502-06	2	[22226] 329	[4] DLarrabee	[21062] a	\N	\N
322ceaa1-42b6-4292-885b-02ea7017a235	2018-03-04 20:09:00.54902-06	2	[22227] 330	[4] DLarrabee	[21062] a	\N	\N
f9295209-aa68-43a0-94d7-77dad7ce66c4	2018-03-04 20:09:00.556021-06	2	[22228] 333	[4] DLarrabee	[21062] a	\N	\N
202fca00-995d-41a5-babe-434363326708	2018-03-04 20:09:00.560021-06	2	[22229] 334	[4] DLarrabee	[21062] a	\N	\N
25fbf60d-f97a-4997-8fe7-3359d25d6dbf	2018-03-04 20:09:00.567022-06	2	[22230] 335	[4] DLarrabee	[21062] a	\N	\N
9caec18b-a6c0-4919-9d3b-dee322d0a90f	2018-03-04 20:09:00.570022-06	2	[22231] 336	[4] DLarrabee	[21062] a	\N	\N
1eebea09-7a78-4b04-ba59-9033cbc0102b	2018-03-04 20:09:00.574022-06	2	[22232] 337	[4] DLarrabee	[21062] a	\N	\N
76353a90-530c-4c1f-aa24-2b2dfa1fba91	2018-03-04 20:09:00.577023-06	2	[22233] 338	[4] DLarrabee	[21062] a	\N	\N
7a7ed8f8-4be7-478e-8326-6c6e54348362	2018-03-04 20:09:00.581023-06	2	[22234] 342	[4] DLarrabee	[21062] a	\N	\N
1b2f141c-27f4-40f3-bf98-173d05ac2f41	2018-03-04 20:09:00.585024-06	2	[22235] 343	[4] DLarrabee	[21062] a	\N	\N
8262d295-9d99-4696-b245-f84456a55b5c	2018-03-04 20:09:00.590024-06	2	[22414] 344	[4] DLarrabee	[21062] a	\N	\N
b9ba3b0f-b4c0-43f6-90ef-d15abedd297c	2018-03-04 20:09:00.596025-06	2	[22415] 346	[4] DLarrabee	[21062] a	\N	\N
ce177d9a-d171-4163-98ff-6d921ae3fa73	2018-03-04 20:09:00.600025-06	2	[22416] 347	[4] DLarrabee	[21062] a	\N	\N
ac087995-f8ec-4f86-8c37-b47ecd2903d8	2018-03-04 20:09:00.604025-06	2	[22417] 348	[4] DLarrabee	[21062] a	\N	\N
b41448d1-5452-4b86-a506-733bf43def64	2018-03-04 20:09:00.608026-06	2	[22418] 349	[4] DLarrabee	[21062] a	\N	\N
13ed5b02-a677-4114-8194-0680ef8abf77	2018-03-04 20:09:00.614026-06	2	[22419] 351	[4] DLarrabee	[21062] a	\N	\N
ba9698af-7537-4a43-8fa6-a3ffe6330cd5	2018-03-04 20:09:09.176883-06	3	[22174] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
54cb9dc0-03db-4687-adf9-84395b4db808	2018-03-04 20:09:09.44891-06	2	[22196] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
964f0cdf-41fc-4b0f-a717-8f10edff1295	2018-03-04 20:09:09.45291-06	2	[22197] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
cdc143bd-f34a-4fb9-b8ba-4e9a1b8f2d8c	2018-03-04 20:09:09.457911-06	2	[22198] 259	[4] DLarrabee	[21062] a	\N	\N
9cac527e-3ae2-4ecb-8ad7-b6a42a598de7	2018-03-04 20:09:09.460911-06	2	[22202] 301	[4] DLarrabee	[21062] a	\N	\N
c9c23b6a-7a5e-4ed5-9c43-386b98b5221c	2018-03-04 20:09:09.465912-06	2	[22209] 306	[4] DLarrabee	[21062] a	\N	\N
da16d850-3eac-4ad2-907d-3b0af5e09152	2018-03-04 20:09:09.469912-06	2	[22218] 307	[4] DLarrabee	[21062] a	\N	\N
b5cbdda5-e2e8-4bbd-894a-47d5f0979a43	2018-03-04 20:09:09.473912-06	2	[22219] 309	[4] DLarrabee	[21062] a	\N	\N
31404fc0-1f35-4411-902c-f501bb146f54	2018-03-04 20:09:09.476913-06	2	[22220] 314	[4] DLarrabee	[21062] a	\N	\N
918a893f-e332-4255-97f6-4eb54eca190b	2018-03-04 20:09:09.480913-06	2	[22211] 316	[4] DLarrabee	[21062] a	\N	\N
435a5d63-5dfd-4cc1-8013-e9cfc9e48b2a	2018-03-04 20:09:09.483913-06	2	[22221] 322	[4] DLarrabee	[21062] a	\N	\N
7d55dc17-91b9-4a32-9bbe-bf4999710942	2018-03-04 20:09:09.487914-06	2	[22222] 323	[4] DLarrabee	[21062] a	\N	\N
92f880fc-ccee-4c6c-b069-9e8d0a7dd36c	2018-03-04 20:09:09.492914-06	2	[22223] 324	[4] DLarrabee	[21062] a	\N	\N
aea8daf1-19bc-4242-abba-ac0e8ce68864	2018-03-04 20:09:09.495915-06	2	[22224] 326	[4] DLarrabee	[21062] a	\N	\N
181a2078-f668-45cf-91e3-b0607fc4b10b	2018-03-04 20:09:09.498915-06	2	[22225] 327	[4] DLarrabee	[21062] a	\N	\N
e6e8ece8-c680-4f34-9c8c-a233438e17f6	2018-03-04 20:09:09.500915-06	2	[22226] 329	[4] DLarrabee	[21062] a	\N	\N
585d1e67-1d1f-4ae2-ae75-5e9bb87801ae	2018-03-04 20:09:09.503915-06	2	[22227] 330	[4] DLarrabee	[21062] a	\N	\N
b7a25683-9d1f-43b9-b088-c245fecebc26	2018-03-04 20:09:09.507916-06	2	[22228] 333	[4] DLarrabee	[21062] a	\N	\N
dfaf5c86-34a1-4b7e-9fe8-c832962953b4	2018-03-04 20:09:09.511916-06	2	[22229] 334	[4] DLarrabee	[21062] a	\N	\N
15e2b665-3c4b-46ab-9849-620bcf3abe93	2018-03-04 20:09:09.515917-06	2	[22230] 335	[4] DLarrabee	[21062] a	\N	\N
a12598d5-3570-4dee-8ce6-c0bc8bd0d296	2018-03-04 20:09:09.517917-06	2	[22231] 336	[4] DLarrabee	[21062] a	\N	\N
c671e250-c763-43a1-a944-8e06d65fbbcd	2018-03-04 20:09:09.521917-06	2	[22232] 337	[4] DLarrabee	[21062] a	\N	\N
47e286ff-1fb1-46eb-be13-423a6bcee03f	2018-03-04 20:09:09.524917-06	2	[22233] 338	[4] DLarrabee	[21062] a	\N	\N
3a3ea0f0-506d-4146-8e91-590d4d7c8ef6	2018-03-04 20:09:09.527918-06	2	[22234] 342	[4] DLarrabee	[21062] a	\N	\N
f0f50852-82eb-455d-8085-0f4dfa18b4d9	2018-03-04 20:09:09.530918-06	2	[22235] 343	[4] DLarrabee	[21062] a	\N	\N
31afbf71-c6b0-460e-a66c-f8ca2fd4da4a	2018-03-04 20:09:09.537919-06	2	[22414] 344	[4] DLarrabee	[21062] a	\N	\N
0166ddc8-765e-4afe-be0b-a69c5fc21c05	2018-03-04 20:09:09.542919-06	2	[22415] 346	[4] DLarrabee	[21062] a	\N	\N
f8174600-33d5-47e3-aee4-29698f188acb	2018-03-04 20:09:09.54692-06	2	[22416] 347	[4] DLarrabee	[21062] a	\N	\N
67a27437-8497-4223-8903-be7708333604	2018-03-04 20:09:09.55092-06	2	[22417] 348	[4] DLarrabee	[21062] a	\N	\N
c86fbe34-8c52-4fd3-be04-4719d84c5284	2018-03-04 20:09:09.55492-06	2	[22418] 349	[4] DLarrabee	[21062] a	\N	\N
06ca5268-379b-4466-9b46-bd47bbcd5165	2018-03-04 20:09:09.558921-06	2	[22419] 351	[4] DLarrabee	[21062] a	\N	\N
84097f9a-9b62-48b3-b916-71bc235e23ba	2018-03-04 20:09:17.572722-06	3	[22196] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
c034d442-75f2-46a5-a135-b1af7103e26f	2018-03-04 20:09:17.865751-06	2	[22197] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
1a1c2ec4-76f1-426a-a079-d2a12974d63d	2018-03-04 20:09:17.870752-06	2	[22198] 259	[4] DLarrabee	[21062] a	\N	\N
264c8b61-16a8-407f-934b-5cc2cd38188c	2018-03-04 20:09:17.873752-06	2	[22202] 301	[4] DLarrabee	[21062] a	\N	\N
831dfa23-283b-4ab9-b264-21b7df7c772b	2018-03-04 20:09:17.877753-06	2	[22209] 306	[4] DLarrabee	[21062] a	\N	\N
61c1122e-54ee-411c-b480-b4e543a6716b	2018-03-04 20:09:17.880753-06	2	[22218] 307	[4] DLarrabee	[21062] a	\N	\N
2c7db0c2-9f99-422e-9246-d20aa8389c03	2018-03-04 20:09:17.883753-06	2	[22219] 309	[4] DLarrabee	[21062] a	\N	\N
f206d0e0-39db-4c26-b2f4-38ed6866f65a	2018-03-04 20:09:17.886754-06	2	[22220] 314	[4] DLarrabee	[21062] a	\N	\N
ed356ce9-6e20-4f9d-ad06-280f862d6fcf	2018-03-04 20:09:17.893754-06	2	[22211] 316	[4] DLarrabee	[21062] a	\N	\N
3d745aea-302b-4cca-95d2-5bbdfe06ca0d	2018-03-04 20:09:17.897755-06	2	[22221] 322	[4] DLarrabee	[21062] a	\N	\N
d92ebd58-e7fe-40f4-8280-451db7570b61	2018-03-04 20:09:17.900755-06	2	[22222] 323	[4] DLarrabee	[21062] a	\N	\N
720cac4f-3d3f-4f0a-83cc-87903af411fb	2018-03-04 20:09:17.904755-06	2	[22223] 324	[4] DLarrabee	[21062] a	\N	\N
48004a91-1911-4d42-9094-ca7928771e66	2018-03-04 20:09:17.907756-06	2	[22224] 326	[4] DLarrabee	[21062] a	\N	\N
65259c0f-3889-45b8-b621-d2c3516ae550	2018-03-04 20:09:17.911756-06	2	[22225] 327	[4] DLarrabee	[21062] a	\N	\N
d28b512e-ff3b-4603-86af-0b2e79414c42	2018-03-04 20:09:17.914756-06	2	[22226] 329	[4] DLarrabee	[21062] a	\N	\N
42a447a7-4a70-465e-9905-3d13b1648249	2018-03-04 20:09:17.918757-06	2	[22227] 330	[4] DLarrabee	[21062] a	\N	\N
899f8680-7a0d-4c11-a310-a45e806b594d	2018-03-04 20:09:17.922757-06	2	[22228] 333	[4] DLarrabee	[21062] a	\N	\N
c3a89c95-6a89-400b-be3f-906e615be742	2018-03-04 20:09:17.926758-06	2	[22229] 334	[4] DLarrabee	[21062] a	\N	\N
2a914f61-a9d6-44d2-9f41-bd8d70e75a2c	2018-03-04 20:09:17.930758-06	2	[22230] 335	[4] DLarrabee	[21062] a	\N	\N
a6be228f-2316-4b3b-bee1-3d858c119f92	2018-03-04 20:09:17.933758-06	2	[22231] 336	[4] DLarrabee	[21062] a	\N	\N
23c821e9-31b9-42d3-a117-537f03b26b6a	2018-03-04 20:09:17.937759-06	2	[22232] 337	[4] DLarrabee	[21062] a	\N	\N
1ecdf6d8-eda6-42da-a5ba-e692f96d60ea	2018-03-04 20:09:17.943759-06	2	[22233] 338	[4] DLarrabee	[21062] a	\N	\N
1ee67133-348c-47ae-962b-c312d92df130	2018-03-04 20:09:17.94776-06	2	[22234] 342	[4] DLarrabee	[21062] a	\N	\N
0ad5521c-0a96-4e31-a812-b146d2c6db63	2018-03-04 20:09:17.95176-06	2	[22235] 343	[4] DLarrabee	[21062] a	\N	\N
f9d41fab-82f3-4a27-ba56-0d9c23d9387a	2018-03-04 20:09:17.95576-06	2	[22414] 344	[4] DLarrabee	[21062] a	\N	\N
0eaa9015-c042-43cc-88c0-d77963dafedf	2018-03-04 20:09:17.958761-06	2	[22415] 346	[4] DLarrabee	[21062] a	\N	\N
6f3cdde2-b8db-469e-9baf-a39a1a1f0a83	2018-03-04 20:09:17.962761-06	2	[22416] 347	[4] DLarrabee	[21062] a	\N	\N
42a32b7a-2125-4d3a-a663-1bbaa80f5c71	2018-03-04 20:09:17.965761-06	2	[22417] 348	[4] DLarrabee	[21062] a	\N	\N
5d380125-48d4-4620-8617-b114569c41a4	2018-03-04 20:09:17.969762-06	2	[22418] 349	[4] DLarrabee	[21062] a	\N	\N
83f70217-7668-44b5-95c2-d040119d1798	2018-03-04 20:09:17.972762-06	2	[22419] 351	[4] DLarrabee	[21062] a	\N	\N
cce67851-74cc-4a36-8935-424899dc04c2	2018-03-04 20:09:28.666831-06	3	[22197] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
99b0c28e-a017-436f-a8a1-935a6745ef65	2018-03-04 20:09:28.939859-06	2	[22198] 259	[4] DLarrabee	[21062] a	\N	\N
a1e23c6a-10da-447d-967d-5599aefd1640	2018-03-04 20:09:28.942859-06	2	[22202] 301	[4] DLarrabee	[21062] a	\N	\N
81283d33-0cc3-4f7a-b62f-166424f58a3c	2018-03-04 20:09:28.945859-06	2	[22209] 306	[4] DLarrabee	[21062] a	\N	\N
f2c8c099-f666-4350-805d-1a00a13e989e	2018-03-04 20:09:28.94986-06	2	[22218] 307	[4] DLarrabee	[21062] a	\N	\N
06d61e02-5397-4b17-bd44-3ec1632d9359	2018-03-04 20:09:28.95586-06	2	[22219] 309	[4] DLarrabee	[21062] a	\N	\N
da906505-4545-4a97-8bf9-124e52e19019	2018-03-04 20:09:28.959861-06	2	[22220] 314	[4] DLarrabee	[21062] a	\N	\N
8de326fa-8b67-4fe4-ac4d-14a44b7d6dca	2018-03-04 20:09:28.962861-06	2	[22211] 316	[4] DLarrabee	[21062] a	\N	\N
3b43466f-034c-4fef-af03-817652f477e5	2018-03-04 20:09:28.964861-06	2	[22221] 322	[4] DLarrabee	[21062] a	\N	\N
2c0ff562-97d4-40cd-b02f-9e31357c6a6f	2018-03-04 20:09:28.968862-06	2	[22222] 323	[4] DLarrabee	[21062] a	\N	\N
f63ca8e4-5082-421b-b7c2-09d0a83ad932	2018-03-04 20:09:28.972862-06	2	[22223] 324	[4] DLarrabee	[21062] a	\N	\N
63956d94-1d5d-4c3f-9d41-430f261689c5	2018-03-04 20:09:28.975862-06	2	[22224] 326	[4] DLarrabee	[21062] a	\N	\N
7dc2ade4-4ed9-4dad-8af7-bb44fe8860ea	2018-03-04 20:09:28.979863-06	2	[22225] 327	[4] DLarrabee	[21062] a	\N	\N
7b51bf7d-a183-43fb-8c04-1cf6a3f04481	2018-03-04 20:09:28.982863-06	2	[22226] 329	[4] DLarrabee	[21062] a	\N	\N
c4c33bbc-cbc4-421e-8d57-208457327fae	2018-03-04 20:09:28.986863-06	2	[22227] 330	[4] DLarrabee	[21062] a	\N	\N
c76bd6ed-7315-403c-849c-08e42fefdd9c	2018-03-04 20:09:28.989864-06	2	[22228] 333	[4] DLarrabee	[21062] a	\N	\N
a66e7d45-f75b-4ade-9b22-5ac87ed74e60	2018-03-04 20:09:28.993864-06	2	[22229] 334	[4] DLarrabee	[21062] a	\N	\N
d312050f-d9d3-486f-a003-4c8586fe14c7	2018-03-04 20:09:28.997865-06	2	[22230] 335	[4] DLarrabee	[21062] a	\N	\N
e05c74b4-cd60-45b1-b580-332d0232f251	2018-03-04 20:09:29.003865-06	2	[22231] 336	[4] DLarrabee	[21062] a	\N	\N
35b29e40-d8f9-4c93-b864-0e8859847fec	2018-03-04 20:09:29.007866-06	2	[22232] 337	[4] DLarrabee	[21062] a	\N	\N
e9aa9788-d8f9-4e86-99dd-752c3917b443	2018-03-04 20:09:29.011866-06	2	[22233] 338	[4] DLarrabee	[21062] a	\N	\N
6d76e348-aeb1-4888-aa93-f0194368b3a4	2018-03-04 20:09:29.014866-06	2	[22234] 342	[4] DLarrabee	[21062] a	\N	\N
8e12271e-7ec8-4c63-ba52-bce8fd17f120	2018-03-04 20:09:29.018867-06	2	[22235] 343	[4] DLarrabee	[21062] a	\N	\N
9da5c5c1-c2f0-46c2-9345-612b9287c92f	2018-03-04 20:09:29.021867-06	2	[22414] 344	[4] DLarrabee	[21062] a	\N	\N
c852303f-b64e-4102-ba9c-c392fc68c040	2018-03-04 20:09:29.025867-06	2	[22415] 346	[4] DLarrabee	[21062] a	\N	\N
3c74f875-2907-48a8-a493-a921e027239c	2018-03-04 20:09:29.029868-06	2	[22416] 347	[4] DLarrabee	[21062] a	\N	\N
2340feb1-83e7-48d2-86d7-10ad87c650ff	2018-03-04 20:09:29.033868-06	2	[22417] 348	[4] DLarrabee	[21062] a	\N	\N
0b278d81-9e28-46f0-8259-3f8a1023feab	2018-03-04 20:09:29.036868-06	2	[22418] 349	[4] DLarrabee	[21062] a	\N	\N
e450afa7-fd99-4e62-a6c3-708a167b0c83	2018-03-04 20:09:29.040869-06	2	[22419] 351	[4] DLarrabee	[21062] a	\N	\N
9237e273-29ac-4821-a823-a8430087e8db	2018-03-04 20:15:23.001261-06	3	[22240] Door 326A	[4] DLarrabee	[21062] a	\N	\N
fc07c44b-a715-4250-b540-a227e7e5fdde	2018-03-04 20:15:23.320293-06	2	[22241] Door 327A 	[4] DLarrabee	[21062] a	\N	\N
f0218637-9775-460f-a29d-aa86dcebb878	2018-03-04 20:15:23.336295-06	2	[22242] Door 329A	[4] DLarrabee	[21062] a	\N	\N
e484adb6-a1f6-4d98-b360-549b17c10c1a	2018-03-04 20:15:23.348296-06	2	[22243] Door 329B	[4] DLarrabee	[21062] a	\N	\N
412f4b49-9441-4415-b989-c9120d60d4fb	2018-03-04 20:15:23.361297-06	2	[22244] Door 334A	[4] DLarrabee	[21062] a	\N	\N
34047b08-9570-45dd-a615-350a2e404c2d	2018-03-04 20:15:23.373299-06	2	[22245] Door 335A	[4] DLarrabee	[21062] a	\N	\N
352e84c8-54b6-44bb-aea9-dc85fe63ec3f	2018-03-04 20:15:23.3853-06	2	[22246] Door 336A	[4] DLarrabee	[21062] a	\N	\N
7a917819-26c0-4d07-a593-91cec27db1af	2018-03-04 20:15:23.399301-06	2	[22247] Door 337A	[4] DLarrabee	[21062] a	\N	\N
5f4cad26-04ef-47ef-9d17-4eae355af737	2018-03-04 20:15:23.411302-06	2	[22248] Door 338A	[4] DLarrabee	[21062] a	\N	\N
f7ad089c-b7b5-4ae7-afeb-04a9d3ac5f57	2018-03-04 20:15:23.422303-06	2	[22249] Door 343A	[4] DLarrabee	[21062] a	\N	\N
0f83c527-ebd7-4275-bdc6-0b00c6f0ee39	2018-03-04 20:15:23.434305-06	2	[22250] Door 344A	[4] DLarrabee	[21062] a	\N	\N
759ca696-04d4-46c7-a858-43fe25c7fb1f	2018-03-04 20:15:23.447306-06	2	[22251] Door 346A	[4] DLarrabee	[21062] a	\N	\N
bcbdbc6f-662b-4af4-9191-a5a2da45ea57	2018-03-04 20:15:23.460307-06	2	[22252] Door 347A	[4] DLarrabee	[21062] a	\N	\N
9dee12aa-e1f1-4a82-8394-6afc08670df8	2018-03-04 20:15:23.472308-06	2	[22253] Door 348A	[4] DLarrabee	[21062] a	\N	\N
498f4dae-33b3-4b4b-af8d-a2f8bbd07f97	2018-03-04 20:15:23.48731-06	2	[22254] Door 349A	[4] DLarrabee	[21062] a	\N	\N
d433b66e-3d4b-45c1-a98e-ac411acca121	2018-03-04 20:15:23.498311-06	2	[22255] Door 351A	[4] DLarrabee	[21062] a	\N	\N
dbccd88d-1130-4d2e-87ee-02fdf1834b9d	2018-03-04 20:15:23.510312-06	2	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
abd832d3-d3a4-4cf9-af26-6d7648e142d5	2018-03-04 20:15:23.523314-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
21a9eb31-8a3c-4d4a-9791-a0f11fd59f51	2018-03-04 20:15:23.538315-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
e5ef2e79-ff08-4c5f-af6d-5a94f5c406fc	2018-03-04 20:15:23.549316-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
ea2f0a1b-91ae-40cf-b409-655f2cd35d3e	2018-03-04 20:15:23.563318-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
734aaf24-29b8-414b-9fb7-5034742c2755	2018-03-04 20:15:23.574319-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
b1f40a55-0dd2-49df-a794-337852ef733c	2018-03-04 20:15:23.58632-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
bab55f7d-60a8-4839-ae2c-dd96a46e68e3	2018-03-04 20:15:23.604322-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
1bc47f4e-f997-4afb-9371-e4175c34b135	2018-03-04 20:15:23.615323-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
49010335-e16f-4f52-b74e-d562a26f46bb	2018-03-04 20:15:23.628324-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
334f46e4-dee7-4f52-8db2-9c8be83e7787	2018-03-04 20:15:23.640325-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
96f2090b-16a7-4756-851b-254f60067b4b	2018-03-04 20:15:23.650326-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
df16555c-14da-4691-bfdf-b61b25602ccf	2018-03-04 20:15:23.665328-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
f0528caa-eb38-43a3-8972-dd8ff2bde651	2018-03-04 20:15:23.676329-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
10de52d8-921d-4a24-93f2-732663f0b016	2018-03-04 20:15:23.68733-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
ab5b481f-dfe0-4d4a-adcf-4eaf7eaa4113	2018-03-04 20:15:23.697331-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
5e34fd0a-f568-4933-999a-bd92ae3d16f7	2018-03-04 20:15:23.707332-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
d98feb51-43a6-49f5-aebc-44fd96d57780	2018-03-04 20:15:23.721333-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
9967123b-2241-4c0a-a435-1806bb5fc481	2018-03-04 20:15:23.739335-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
2357b2e2-fb83-4eb8-a0db-6da09fd11467	2018-03-04 20:15:23.746336-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
db3fa910-d169-450d-b109-1a9f918ce36e	2018-03-04 20:15:36.412602-06	3	[22241] Door 327A 	[4] DLarrabee	[21062] a	\N	\N
3722ba7e-ccb3-45c3-bf7d-f6e0bac0f2fe	2018-03-04 20:15:36.676629-06	2	[22242] Door 329A	[4] DLarrabee	[21062] a	\N	\N
f9be49ad-a22b-4fb2-b99b-7245598512fc	2018-03-04 20:15:36.69063-06	2	[22243] Door 329B	[4] DLarrabee	[21062] a	\N	\N
3f0f7848-cc7e-40c5-a9f2-9ac803fefa55	2018-03-04 20:15:36.705632-06	2	[22244] Door 334A	[4] DLarrabee	[21062] a	\N	\N
b125b534-32db-4eac-9bee-7f0d6b0508b8	2018-03-04 20:15:36.717633-06	2	[22245] Door 335A	[4] DLarrabee	[21062] a	\N	\N
0de2dcd0-cba5-4515-a764-8c70234e85ab	2018-03-04 20:15:36.730634-06	2	[22246] Door 336A	[4] DLarrabee	[21062] a	\N	\N
931dcf3a-aea0-4b1c-80d6-ab18746a03f7	2018-03-04 20:15:36.740635-06	2	[22247] Door 337A	[4] DLarrabee	[21062] a	\N	\N
dae107b0-1be3-4bbf-add0-bd49a65e3778	2018-03-04 20:15:36.750636-06	2	[22248] Door 338A	[4] DLarrabee	[21062] a	\N	\N
d0e62f3a-86f1-425a-a7ac-0852763f8706	2018-03-04 20:15:36.764638-06	2	[22249] Door 343A	[4] DLarrabee	[21062] a	\N	\N
ca6ca38a-4d14-425c-93af-702126a946be	2018-03-04 20:15:36.774639-06	2	[22250] Door 344A	[4] DLarrabee	[21062] a	\N	\N
6f2294bb-02e6-46bf-8f95-af65017c05a7	2018-03-04 20:15:36.78964-06	2	[22251] Door 346A	[4] DLarrabee	[21062] a	\N	\N
4425bf68-304e-4fe2-8e95-8bb55dd99b83	2018-03-04 20:15:36.798641-06	2	[22252] Door 347A	[4] DLarrabee	[21062] a	\N	\N
32e78dbf-e379-4345-bf68-a2142857c0d3	2018-03-04 20:15:36.810642-06	2	[22253] Door 348A	[4] DLarrabee	[21062] a	\N	\N
86cda392-0e0b-41e1-8722-02b29390bcbc	2018-03-04 20:15:36.825644-06	2	[22254] Door 349A	[4] DLarrabee	[21062] a	\N	\N
eaaaa452-fb2f-4649-ae29-9d745ad50351	2018-03-04 20:15:36.839645-06	2	[22255] Door 351A	[4] DLarrabee	[21062] a	\N	\N
7fecd0b1-4217-4af3-a3fa-d9997969e761	2018-03-04 20:15:36.849646-06	2	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
09900f9c-2105-4f7b-b198-ca94c9747f36	2018-03-04 20:15:36.861647-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
280cf189-b7c0-4780-9b72-672eb3a747e0	2018-03-04 20:15:36.875649-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
fc063806-89b8-4880-a48a-b4e497b685a7	2018-03-04 20:15:36.88665-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
d906b39d-7cd1-4233-aa83-1df6240c4460	2018-03-04 20:15:36.897651-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
4d22ed12-f463-4acf-a980-e4955d50c7f6	2018-03-04 20:15:36.913652-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
87a1b204-17c4-4237-a883-3efe3e62e42a	2018-03-04 20:15:36.928654-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
64cd360f-6036-479a-b023-5e5ed035f15a	2018-03-04 20:15:36.941655-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
655767ed-d052-45a9-9d34-88335f7e879d	2018-03-04 20:15:36.956657-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
8dbb8dee-6085-4ec1-9f92-29e86d361e3c	2018-03-04 20:15:36.971658-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
f5520193-e2fd-44f1-9885-00dd577d9e97	2018-03-04 20:15:37.005662-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
edb9ae77-954c-4f59-920c-d80ccd03f446	2018-03-04 20:15:37.017663-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
29a2c09d-fa60-4676-860d-81511387b17f	2018-03-04 20:15:37.030664-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
da47bb6f-d6f4-416d-9af8-e38307ce0764	2018-03-04 20:15:37.041665-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
b9652e96-f1ab-47e5-97a2-33d1328c1c99	2018-03-04 20:15:37.055667-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
bed85a7c-e726-4bb2-b9d8-31acd39e5637	2018-03-04 20:15:37.068668-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
6d7649ca-5c90-46b1-959f-d2b576b0f244	2018-03-04 20:15:37.081669-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
e2a83ef1-1313-4fee-8ead-961ece41d8b9	2018-03-04 20:15:37.09367-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
89d9a965-a82d-4c05-9b8d-98a4e7423f56	2018-03-04 20:15:37.106672-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
d293d800-e65b-492c-bb83-2f6a896b1fbc	2018-03-04 20:15:37.109672-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
c6d26807-5fb4-42ca-92ac-a6698e629187	2018-03-04 20:19:52.257184-06	1	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
3e3cf52e-b68f-4d55-974e-669109f2dd4d	2018-03-04 20:22:55.370494-06	3	[22374] 259	[4] DLarrabee	[21062] a	\N	\N
68f2dd0c-bb7b-4d6d-a058-c071827f22bb	2018-03-04 20:22:55.641521-06	2	[22378] 301	[4] DLarrabee	[21062] a	\N	\N
2c8391fb-c4dc-4265-8aaa-c6f3c44bcbd9	2018-03-04 20:22:55.646521-06	2	[22385] 306	[4] DLarrabee	[21062] a	\N	\N
3100e56f-ab71-49da-b0d8-b41391f6943d	2018-03-04 20:22:55.650522-06	2	[22387] 316	[4] DLarrabee	[21062] a	\N	\N
2ae158eb-02c5-4d30-96ea-d3865f0e5555	2018-03-04 20:22:55.654522-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
bda44585-aece-4000-beb6-2578e603aa9b	2018-03-04 20:22:55.658523-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
58eff72f-b397-4b9d-b8a2-8136cf956760	2018-03-04 20:22:55.661523-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9f5a25f7-7428-4f0b-ae62-b655bf32d2e9	2018-03-04 20:22:55.664523-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fd1fdfe7-51bc-43e6-aa40-25e6c7d30f26	2018-03-04 20:22:55.670524-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1b5376e0-8c1a-44d1-8d63-91f732584434	2018-03-04 20:22:55.673524-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8204a5e9-086c-4f60-8bac-7ec22ffe3785	2018-03-04 20:22:55.677524-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
699ecdf5-b305-4d52-abaa-9782b3aa3e38	2018-03-04 20:22:55.680525-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fd82a5cc-0e9c-468d-a801-42532e2a0292	2018-03-04 20:22:55.684525-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
94f6c716-b8db-46d9-97e4-d45791437512	2018-03-04 20:22:55.687525-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3e243c47-fe42-4541-aac6-ece69632a03b	2018-03-04 20:22:55.690526-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
56f66631-4c66-468b-8350-7fbf4ce59537	2018-03-04 20:22:55.693526-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1a7ce858-a23f-45dc-b385-2b7cf00ff8d8	2018-03-04 20:22:55.697526-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8554153a-f30b-45a1-a20e-25748e3213f4	2018-03-04 20:22:55.700527-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3dbcf26e-67c4-425a-af18-bad22854f3b8	2018-03-04 20:22:55.704527-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7e5f0e52-3421-4a48-9a33-c47ad70ed9c4	2018-03-04 20:22:55.707527-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6e75b550-f982-4a26-9522-61a33fef4e00	2018-03-04 20:22:55.710528-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fd402f2f-1600-49f1-8905-16f3ed2e9768	2018-03-04 20:22:55.714528-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fd9d86f3-8022-4dc4-9b8a-f5c8b15e8dac	2018-03-04 20:22:55.717528-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
fad3c442-0f4d-407b-bd08-bbc77a583aa3	2018-03-04 20:22:55.720529-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
2fb97356-f446-400a-a43d-80fc1bc6feed	2018-03-04 20:22:55.724529-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
840de515-be56-44ea-b488-0fba4c5ecd1d	2018-03-04 20:25:07.363692-06	3	[22378] 301	[4] DLarrabee	[21062] a	\N	\N
f43ae83b-88fc-4ddc-ac99-2c1842e1b3c1	2018-03-04 20:25:07.651721-06	2	[22385] 306	[4] DLarrabee	[21062] a	\N	\N
785dcd24-08a9-4aed-92d3-e9ec713d4f20	2018-03-04 20:25:07.657721-06	2	[22387] 316	[4] DLarrabee	[21062] a	\N	\N
7951d74c-8c18-4ebb-9565-c812be8db010	2018-03-04 20:25:07.662722-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4ca6c777-dbbd-45a9-b963-1a45c1266aa5	2018-03-04 20:25:07.665722-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
724e7ee0-6dcc-4244-b6bd-8d50281046ac	2018-03-04 20:25:07.668722-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c6addb60-c4fd-49d1-b8d6-f9636ef79e1f	2018-03-04 20:25:07.672723-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f1cda3cb-b2eb-4459-b886-f46240249468	2018-03-04 20:25:07.675723-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4091318a-d80e-452a-950d-2d361280ec83	2018-03-04 20:25:07.678723-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b9ac4234-aa49-47e8-a5f1-36215ec4b287	2018-03-04 20:25:07.682724-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c7dabfe6-adf9-4c91-b5ad-d59081867017	2018-03-04 20:25:07.685724-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4e1d5b79-5b5b-48ab-98d8-0627a364f77a	2018-03-04 20:25:07.690724-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ded952c9-243a-475a-891f-3afb62141859	2018-03-04 20:25:07.693725-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1dea4a69-9d75-44db-ac94-6552e77dbde1	2018-03-04 20:25:07.696725-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8e7220f5-f320-45f8-9ce3-fcc6aa0805b6	2018-03-04 20:25:07.700725-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cde00b1c-21df-48fa-922b-d8fe3716972e	2018-03-04 20:25:07.703726-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
aada5ca5-5f89-459e-834a-cf3ea5a3e582	2018-03-04 20:25:07.707726-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
61b09e42-f6e9-4db4-ad50-9effbf7a952c	2018-03-04 20:25:07.709726-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
73e20a4d-eb88-4c62-af9a-876e1652cd65	2018-03-04 20:25:07.712727-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a4afac67-f378-4699-a073-11de7feef193	2018-03-04 20:25:07.718727-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
106916a9-4942-488d-b328-30f62b56c2ae	2018-03-04 20:25:07.721728-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c101b9c5-7404-44e9-a9ec-04f71e78742a	2018-03-04 20:25:07.724728-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
f0f3d9ba-b52f-4dec-86fb-b9d336e122c4	2018-03-04 20:25:07.728728-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
cdda7d8e-73ef-4e4e-a2c0-937befad5b97	2018-03-04 20:25:07.731729-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
39b2729b-f6a2-410f-afe0-5a8a3749ae11	2018-03-04 20:25:22.292184-06	3	[22385] 306	[4] DLarrabee	[21062] a	\N	\N
ce256344-64a6-42de-a384-e579f93fe976	2018-03-04 20:25:22.565212-06	2	[22387] 316	[4] DLarrabee	[21062] a	\N	\N
a09c774f-57d8-446d-a3d7-6076356fcc34	2018-03-04 20:25:22.568212-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
10a0af33-08f5-4e22-832d-e7e9dfa6d355	2018-03-04 20:25:22.571212-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
dbdb4b9d-6aa5-47a2-8a35-5c276a67cf04	2018-03-04 20:25:22.575213-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7ef9ac38-2f85-4cb5-b1be-323e60a68aa2	2018-03-04 20:25:22.579213-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7a5f4b00-1309-4c08-b844-f8a3448d8a58	2018-03-04 20:25:22.603216-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
42d82956-fac4-4c2f-a331-87bdc46e0690	2018-03-04 20:25:22.606216-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3b81a0b0-2543-47d0-b856-f2924f634f5f	2018-03-04 20:25:22.610216-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9a85ae86-8381-4387-a6cc-7f47eaf6beb6	2018-03-04 20:25:22.615217-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6236b7ac-ae27-4938-bf49-7689ce3e5f26	2018-03-04 20:25:22.619217-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6ca2467f-821d-41ba-ba84-6e964f0db3f6	2018-03-04 20:25:22.623218-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e4d06686-12f3-4eb4-9fd4-4fec67eb676e	2018-03-04 20:25:22.629218-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f60e603c-c35b-4ef1-9ffb-79f7236f8c03	2018-03-04 20:25:22.632218-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c146d7d8-c43d-4296-8d50-a7f1542fc7ce	2018-03-04 20:25:22.635219-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e63dee16-fad9-45ce-8a18-ae6708fff5ec	2018-03-04 20:25:22.639219-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e1a5376b-fe6a-4200-acea-629713bfa989	2018-03-04 20:25:22.642219-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3f3e9598-ae7d-47db-8543-4e07cec0a17a	2018-03-04 20:25:22.64622-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c814ae5d-589c-4fb0-8cad-bc6a02d7d8ed	2018-03-04 20:25:22.65122-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c7e7e08f-7360-4c60-b14e-a6c204700e0c	2018-03-04 20:25:22.655221-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
aa834046-bed8-4d04-a335-d746bd83a3cd	2018-03-04 20:25:22.658221-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
145b04a7-2497-4eea-9877-93cad98f392c	2018-03-04 20:25:22.661221-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
d85d305f-fb91-444b-a5c4-db1f2c661f7a	2018-03-04 20:25:22.665222-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
7ac6a664-8ac6-4755-862e-0f7923760a8e	2018-03-04 20:27:27.391693-06	3	[22387] 316	[4] DLarrabee	[21062] a	\N	\N
2be089f8-26c6-4a54-a30f-a9f9505a2a0b	2018-03-04 20:27:27.66472-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
91a6792f-cf04-4b52-bc07-d57ac44271f3	2018-03-04 20:27:27.668721-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9eb6ec35-fcbb-4b32-9b28-6bb16068d7be	2018-03-04 20:27:27.670721-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7be4f162-3975-49d0-85de-b3b10d8fc60d	2018-03-04 20:27:27.673721-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b4f38a10-39e9-4372-9965-18f8aa62a57e	2018-03-04 20:27:27.678722-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9eb18bfe-0ce9-4cef-80e9-8562e0e9ad7a	2018-03-04 20:27:27.682722-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
06a71c69-c456-4291-a40a-ff8652b1b1b4	2018-03-04 20:27:27.685723-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a2c5fe7b-cdd9-4ddc-ab2f-4b5cebaf5584	2018-03-04 20:27:27.688723-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3ab1491a-5fd7-44f7-85e3-945afcd94a07	2018-03-04 20:27:27.692723-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0fb4548c-0601-4986-b191-c64a536a604f	2018-03-04 20:27:27.695724-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2c11ee22-0209-4c2f-a575-f654d20de3a6	2018-03-04 20:27:27.699724-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7ee6f1a2-7af5-4b00-b6e2-d7f2c750ad5b	2018-03-04 20:27:27.702724-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3760c471-246f-4c2e-b749-8755f34d3b24	2018-03-04 20:27:27.704724-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
88f8eb77-4e05-4e95-8b49-66d92f059ce6	2018-03-04 20:27:27.707725-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
34b702d0-af82-438c-85cc-8d337b6a746e	2018-03-04 20:27:27.713725-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9b58a0b6-7828-4fac-b0ac-816b98fa619f	2018-03-04 20:27:27.717726-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
abac6e73-d881-4fb9-bd1a-cd8c07df975d	2018-03-04 20:27:27.720726-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7daa4582-c6b7-4940-bb7b-e6e162b124dd	2018-03-04 20:27:27.723726-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
23efc484-20db-4d7f-8087-29b186e7236c	2018-03-04 20:27:27.727727-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
61bfac36-ec35-41c2-97e4-7e230b54c825	2018-03-04 20:27:27.731727-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
1d584f10-065f-426f-8f0c-4fc714f2d9d7	2018-03-04 20:27:27.733727-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
7bb8383e-81e9-4f7b-972b-87a588287598	2018-03-04 20:28:37.4627-06	1	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
45f5117d-11bd-4753-9389-6b56f6bed9cf	2018-03-04 20:30:25.631515-06	1	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
7e0f2836-447f-4935-a6c6-2a1c6bd6e32f	2018-03-04 20:31:43.652317-06	1	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
2449d44e-06b3-4f3e-8cef-585fee5f0db8	2018-03-04 20:39:17.309678-06	3	[22244] Door 334A	[4] DLarrabee	[21062] a	\N	\N
7d511e07-8ec6-49d1-84e6-a223f51503a6	2018-03-04 20:39:17.660713-06	2	[22245] Door 335A	[4] DLarrabee	[21062] a	\N	\N
4f3989f4-ebc0-47c1-ba8d-24ef08965ef0	2018-03-04 20:39:17.674714-06	2	[22246] Door 336A	[4] DLarrabee	[21062] a	\N	\N
f2d599dd-4f5c-40cb-8e12-0749c7cf60ef	2018-03-04 20:39:17.684715-06	2	[22247] Door 337A	[4] DLarrabee	[21062] a	\N	\N
f25aab3a-f6ec-4ebd-bbd1-cc0dd080dce0	2018-03-04 20:39:17.699717-06	2	[22248] Door 338A	[4] DLarrabee	[21062] a	\N	\N
7b4b379c-a521-42ed-90c1-3aa111b62edc	2018-03-04 20:39:17.713718-06	2	[22249] Door 343A	[4] DLarrabee	[21062] a	\N	\N
0743637b-5cf9-4b04-ad4f-7d0fc342e07f	2018-03-04 20:39:17.723719-06	2	[22250] Door 344A	[4] DLarrabee	[21062] a	\N	\N
8089ff89-0de9-404b-979c-e5eb00f6a7f8	2018-03-04 20:39:17.73372-06	2	[22251] Door 346A	[4] DLarrabee	[21062] a	\N	\N
7fd5e8b2-57e3-4c2a-bae3-3b04105278cc	2018-03-04 20:39:17.747722-06	2	[22252] Door 347A	[4] DLarrabee	[21062] a	\N	\N
e8519b1e-3256-4ef6-9ce7-20677bbc607d	2018-03-04 20:39:17.763723-06	2	[22253] Door 348A	[4] DLarrabee	[21062] a	\N	\N
b512ffdb-b248-4e8b-bc8e-5e6223671fb7	2018-03-04 20:39:17.776725-06	2	[22254] Door 349A	[4] DLarrabee	[21062] a	\N	\N
af950b0d-800c-40bf-8ba6-ef92543f7ec4	2018-03-04 20:39:17.789726-06	2	[22255] Door 351A	[4] DLarrabee	[21062] a	\N	\N
c96d75c9-4ece-42a0-aa84-125fab91267d	2018-03-04 20:39:17.803727-06	2	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
d40a66a4-3dcd-4a6a-b374-c1c666fa66ed	2018-03-04 20:39:17.816729-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
3d33573e-3ec3-4a94-ab7f-336101320281	2018-03-04 20:39:17.82673-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
8640f251-123f-4c1d-b129-661ee6446133	2018-03-04 20:39:17.840731-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
8f59a5ee-217f-4eab-937f-73fee51b6f07	2018-03-04 20:39:17.853732-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
fd2face8-bb9a-4fb0-b655-722bd22cb6a6	2018-03-04 20:39:17.866734-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
0af6c0bc-c4b1-4f50-8454-7faafce3dc43	2018-03-04 20:39:17.877735-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
21b4ed14-b8c7-43f9-965b-758dfd69bb69	2018-03-04 20:39:17.890736-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
9314ffff-47aa-4fc9-87c0-98a46695524e	2018-03-04 20:39:17.904737-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
515f54f9-0f2d-4b0c-94be-5e0e4a695e03	2018-03-04 20:39:17.916739-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
50686f37-6ca5-40f7-bb2f-2debd84d0357	2018-03-04 20:39:17.92874-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
4bec440a-fe42-43ec-9c5a-ea828e06bd81	2018-03-04 20:39:17.941741-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
c0929b12-44f0-44e2-8ca3-d7362583e814	2018-03-04 20:39:17.953742-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
470f3e66-f49b-4966-8c05-190400df6de0	2018-03-04 20:39:17.968744-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
a29bc711-f4fc-4aba-8f77-64e09885cc84	2018-03-04 20:39:17.978745-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
9e85c77f-1313-41f1-95bb-cf8a8608eac0	2018-03-04 20:39:17.990746-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
d28c8162-29de-4d5c-a1cc-5830d823f28c	2018-03-04 20:39:18.000747-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
2695d117-3caf-4fc9-a0e1-de192e8348f7	2018-03-04 20:39:18.011748-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
8d146f77-12b3-47dc-81d8-62308a916171	2018-03-04 20:39:18.02675-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
f29d92f7-2a50-47ef-9cd2-9e9054806677	2018-03-04 20:39:18.02975-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
58e2d705-513b-4016-bcca-c757f989b029	2018-03-04 20:40:49.199866-06	3	[22242] Door 329A	[4] DLarrabee	[21062] a	\N	\N
6e92786f-8223-4ead-bb8f-eddafe526576	2018-03-04 20:40:49.494895-06	2	[22243] Door 329B	[4] DLarrabee	[21062] a	\N	\N
7ea3670c-29ae-4986-8994-66666f47eb6b	2018-03-04 20:40:49.510897-06	2	[22245] Door 335A	[4] DLarrabee	[21062] a	\N	\N
49d82ec7-4286-4dc3-a68a-28a7a2a22dde	2018-03-04 20:40:49.525899-06	2	[22246] Door 336A	[4] DLarrabee	[21062] a	\N	\N
c0872e97-fd8c-4507-bebd-840e3c3724b5	2018-03-04 20:40:49.5369-06	2	[22247] Door 337A	[4] DLarrabee	[21062] a	\N	\N
83dbf445-6585-40ba-be52-846ae8531afd	2018-03-04 20:40:49.547901-06	2	[22248] Door 338A	[4] DLarrabee	[21062] a	\N	\N
03dc5759-c85a-4570-9e3e-8734b0cbf1af	2018-03-04 20:40:49.561902-06	2	[22249] Door 343A	[4] DLarrabee	[21062] a	\N	\N
6c9a638c-3429-4b27-8705-5e3c9225e98b	2018-03-04 20:40:49.573903-06	2	[22250] Door 344A	[4] DLarrabee	[21062] a	\N	\N
92821cdd-ee5c-4c3b-8c53-f71f2c523cd3	2018-03-04 20:40:49.589905-06	2	[22251] Door 346A	[4] DLarrabee	[21062] a	\N	\N
9eda0714-90bc-41af-b209-e51f5c4c9601	2018-03-04 20:40:49.602906-06	2	[22252] Door 347A	[4] DLarrabee	[21062] a	\N	\N
341bb986-cc3e-45e5-8e85-faab4128f7bc	2018-03-04 20:40:49.614907-06	2	[22253] Door 348A	[4] DLarrabee	[21062] a	\N	\N
bc308761-0642-4215-b2e1-7ee6d20fd5d7	2018-03-04 20:40:49.624908-06	2	[22254] Door 349A	[4] DLarrabee	[21062] a	\N	\N
4ca7d8cd-07ba-4a7a-ada4-5f917016e0cb	2018-03-04 20:40:49.63591-06	2	[22255] Door 351A	[4] DLarrabee	[21062] a	\N	\N
b4b69fca-2beb-4e59-9f5c-8ec86745b1d6	2018-03-04 20:40:49.650911-06	2	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
09938d94-437b-4ebb-8fd6-eb7f5fc17172	2018-03-04 20:40:49.664912-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
afc06559-9091-4669-bb1c-240bf0f7cc97	2018-03-04 20:40:49.678914-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
beab33eb-e798-4048-93d8-35f7ed92cfd6	2018-03-04 20:40:49.692915-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
44075519-0562-4948-a0dc-380919b8f4f2	2018-03-04 20:40:49.705917-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
399cf76a-7b43-4e35-9761-d6fecdc6635c	2018-03-04 20:40:49.718918-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
9f8b46b7-ec58-4366-b681-c3c0868bf8b2	2018-03-04 20:40:49.727919-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
b781b197-9fc2-4b71-84d5-d52e332ac148	2018-03-04 20:40:49.73792-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
d0c766e8-a4ee-4da3-8d37-4560c3a990f5	2018-03-04 20:40:49.749921-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
40c0dc84-9256-4f79-96b6-4e4a8a5e04f3	2018-03-04 20:40:49.759922-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
8dd5bffe-0c56-488e-9628-224023cbad41	2018-03-04 20:40:49.775924-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
b0638176-acc4-4f1d-892d-5595d8438328	2018-03-04 20:40:49.784924-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
e3e83adf-f8a1-4b48-aab2-b8a68f33a2fd	2018-03-04 20:40:49.794925-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
ec336e50-f8bb-4e8e-af97-536dd3dfbf1f	2018-03-04 20:40:49.805927-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
d51da802-34cf-4990-a286-77f8a3041a34	2018-03-04 20:40:49.818928-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
627fbac5-8c8a-4fb5-941e-e195c501c23b	2018-03-04 20:40:49.831929-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
8494862f-4423-49c6-a927-c645e0bd6cb0	2018-03-04 20:40:49.84293-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
eb310f94-33b2-4e91-aba9-438774c7b77d	2018-03-04 20:40:49.855932-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
cc9156c2-616e-47f1-8b83-28d83c6cd85e	2018-03-04 20:40:49.868933-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
77108bfd-e6a7-4acd-aba2-4df03e46d327	2018-03-04 20:40:49.871933-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
8f653f79-5558-41b2-ac0b-6b7c3cc4c6b2	2018-03-04 20:41:08.822828-06	3	[22243] Door 329B	[4] DLarrabee	[21062] a	\N	\N
804c69f4-23d3-4602-9981-2a3f37244ca2	2018-03-04 20:41:09.085854-06	2	[22245] Door 335A	[4] DLarrabee	[21062] a	\N	\N
95021dd4-5858-40a8-9db2-4de533f7660f	2018-03-04 20:41:09.101856-06	2	[22246] Door 336A	[4] DLarrabee	[21062] a	\N	\N
318ea860-f006-4334-8f17-4229136cb201	2018-03-04 20:41:09.118858-06	2	[22247] Door 337A	[4] DLarrabee	[21062] a	\N	\N
12c60b1e-c986-401f-a6c6-13de70680ddb	2018-03-04 20:41:09.132859-06	2	[22248] Door 338A	[4] DLarrabee	[21062] a	\N	\N
51106fd9-7cef-4088-af7a-ec5c888f3bfb	2018-03-04 20:41:09.14686-06	2	[22249] Door 343A	[4] DLarrabee	[21062] a	\N	\N
433444d9-f429-4592-b1d9-944935a22894	2018-03-04 20:41:09.159862-06	2	[22250] Door 344A	[4] DLarrabee	[21062] a	\N	\N
3fcebfa3-0c74-4522-b787-774082e69a28	2018-03-04 20:41:09.176863-06	2	[22251] Door 346A	[4] DLarrabee	[21062] a	\N	\N
b814bd8d-f9ce-419a-8c88-622f517261db	2018-03-04 20:41:09.189865-06	2	[22252] Door 347A	[4] DLarrabee	[21062] a	\N	\N
bc383725-cff2-4e9c-b0d3-f2cfa4150de5	2018-03-04 20:41:09.201866-06	2	[22253] Door 348A	[4] DLarrabee	[21062] a	\N	\N
e56bae34-375e-4cd4-8c9e-1c415d7fad79	2018-03-04 20:41:09.211867-06	2	[22254] Door 349A	[4] DLarrabee	[21062] a	\N	\N
38b39fb7-5f6f-412a-908a-27ae528a37b2	2018-03-04 20:41:09.221868-06	2	[22255] Door 351A	[4] DLarrabee	[21062] a	\N	\N
43a35046-664b-4753-a1df-23cf9932e855	2018-03-04 20:41:09.234869-06	2	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
c5c1d0a7-0ffc-48e9-9e89-f42758cdff47	2018-03-04 20:41:09.24687-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
b52801cb-86ed-4644-9bb8-e7e73c7f8908	2018-03-04 20:41:09.258872-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
29752f86-3e8b-4cb5-a2ca-c854f2354b2b	2018-03-04 20:41:09.273873-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
2b92b1f0-3924-4414-a906-c86c570cb04f	2018-03-04 20:41:09.285874-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
12779d03-3c02-40ce-910d-0fa18ee8179f	2018-03-04 20:41:09.294875-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
4ae0b219-1c16-4632-864d-2a80316476d9	2018-03-04 20:41:09.306876-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
00cc2cf6-6691-4db4-b4ad-f3df4cc4b265	2018-03-04 20:41:09.318878-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
c04022e2-b2a7-434f-adfb-fb84feeaeffc	2018-03-04 20:41:09.332879-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
8c9453ff-701d-4314-952e-302e5690784f	2018-03-04 20:41:09.349881-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
4244e890-1d9f-4436-81e6-b3be5c76f0f4	2018-03-04 20:41:09.365882-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
1116b3fb-5e61-4985-8d8d-f4823353226b	2018-03-04 20:41:09.376883-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
30e9dc45-3289-4e61-8e5c-6dce8be1e984	2018-03-04 20:41:09.391885-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
f5f604be-8539-4092-abd4-2fc8d584bdbe	2018-03-04 20:41:09.404886-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
7ca5a1a1-beae-4c90-b8d0-52218f69e13a	2018-03-04 20:41:09.416887-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
13baec8d-c1ab-4e20-ac7b-311f547aedf6	2018-03-04 20:41:09.430889-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
896f04de-ada9-4bdb-9f02-5e38a15c063c	2018-03-04 20:41:09.44589-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
8bb2d93d-642a-4670-a6fa-b770439bd008	2018-03-04 20:41:09.458892-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
0d5da336-34c3-45a3-996f-ef90c3bcacc1	2018-03-04 20:41:09.472893-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
7c9444a8-fbb4-4bca-b5d0-faf1d0b3c13d	2018-03-04 20:41:09.475893-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
6048853a-20bb-4a23-b38c-4bf2005edc3e	2018-03-04 20:41:26.087554-06	3	[22245] Door 335A	[4] DLarrabee	[21062] a	\N	\N
e98c5c5f-8448-4f7f-ac6b-733fd9925e77	2018-03-04 20:41:26.353581-06	2	[22246] Door 336A	[4] DLarrabee	[21062] a	\N	\N
43ca353a-f626-463b-a162-2c709172ed57	2018-03-04 20:41:26.363582-06	2	[22247] Door 337A	[4] DLarrabee	[21062] a	\N	\N
1b447d55-ba4c-4c4a-a1b8-c9e622d3ee94	2018-03-04 20:41:26.378583-06	2	[22248] Door 338A	[4] DLarrabee	[21062] a	\N	\N
7f89567a-0750-4062-a4ee-af999c158b42	2018-03-04 20:41:26.390585-06	2	[22249] Door 343A	[4] DLarrabee	[21062] a	\N	\N
e5fb5390-7f4c-4ac3-b295-fdbe662d4975	2018-03-04 20:41:26.403586-06	2	[22250] Door 344A	[4] DLarrabee	[21062] a	\N	\N
090a6a90-773a-46f2-96fb-7a659b35398f	2018-03-04 20:41:26.413587-06	2	[22251] Door 346A	[4] DLarrabee	[21062] a	\N	\N
9860a26b-acef-45d3-b31d-50b9e827f606	2018-03-04 20:41:26.423588-06	2	[22252] Door 347A	[4] DLarrabee	[21062] a	\N	\N
a165a1d9-0af5-4173-a3f3-c319fd1da264	2018-03-04 20:41:26.434589-06	2	[22253] Door 348A	[4] DLarrabee	[21062] a	\N	\N
810cd9e3-db57-4197-98de-d92924d32a37	2018-03-04 20:41:26.449591-06	2	[22254] Door 349A	[4] DLarrabee	[21062] a	\N	\N
7990b6db-9883-4a09-8558-8a5aee5e2733	2018-03-04 20:41:26.459592-06	2	[22255] Door 351A	[4] DLarrabee	[21062] a	\N	\N
643d5f9c-ea9b-4ac1-897b-f9059a5e6c3a	2018-03-04 20:41:26.473593-06	2	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
ad5af5a0-3788-48fc-bac8-b1ad2d53b788	2018-03-04 20:41:26.483594-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
b8f83081-d189-4a98-b55d-3551bdb35a9e	2018-03-04 20:41:26.496595-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
5df6fdf7-dd07-450c-a466-a3868d4dd3e2	2018-03-04 20:41:26.510597-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
1c98fa95-f7e7-416e-96b9-d787e4a324a6	2018-03-04 20:41:26.520598-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
61ce349a-1322-4dea-a0f8-a859b9263ace	2018-03-04 20:41:26.533599-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
3559f6b8-65f8-4e97-a7ff-2ab6c085da8e	2018-03-04 20:41:26.5446-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
5a5c03e8-d67f-4f40-8f66-3dd8a6e37c1a	2018-03-04 20:41:26.557601-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
0f3b54cf-4fe9-4d90-8538-bc73ec2362a6	2018-03-04 20:41:26.569603-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
1a727ac3-c4eb-491e-8435-9a08652ef613	2018-03-04 20:41:26.584604-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
643c6bfa-71f3-4ee0-9a3c-7f3751dbc12d	2018-03-04 20:41:26.597605-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
71eff7c7-9284-476e-abd8-c380471747d2	2018-03-04 20:41:26.610607-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
6fc8c411-8965-4611-9da2-0128c0efa105	2018-03-04 20:41:26.624608-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
e7b52182-4d99-4f2b-9664-a901e9153f0d	2018-03-04 20:41:26.634609-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
5f147564-1dcb-40a4-905f-5d4ac57770ca	2018-03-04 20:41:26.64461-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
76c1ce49-61af-45ab-a156-e52876e87cd6	2018-03-04 20:41:26.654611-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
a17a7ef3-276e-40c5-a064-54bc9319e6cd	2018-03-04 20:41:26.663612-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
c958ac70-c38d-46f3-8d9e-5d06fcd9f7df	2018-03-04 20:41:26.675613-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
a0d9f1a0-063b-473a-b711-e65372baa38a	2018-03-04 20:41:26.691615-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
91718a51-ed6b-450f-b74e-acdd841177be	2018-03-04 20:41:26.694615-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
065bedb7-18c6-437b-a8f7-8977a54f3a81	2018-03-04 20:41:38.488794-06	3	[22246] Door 336A	[4] DLarrabee	[21062] a	\N	\N
5234e94b-6315-49e5-a909-a12eb49a2479	2018-03-04 20:41:38.757821-06	2	[22247] Door 337A	[4] DLarrabee	[21062] a	\N	\N
d43bb104-e5c9-452a-a572-197eeb61f77d	2018-03-04 20:41:38.769822-06	2	[22248] Door 338A	[4] DLarrabee	[21062] a	\N	\N
38317ea3-816f-4b40-b370-5f2dd723d057	2018-03-04 20:41:38.779823-06	2	[22249] Door 343A	[4] DLarrabee	[21062] a	\N	\N
0c98bf4d-55ff-4252-9015-db3bbf65b33d	2018-03-04 20:41:38.791825-06	2	[22250] Door 344A	[4] DLarrabee	[21062] a	\N	\N
e3e54466-03f5-4c9a-9c7a-d9a695bd1cc0	2018-03-04 20:41:38.805826-06	2	[22251] Door 346A	[4] DLarrabee	[21062] a	\N	\N
b5c0d79f-5f20-4ff0-b0c1-db1e659af2d9	2018-03-04 20:41:38.817827-06	2	[22252] Door 347A	[4] DLarrabee	[21062] a	\N	\N
74bdb8ca-43f5-4828-b7a0-2e907854e0d5	2018-03-04 20:41:38.831829-06	2	[22253] Door 348A	[4] DLarrabee	[21062] a	\N	\N
679b1bcd-0647-4e08-b764-1af4873396cb	2018-03-04 20:41:38.84383-06	2	[22254] Door 349A	[4] DLarrabee	[21062] a	\N	\N
86f52ede-1a2a-43e0-980b-d6f9b6eae861	2018-03-04 20:41:38.858831-06	2	[22255] Door 351A	[4] DLarrabee	[21062] a	\N	\N
4fa13dae-7643-4cd2-93a6-18753d44b9b7	2018-03-04 20:41:38.872833-06	2	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
b0fb2544-1a04-4478-8f6f-b73ccd982721	2018-03-04 20:41:38.885834-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
93ab5136-68fb-448b-bccf-bb1522ca3400	2018-03-04 20:41:38.899835-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
329bc795-7749-421b-b0e0-076658f81ccc	2018-03-04 20:41:38.913837-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
9c7bda62-cd79-43f9-859d-e3c868e6d272	2018-03-04 20:41:38.923838-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
70622bc3-18c4-4c4c-8fbf-5bb5b03d528c	2018-03-04 20:41:38.933839-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
8074fa9e-f823-4e81-aac4-492761810c1d	2018-03-04 20:41:38.94584-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
331d5ba0-43e8-4ccb-a1d0-d945aebf3f78	2018-03-04 20:41:38.955841-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
aea65791-a068-4253-b180-766a76f3afb1	2018-03-04 20:41:38.965842-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
4a0641b2-9558-4a05-bb53-151ff40cedc5	2018-03-04 20:41:38.978843-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
8d3ff47a-2940-4cdb-b1b0-39d663f7cf21	2018-03-04 20:41:38.989844-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
935bb8f2-d572-4ea2-9469-73a277380d9b	2018-03-04 20:41:39.004846-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
f0e22502-c226-4d90-8b2f-473ef63c2286	2018-03-04 20:41:39.015847-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
59f9b008-15ff-4fcc-ae9d-acdd28b8e89e	2018-03-04 20:41:39.025848-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
6acb0861-9df3-44e2-98ca-e6f2249243f4	2018-03-04 20:41:39.037849-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
1e2eabc6-1c35-4cd7-8efe-8fa066383ff4	2018-03-04 20:41:39.050851-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
79da864f-e2d0-4603-ad68-60a9896d3179	2018-03-04 20:41:39.061852-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
50079bed-ac73-401c-b3ef-ec0337c71c76	2018-03-04 20:41:39.075853-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
0d8565e4-5e8d-4bcd-8f0c-6e2952fe87cc	2018-03-04 20:41:39.084854-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
19483964-f823-4274-a0f3-4a356ca17ef3	2018-03-04 20:41:39.088854-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
de10ee17-8750-48bd-99f7-e4a51960c489	2018-03-04 20:41:59.24287-06	3	[22247] Door 337A	[4] DLarrabee	[21062] a	\N	\N
a4b117ed-ef8a-4a7c-af2d-0f001d52acbd	2018-03-04 20:41:59.522898-06	2	[22248] Door 338A	[4] DLarrabee	[21062] a	\N	\N
4afa9701-c9f9-4c72-957c-1bea9a4e28bc	2018-03-04 20:41:59.536899-06	2	[22249] Door 343A	[4] DLarrabee	[21062] a	\N	\N
d4c368c6-cc05-4d7f-b8fd-d5fc3310d71a	2018-03-04 20:41:59.552901-06	2	[22250] Door 344A	[4] DLarrabee	[21062] a	\N	\N
491dbf60-7a5a-4d1f-a6b0-4161bb0e36f8	2018-03-04 20:41:59.567902-06	2	[22251] Door 346A	[4] DLarrabee	[21062] a	\N	\N
68692cd8-e0fc-475f-875f-e4fff04df9c9	2018-03-04 20:41:59.584904-06	2	[22252] Door 347A	[4] DLarrabee	[21062] a	\N	\N
d6fe234e-70c6-494d-9497-fdc18a073d96	2018-03-04 20:41:59.594905-06	2	[22253] Door 348A	[4] DLarrabee	[21062] a	\N	\N
5b0eb783-69d8-452a-90ed-dc073f0bf0f7	2018-03-04 20:41:59.608906-06	2	[22254] Door 349A	[4] DLarrabee	[21062] a	\N	\N
f18ae72e-99d0-44bb-b9c4-5658b49df93c	2018-03-04 20:41:59.618907-06	2	[22255] Door 351A	[4] DLarrabee	[21062] a	\N	\N
a772f3c9-b64c-494d-bf30-98579cd23e71	2018-03-04 20:41:59.629908-06	2	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
7d266664-fe52-4442-ac76-f9a42ae3e303	2018-03-04 20:41:59.641909-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
42d713e0-742a-4f48-9998-3ffe3cc8a29b	2018-03-04 20:41:59.65191-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
a7b38f0b-e73c-40db-919e-6ed1bd8bc68b	2018-03-04 20:41:59.665912-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
cb87aeda-ef6b-4563-a526-c359e7908096	2018-03-04 20:41:59.677913-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
809188fd-62d5-49d6-9e31-94aa169f6c61	2018-03-04 20:41:59.690914-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
14553ee9-fd5b-4c87-a35c-f7b704798ff4	2018-03-04 20:41:59.705916-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
b6befc0e-ddb8-4da9-83f2-bfc17336a113	2018-03-04 20:41:59.716917-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
049482dd-2c68-4491-ac9f-8b1214a60075	2018-03-04 20:41:59.726918-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
e73c220e-ad9c-4823-802a-68ee7c750d89	2018-03-04 20:41:59.738919-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
69984481-61f2-4912-9c99-7b53a007bf6e	2018-03-04 20:41:59.75092-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
05af8f41-a1c1-4466-aebe-e2d2d40c37fb	2018-03-04 20:41:59.762922-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
aed63c38-e468-4488-93f0-707ece0aa17f	2018-03-04 20:41:59.773923-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
924c6a80-878f-4683-b9e0-31b492c64144	2018-03-04 20:41:59.784924-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
ed7173f3-924b-477b-a828-977b458eea96	2018-03-04 20:41:59.794925-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
4d917c18-c22c-4918-9f1c-1271e9eda3f1	2018-03-04 20:41:59.804926-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
2a635f0a-a939-4b14-a121-a917091048fb	2018-03-04 20:41:59.816927-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
898b8f6c-c234-4f21-a192-7490bd8c7464	2018-03-04 20:41:59.827928-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
67c5c81c-29e2-412e-81af-6588a04d6777	2018-03-04 20:41:59.841929-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
d70649ee-4f28-40e8-9cea-7b0204b1d398	2018-03-04 20:41:59.84493-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
58b10ef5-efdd-45cb-8e48-db6abea8b685	2018-03-04 20:42:09.833929-06	3	[22248] Door 338A	[4] DLarrabee	[21062] a	\N	\N
0772015d-f4a6-43db-a387-bdaa63312cbc	2018-03-04 20:42:10.106956-06	2	[22249] Door 343A	[4] DLarrabee	[21062] a	\N	\N
82ccb7c2-c851-44a8-bd84-453d25b001f2	2018-03-04 20:42:10.120957-06	2	[22250] Door 344A	[4] DLarrabee	[21062] a	\N	\N
4d9ac974-1c01-4060-aec0-0bf2d9fc089e	2018-03-04 20:42:10.134959-06	2	[22251] Door 346A	[4] DLarrabee	[21062] a	\N	\N
4e6be7b9-eb15-4405-943d-f64e8bc89225	2018-03-04 20:42:10.14796-06	2	[22252] Door 347A	[4] DLarrabee	[21062] a	\N	\N
6a12f43c-6058-4ef7-9fea-79d6c05f6648	2018-03-04 20:42:10.157961-06	2	[22253] Door 348A	[4] DLarrabee	[21062] a	\N	\N
22f6e696-6cc4-43c4-b177-1bbfeee5e501	2018-03-04 20:42:10.171962-06	2	[22254] Door 349A	[4] DLarrabee	[21062] a	\N	\N
25ecd2be-0e0a-44fb-a0fa-441beae00c0c	2018-03-04 20:42:10.184964-06	2	[22255] Door 351A	[4] DLarrabee	[21062] a	\N	\N
b52c0943-3482-4b26-b567-c2bd13f91c7d	2018-03-04 20:42:10.203966-06	2	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
aefec343-302d-498c-9b4c-20ce8de10970	2018-03-04 20:42:10.215967-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
c2226c34-e7c1-4588-baf7-8d455272c5a8	2018-03-04 20:42:10.229968-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
0f16d58d-6355-45c1-b3f8-e88c532f0d7b	2018-03-04 20:42:10.240969-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
c8361cba-4300-48f1-87dd-78425c3a2dfa	2018-03-04 20:42:10.25297-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
194402d0-ca06-42ad-b41d-ff608758b514	2018-03-04 20:42:10.265972-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
f126e107-ff88-45a7-9d74-dfdbe3663312	2018-03-04 20:42:10.277973-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
5ba44100-65b2-4b83-8d31-49998ef7f023	2018-03-04 20:42:10.289974-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
2b72fb0c-6244-4045-a57c-926806db5e92	2018-03-04 20:42:10.300975-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
d4b660f6-e0db-40f4-86c4-eb60ac08ac83	2018-03-04 20:42:10.310976-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
db1e1404-a0fb-49cb-8072-be65a52f413c	2018-03-04 20:42:10.319977-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
dc9cdf00-346f-4b76-92af-ead62209b404	2018-03-04 20:42:10.333979-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
631de831-634c-442d-b2e9-b869f1f51a14	2018-03-04 20:42:10.34498-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
49c26932-e1ab-4ef3-b272-9e3575ca25eb	2018-03-04 20:42:10.359981-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
936ac4ba-8ce8-48f7-8a2f-dc84d912c4ac	2018-03-04 20:42:10.370982-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
78a2ae04-d4ff-4a8e-a9ef-12fa66b04831	2018-03-04 20:42:10.380983-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
43355d68-23c2-4dde-bb80-2c550e63ce35	2018-03-04 20:42:10.392984-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
0f8eef6c-0382-45e6-a3f6-f61280d95acb	2018-03-04 20:42:10.404986-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
3f54c8e6-fe3b-4702-aa84-50fec40ae8af	2018-03-04 20:42:10.415987-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
69da4e54-bcec-426f-b580-7ee96c1d8648	2018-03-04 20:42:10.419987-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
4875c7b6-8d11-4b1d-8d4a-55567f577afb	2018-03-04 20:42:20.181963-06	3	[22249] Door 343A	[4] DLarrabee	[21062] a	\N	\N
617d3482-2d95-4ec3-a159-b4666e13fbcf	2018-03-04 20:42:20.455991-06	2	[22250] Door 344A	[4] DLarrabee	[21062] a	\N	\N
5424cc3d-3ace-4b1e-89ef-469ba45e501a	2018-03-04 20:42:20.469992-06	2	[22251] Door 346A	[4] DLarrabee	[21062] a	\N	\N
df77918a-621b-4949-8ab5-c4221729a7c7	2018-03-04 20:42:20.483993-06	2	[22252] Door 347A	[4] DLarrabee	[21062] a	\N	\N
0b1c8f7b-0151-474b-b5ca-9cdc3cd3b65c	2018-03-04 20:42:20.493994-06	2	[22253] Door 348A	[4] DLarrabee	[21062] a	\N	\N
adb3aa17-04fd-42c9-9396-1e1f7b9b8fcc	2018-03-04 20:42:20.506996-06	2	[22254] Door 349A	[4] DLarrabee	[21062] a	\N	\N
7b4b9dad-9728-4dc0-9367-804069a604b9	2018-03-04 20:42:20.518997-06	2	[22255] Door 351A	[4] DLarrabee	[21062] a	\N	\N
87198a95-93a7-44dd-b631-720516f8a5e9	2018-03-04 20:42:20.530998-06	2	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
ab7c2821-e58e-4f88-9e7c-5f0a6d38ae7d	2018-03-04 20:42:20.543999-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
7997b3a6-12a6-4996-84b0-16fb5af13a74	2018-03-04 20:42:20.558001-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
80ec50ae-4296-48de-8dfe-08abf0acbdc8	2018-03-04 20:42:20.568002-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
9404a0e0-ed3c-4643-bb64-670d7c68a755	2018-03-04 20:42:20.583003-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
c67c6060-da78-44ba-adae-d81956693c8a	2018-03-04 20:42:20.594004-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
e0b9383b-bcf1-49e5-8c03-d87b994444d7	2018-03-04 20:42:20.608006-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
339f84fb-6049-47b6-946d-591ea5c67194	2018-03-04 20:42:20.621007-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
cabda9df-8966-4f12-a618-012aa07189fc	2018-03-04 20:42:20.630008-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
170b2ae9-a180-42a8-bb00-a379186fcab9	2018-03-04 20:42:20.642009-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
a737f14d-ae59-468d-967b-469b3c791805	2018-03-04 20:42:20.65301-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
35742564-904d-46d0-8001-80d5ae155e3d	2018-03-04 20:42:20.665012-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
c590bc98-f6b2-461c-a1e1-8003598e2cfb	2018-03-04 20:42:20.677013-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
28518d75-c976-455d-be67-e077d2dba0c2	2018-03-04 20:42:20.689014-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
69b7c585-7325-4629-bf7d-57fa8577a537	2018-03-04 20:42:20.700015-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
a656dc99-8d03-498a-8ed9-7c0af4aa61c3	2018-03-04 20:42:20.710016-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
a428c290-2be8-45c5-bbf1-31ccb883448c	2018-03-04 20:42:20.723017-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
3a48b19e-24eb-4e16-82f1-ac30cc8386ed	2018-03-04 20:42:20.736019-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
4fb06752-4585-4208-8460-c8d697deface	2018-03-04 20:42:20.74902-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
f09c3ca4-ee43-4f74-976d-51ff36eaf20e	2018-03-04 20:42:20.75202-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
a8bbd2ec-9c11-4a39-8a81-2e23aed84440	2018-03-04 20:42:32.860231-06	3	[22250] Door 344A	[4] DLarrabee	[21062] a	\N	\N
2c7315c1-b181-42dd-bf56-e671c0f55545	2018-03-04 20:42:33.120257-06	2	[22251] Door 346A	[4] DLarrabee	[21062] a	\N	\N
bd8616d2-df67-4609-bb94-f50fb851589f	2018-03-04 20:42:33.134258-06	2	[22252] Door 347A	[4] DLarrabee	[21062] a	\N	\N
33d6718d-055f-4dbe-8e35-0ebbd77507b8	2018-03-04 20:42:33.15126-06	2	[22253] Door 348A	[4] DLarrabee	[21062] a	\N	\N
4d7ae9f6-c989-4e6f-97ce-9cdeeefb6c5f	2018-03-04 20:42:33.161261-06	2	[22254] Door 349A	[4] DLarrabee	[21062] a	\N	\N
8b50b0a8-5193-4e5d-a47b-2269d356d27e	2018-03-04 20:42:33.172262-06	2	[22255] Door 351A	[4] DLarrabee	[21062] a	\N	\N
33bb49c8-d0f0-40a4-a5b1-17649f8a8609	2018-03-04 20:42:33.182263-06	2	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
3faa417a-b1cc-41da-a408-557acbc5a789	2018-03-04 20:42:33.194264-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
8e60ecf8-0ae2-403a-8e13-8c6a5d7ff612	2018-03-04 20:42:33.207266-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
ab653191-b89b-4dd8-9845-89368f20af95	2018-03-04 20:42:33.226268-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
38347225-305d-41e5-b890-bcd0de5d331e	2018-03-04 20:42:33.237269-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
0d6ae7aa-7921-487a-8d10-cef5a020e115	2018-03-04 20:42:33.24727-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
850a67d6-a51f-418d-bb38-adc0a675198f	2018-03-04 20:42:33.259271-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
62e8ef7e-cd2a-41de-8e75-4fbccba582af	2018-03-04 20:42:33.273272-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
f02ec2a8-e0fd-4dd8-b860-494d4a4667d1	2018-03-04 20:42:33.285273-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
e8d54310-3c2a-46bb-b7d4-ec72c4c746f3	2018-03-04 20:42:33.294274-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
1d025b3a-a3a6-4052-a9b6-ddbe7ef737d9	2018-03-04 20:42:33.307276-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
9956b717-b926-4b60-a547-5959bf18184a	2018-03-04 20:42:33.321277-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
0ee2ea64-4c39-43c5-a960-2a201ae7f982	2018-03-04 20:42:33.336279-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
0990912f-afd4-4513-8ef7-77a1cab82d8d	2018-03-04 20:42:33.35328-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
fd4a28d0-ba12-454a-bf1b-7dca0855269d	2018-03-04 20:42:33.365281-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
90e42b86-ef74-4e07-a309-90244931e05e	2018-03-04 20:42:33.380283-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
01d26b35-ede1-49ef-9bd3-82d26f87d93d	2018-03-04 20:42:33.391284-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
441f7924-edbf-4369-9d15-bad864200b28	2018-03-04 20:42:33.404285-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
fff279d5-1ebb-4ed6-b3d2-1c4fcc195c49	2018-03-04 20:42:33.417287-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
496c7eee-dbc6-4da9-b8e0-32dd127f520a	2018-03-04 20:42:33.421287-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
98245d6d-0102-464f-91cb-85a972b6e876	2018-03-04 20:43:12.268171-06	3	[22251] Door 346A	[4] DLarrabee	[21062] a	\N	\N
26f112eb-37f3-4913-b965-e64645565174	2018-03-04 20:43:12.562201-06	2	[22252] Door 347A	[4] DLarrabee	[21062] a	\N	\N
d3925f24-ed55-4923-9e3d-56a493acf5fc	2018-03-04 20:43:12.573202-06	2	[22253] Door 348A	[4] DLarrabee	[21062] a	\N	\N
92225ebf-dd5e-4878-ae16-a4282268ea1b	2018-03-04 20:43:12.586203-06	2	[22254] Door 349A	[4] DLarrabee	[21062] a	\N	\N
9577a848-bbd1-4d95-94f9-d7652e30ea78	2018-03-04 20:43:12.600205-06	2	[22255] Door 351A	[4] DLarrabee	[21062] a	\N	\N
d009fee0-04b9-4e28-815c-8a880247b589	2018-03-04 20:43:12.615206-06	2	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
9d6a9174-2b93-4dcc-9ab8-39b93fc86faa	2018-03-04 20:43:12.629207-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
84b3c37d-ce31-4d25-a981-228596ae0603	2018-03-04 20:43:12.640209-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
368a8d08-0266-4fce-beb6-dce958bef320	2018-03-04 20:43:12.65221-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
ea07a7f9-2620-435a-a42e-fb04cb1f8067	2018-03-04 20:43:12.664211-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
e2da4a9d-9103-4653-976f-480d98698162	2018-03-04 20:43:12.678212-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
ff2062c9-ef4b-4135-9121-c745254d199b	2018-03-04 20:43:12.690214-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
988b80a3-964b-4dda-a652-2932fad5608f	2018-03-04 20:43:12.702215-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
939a8379-a636-464b-ad7c-59f5f616ef6b	2018-03-04 20:43:12.712216-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
827c24d2-451c-40c3-934c-7632899b777b	2018-03-04 20:43:12.723217-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
a8343b85-2af3-4289-b526-d04aaa704bea	2018-03-04 20:43:12.735218-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
c30e0a50-b00d-4090-a2cd-9fea96e2e5fc	2018-03-04 20:43:12.746219-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
342b1656-5559-4f23-ba98-5c7c13522621	2018-03-04 20:43:12.75722-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
b4a4e576-fc26-4b51-8b1b-0decfafdcac5	2018-03-04 20:43:12.766221-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
6915104b-a36a-4cfb-a541-12a0686880ea	2018-03-04 20:43:12.776222-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
5b55a3e4-41b2-49a0-b45d-ae7eed461e7d	2018-03-04 20:43:12.787223-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
3d524f74-f8bc-4c2c-baca-662d85edf092	2018-03-04 20:43:12.797224-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
3b3d2424-971a-48b2-813d-5a44fb77e33d	2018-03-04 20:43:12.808225-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
3c8fc583-f9df-449e-9f78-f87eec1a0c58	2018-03-04 20:43:12.822227-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
c10934cb-8ab5-4023-b8c7-b101cf7152d6	2018-03-04 20:43:12.825227-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
aded29d4-c1a5-4929-b231-2b1bf50bc0c5	2018-03-04 20:43:19.434888-06	3	[22252] Door 347A	[4] DLarrabee	[21062] a	\N	\N
71c3c4ef-99ab-4ae1-9b47-72e940026509	2018-03-04 20:43:19.713916-06	2	[22253] Door 348A	[4] DLarrabee	[21062] a	\N	\N
728169d2-f7b3-4d38-b0b0-3cc12a6ba164	2018-03-04 20:43:19.724917-06	2	[22254] Door 349A	[4] DLarrabee	[21062] a	\N	\N
b1bf67e1-f723-47ee-89e1-57bafaa27e35	2018-03-04 20:43:19.734918-06	2	[22255] Door 351A	[4] DLarrabee	[21062] a	\N	\N
67a1f243-2eb5-45f7-9e2f-e9de5315472d	2018-03-04 20:43:19.748919-06	2	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
1fad9222-2dcc-467c-afe9-bccb0544b470	2018-03-04 20:43:19.762921-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
67771fe2-cfe4-4ffa-91dd-fe7ab0541a14	2018-03-04 20:43:19.775922-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
3e9b9af3-3fe7-4765-92dd-53bffac1f236	2018-03-04 20:43:19.788923-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
a252fd9a-79a3-4001-89cd-53439397272a	2018-03-04 20:43:19.803925-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
5198fee0-9f3b-458f-9f45-cdde8d7ecf4d	2018-03-04 20:43:19.817926-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
32ecabb3-1db1-4992-b384-c8e1bda6b8ec	2018-03-04 20:43:19.831928-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
06d6b940-56c9-4321-9dd5-a61c2e27d922	2018-03-04 20:43:19.840929-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
0e1beff4-643f-4ca1-a3e4-8f45abb057d7	2018-03-04 20:43:19.85293-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
2bca3f72-476e-460f-8f59-1c5c20f16ecb	2018-03-04 20:43:19.863931-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
bd7cfeb0-d508-4447-8643-0b08edfe583d	2018-03-04 20:43:19.875932-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
7c556ca6-8446-4328-ab99-c1f47f7cabdb	2018-03-04 20:43:19.884933-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
d4eae3c7-94bd-483f-bc68-abc0b9e56b47	2018-03-04 20:43:19.898934-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
309e8387-7566-4c89-835a-df04978a7bf6	2018-03-04 20:43:19.911936-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
1f5b0269-9f84-43bb-869a-8a2475b6b9da	2018-03-04 20:43:19.928937-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
39d5d7c1-2edc-4885-920f-657345a837ec	2018-03-04 20:43:19.943939-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
156caaee-b9f3-4fb0-a821-dde80d1d537c	2018-03-04 20:43:19.95794-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
faa1d048-90a2-4085-a0ea-d8bbcee85d68	2018-03-04 20:43:19.970942-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
3c142a82-cd24-4c60-bf59-2b2c268a91d6	2018-03-04 20:43:19.979942-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
664ad262-feee-4343-b7f8-0de008ed4c10	2018-03-04 20:43:19.984943-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
428f7444-2812-462b-bbbc-c531f62a9793	2018-03-04 20:43:36.937638-06	3	[22253] Door 348A	[4] DLarrabee	[21062] a	\N	\N
1abc8ec1-6698-4821-897d-73a76a401bcf	2018-03-04 20:43:37.217666-06	2	[22254] Door 349A	[4] DLarrabee	[21062] a	\N	\N
a57b3be0-03ee-428e-9054-01736853026d	2018-03-04 20:43:37.230667-06	2	[22255] Door 351A	[4] DLarrabee	[21062] a	\N	\N
8de31ccf-cad8-40b6-b487-03f405b9d927	2018-03-04 20:43:37.242669-06	2	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
2e092b2b-8f49-4fbb-8b23-ac11724f40a1	2018-03-04 20:43:37.25267-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
7be0f808-1b9f-4509-9d94-2edc39977de0	2018-03-04 20:43:37.264671-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
cc1ce3c7-53a0-492b-8dd4-0873baa06b53	2018-03-04 20:43:37.275672-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
c1b86ce3-a649-451c-a231-8c2267f605e2	2018-03-04 20:43:37.287673-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
3817b313-2ce5-4a1e-a5bc-9f676a884a75	2018-03-04 20:43:37.299674-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
5a452a2c-a648-4ea0-a7e6-99938cd002d7	2018-03-04 20:43:37.314676-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
2e1c46de-1e12-4579-90e7-a0ec9cd44dc9	2018-03-04 20:43:37.328677-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
77e25fa3-7ce9-4ab8-91dc-e9ea4598f6f7	2018-03-04 20:43:37.342679-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
6ec92ccb-abd5-49ae-aef2-e043b7945613	2018-03-04 20:43:37.35668-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
2653730a-dc7d-4dec-9989-7e4460a9bf02	2018-03-04 20:43:37.371681-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
2494e4cb-3bea-44f3-95d7-d16166e62545	2018-03-04 20:43:37.385683-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
3f9e4164-a857-4367-861c-91b7ca5e8759	2018-03-04 20:43:37.397684-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
b506ccca-8adf-47e9-8bce-d0c7552e63cd	2018-03-04 20:43:37.415686-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
bc6a907e-2387-4962-85e5-56e022981310	2018-03-04 20:43:37.430687-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
c8d09344-7f39-4ef2-b8f7-45d446b88f08	2018-03-04 20:43:37.445689-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
524fc1eb-ac5a-4a82-a454-07998af7fef7	2018-03-04 20:43:37.45869-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
22c29706-96f9-4b18-86d5-ecb429b916a4	2018-03-04 20:43:37.470691-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
7b573d65-f40d-464c-bc8d-acb77332ec2c	2018-03-04 20:43:37.482693-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
2b04c15d-efdd-4b0e-a573-28f2796d054c	2018-03-04 20:43:37.486693-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
ea2f6327-3503-4cf7-a1dc-9921404a1e1f	2018-03-04 20:43:44.827427-06	3	[22254] Door 349A	[4] DLarrabee	[21062] a	\N	\N
4004ce27-e1cd-4f29-97b4-72043010ad15	2018-03-04 20:43:45.111455-06	2	[22255] Door 351A	[4] DLarrabee	[21062] a	\N	\N
6c77ff4b-52f6-4c25-80ac-2eb964314d8f	2018-03-04 20:43:45.125457-06	2	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
77b13890-983c-44fa-9342-5a5dc4a0d4a0	2018-03-04 20:43:45.136458-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
ebda5376-c61c-4a04-ada8-73f4a633704f	2018-03-04 20:43:45.148459-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
b6c87069-b949-4f4c-a29f-9655e17fc2d9	2018-03-04 20:43:45.16146-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
097cffbd-a8bc-4df1-9cfc-a4d6aa31e94a	2018-03-04 20:43:45.173462-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
14cc9dc3-f8f0-46d7-b06c-5ef6eea72a58	2018-03-04 20:43:45.184463-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
6cc217ef-700b-4ecc-8bea-e4277cdf4c4f	2018-03-04 20:43:45.197464-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
975fee89-a3ae-4f82-bc54-c82fef6f4519	2018-03-04 20:43:45.207465-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
135d240f-4043-494d-81dc-1b4e084c74be	2018-03-04 20:43:45.218466-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
fc423b17-efa2-4e2f-bcfc-bed08d6ef765	2018-03-04 20:43:45.228467-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
5fcd0df1-b3e2-4bac-a795-45b9d71c99e1	2018-03-04 20:43:45.239468-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
46839a62-8403-4b6b-9815-f8a58c47ef14	2018-03-04 20:43:45.248469-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
3b78cba9-d7f0-42e0-9a7b-b5793d56d285	2018-03-04 20:43:45.25847-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
26dcf5ad-206b-4922-b828-ad54e0296d07	2018-03-04 20:43:45.273472-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
47745f19-ea79-4acc-a313-e0148fd6c566	2018-03-04 20:43:45.284473-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
89ed5edb-0ced-46a2-895f-3545d8f724a5	2018-03-04 20:43:45.294474-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
9a3638f6-757a-4846-8349-6b0de71ffc62	2018-03-04 20:43:45.304475-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
efb6c50c-a1f2-4bd1-9024-b98ceaa90e85	2018-03-04 20:43:45.315476-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
f0e2d4fc-080d-41db-87f8-2085fd91aea7	2018-03-04 20:43:45.328477-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
cd0f5ce6-faf7-4529-9b54-31945a5aa476	2018-03-04 20:43:45.331477-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
7c5568d2-4074-4860-8a04-9e8e4c52227b	2018-03-04 20:44:38.013745-06	3	[22255] Door 351A	[4] DLarrabee	[21062] a	\N	\N
bc40688e-0777-473d-a183-6a6a215dfacf	2018-03-04 20:44:38.296773-06	2	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
452f67c8-1264-4a58-9a75-8b6ec2ea3575	2018-03-04 20:44:38.310775-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
029a75c3-917a-46ab-96c7-6fc62fe66db7	2018-03-04 20:44:38.321776-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
34819d6c-0fa3-44d1-a370-d15a02137214	2018-03-04 20:44:38.332777-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
18e41dde-124d-4752-99fd-7e8d31dce6ab	2018-03-04 20:44:38.343778-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
9d96e01b-601c-44c7-9a2c-7e091987eb7d	2018-03-04 20:44:38.357779-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
6b85d42e-1a42-4e9b-9113-a214dd6719c3	2018-03-04 20:44:38.36678-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
0206d885-5734-406a-8db5-91a16852fb41	2018-03-04 20:44:38.380782-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
5658e017-f8bc-4731-9f0f-4d185125851d	2018-03-04 20:44:38.393783-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
a734e2aa-2b03-4060-9c33-6b2471d4bc1a	2018-03-04 20:44:38.408785-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
15d3d29f-2605-4b57-a245-ab783f203011	2018-03-04 20:44:38.419786-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
f87ce084-f0ef-46fc-bf90-88248e1e68d8	2018-03-04 20:44:38.429787-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
35392a41-a0f1-421b-867f-0311c27fa04a	2018-03-04 20:44:38.440788-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
38c73367-96ef-4ac5-9f39-909c5e2becd6	2018-03-04 20:44:38.456789-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
9bb55811-0d97-4baf-b0db-198236fa6b15	2018-03-04 20:44:38.46679-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
b0a04e2a-f29b-43fb-afbc-885e60f2b87e	2018-03-04 20:44:38.476791-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
f9e165a2-86a7-44af-ba40-cb867e96714d	2018-03-04 20:44:38.488793-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
ce60d94f-3630-4d53-9d68-c130da28fca4	2018-03-04 20:44:38.502794-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
085c2212-8d53-401b-9f95-fcc5ea380bae	2018-03-04 20:44:38.519796-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
391dbff6-f62c-4363-ba8a-9690a796a757	2018-03-04 20:44:38.522796-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
9db4c285-7d76-45f0-8922-cb45e8696b90	2018-03-04 20:44:46.030547-06	3	[22256] Door 351B	[4] DLarrabee	[21062] a	\N	\N
8582de60-e9ac-4e07-bd43-e683220d60bf	2018-03-04 20:44:46.312575-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
cc8c65e2-9886-45cb-bfed-1fe5e4dbe600	2018-03-04 20:44:46.334577-06	2	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
c6448920-8aa5-4516-9c6e-8a4f481440b5	2018-03-04 20:44:46.348578-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
fb6bc5cb-d554-4ca1-be50-292da281cd6a	2018-03-04 20:44:46.36358-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
89240db5-9e09-4b9e-8280-606f04aec587	2018-03-04 20:44:46.384582-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
895d8cfa-2c99-43db-8b4d-916cbd18d186	2018-03-04 20:44:46.397583-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
816c72d4-e4b4-43ec-9337-2b47434f4707	2018-03-04 20:44:46.410585-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
310f7db1-e0af-43eb-b873-2f6bde7beb8a	2018-03-04 20:44:46.421586-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
40623641-013f-49e5-b3cc-60e7f35159b7	2018-03-04 20:44:46.433587-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
8b618e35-640d-4ffd-9d2b-8eb20c9e0687	2018-03-04 20:44:46.445588-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
565fbb8c-c642-498b-8e95-f5c5ce88684d	2018-03-04 20:44:46.457589-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
aa4f2d89-6ec6-4654-b902-c2bc71b416ea	2018-03-04 20:44:46.46859-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
90b59ddc-1157-42a0-820d-d1044b228198	2018-03-04 20:44:46.481592-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
b8805bbe-e6ec-4746-9083-477d9b405df2	2018-03-04 20:44:46.493593-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
9668f337-af53-49bc-8a11-fa5f73aa932f	2018-03-04 20:44:46.509595-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
944c51a8-55f1-4654-90bb-0a951e9e0ffb	2018-03-04 20:44:46.521596-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
45e59da9-58af-4d97-acbb-d0d41398d17b	2018-03-04 20:44:46.540598-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
9f6a5c1f-2c6e-45fc-a7c4-8dff9bf326ef	2018-03-04 20:44:46.554599-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
ff3655a0-90fb-4949-856a-551e161f16ff	2018-03-04 20:44:46.557599-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
c2cf77b0-7127-4029-b403-b52cf4935082	2018-03-04 20:46:13.762319-06	1	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
0038674c-7e77-4dd8-b438-d5026b8e2520	2018-03-04 20:47:13.317274-06	1	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
79eb7f66-6602-4911-9313-7fff7ba58ea4	2018-03-04 20:48:26.606602-06	1	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
480f4a41-3566-4dac-b447-17b123726c2e	2018-03-04 20:49:41.285069-06	1	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
ee95de2f-b2e5-4522-a6e6-4ed2254946cd	2018-03-04 20:50:35.926533-06	1	[22292] Area-A.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
30c4d292-1ec7-46cd-b46b-e5113d58a230	2018-03-04 20:50:38.226763-06	2	[22292] Area-A.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
fd59f0e7-7b51-4106-85b9-74d17c5e0d7d	2018-03-04 20:50:58.493789-06	2	[21045] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
1933d1d6-a71d-42ff-8e29-2478353d0720	2018-03-04 20:53:04.239363-06	1	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
705c52cb-c9e0-485b-9713-2aac9c828879	2018-03-04 20:55:43.613298-06	2	[21045] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
2ec1eee1-1eef-4716-9b7b-32d3401ac381	2018-03-04 20:56:05.786515-06	2	[22375] 351B	[4] DLarrabee	[21062] a	\N	\N
cb9a4fe2-be6b-41f6-a107-be2518cc7ab6	2018-03-04 20:59:47.85572-06	2	[22189] 351B	[4] DLarrabee	[21062] a	\N	\N
d6240306-018e-42db-b454-8e7afb12fb78	2018-03-04 21:00:36.821616-06	3	[22314] IC 306B-InB	[4] DLarrabee	[21062] a	\N	\N
0b1d0759-047d-4d8e-955e-4434cf97590f	2018-03-04 21:00:37.108645-06	2	[22315] IC 306B-OutB	[4] DLarrabee	[21062] a	\N	\N
c99a9e6b-87f7-43a0-9f74-4dbcc4a4c671	2018-03-04 21:00:37.113645-06	2	[22316] IC 326A-OutB	[4] DLarrabee	[21062] a	\N	\N
66e0415b-399f-4c6c-8881-6a59b6252f02	2018-03-04 21:00:37.118646-06	2	[22317] IC 327A	[4] DLarrabee	[21062] a	\N	\N
a98e5538-df5c-424f-afc1-a24be87aba01	2018-03-04 21:00:37.122646-06	2	[22318] IC 327A-outB	[4] DLarrabee	[21062] a	\N	\N
247499eb-14ee-4848-b3ff-7aec895bbcb6	2018-03-04 21:00:37.127647-06	2	[22319] IC 329A	[4] DLarrabee	[21062] a	\N	\N
640983dc-5959-43cf-873d-9155d53328c1	2018-03-04 21:00:37.135648-06	2	[22320] IC 329A-outB	[4] DLarrabee	[21062] a	\N	\N
4d38a866-a769-4d50-a37b-ff97779902c8	2018-03-04 21:00:37.138648-06	2	[22321] IC 329B	[4] DLarrabee	[21062] a	\N	\N
21ca29de-4263-4719-8832-b98dd4c849ff	2018-03-04 21:00:37.143648-06	2	[22322] IC 329B-outB	[4] DLarrabee	[21062] a	\N	\N
73874674-6aa1-4dde-97b2-0c520409498e	2018-03-04 21:00:37.148649-06	2	[22323] IC 334A	[4] DLarrabee	[21062] a	\N	\N
212c403a-d6d4-497b-a1f1-837a8a1ab4db	2018-03-04 21:00:37.153649-06	2	[22324] IC 334A-outB	[4] DLarrabee	[21062] a	\N	\N
ff7442ef-11c9-4254-9bbd-6607872985ec	2018-03-04 21:00:37.15765-06	2	[22325] IC 335A	[4] DLarrabee	[21062] a	\N	\N
2f450c17-7456-4697-8f81-9af30728cbcb	2018-03-04 21:00:37.16165-06	2	[22326] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
09afed05-154d-45fa-8684-884126c36d82	2018-03-04 21:00:37.166651-06	2	[22327] IC 336A	[4] DLarrabee	[21062] a	\N	\N
a4690979-20b5-4b9f-adf4-a979093f45e7	2018-03-04 21:00:37.174652-06	2	[22328] IC 336A-outB	[4] DLarrabee	[21062] a	\N	\N
d373eec0-3ce5-4b0e-bbc2-9f7a4eef8a79	2018-03-04 21:00:37.178652-06	2	[22329] IC 337A	[4] DLarrabee	[21062] a	\N	\N
d30bddeb-32fd-4a2f-957a-888d84179694	2018-03-04 21:00:37.183652-06	2	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
3d88c943-801a-4984-9597-63de57455b30	2018-03-04 21:00:37.188653-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
2afd5102-94e2-4a32-b263-402c8f01f38e	2018-03-04 21:00:37.193653-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
6a8b80cf-d5fc-4c1e-a48f-43e49b53f26b	2018-03-04 21:00:37.197654-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
14d6c6c5-7a48-464b-a31f-8b9490719a45	2018-03-04 21:00:37.200654-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
1169a1cd-597c-42ff-ac91-24687206623b	2018-03-04 21:00:37.207655-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
1488922a-e736-463c-82ab-a3c5996a88e3	2018-03-04 21:00:37.212655-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
d908547e-5fdd-41d3-9992-d1d107949d02	2018-03-04 21:00:37.216656-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
8cfef45f-92ea-4a7a-913c-e5a61893a845	2018-03-04 21:00:37.220656-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
6e2ec002-4dc0-4126-ba67-c653cd6848ca	2018-03-04 21:00:37.223656-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
3647f812-0448-4a03-b501-af561bf17e91	2018-03-04 21:00:37.227657-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
3836d2b9-09f0-407f-9ab4-a5514634a7d8	2018-03-04 21:00:37.232657-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
642bd56c-16c6-4d22-98db-8bcf06f3ff34	2018-03-04 21:00:37.238658-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
c4cdb356-02c9-4973-91b7-131ce3433386	2018-03-04 21:00:37.243658-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
c91e9fa9-93d8-426d-becf-8bf5d221cc85	2018-03-04 21:00:37.246659-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
3e77f06f-da95-47af-a150-2ea48db0fb06	2018-03-04 21:00:37.250659-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
58e28cd5-3758-4f62-8497-39d4530e6f6a	2018-03-04 21:00:37.25566-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
3e9f841c-9096-4b9b-ad1e-4f851a444990	2018-03-04 21:00:37.25966-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
70c00fff-1f34-49ad-b80e-ac72ac929f60	2018-03-04 21:00:37.264661-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
382d1b2b-7813-4b96-8693-bcf21e89bdfb	2018-03-04 21:00:37.268661-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
8c751f76-b841-480d-b416-a4ae7f82a0f5	2018-03-04 21:00:37.276662-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
b9622039-80ba-48b1-a524-75055cac9955	2018-03-04 21:00:37.280662-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
3f78d5a2-d7aa-40c3-b472-398cd7063d03	2018-03-04 21:00:37.284663-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
6664b97b-d19d-4b39-b1ce-5d6d29be1ae0	2018-03-04 21:00:37.287663-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
dbf03ec5-819c-4efc-9651-1c3c84e8e5ab	2018-03-04 21:00:37.290663-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
83f7dbd7-f5ba-4120-a009-9fc7e0aa31ba	2018-03-04 21:00:37.295664-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
7966a631-d323-43db-9ce7-a219091931ee	2018-03-04 21:00:37.299664-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
28e565f5-e42e-423e-ac75-dcc2f56b7a61	2018-03-04 21:00:37.306665-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
793fe570-495d-4a29-9a43-2ed0be7a07e6	2018-03-04 21:00:37.311665-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
bce85c1f-4c02-4d93-91f4-2022bf24fff7	2018-03-04 21:00:37.315666-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
0daf7f15-b6d6-4f27-8d05-5a1763b6b20c	2018-03-04 21:00:37.319666-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
8dfddeb8-9631-4fe6-893a-d77900c203df	2018-03-04 21:00:37.323666-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
38ebf59e-b6a2-4120-8444-61d69df63d6e	2018-03-04 21:00:37.327667-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
061c0395-d9bf-4871-9ccb-edbbb2bde826	2018-03-04 21:00:37.332667-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
67e9e36b-10be-491e-8fa3-694d00109773	2018-03-04 21:00:37.338668-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
961d959e-0ca8-4fa5-916c-5b2c56904a06	2018-03-04 21:00:37.343668-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
a12241a1-4f07-4b96-871f-18513fb439cd	2018-03-04 21:00:37.347669-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
8cfdc803-a3a0-4669-8e3f-5c04022e8467	2018-03-04 21:00:37.352669-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
dcea047a-4a5b-4a8f-bb89-d599c79d8494	2018-03-04 21:00:37.35667-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
5f45e9c2-4dea-4d60-920c-c3947703a9f7	2018-03-04 21:00:37.36167-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
6955c135-5ea3-4371-ac4e-2882d1ed0e9e	2018-03-04 21:00:37.366671-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
0b8fc748-7dc5-46dc-bb1a-5d4e48053885	2018-03-04 21:00:37.373671-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
eb7c2c2e-0bf6-4db1-99bd-c584459174a3	2018-03-04 21:00:37.376672-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
a32d5f8a-c5a6-41e5-9d43-73429477aea8	2018-03-04 21:00:37.380672-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
e6e04773-a704-4543-a79f-d10448f3f8e1	2018-03-04 21:00:37.383672-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4a80cdd6-ab44-4d59-afb4-abd9fdbe41cd	2018-03-04 21:00:37.387673-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
73a00055-9d39-4958-a389-af810f4853aa	2018-03-04 21:00:37.390673-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
54eb5645-c8f8-4641-8e41-ba04f403e77d	2018-03-04 21:00:37.392673-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b851c95d-c892-4344-b7d6-830a270c7cde	2018-03-04 21:00:37.396674-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
878276b3-69a8-4c1e-8dc8-aa68971c5987	2018-03-04 21:00:37.399674-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2badd26b-284e-4f4a-8c3d-007f108dda4d	2018-03-04 21:00:37.401674-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4b491926-5b49-4ccd-9721-5d3ab88b3211	2018-03-04 21:00:37.404675-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5e919a7b-d5d7-4f6d-b50f-42d234235ceb	2018-03-04 21:00:37.408675-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
df83de5e-bdd7-469e-99c6-97df88d181ba	2018-03-04 21:00:37.411675-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fc72eed7-811e-4132-947d-792409cfe697	2018-03-04 21:00:37.415676-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2baee86a-2fed-44bf-967d-c7aedb793352	2018-03-04 21:00:37.418676-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0c56f5e5-4a10-4a73-a7e0-d31a821de110	2018-03-04 21:00:37.421676-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
59257a44-6025-4dd8-9e5f-1f64bb7739bd	2018-03-04 21:00:37.424677-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
704292c4-4a84-4ba3-bc9d-bec5f0595023	2018-03-04 21:00:37.426677-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
006ae1fc-a665-41e2-9da6-7c76163f51ac	2018-03-04 21:00:37.429677-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8cb5bfe6-e4e4-4095-897d-a44c1c92ac93	2018-03-04 21:00:37.433677-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0248c71b-ac0a-4030-a5bd-12efad4e0690	2018-03-04 21:00:37.435678-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8dfc5548-b5c5-43b4-afcf-593a5d9ad82a	2018-03-04 21:00:37.438678-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
dfa232f1-71f3-47c2-abd5-8b90709afe0b	2018-03-04 21:00:37.441678-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
e4c94503-357b-4de9-b53c-f3bcc342412d	2018-03-04 21:00:37.443678-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
1a154083-492b-454b-858f-95c22022c112	2018-03-04 21:00:37.447679-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
844b514b-2fc3-4129-9c0b-6f074fc548d6	2018-03-04 21:00:37.451679-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
1842bb31-bcd2-4a4a-912d-8e67584fd8ee	2018-03-04 21:00:37.45568-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
5dceeabf-993e-4d1a-ba2d-ceafbd84913e	2018-03-04 21:00:37.46268-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
35bec0e5-dd28-40bc-baa0-f003b680c330	2018-03-04 21:00:37.466681-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
d7d5877c-6f2e-45ea-b69b-580bf8f4a715	2018-03-04 21:00:37.470681-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
968d95f1-3fbd-4a60-9929-b136a7437a78	2018-03-04 21:00:37.473681-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
3a99aed7-9e69-4a5c-83a0-19d00f42754c	2018-03-04 21:00:37.477682-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
c1482146-34ac-4ad0-ac99-b3589d9acf72	2018-03-04 21:00:51.814115-06	3	[22315] IC 306B-OutB	[4] DLarrabee	[21062] a	\N	\N
238e6b6c-333a-4ef6-bc80-63ff3c38066d	2018-03-04 21:00:52.071141-06	2	[22316] IC 326A-OutB	[4] DLarrabee	[21062] a	\N	\N
a9612625-9e73-41e4-93f2-4c9a857eb378	2018-03-04 21:00:52.076142-06	2	[22317] IC 327A	[4] DLarrabee	[21062] a	\N	\N
1445a81c-1e9c-498b-b97b-403c313d774c	2018-03-04 21:00:52.082142-06	2	[22318] IC 327A-outB	[4] DLarrabee	[21062] a	\N	\N
ed6a89b4-38a5-421c-a4ca-4fc81c446fcf	2018-03-04 21:00:52.089143-06	2	[22319] IC 329A	[4] DLarrabee	[21062] a	\N	\N
91c98112-9b67-4133-9a3a-1961b6fd1a33	2018-03-04 21:00:52.093143-06	2	[22320] IC 329A-outB	[4] DLarrabee	[21062] a	\N	\N
6d1f8182-2835-49c2-b587-c8efe4675b40	2018-03-04 21:00:52.098144-06	2	[22321] IC 329B	[4] DLarrabee	[21062] a	\N	\N
0a7f06cc-a8b2-4600-adcc-d12769e50851	2018-03-04 21:00:52.103144-06	2	[22322] IC 329B-outB	[4] DLarrabee	[21062] a	\N	\N
4d391a96-4b28-4e52-a16b-74c3f5d6763b	2018-03-04 21:00:52.107145-06	2	[22323] IC 334A	[4] DLarrabee	[21062] a	\N	\N
bb7da77b-b666-49b3-8d56-187df76478ac	2018-03-04 21:00:52.112145-06	2	[22324] IC 334A-outB	[4] DLarrabee	[21062] a	\N	\N
6dfaac6a-3389-4bc9-9418-1c7d2a2e1571	2018-03-04 21:00:52.116146-06	2	[22325] IC 335A	[4] DLarrabee	[21062] a	\N	\N
72157b36-62fb-4e72-95b7-e76bbc913ea0	2018-03-04 21:00:52.122146-06	2	[22326] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
99deec56-6373-42c0-8d9e-c356ae38323e	2018-03-04 21:00:52.127147-06	2	[22327] IC 336A	[4] DLarrabee	[21062] a	\N	\N
3ce6dc98-160c-48fd-b6fb-3a8aa070739a	2018-03-04 21:00:52.131147-06	2	[22328] IC 336A-outB	[4] DLarrabee	[21062] a	\N	\N
fa5e7bfc-71ef-416b-b17a-da4d577c9f5b	2018-03-04 21:00:52.135147-06	2	[22329] IC 337A	[4] DLarrabee	[21062] a	\N	\N
b77a7a94-666b-4428-9b8f-837d3dbdb59c	2018-03-04 21:00:52.139148-06	2	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
6d237523-1740-44b0-b7ed-e79ac5a1c2ab	2018-03-04 21:00:52.144148-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
18f71457-53c9-49ee-9522-5960b431857e	2018-03-04 21:00:52.149149-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
4822d0a7-dd09-420b-adc6-c8d04d92dc40	2018-03-04 21:00:52.15615-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
ef9c557a-717e-4aff-b19d-fb8caf83bb06	2018-03-04 21:00:52.16015-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
32793544-c774-4326-8717-0a3840ef1501	2018-03-04 21:00:52.16315-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
a1005b89-0002-4ee9-8003-e3a201b2aba0	2018-03-04 21:00:52.167151-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
b3ed1c86-7910-42f0-a68e-d00a657680f7	2018-03-04 21:00:52.170151-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
c49afcfb-7b59-4b92-b689-2aeeed41b38c	2018-03-04 21:00:52.174151-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
40bfed25-1582-428b-99cd-2f3405017f22	2018-03-04 21:00:52.179152-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
df170d99-59bf-4635-bcfe-27d1deaf0fa4	2018-03-04 21:00:52.183152-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
04ddc428-d64c-4e55-a4ff-2cf2e76fa4d7	2018-03-04 21:00:52.189153-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
222a7629-e589-4453-b595-8b9fe7524cfb	2018-03-04 21:00:52.194153-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
41be4b3d-6c9a-4b2a-98d9-176a8842ef90	2018-03-04 21:00:52.198154-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
b4db9781-e44f-4ef4-8c43-c1a2305ac0a8	2018-03-04 21:00:52.201154-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
4d7e27c3-3e4a-4708-b30d-531bd0d93b38	2018-03-04 21:00:52.206155-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
46e3feab-0e9b-466a-976e-ac0fc7aacf03	2018-03-04 21:00:52.210155-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
38a0d1e9-4976-4aa6-919b-33c798ea0976	2018-03-04 21:00:52.214155-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
05efc194-f244-4085-b7cb-5c399163295d	2018-03-04 21:00:52.221156-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
09611fc4-40dd-405d-8b59-c0e4efc4647d	2018-03-04 21:00:52.224156-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
26b44af2-5a11-4355-8dda-2175c55c106b	2018-03-04 21:00:52.228157-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
ba085612-76fc-436f-a6cd-19519f7108f9	2018-03-04 21:00:52.232157-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
006f4eaa-cf65-4f50-bce9-fead67cf692a	2018-03-04 21:00:52.237158-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
93ea11b5-fe6b-4d98-b9e7-c77fd6b4d593	2018-03-04 21:00:52.241158-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
59dfee9c-028e-4d4e-a027-92d1f840d16f	2018-03-04 21:00:52.246159-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
255f628b-f884-472b-b70d-173f89ae7727	2018-03-04 21:00:52.253159-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
5e045afa-7357-48d2-97e5-c0d05e3d8a98	2018-03-04 21:00:52.25716-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
7be043ed-d455-41b6-bf17-7457e3e39d11	2018-03-04 21:00:52.26116-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
4dcb1595-ecaa-470e-97c4-ae4b66b0920f	2018-03-04 21:00:52.26516-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
f0c4ec5d-e953-435b-a0a5-11235a3f2642	2018-03-04 21:00:52.270161-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
08688a1a-7d56-49ac-ae25-5a5f0d74e4e1	2018-03-04 21:00:52.274161-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
1e11b49e-9ddb-4f1a-98a2-d6e3c2ced18a	2018-03-04 21:00:52.278162-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
60d1a42a-5a7c-4a6a-93cf-2ba03063d49b	2018-03-04 21:00:52.285162-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
44358404-08a2-452f-9a9e-61c490e60e2f	2018-03-04 21:00:52.289163-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
bc73cff5-b889-4cc5-bc5b-270a48a526d0	2018-03-04 21:00:52.293163-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
edba2059-6045-4d37-a78f-d084f57dbdf4	2018-03-04 21:00:52.297164-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
fc0e2f9f-a6c5-45b4-8e3f-de004965184d	2018-03-04 21:00:52.301164-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
19eef72b-da46-4faa-8e8c-fd9e40230db8	2018-03-04 21:00:52.306165-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
7766ce31-2f5a-478f-beea-c090aa6a496a	2018-03-04 21:00:52.310165-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
76fc9868-c8f8-4ee4-809d-7139cf9155f8	2018-03-04 21:00:52.315165-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
812fe135-2615-454d-b20c-762a4cc9a071	2018-03-04 21:00:52.322166-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
02b53ac6-7310-4d33-a6c2-72b236f13454	2018-03-04 21:00:52.326167-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
b057796f-6116-403e-ac68-995fe96250f8	2018-03-04 21:00:52.330167-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
459867bc-92f1-4cea-8fca-3390d80015b8	2018-03-04 21:00:52.335167-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
31416ff2-9233-4679-bd25-51f4c539dae1	2018-03-04 21:00:52.338168-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0c161300-ae34-4de5-8a82-afccf8d53cb2	2018-03-04 21:00:52.342168-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d9ca19ed-16b0-457c-a644-278f3c05fa34	2018-03-04 21:00:52.344168-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ed328b93-3567-416e-a346-f600221b117e	2018-03-04 21:00:52.347169-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6bd3b2cd-82ad-4dbc-8f83-2c6d3e3f7605	2018-03-04 21:00:52.349169-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7154b782-f27d-4793-8f5b-7cfe69d3c704	2018-03-04 21:00:52.352169-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1c8524f3-4c06-42ca-af1f-c2cc33bd0fb8	2018-03-04 21:00:52.35617-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f45f6c11-808e-4222-8273-a07230320d50	2018-03-04 21:00:52.36217-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
43695398-e62a-4ed8-b544-122086a8b089	2018-03-04 21:00:52.366171-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c526a5a7-b683-4c35-9eea-71767878b329	2018-03-04 21:00:52.369171-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d3396ed2-e45d-42c5-bc47-7cf49856502f	2018-03-04 21:00:52.373171-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
eaf2f10b-e0f4-4397-87e8-b19b1400afe1	2018-03-04 21:00:52.376172-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
37eb5cda-343e-4872-a631-764e5a8871e4	2018-03-04 21:00:52.380172-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7a961697-e968-4386-ad24-5bd0221683d5	2018-03-04 21:00:52.383172-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
49c59be4-3b02-4aba-9bd3-69d63cc6955c	2018-03-04 21:00:52.387173-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
824742f6-a1b8-4b20-8899-b920b82f26a7	2018-03-04 21:00:52.390173-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5536c140-1f35-490b-b86c-377a9c4a1c4d	2018-03-04 21:00:52.393173-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
00844bcb-96c2-46cc-b258-93928e2a605e	2018-03-04 21:00:52.397174-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c7e03fc1-ad77-46d7-9784-8fc14db2b8f6	2018-03-04 21:00:52.402174-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
3f462565-931e-4d75-adda-dadc6ff25e43	2018-03-04 21:00:52.406175-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
39cb727b-e4bf-499b-8581-bd1b7a1ab72e	2018-03-04 21:00:52.409175-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
d85037d0-8103-4d9c-aed6-21e0bf2223ed	2018-03-04 21:00:52.416176-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
4437666c-6654-44a2-91df-903e66a36400	2018-03-04 21:00:52.420176-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
dc6b02b4-982d-4df0-b03b-5e2339abb4ee	2018-03-04 21:00:52.424176-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
aabd52e7-711b-4229-b8df-8d302e02c3ae	2018-03-04 21:00:52.427177-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
ccb6a042-ce8e-40cc-b6f0-a837151fff4d	2018-03-04 21:00:52.431177-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
ea4a4e25-ec1b-419e-88a9-8d8e533ed598	2018-03-04 21:00:52.435177-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
7d0d758e-979a-45fc-bb1e-85b1a0fdfe7b	2018-03-04 21:00:52.438178-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
d695c678-fd39-406d-b01a-3db768a2560f	2018-03-04 21:00:52.442178-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
c3b68653-9d00-4ecc-aa15-5db07ac4a17b	2018-03-04 21:01:19.013835-06	3	[22316] IC 326A-OutB	[4] DLarrabee	[21062] a	\N	\N
98570880-7293-49e6-977d-0dc49c6d3746	2018-03-04 21:01:19.287862-06	2	[22317] IC 327A	[4] DLarrabee	[21062] a	\N	\N
84624207-cee2-4064-8652-5a522faa958b	2018-03-04 21:01:19.293863-06	2	[22318] IC 327A-outB	[4] DLarrabee	[21062] a	\N	\N
78f5c4ad-a861-4601-aa36-b1c31cb7a538	2018-03-04 21:01:19.297863-06	2	[22319] IC 329A	[4] DLarrabee	[21062] a	\N	\N
335e26a0-b7c9-4ffd-8715-b898f766cd5b	2018-03-04 21:01:19.302864-06	2	[22320] IC 329A-outB	[4] DLarrabee	[21062] a	\N	\N
a9d3a74d-042c-497a-867d-8070d222e092	2018-03-04 21:01:19.307864-06	2	[22321] IC 329B	[4] DLarrabee	[21062] a	\N	\N
a651f001-bf4f-4bcc-8b35-e8278825b440	2018-03-04 21:01:19.312865-06	2	[22322] IC 329B-outB	[4] DLarrabee	[21062] a	\N	\N
3f5ac9a3-fd92-4d99-bba3-d06488f60c70	2018-03-04 21:01:19.316865-06	2	[22323] IC 334A	[4] DLarrabee	[21062] a	\N	\N
762d57a2-db1b-46ac-907e-641655562a0a	2018-03-04 21:01:19.323866-06	2	[22324] IC 334A-outB	[4] DLarrabee	[21062] a	\N	\N
337ddb70-94a4-41dc-a3ae-266f3380a0bb	2018-03-04 21:01:19.327866-06	2	[22325] IC 335A	[4] DLarrabee	[21062] a	\N	\N
8d84e464-b43e-4ca4-9a69-41ac5c4700c3	2018-03-04 21:01:19.331867-06	2	[22326] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
374df4e7-29c9-432f-98f6-ca6a6533fd74	2018-03-04 21:01:19.336867-06	2	[22327] IC 336A	[4] DLarrabee	[21062] a	\N	\N
45bfc6fb-8aab-4a85-bac3-d55ec3380de7	2018-03-04 21:01:19.340868-06	2	[22328] IC 336A-outB	[4] DLarrabee	[21062] a	\N	\N
f7c7602e-b5f1-4feb-a053-ce5429430ee2	2018-03-04 21:01:19.344868-06	2	[22329] IC 337A	[4] DLarrabee	[21062] a	\N	\N
87d1df6f-8762-441f-89d4-83616cc09299	2018-03-04 21:01:19.349869-06	2	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
ea79d785-3772-41fb-9d0a-4e163da15947	2018-03-04 21:01:19.353869-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
c1dd48c0-9847-4719-a5ff-60ae2b0bf391	2018-03-04 21:01:19.35987-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
50a186b8-946d-4f35-b77d-7e6378a68a09	2018-03-04 21:01:19.36287-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
86fc3792-f498-4970-a464-ebb70a8517da	2018-03-04 21:01:19.36687-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
12ef1074-4937-441f-b97d-3c23d83021ab	2018-03-04 21:01:19.370871-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
ae89ad98-bfc3-449d-80e0-0bbd4cdab5f6	2018-03-04 21:01:19.374871-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
bd95070d-f25a-4d3d-b2e5-c5e25aed1a6b	2018-03-04 21:01:19.378872-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
9332bab1-dfbb-4330-8b96-998cb42d2107	2018-03-04 21:01:19.383872-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
5d02461e-4f05-4058-8a0d-d50e16989978	2018-03-04 21:01:19.388873-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
235da1e6-673b-4720-ac03-183281679411	2018-03-04 21:01:19.392873-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
df469703-411d-4482-aef0-9d024d48a1eb	2018-03-04 21:01:19.395873-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
b4272230-9920-47b4-80f9-58f942204c06	2018-03-04 21:01:19.399874-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
365940d1-fd14-4078-9c06-ac7307d9f26c	2018-03-04 21:01:19.404874-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
6d425179-1daa-4534-8b6b-018abb67a955	2018-03-04 21:01:19.408875-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
017290cf-24d4-42b3-9226-08726c2e7feb	2018-03-04 21:01:19.413875-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
b4a7ea4b-ee84-4a6e-9c78-bbe2eb49c256	2018-03-04 21:01:19.419876-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
909f7074-2102-489c-9d71-0b98acf937e3	2018-03-04 21:01:19.423876-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
fee94be1-54b6-48ec-ab83-b72d94d09ef8	2018-03-04 21:01:19.426876-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
c2c0c070-ecd2-4424-a5e8-828e8b004787	2018-03-04 21:01:19.431877-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
eae3390f-f6c3-4687-9164-5f257c8cd3e3	2018-03-04 21:01:19.435877-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
863e04bb-d180-4646-9303-75b21f980587	2018-03-04 21:01:19.440878-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
c537e557-9a00-4e77-905b-5aaff495f2fc	2018-03-04 21:01:19.445878-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
e62c057c-b075-43b6-b00d-f8d901940edb	2018-03-04 21:01:19.449879-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
d2eef5ec-d883-47f8-8ef9-36cb4925fc00	2018-03-04 21:01:19.455879-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
eb145d1b-b410-40cc-b94c-1aff14ad7c43	2018-03-04 21:01:19.46088-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
0679e150-57cd-4810-98bc-1c5ec9991bef	2018-03-04 21:01:19.46388-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
51abdd48-6d54-4a37-81a6-3d4ce63cf4a0	2018-03-04 21:01:19.46788-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
dec79c22-4d8b-4e07-a1a3-c453c09b0dcf	2018-03-04 21:01:19.471881-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
33e3e206-4c93-4268-9dd0-675df4e6b52d	2018-03-04 21:01:19.475881-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
7852e619-5154-4ce6-96bc-3f46bcfbf454	2018-03-04 21:01:19.478882-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
42b6cd70-92d3-474d-8215-64fc525c2bbe	2018-03-04 21:01:19.485882-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
1639b3e4-fddb-4bea-a21a-15eed9711a78	2018-03-04 21:01:19.489883-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
b5e9caf8-0ed2-4293-b228-d07f79ad776a	2018-03-04 21:01:19.493883-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
93de5812-ead2-46aa-a8a1-ff2d3c1fc752	2018-03-04 21:01:19.497883-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
b9f2b322-b906-4854-bced-ecdec14badb5	2018-03-04 21:01:19.501884-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
4de2089f-506b-433e-b9fa-858f913cf553	2018-03-04 21:01:19.506884-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
adfb9f8c-665e-401d-913d-193332ffebc9	2018-03-04 21:01:19.510885-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
cffb332d-f966-44a7-b699-cf1c6514fa98	2018-03-04 21:01:19.516885-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
c8354335-ff20-4aa8-9d23-78a8bcf954c2	2018-03-04 21:01:19.521886-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
6340ac30-b774-4b30-a290-4eb78b58e657	2018-03-04 21:01:19.525886-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
19562970-f35e-4af3-baf7-0b14c2b30835	2018-03-04 21:01:19.530887-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
c1c8a85a-5700-4da5-9bc3-69b7b05867a6	2018-03-04 21:01:19.534887-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
5b816ba1-6d3a-43b3-80fc-fb04f7bff685	2018-03-04 21:01:19.538888-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
233d77f0-a39c-468e-a5eb-cf116a84d0fc	2018-03-04 21:01:19.542888-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
15a14977-ceb9-41ef-b2da-165eb13eaa6e	2018-03-04 21:01:19.545888-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f76186d4-64d5-4ee3-a9d1-c144755aaf8a	2018-03-04 21:01:19.549889-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
953ae7ec-3432-4200-b7f7-caae0769b5cb	2018-03-04 21:01:19.555889-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6aefb864-9fc1-4134-8baa-eeae27d6800d	2018-03-04 21:01:19.55889-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5a49e723-bd96-4729-9dc8-7574b478a9d7	2018-03-04 21:01:19.56189-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
632ff193-b0cf-4fa6-92dd-e42519ef4df1	2018-03-04 21:01:19.56589-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cb8ff04d-d7b6-4a38-922a-d86a40a9a3f8	2018-03-04 21:01:19.568891-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
181aedcc-8bed-4660-a638-3953c37167f7	2018-03-04 21:01:19.571891-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9eb50feb-a764-4246-b575-e45f5257c310	2018-03-04 21:01:19.574891-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2d54f992-611a-466b-8df9-3be648258025	2018-03-04 21:01:19.576891-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
37c974a7-82af-40a6-8187-5f0349e745af	2018-03-04 21:01:19.579892-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
57cf1574-4b97-437b-8a68-c9d0c2712c1f	2018-03-04 21:01:19.582892-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ae46e2d8-477b-43bf-8f4f-95215f445565	2018-03-04 21:01:19.586892-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e33e0b4d-c274-4b18-b9dc-9418de56f799	2018-03-04 21:01:19.589893-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d7f1a5a0-febf-41f0-b2bf-8083b9adb319	2018-03-04 21:01:19.592893-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d11da8d3-5111-40b6-b778-9faf72b99d8a	2018-03-04 21:01:19.595893-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
eeb5bc3c-5337-4e76-a16b-2643f4c94575	2018-03-04 21:01:19.598894-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1c4b2154-05a6-4bd2-95ee-95b7fcdd2acb	2018-03-04 21:01:19.605894-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
9261fc40-ef5b-4fd2-bb34-8d2ffc435d2e	2018-03-04 21:01:19.608895-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
ca3bbd2c-9288-40ec-ae41-92318f630357	2018-03-04 21:01:19.612895-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
cfb8f3b4-f53b-4324-b794-66101eff2f2c	2018-03-04 21:01:19.616895-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
8cc77a62-65fa-4090-b407-3a02d3255ccb	2018-03-04 21:01:19.619896-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
32112475-1691-44ac-a8aa-6e9707743c35	2018-03-04 21:01:19.623896-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
0e075dd8-5f1b-4d1b-8e3c-a23c856de715	2018-03-04 21:01:19.627896-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
88813745-7e2a-47a6-9f8d-1a8d03776d7c	2018-03-04 21:01:19.630897-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
615b783a-30e3-4219-82f2-e9a405ae78ae	2018-03-04 21:01:19.634897-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
78fac8a4-b695-4198-9ad6-49496d20de36	2018-03-04 21:01:19.637897-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
ed70103e-18b3-4340-8402-f210e5a6e881	2018-03-04 21:01:19.640898-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
e735a064-eb13-4730-a98a-84ad75c86178	2018-03-04 21:01:30.016935-06	3	[22317] IC 327A	[4] DLarrabee	[21062] a	\N	\N
29b806c8-1a0e-4d7a-9142-970d3ea4d45c	2018-03-04 21:01:30.298963-06	2	[22318] IC 327A-outB	[4] DLarrabee	[21062] a	\N	\N
debd1c47-88b0-4db1-907e-92cc674017c7	2018-03-04 21:01:30.304964-06	2	[22319] IC 329A	[4] DLarrabee	[21062] a	\N	\N
f29af690-dadb-4415-a40c-81b292226692	2018-03-04 21:01:30.308964-06	2	[22320] IC 329A-outB	[4] DLarrabee	[21062] a	\N	\N
ea2a993c-72b1-4e88-b11f-c54471a7f5ee	2018-03-04 21:01:30.312965-06	2	[22321] IC 329B	[4] DLarrabee	[21062] a	\N	\N
7447155c-c356-46d8-9d08-cbec61b2b5bd	2018-03-04 21:01:30.316965-06	2	[22322] IC 329B-outB	[4] DLarrabee	[21062] a	\N	\N
5ea91554-cc02-41ed-86c0-e7ac0710acfd	2018-03-04 21:01:30.321966-06	2	[22323] IC 334A	[4] DLarrabee	[21062] a	\N	\N
5a8b905f-2cff-4862-a18c-00b7a295a817	2018-03-04 21:01:30.325966-06	2	[22324] IC 334A-outB	[4] DLarrabee	[21062] a	\N	\N
df743109-0181-4d10-9b83-8c90b9bc8d9a	2018-03-04 21:01:30.330967-06	2	[22325] IC 335A	[4] DLarrabee	[21062] a	\N	\N
47d373f3-ebd3-4d47-8400-bcb66a79ca66	2018-03-04 21:01:30.338967-06	2	[22326] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
338680bb-2ebb-4291-b1ac-622465cf2cb8	2018-03-04 21:01:30.341968-06	2	[22327] IC 336A	[4] DLarrabee	[21062] a	\N	\N
c25cf4ca-9bf6-4337-b0e5-be4d9e60a3d4	2018-03-04 21:01:30.345968-06	2	[22328] IC 336A-outB	[4] DLarrabee	[21062] a	\N	\N
8b504e84-a4df-4f95-b9a1-56e4138da26c	2018-03-04 21:01:30.350969-06	2	[22329] IC 337A	[4] DLarrabee	[21062] a	\N	\N
75cb2408-c43e-40a7-86c9-ea66b81ad5ea	2018-03-04 21:01:30.354969-06	2	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
02b9a3f2-855a-487e-a907-2ecfabc31443	2018-03-04 21:01:30.35997-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
176484b9-aee2-49e1-a33f-d44e0348e427	2018-03-04 21:01:30.36497-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
c382a8ed-6f45-4459-aba9-0b8c57a8fc58	2018-03-04 21:01:30.36897-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
09699297-9998-4aac-9d4f-94d260fa1e40	2018-03-04 21:01:30.375971-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
dc524afa-a07e-4469-a90c-525ce1a134b5	2018-03-04 21:01:30.380972-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
eca3a611-bf00-4069-b1cc-bd943d253245	2018-03-04 21:01:30.384972-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
5eee80ed-84da-4cad-8661-3a112e7d5146	2018-03-04 21:01:30.388972-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
1aa34833-d272-48e9-8ab8-c69139f48f11	2018-03-04 21:01:30.392973-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
0340ce9e-830e-4eb3-a32f-5cb38497f8a3	2018-03-04 21:01:30.396973-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
c6257a0f-d554-4427-90f5-97c3069aaba3	2018-03-04 21:01:30.401974-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
64954e83-8e02-4aec-9352-915f277c40cd	2018-03-04 21:01:30.422976-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
5c18cb01-3832-4a0a-a67f-5147f5dd7a2a	2018-03-04 21:01:30.426976-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
2f1dc90c-bb5c-45fa-a057-822863278046	2018-03-04 21:01:30.430977-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
b4b62aa9-e7c8-400a-acd7-3ccb9fc60206	2018-03-04 21:01:30.435977-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
dc7d1853-800b-4c86-8ec0-45d26999cf65	2018-03-04 21:01:30.439978-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
f2225b46-b448-4da5-b25f-d12c3f60d765	2018-03-04 21:01:30.444978-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
57449f42-5d65-487d-aa21-f9c7dc066552	2018-03-04 21:01:30.447978-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
107327a5-6915-4611-b796-6b1cc1f58488	2018-03-04 21:01:30.454979-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
0bb8fc13-3fbd-4123-9a4c-a717d74f3297	2018-03-04 21:01:30.458979-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
3e204ec2-0d90-4cce-a4a7-f74ee9adff3a	2018-03-04 21:01:30.46398-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
48838cb6-67e4-44d4-918b-45bd0a269f8c	2018-03-04 21:01:30.46798-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
a0f39f8b-fb44-4779-b742-d8e92faab206	2018-03-04 21:01:30.471981-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
e5a75a60-91f2-438b-82b9-7dd89a59fe76	2018-03-04 21:01:30.474981-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
c7beda99-ffc5-4705-8cae-73bbd5b44b3b	2018-03-04 21:01:30.478981-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
283f43f8-852d-4d9b-a048-0e2c15220fa5	2018-03-04 21:01:30.485982-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
9b667a3b-3b26-4265-9d89-f67e11510532	2018-03-04 21:01:30.489983-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
27c87ac2-aea2-4511-8e27-f0dc5e773759	2018-03-04 21:01:30.492983-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
d4b53598-cd8b-40a8-bc8c-0459fbf65ba4	2018-03-04 21:01:30.495983-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
8fcd403e-3462-4e18-8515-14b8b95d9276	2018-03-04 21:01:30.500984-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
4f019dd5-cf61-48fd-9221-4106aadf4af4	2018-03-04 21:01:30.504984-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
0a5d9a48-8825-4113-9270-3cfbcafeb55f	2018-03-04 21:01:30.509985-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
7fb5b300-913a-4fda-b636-8581ad7acdd5	2018-03-04 21:01:30.513985-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
cf15177c-bc37-45a3-9477-3d8a685e6503	2018-03-04 21:01:30.520986-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
a061ddcc-eb97-4636-bec0-17e3a4186fe1	2018-03-04 21:01:30.524986-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
4e1b72b0-ad96-450b-b5d3-67194b4fc731	2018-03-04 21:01:30.528986-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
9b58ec08-af61-4a7d-a32a-71e3b1ccb08b	2018-03-04 21:01:30.533987-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
fa375590-51b9-4669-af7d-b3cfe7366fdb	2018-03-04 21:01:30.537987-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
6cb91aa7-b243-44e9-81a9-b303d616e742	2018-03-04 21:01:30.542988-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
7f50d477-0d1b-499c-9def-a071c37f19fc	2018-03-04 21:01:30.546988-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
4bf6007c-9b64-4186-af63-5ca22262cfd1	2018-03-04 21:01:30.554989-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
08619d0d-4112-457f-9e02-d2a66933afee	2018-03-04 21:01:30.558989-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
b9933e80-7dda-46fd-a110-da5e0c9b7ba5	2018-03-04 21:01:30.56299-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
02c671e3-a292-4e82-b634-928ac6358d94	2018-03-04 21:01:30.56699-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
f38089df-4f2b-41c2-9e38-b9d80102c468	2018-03-04 21:01:30.569991-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a2dff43d-441f-40fa-8093-b54c0f892f35	2018-03-04 21:01:30.573991-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f58bdb7a-7c89-4c77-ba7e-bbcdb515bbd7	2018-03-04 21:01:30.577991-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c75d3045-01c0-4437-8dbe-ca2fae7c2af7	2018-03-04 21:01:30.580992-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c095650d-eb27-4b57-8a6b-58e5db0ef5ed	2018-03-04 21:01:30.582992-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
262bdada-105c-41c5-88a8-3981c6a5b583	2018-03-04 21:01:30.585992-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
bda23ab4-564f-4628-9796-f3cc3aa24fa5	2018-03-04 21:01:30.588992-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
29108db5-7ad6-4e6b-b85b-ebd7e44d8b84	2018-03-04 21:01:30.592993-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cbdecbbf-76c9-400d-9627-de534fc9a591	2018-03-04 21:01:30.596993-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fb5d8929-dd7d-4d2f-8fba-72fff46184bd	2018-03-04 21:01:30.599994-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3443a4ae-ef3d-4c61-8c4e-ddd3e9a8ce69	2018-03-04 21:01:30.602994-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
91b50b9f-4b9e-4fac-aa15-ee69c76406d0	2018-03-04 21:01:30.604994-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
bb5a4c9a-8484-4de2-adb1-bc388505ec07	2018-03-04 21:01:30.607994-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
27f7fdb9-636f-4f15-8761-2379924f80db	2018-03-04 21:01:30.611995-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9925eff2-7100-4bf0-ac66-830231022a17	2018-03-04 21:01:30.615995-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7be5e4be-754a-47af-bc2a-c83a4d89bd25	2018-03-04 21:01:30.618995-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0bb7df16-a290-4baf-a04c-00ad3d0419e0	2018-03-04 21:01:30.622996-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6f088b6c-b29e-4f6a-a399-56699c670b76	2018-03-04 21:01:30.625996-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
107cadc8-3b7f-47e1-8d57-0469fd2ef0fc	2018-03-04 21:01:30.628996-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
beb03d7b-498f-47c3-967f-a67fa168bd52	2018-03-04 21:01:30.630997-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
b6906955-f868-47cf-943d-c40ad920375c	2018-03-04 21:01:30.634997-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
a51ffeda-8822-4126-81b6-6ba5c7003fda	2018-03-04 21:01:30.640998-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
767ef37e-9228-4a74-8705-8dcbc2248448	2018-03-04 21:01:30.643998-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
67c27359-b8ba-43fa-b112-ed942c68cdba	2018-03-04 21:01:30.646998-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
0c8308b2-a3a8-4989-ab58-6e2ec627e987	2018-03-04 21:01:30.649999-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
b2c37f08-4d62-4388-b269-bdd3c64e1b20	2018-03-04 21:01:30.653999-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
0dd7212c-04d2-487d-8085-75947b313713	2018-03-04 21:01:30.657999-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
9cc43e29-743e-4a47-bd5c-9527fc0ccc03	2018-03-04 21:01:30.661-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
e4f5bc92-e720-4bfc-8850-270f6105f50c	2018-03-04 21:01:30.665-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
eef1bca7-2a3c-46db-b4e2-510ca4c80e06	2018-03-04 21:01:43.499283-06	3	[22318] IC 327A-outB	[4] DLarrabee	[21062] a	\N	\N
0244551d-cd95-4dd2-9063-dc72e5d91736	2018-03-04 21:01:43.787312-06	2	[22319] IC 329A	[4] DLarrabee	[21062] a	\N	\N
69ce49dc-51e9-488b-b1c3-03aa087d5fa1	2018-03-04 21:01:43.792313-06	2	[22320] IC 329A-outB	[4] DLarrabee	[21062] a	\N	\N
df1daeeb-fabb-45d7-8c4c-f4977a1623c6	2018-03-04 21:01:43.797313-06	2	[22321] IC 329B	[4] DLarrabee	[21062] a	\N	\N
b0520c19-93c2-4069-b77a-526a8577699e	2018-03-04 21:01:43.803314-06	2	[22322] IC 329B-outB	[4] DLarrabee	[21062] a	\N	\N
3222fbdf-7ed6-4512-b11b-5374037fb005	2018-03-04 21:01:43.808314-06	2	[22323] IC 334A	[4] DLarrabee	[21062] a	\N	\N
76ad692a-9ab3-4d4e-a28e-d803aec444fe	2018-03-04 21:01:43.813315-06	2	[22324] IC 334A-outB	[4] DLarrabee	[21062] a	\N	\N
077fdd7b-91b0-4fb0-999d-500680f9effc	2018-03-04 21:01:43.817315-06	2	[22325] IC 335A	[4] DLarrabee	[21062] a	\N	\N
e5561979-9a8b-42a5-99d0-d3820db58997	2018-03-04 21:01:43.821316-06	2	[22326] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
298fd289-1736-46b4-b102-0e33ce09ea58	2018-03-04 21:01:43.826316-06	2	[22327] IC 336A	[4] DLarrabee	[21062] a	\N	\N
ee6fe8a6-7ab9-4cd9-800f-e8e1b7ee483a	2018-03-04 21:01:43.831317-06	2	[22328] IC 336A-outB	[4] DLarrabee	[21062] a	\N	\N
98503ab5-8899-46e5-a455-daa90d04ecfd	2018-03-04 21:01:43.836317-06	2	[22329] IC 337A	[4] DLarrabee	[21062] a	\N	\N
33479870-50b6-4671-90c9-d5ddb447bf2c	2018-03-04 21:01:43.841318-06	2	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
3525a1ae-05dc-4dd5-9405-1a52ae2019df	2018-03-04 21:01:43.845318-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
5ad1fb9d-0f9e-4467-80d9-1ed6079f35cd	2018-03-04 21:01:43.849318-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
5f5040b7-53d5-4e42-b0dd-3c7601349652	2018-03-04 21:01:43.853319-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
76c6a96a-b7e1-4059-a41a-d39e3bc19c06	2018-03-04 21:01:43.856319-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
50b093ec-3963-4da8-a437-e27972f04b3f	2018-03-04 21:01:43.860319-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
0a1ecf0a-2830-46e7-bb9e-10f12169f39d	2018-03-04 21:01:43.86432-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
28017f88-761d-4b0d-ba05-e29158029e9c	2018-03-04 21:01:43.86832-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
0e725060-323a-46e4-b689-ff981a8aa76e	2018-03-04 21:01:43.871321-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
3dc5899c-7c85-4f91-9f78-f9731211106d	2018-03-04 21:01:43.874321-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
40d65f27-c3f6-4d3e-b3ae-06f0629dc545	2018-03-04 21:01:43.879321-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
a0f95637-776c-4a82-93af-52e56285836d	2018-03-04 21:01:43.883322-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
7541cf72-39aa-418c-b9fd-d4befa22ec26	2018-03-04 21:01:43.887322-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
19b5f645-d1d3-480f-b7ae-2272aafad68a	2018-03-04 21:01:43.890322-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
283ee295-bf60-4624-83bf-712aebfe5101	2018-03-04 21:01:43.894323-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
8a7edc73-7341-4317-9cb3-8624f8cef5d6	2018-03-04 21:01:43.899323-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
1cadf089-e34c-4058-9950-6babf31c6c80	2018-03-04 21:01:43.903324-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
8b5c46a6-43d9-4709-bb2d-63e249de4b9a	2018-03-04 21:01:43.907324-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
25ea43de-3870-443a-bf05-4f7b56d14314	2018-03-04 21:01:43.912325-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
2fa66d13-c3ed-44b6-ae6e-e4cefec506db	2018-03-04 21:01:43.916325-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
2b42ce05-49c2-4ae2-a6f8-b1f0bcb1f65b	2018-03-04 21:01:43.920325-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
0ccf6cab-61d2-4f84-ad22-3c520732568e	2018-03-04 21:01:43.924326-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
8cf9d5a4-775f-4e79-8dc5-f9dcfcac89b5	2018-03-04 21:01:43.928326-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
10af8f9b-38a5-4fd3-9f32-2c2fd947c8a6	2018-03-04 21:01:43.933327-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
590b8477-1799-4e8a-bde4-97a606b6e10c	2018-03-04 21:01:43.936327-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
fc28ea13-a5af-4f0a-a567-75b6b20a9280	2018-03-04 21:01:43.940327-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
c6796604-e192-4e03-b884-b1f24c330a48	2018-03-04 21:01:43.944328-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
c33167cf-29dd-48db-8c0b-0824f8467bda	2018-03-04 21:01:43.949328-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
286fa1e6-f05c-426e-b1cb-e33d9335d203	2018-03-04 21:01:43.954329-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
5a454c91-b951-4fd7-bd8f-e3cc046cde52	2018-03-04 21:01:43.958329-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
c4970621-9f06-4d93-8aba-d03e667406e3	2018-03-04 21:01:43.96333-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
1f1e6ca1-437e-42cb-833c-a57f49d01893	2018-03-04 21:01:43.96933-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
09608235-9bc3-41b9-b0d2-8c9502114b19	2018-03-04 21:01:43.974331-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
c5a2310e-0e25-40d0-8b88-d0ccb948bf3f	2018-03-04 21:01:43.980331-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
d5948047-f055-4b79-89b4-30b7e33c0dd2	2018-03-04 21:01:43.984332-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
5c4a0fd0-b771-439e-ac2f-d894822dc4be	2018-03-04 21:01:43.989332-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
2403050c-0d12-49f0-926c-af960156c593	2018-03-04 21:01:43.993333-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
3b28c3fa-fe75-4283-a18f-0951ded5ec01	2018-03-04 21:01:43.996333-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
2697864d-1074-4e96-8923-636b153e8da0	2018-03-04 21:01:44.000333-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
3247cb39-0f3c-44ee-b38d-2b9471efffa4	2018-03-04 21:01:44.005334-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
d55089db-0d16-44ff-be07-5e4da244bf06	2018-03-04 21:01:44.008334-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
f9042f0d-aea8-42a0-ac93-7baa0e1a5403	2018-03-04 21:01:44.013335-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
847444e9-2a47-42cb-83b9-ebd143ff1758	2018-03-04 21:01:44.017335-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
fafa04ee-0d43-4259-b5d8-5c86e6e98bbd	2018-03-04 21:01:44.023336-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
ef3da010-1957-485c-945d-90db91c73e5c	2018-03-04 21:01:44.026336-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d2e6b93a-71b3-4e79-99e5-b40917fda0a7	2018-03-04 21:01:44.030336-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
afa7c864-ce2e-4d10-8c65-a945c56a634b	2018-03-04 21:01:44.033337-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ac994e67-ea60-4f7e-97a5-96b934765e86	2018-03-04 21:01:44.036337-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
828eef6c-eb53-4307-9d78-ce22eb2c647d	2018-03-04 21:01:44.038337-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2be4509b-9aed-4ef4-b461-c4a1474c3781	2018-03-04 21:01:44.041338-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
eb5e21e6-e6dd-49a9-a186-fb338618f46c	2018-03-04 21:01:44.044338-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c42c3712-1360-458d-99dc-8aae28f5f66e	2018-03-04 21:01:44.046338-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
24152129-581a-447e-91cf-458e1dd1d9bf	2018-03-04 21:01:44.050338-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e832b66c-ea09-41fe-8694-af55644ae455	2018-03-04 21:01:44.053339-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c345023c-c885-41ad-bb98-ee5c03b034e6	2018-03-04 21:01:44.057339-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5bb4efe5-c196-4705-b77c-56103529472d	2018-03-04 21:01:44.060339-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
67a22424-7842-435f-b23e-8795dbabde2b	2018-03-04 21:01:44.06534-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e714b77f-de95-4eab-8d03-d0aa472c98b7	2018-03-04 21:01:44.06834-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4b992ddd-cab9-4e59-9e9d-f6c82fc5754a	2018-03-04 21:01:44.071341-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b19e8e89-a4c7-456b-bdbe-e9cf1db93c39	2018-03-04 21:01:44.075341-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2c3c63ef-2871-40e7-8004-62b7ab79bae2	2018-03-04 21:01:44.078341-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
eca1315d-43dd-4d3d-907e-b1bce3de3bf7	2018-03-04 21:01:44.082342-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
85407678-c6a2-4fb4-a255-f1a4ae734d59	2018-03-04 21:01:44.085342-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
97c792aa-2f98-41e7-a54a-614f309811db	2018-03-04 21:01:44.089342-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
50d0b6c4-7c9d-4096-888b-128cd4abe2b4	2018-03-04 21:01:44.093343-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
fa3d5c0b-ca9d-4fb0-8eb4-7d8b6a3dee33	2018-03-04 21:01:44.096343-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
d2161a8b-f54b-4eb1-ba8e-4f992eefc384	2018-03-04 21:01:44.100343-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
f401ca60-bb28-4c9f-8701-f59ffe9c17ba	2018-03-04 21:01:44.104344-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
630f6786-fecd-4fa8-9ee9-e03b6dabe547	2018-03-04 21:01:44.108344-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
5f0c8e59-b634-4d2a-9285-97b7bef7ee08	2018-03-04 21:01:44.110344-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
21d6f382-efda-428b-95f7-94470b593617	2018-03-04 21:01:44.114345-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
662661e9-f418-47f1-b69e-4e16b824b0d5	2018-03-04 21:01:44.118345-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
19ff79ff-86cd-4f19-92d0-4201b3d5c422	2018-03-04 21:01:44.121346-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
de6bc008-9476-4829-88a1-9f67b7a92741	2018-03-04 21:01:59.489882-06	3	[22319] IC 329A	[4] DLarrabee	[21062] a	\N	\N
90442c42-8b80-45d9-8d12-e45ed861df38	2018-03-04 21:01:59.772911-06	2	[22320] IC 329A-outB	[4] DLarrabee	[21062] a	\N	\N
b984e95c-1dab-4eda-bc14-b333f93812fb	2018-03-04 21:01:59.776911-06	2	[22321] IC 329B	[4] DLarrabee	[21062] a	\N	\N
5aac7d0d-7691-4e61-b69f-19c7b2dd89b5	2018-03-04 21:01:59.784912-06	2	[22322] IC 329B-outB	[4] DLarrabee	[21062] a	\N	\N
38f661ba-946b-4835-afce-cb21d74bc661	2018-03-04 21:01:59.788912-06	2	[22323] IC 334A	[4] DLarrabee	[21062] a	\N	\N
d2531ba5-2c82-46e1-8c61-e74d08c91816	2018-03-04 21:01:59.792913-06	2	[22324] IC 334A-outB	[4] DLarrabee	[21062] a	\N	\N
e0de9f30-7121-4dcc-b115-9d468ce743f7	2018-03-04 21:01:59.796913-06	2	[22325] IC 335A	[4] DLarrabee	[21062] a	\N	\N
31c63e7e-2bf1-4696-86b9-a7097519fe8c	2018-03-04 21:01:59.801913-06	2	[22326] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
c40dd57b-316c-4531-8408-04583f81061a	2018-03-04 21:01:59.806914-06	2	[22327] IC 336A	[4] DLarrabee	[21062] a	\N	\N
8769e5d2-a498-4dc0-bafc-11032b6a511c	2018-03-04 21:01:59.810914-06	2	[22328] IC 336A-outB	[4] DLarrabee	[21062] a	\N	\N
0d03cf13-c885-4f27-81b0-647c7af191c0	2018-03-04 21:01:59.815915-06	2	[22329] IC 337A	[4] DLarrabee	[21062] a	\N	\N
5a7b9833-055d-4dd0-8ef3-36c69caf60de	2018-03-04 21:01:59.821915-06	2	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
9d653014-fbf6-4cde-825e-6c8bf2baaebf	2018-03-04 21:01:59.826916-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
6fd81e1d-2d3e-4f51-9f5e-5df23a4b59e5	2018-03-04 21:01:59.830916-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
3c12f66d-57c6-421e-b3cf-0e30205e1e89	2018-03-04 21:01:59.835917-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
c21d469f-7395-485c-95f0-62d666acfe67	2018-03-04 21:01:59.840917-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
a4641333-33d1-41c5-9a00-3481aa2b2e37	2018-03-04 21:01:59.844918-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
28336ce8-61f9-4b57-b544-fba2c34fb806	2018-03-04 21:01:59.86392-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
3716169f-ba04-4199-a32a-e9d54f28477b	2018-03-04 21:01:59.86992-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
a89e2494-2eec-4364-983d-4d153f15517b	2018-03-04 21:01:59.873921-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
1e80f32e-bdf0-4f88-b0a6-271732f0f132	2018-03-04 21:01:59.878921-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
82946ebc-da8e-479a-81ee-b070b8aaddcf	2018-03-04 21:01:59.883922-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
fba9129b-8da9-4bcf-abdc-79021794c19a	2018-03-04 21:01:59.887922-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
a59b219c-2acb-42c2-955f-bd97af287594	2018-03-04 21:01:59.891922-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
5a3d69e1-4d33-40ed-a94a-5704300cef2c	2018-03-04 21:01:59.895923-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
fac760d8-497c-4c9c-944b-fe19e2e2e8c2	2018-03-04 21:01:59.901923-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
6721d8f4-3383-47ef-8736-1506048d923e	2018-03-04 21:01:59.905924-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
0df3e0fd-4c83-4bd0-b22e-18b97e03e2f2	2018-03-04 21:01:59.909924-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
e44f8c48-edce-439e-87f2-150f9372500f	2018-03-04 21:01:59.914925-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
c1e6654f-0238-400b-807d-cb8901e053db	2018-03-04 21:01:59.919925-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
5f47e60b-dbd5-4211-8dd6-38ad2cea2c44	2018-03-04 21:01:59.923926-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
cb82fe24-72f4-4a76-bfd9-e92948e0a287	2018-03-04 21:01:59.927926-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
7d644e28-b668-4d4f-8b59-ed745eebc3c6	2018-03-04 21:01:59.934927-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
8b538f86-4787-428a-b756-a036cefd9364	2018-03-04 21:01:59.938927-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
0374a1d3-ff49-45c8-bea1-b6e0f23eaf76	2018-03-04 21:01:59.943928-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
8c7c4394-1d01-4482-9abe-1ec1a6b833c9	2018-03-04 21:01:59.947928-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
0f79c740-215d-474d-beb3-5eeae4632127	2018-03-04 21:01:59.952929-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
8a9c5a38-96ea-461e-8813-4a51439c85d6	2018-03-04 21:01:59.956929-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
a0c9f96e-2283-418b-9c5a-cccfa8f934e2	2018-03-04 21:01:59.961929-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
5f7d5144-ecfe-4a69-825f-0fcd2f061508	2018-03-04 21:01:59.96593-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
83fa9285-9b8b-40b0-8c2f-072251b86bab	2018-03-04 21:01:59.974931-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
02c6c070-f3ab-4033-ac3d-44cbd994c604	2018-03-04 21:01:59.979931-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
b8ad7f5c-0e70-4040-b827-2520a4404b6a	2018-03-04 21:01:59.985932-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
02832662-0ec6-40fd-8cf4-8cad78ffd145	2018-03-04 21:01:59.990932-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
36a2ed17-499f-4348-a5f4-e46c8d2f9a32	2018-03-04 21:01:59.994933-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
22d7f58a-d7d1-421b-92cd-7fb9a37eab5c	2018-03-04 21:01:59.998933-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
c220d83f-5ccc-44da-a1ef-3421652e880b	2018-03-04 21:02:00.001933-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
55cd0f08-3097-4c01-9cac-65aa3e99ff2a	2018-03-04 21:02:00.007934-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
3983bc45-0382-4944-a2e2-c8d2466d1852	2018-03-04 21:02:00.012935-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
34476c4d-39a3-4a56-b4c2-8c3d2583e995	2018-03-04 21:02:00.016935-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
035e19e8-38e8-4f89-9203-a8e5124c105b	2018-03-04 21:02:00.019935-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
4f541555-c143-42a4-8ed8-04c6a34efe4e	2018-03-04 21:02:00.024936-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
a6c3c606-c5ac-46ab-9857-2f65415523d1	2018-03-04 21:02:00.029936-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
d1699204-2327-4eb3-8db5-7e7694e71177	2018-03-04 21:02:00.032937-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
7c6ebe17-fcaa-40f4-b31b-9bf63889bd38	2018-03-04 21:02:00.038937-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
85976518-f536-43da-8bce-49e259ff9ea3	2018-03-04 21:02:00.042938-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4d0c8774-042d-4971-88aa-252d651136ea	2018-03-04 21:02:00.045938-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
dd444b7c-cd5b-44b2-9a9c-966f952b73ae	2018-03-04 21:02:00.049938-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4c98c9c2-9225-4539-8408-45fcff525461	2018-03-04 21:02:00.052939-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1483792c-dbfa-42ab-bf8f-45b1c03b31ed	2018-03-04 21:02:00.056939-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3f9fc099-5bdd-4ceb-81f0-71f2c79d2951	2018-03-04 21:02:00.060939-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
51c9a3b6-20e2-49e9-a5b5-4212bcafbb61	2018-03-04 21:02:00.06494-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6c21e5de-5edb-4c34-a40b-ad965bb6db16	2018-03-04 21:02:00.06794-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
477474ca-16b2-4bd8-80c8-8c8679f34601	2018-03-04 21:02:00.07094-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2d368c69-b79b-4c18-8fa4-5c5359640ff6	2018-03-04 21:02:00.073941-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d45974f1-cb6f-48ec-8dfa-efc5ad3fee90	2018-03-04 21:02:00.075941-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
da3b8d14-fcd2-41b3-af13-180006c6e4b8	2018-03-04 21:02:00.078941-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
397f2744-e131-4046-8e97-75bd54598199	2018-03-04 21:02:00.082942-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
20cc0d9a-2fd7-40ec-8228-fcf12b63f597	2018-03-04 21:02:00.088942-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8b78dd6c-4ad3-4b04-aa37-41d31fab4abb	2018-03-04 21:02:00.091942-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8a9704bf-e98d-45a9-af50-e6ca6c36affe	2018-03-04 21:02:00.095943-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
da1beb10-ce1c-475c-a25b-591e105d0d49	2018-03-04 21:02:00.098943-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4048e206-b238-41b7-9344-ce415f08a6e4	2018-03-04 21:02:00.101943-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
895d8088-e9e3-4ed5-b20f-b8a08edceeb2	2018-03-04 21:02:00.105944-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
956a2f78-d585-4bfa-af50-569821042cc0	2018-03-04 21:02:00.109944-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
d0fcacf8-6049-43d9-bbe5-1277cb22bc73	2018-03-04 21:02:00.112945-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
b5d40da9-139d-40c9-8d16-163f704939ae	2018-03-04 21:02:00.115945-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
b68891ca-b075-4c4b-b6f9-3e369253fa6d	2018-03-04 21:02:00.119945-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
5505f57d-adce-4600-b9a2-aaa404176c0c	2018-03-04 21:02:00.122946-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
4fea9cb4-60ab-426a-9d44-71ed74490401	2018-03-04 21:02:00.125946-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
a2bf5838-6917-4f3b-810a-dafb8e34152e	2018-03-04 21:02:00.129946-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
9ea6b543-0eeb-457a-99ae-ed0f61ddc2bf	2018-03-04 21:02:00.132947-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
8c594e0d-a0e5-42ca-aa3c-8e5cdf948968	2018-03-04 21:02:00.136947-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
ba1f65dc-317d-4b98-9c7e-e44cff9d3da5	2018-03-04 21:02:00.141947-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
86b3eb9e-f2d4-4505-8329-e55070a768c9	2018-03-04 21:02:13.452278-06	3	[22320] IC 329A-outB	[4] DLarrabee	[21062] a	\N	\N
437b203e-1d7c-4233-bd3f-0fffb2ceb291	2018-03-04 21:02:13.713304-06	2	[22321] IC 329B	[4] DLarrabee	[21062] a	\N	\N
c084b9a2-f6a9-41b1-aafe-7fcdf9203fca	2018-03-04 21:02:13.718305-06	2	[22322] IC 329B-outB	[4] DLarrabee	[21062] a	\N	\N
38fa3381-ec8d-4715-b825-061bf53fdd96	2018-03-04 21:02:13.723305-06	2	[22323] IC 334A	[4] DLarrabee	[21062] a	\N	\N
a9e9967c-f515-4796-9de2-cb8071387f33	2018-03-04 21:02:13.729306-06	2	[22324] IC 334A-outB	[4] DLarrabee	[21062] a	\N	\N
b06b9700-f49d-4024-aeb9-1b5fafceada3	2018-03-04 21:02:13.732306-06	2	[22325] IC 335A	[4] DLarrabee	[21062] a	\N	\N
e98ee8ed-cbfe-4454-a77a-ae2100549a24	2018-03-04 21:02:13.737307-06	2	[22326] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
33a36995-909b-4d42-aec0-c363308af0cb	2018-03-04 21:02:13.744308-06	2	[22327] IC 336A	[4] DLarrabee	[21062] a	\N	\N
11c16bc7-f748-4749-9676-4a5a2dbd5b90	2018-03-04 21:02:13.748308-06	2	[22328] IC 336A-outB	[4] DLarrabee	[21062] a	\N	\N
23ac119f-bc98-4319-9dbf-1b3a71cf1b03	2018-03-04 21:02:13.751308-06	2	[22329] IC 337A	[4] DLarrabee	[21062] a	\N	\N
07cec9da-6206-4a02-a3ce-ce60cd661269	2018-03-04 21:02:13.755309-06	2	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
4a2256bf-0404-45db-8dce-b9ad2d2810ae	2018-03-04 21:02:13.760309-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
50ee3acb-7bdb-48c2-b0e0-3f85bb20010e	2018-03-04 21:02:13.76431-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
b1fe89e0-2ede-4799-8b33-1df13926c124	2018-03-04 21:02:13.76931-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
614e71a7-2cd3-401f-a7d9-cc53acfeca75	2018-03-04 21:02:13.776311-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
01585790-76bf-4c90-a232-f30d4a2813da	2018-03-04 21:02:13.779311-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
79e27102-841d-4216-958c-587997d254ef	2018-03-04 21:02:13.782311-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
95cf377c-bcb5-475f-a23d-c87c85633f50	2018-03-04 21:02:13.786312-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
323adfa0-9972-4e2a-9656-0029e8ec7e3e	2018-03-04 21:02:13.791312-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
9c6c0abd-59a6-4a45-8a02-2723389ad751	2018-03-04 21:02:13.794313-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
4f6e6e6a-91ba-4d2b-8a82-367594583ce9	2018-03-04 21:02:13.798313-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
a22201b1-33e8-4b2b-8f1f-d5f1db9aa688	2018-03-04 21:02:13.805314-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
9e1de4cb-11fa-439b-a980-4021c474e24f	2018-03-04 21:02:13.810314-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
65c1f2e1-577a-400f-957d-b593577944f3	2018-03-04 21:02:13.815315-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
0b1b2c5c-6868-411d-9575-f904b9d48f69	2018-03-04 21:02:13.818315-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
57fd3dbe-ae25-4ad9-a959-258032e9cd0e	2018-03-04 21:02:13.822315-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
67519660-fc01-4c08-be68-42802c1b287e	2018-03-04 21:02:13.825316-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
0b1d7ce8-96e4-47de-bffa-6dd164ab52b5	2018-03-04 21:02:13.829316-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
942694d1-8e63-4698-8b89-689bebccc401	2018-03-04 21:02:13.836317-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
6b3271ee-f29c-405a-acd8-213d37e00337	2018-03-04 21:02:13.839317-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
ca503016-44ef-4aff-b0d6-cc35d7437262	2018-03-04 21:02:13.844318-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
ba6d3102-bfef-4a8b-87a6-da1a26b47c89	2018-03-04 21:02:13.847318-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
54384e52-526c-4d56-9f1b-00e7a5ff3eeb	2018-03-04 21:02:13.850318-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
8f55b03b-0e9e-4a55-a6ce-8afa3dc09217	2018-03-04 21:02:13.855319-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
652acecd-0cc3-418c-a4c8-4f1a9c0d3524	2018-03-04 21:02:13.859319-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
b82b7388-a1f7-43cd-b486-d03b7930208f	2018-03-04 21:02:13.863319-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
692f8a98-a450-44f1-9a0d-f7aafb3ad282	2018-03-04 21:02:13.87132-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
fdcc9579-1c03-4269-a1fd-e71f8e819df6	2018-03-04 21:02:13.877321-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
d4c8c6b8-d6f3-47af-b861-114a5db8b7da	2018-03-04 21:02:13.881321-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
4ea3c797-ec8d-4bdf-a0b7-1d442e9570af	2018-03-04 21:02:13.886322-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
6c6cd1f3-2f28-4f5d-8f9b-71e1f239580b	2018-03-04 21:02:13.891322-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
7949d51e-e385-4051-a9e8-5bee61e62a4a	2018-03-04 21:02:13.896323-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
cd7a5bbc-581d-40a1-874d-b92cbd0f7a1b	2018-03-04 21:02:13.900323-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
90927702-3d81-4880-97d4-9d11085a27f5	2018-03-04 21:02:13.907324-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
62550de6-12ea-4ee3-80a0-3eade5654e3e	2018-03-04 21:02:13.912324-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
163c4266-3442-4969-b98d-f2b29a749d77	2018-03-04 21:02:13.915325-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
473d32c1-8a86-4b63-af0c-bb368ce2f3e5	2018-03-04 21:02:13.920325-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
38439689-d6b8-4f81-8748-9df8a713bc2a	2018-03-04 21:02:13.924326-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
30dc9ffc-d7ee-4112-a8b7-3c13e2ecb84d	2018-03-04 21:02:13.928326-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
8e19e631-4630-4644-a021-16354dc0a8e7	2018-03-04 21:02:13.933326-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
e65e3cfd-7a1d-4172-ade6-8887dda51c5f	2018-03-04 21:02:13.939327-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
415b12db-4c3c-4afe-aa67-1e5742215943	2018-03-04 21:02:13.943327-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
8179fdc7-8274-4820-8cd0-9886e25a251b	2018-03-04 21:02:13.946328-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
ae959b73-6668-4f90-b532-e5d9fcbbb146	2018-03-04 21:02:13.951328-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
3306f78a-aac4-459f-97ea-7193ef98e3b6	2018-03-04 21:02:13.954329-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a214494a-97e7-4e0b-bb6b-58e4055d8580	2018-03-04 21:02:13.957329-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f6d157ca-1864-490e-882d-86c55990608d	2018-03-04 21:02:13.961329-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6d320d55-6c2e-4fe1-81b5-c4fc46914972	2018-03-04 21:02:13.96533-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d0f3eea6-107e-4d68-b994-8473ddd268bc	2018-03-04 21:02:13.96833-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0758eab4-4154-47d7-acf6-d503e3e79a88	2018-03-04 21:02:13.97133-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
75868f28-1eac-473a-87f1-0f1fe7619e5f	2018-03-04 21:02:13.97333-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
bd4ff53d-8170-4133-a5fe-8b1932db2fd5	2018-03-04 21:02:13.980331-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
79766a07-39e9-42eb-a7bb-9a1de9ee7fed	2018-03-04 21:02:13.984332-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f5c56ae7-5063-47a1-9883-39d1747ee632	2018-03-04 21:02:13.989332-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9756d2b7-3899-4b51-baad-4ea68cc62662	2018-03-04 21:02:13.992332-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ec4d5cb7-a9a9-4074-86d7-afceafd1f6de	2018-03-04 21:02:13.996333-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9d9de915-d0c7-41c0-8f69-a9ef5af46941	2018-03-04 21:02:14.000333-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
447aff8a-999c-4fb7-b034-17ab2f8e2a88	2018-03-04 21:02:14.003333-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
061c511d-4687-4ed2-a075-e2435cf6f633	2018-03-04 21:02:14.006334-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0cf06325-6d6a-471f-9030-801692284e15	2018-03-04 21:02:14.008334-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d00d11b9-8048-41c8-973a-ef2e3d7bd756	2018-03-04 21:02:14.011334-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
51fe1c7b-a7ac-413d-b4e3-473a53767f33	2018-03-04 21:02:14.015335-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
70e9dc74-f0e7-41d6-a2fa-ca688bc47692	2018-03-04 21:02:14.018335-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
e3d148e6-950e-4f94-bfd0-2c3c41da04e6	2018-03-04 21:02:14.022335-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
50e6b06f-ed88-4a48-b33e-28c131ec18c7	2018-03-04 21:02:14.026336-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
9ae6ed08-b7a4-4044-a6e3-e37bee377fca	2018-03-04 21:02:14.031336-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
f0eec5df-e57e-4077-829d-f6f680676bcb	2018-03-04 21:02:14.035337-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
9d2e8f5f-6600-4415-93c6-5a694f4ebfbd	2018-03-04 21:02:14.039337-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
f95be6ec-c1c9-4ad7-88aa-d03af58c9a5b	2018-03-04 21:02:14.042337-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
269e867f-5425-459b-a59a-8cc6bbf3776d	2018-03-04 21:02:14.046338-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
41d909a5-6125-4d0e-8afb-c6956b32bff4	2018-03-04 21:02:14.049338-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
113a8275-70b5-49b4-90be-0b8a81be71ff	2018-03-04 21:02:14.053338-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
1f800226-bb4a-46ea-a9bc-a51ea569dd28	2018-03-04 21:02:14.056339-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
e7ee0c96-e082-45d7-86e8-31d41f8d5162	2018-03-04 21:02:27.254658-06	3	[22321] IC 329B	[4] DLarrabee	[21062] a	\N	\N
f549bf23-a6a3-4439-87c0-327ee711106c	2018-03-04 21:02:27.517685-06	2	[22322] IC 329B-outB	[4] DLarrabee	[21062] a	\N	\N
60947f16-0de5-495d-b681-ac0eb49fc185	2018-03-04 21:02:27.521685-06	2	[22323] IC 334A	[4] DLarrabee	[21062] a	\N	\N
a894bd15-aa04-490a-8373-4cb5d47fa6e9	2018-03-04 21:02:27.526686-06	2	[22324] IC 334A-outB	[4] DLarrabee	[21062] a	\N	\N
f4a93c44-37f9-4e3b-b1b9-eeada75b51da	2018-03-04 21:02:27.533686-06	2	[22325] IC 335A	[4] DLarrabee	[21062] a	\N	\N
f297cb53-ea24-4d73-aaf6-79594a2c3d43	2018-03-04 21:02:27.537687-06	2	[22326] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
a80922d3-462a-4fc2-a339-940594cdabeb	2018-03-04 21:02:27.542687-06	2	[22327] IC 336A	[4] DLarrabee	[21062] a	\N	\N
0b65f351-dea0-4148-90ab-4af7dbb52ccf	2018-03-04 21:02:27.546688-06	2	[22328] IC 336A-outB	[4] DLarrabee	[21062] a	\N	\N
3889503e-f039-43b6-b241-0b1aaf214aab	2018-03-04 21:02:27.549688-06	2	[22329] IC 337A	[4] DLarrabee	[21062] a	\N	\N
5277ec4d-038d-4fd2-9cf1-832bc92bcb59	2018-03-04 21:02:27.554688-06	2	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
c673ca73-2b16-48e1-b4d2-c2a0577b48d6	2018-03-04 21:02:27.558689-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
f611cd5f-d5bd-4ad0-b3e2-1029b100c6cf	2018-03-04 21:02:27.563689-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
27dfaf68-eb2c-4647-ad05-59ea72d54145	2018-03-04 21:02:27.56869-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
aecfa81c-7beb-47b3-b386-7783faacda30	2018-03-04 21:02:27.57169-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
313f7257-aeec-4c9a-84c1-44d43950e26e	2018-03-04 21:02:27.575691-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
57c69e97-0c58-41cc-8b69-a3463b0c4edd	2018-03-04 21:02:27.581691-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
98558bf6-56a6-4698-9585-b750a05d90e1	2018-03-04 21:02:27.585692-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
955cedf0-741b-418a-a911-28afd118b200	2018-03-04 21:02:27.588692-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
bd8d1b0c-fbde-420e-8cfa-53ba519d61e0	2018-03-04 21:02:27.594692-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
d2ea5b17-92df-4816-aee4-d594868b4c77	2018-03-04 21:02:27.598693-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
867406db-2283-4e20-ba31-33424d9c1b12	2018-03-04 21:02:27.603693-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
c25613c2-f1d6-4f12-8e2a-3de4f44f7dc2	2018-03-04 21:02:27.607694-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
4ddc85db-bc34-4099-96e5-c9dc2f5dad2c	2018-03-04 21:02:27.612694-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
fb723e78-ea35-4659-b7d9-9dbd8ff651e6	2018-03-04 21:02:27.616695-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
1c1ad2e9-231d-445b-81e2-12c4feaf3af2	2018-03-04 21:02:27.621695-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
be3a7d8b-4d4c-4ec7-8fe6-82bd705d9ef5	2018-03-04 21:02:27.626696-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
bce0d241-8f00-4971-aff1-84e6bcfe7810	2018-03-04 21:02:27.630696-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
888e81a4-2db3-4fa5-8587-e05c30c9ce82	2018-03-04 21:02:27.634696-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
ebaf9ce7-aff8-44b3-95a6-49c50858bd15	2018-03-04 21:02:27.637697-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
a1272dcc-ed4a-4295-aaa9-cfb484527710	2018-03-04 21:02:27.641697-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
6551794f-7be2-4a03-ac2c-26a689925bac	2018-03-04 21:02:27.645698-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
9f1472c2-20e7-4b02-85da-a6be89eb8036	2018-03-04 21:02:27.649698-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
a7cad141-f3c0-4c58-a622-470c9aadcf13	2018-03-04 21:02:27.652698-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
662df300-b347-4632-9d24-237a691dbd8c	2018-03-04 21:02:27.658699-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
e637ec73-359d-4d0a-a21d-798eb61b5249	2018-03-04 21:02:27.662699-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
0f701cd5-18e7-4779-8338-a7dad4e2452e	2018-03-04 21:02:27.6667-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
3eb15199-ce7d-424e-97fd-4a513c230076	2018-03-04 21:02:27.6697-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
1b4ae590-5b75-4712-868b-a77f4d355921	2018-03-04 21:02:27.6737-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
9b1cf329-706b-418e-90d2-ac72912a58cc	2018-03-04 21:02:27.677701-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
8c24f9b6-ec6b-4b46-9e1a-92e186fa2c23	2018-03-04 21:02:27.682701-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
faed7d04-ea61-470b-afce-2acb97219a16	2018-03-04 21:02:27.689702-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
772f1c73-8c2b-48a8-924d-38e06e2482ce	2018-03-04 21:02:27.693702-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
e51fb668-8564-4c4a-b9c0-1705dfb16167	2018-03-04 21:02:27.697703-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
ec8737ac-ea2e-4ae6-a8b4-fa0453a7e407	2018-03-04 21:02:27.702703-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
56b8f77b-e5f5-4d0e-b9f0-e30bf27cbbb0	2018-03-04 21:02:27.706704-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
0633bf81-4f32-4628-b824-7166506faec1	2018-03-04 21:02:27.710704-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
01eed59b-c35d-4cf0-89e0-8fd1ff7f643b	2018-03-04 21:02:27.714704-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
458e32eb-cc14-40d7-9b68-fc1a5dbfe257	2018-03-04 21:02:27.721705-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
b72010b7-4532-49b5-bcf3-0de76d61c909	2018-03-04 21:02:27.725706-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
77330368-d654-4575-9d24-bacdcf15680f	2018-03-04 21:02:27.728706-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
64148f8e-c4b2-4709-be77-89a0e8b30bdb	2018-03-04 21:02:27.732706-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
e1459d40-f238-4bc8-8de1-e1e22d189110	2018-03-04 21:02:27.736707-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
7a6a0942-acfd-4ff6-a0d8-b71c58e7248a	2018-03-04 21:02:27.741707-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
0196f08a-b77d-4016-90ca-ea3a6040cf4d	2018-03-04 21:02:27.744707-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
92d6d40a-423b-4824-ac67-705989369d98	2018-03-04 21:02:27.747708-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5bd5508e-7e47-4d31-a779-5a464b5faccd	2018-03-04 21:02:27.750708-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a27d2fb0-2308-4c75-a433-4507fb74c74f	2018-03-04 21:02:27.756709-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d5063218-bcd7-4831-8156-bc61b59df2e8	2018-03-04 21:02:27.759709-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
24db44eb-9931-404b-88e8-2b5b283bbd83	2018-03-04 21:02:27.763709-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d62d0c97-55f0-4e9c-98ed-4942a627ad00	2018-03-04 21:02:27.76671-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
79ff89d1-361e-4a3e-a51d-8efa4b5a5b75	2018-03-04 21:02:27.76971-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a07eed8b-82d6-4d6e-85d3-ec798829c387	2018-03-04 21:02:27.77271-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7e7ae938-16cd-4819-8016-0fcfed2f248c	2018-03-04 21:02:27.776711-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e372613e-03dd-4cc6-ae11-05b4416db37d	2018-03-04 21:02:27.779711-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
36d3eca4-ea18-49a2-96ca-a2122e29b15d	2018-03-04 21:02:27.782711-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e0e9db69-ae11-4b6f-9890-760e325e6f92	2018-03-04 21:02:27.785712-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f1419f5e-7e9c-41ec-a6ed-c6ea5f44b7ba	2018-03-04 21:02:27.788712-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
85245be3-4a94-47a8-b8e4-ff64c48a5fb6	2018-03-04 21:02:27.792712-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
20279dd2-32fd-4227-9efb-272f1e14b4f1	2018-03-04 21:02:27.795713-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
14f450f5-87b8-4293-a50b-86223eb31358	2018-03-04 21:02:27.799713-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
dcb52cc2-e07d-4671-a6de-493d34b34da8	2018-03-04 21:02:27.803713-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5aeccd5e-127e-445d-8a60-f12e75db8445	2018-03-04 21:02:27.809714-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
35858e61-4dd0-424b-a463-1bdd9aa868b0	2018-03-04 21:02:27.812714-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
c08e27d8-e576-4534-9ed7-611bc94b5995	2018-03-04 21:02:27.816715-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
44c0c00b-9608-42b7-a87a-43e1bf0e8f26	2018-03-04 21:02:27.820715-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
6e4b9ca2-f924-4231-aa7a-6253e2a67ca7	2018-03-04 21:02:27.823715-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
2ab94d3e-16d4-47c5-944d-a79c1ad0589c	2018-03-04 21:02:27.827716-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
70a422a8-6728-4b55-b7ed-ac86a7725fb3	2018-03-04 21:02:27.831716-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
4eb1c89d-0187-4121-b881-8c12dac69e47	2018-03-04 21:02:27.835717-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
550da653-4c14-48e5-ad0c-bac2a1999593	2018-03-04 21:02:27.839717-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
eecf7831-8b3b-46d1-898f-1cd9580d8555	2018-03-04 21:02:27.842717-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
6d1bf449-4eed-4d3b-80f0-4ed743311647	2018-03-04 21:02:27.846718-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
4842bc55-b5ae-48b4-a298-6f93caed3d39	2018-03-04 21:02:36.628596-06	2	[21216] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
98fbbb94-7de8-43a5-8b7d-3da31a91b043	2018-03-04 21:02:43.331266-06	3	[22322] IC 329B-outB	[4] DLarrabee	[21062] a	\N	\N
e5c01d50-3665-48e1-9dbd-fecf5b26b96e	2018-03-04 21:02:43.594292-06	2	[22323] IC 334A	[4] DLarrabee	[21062] a	\N	\N
4ea0fde3-c11e-48cb-99e1-553a9ae8bbf2	2018-03-04 21:02:43.598293-06	2	[22324] IC 334A-outB	[4] DLarrabee	[21062] a	\N	\N
b67bbefa-e2a9-45ab-8dbe-4e42e02aaf34	2018-03-04 21:02:43.602293-06	2	[22325] IC 335A	[4] DLarrabee	[21062] a	\N	\N
7c82f10c-7bf3-41d0-b115-79e45ef7d7a9	2018-03-04 21:02:43.606293-06	2	[22326] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
7684f9e0-d5c9-4701-b422-1b1ede52bc77	2018-03-04 21:02:43.611294-06	2	[22327] IC 336A	[4] DLarrabee	[21062] a	\N	\N
99283722-035b-48e5-858b-5b868e03138f	2018-03-04 21:02:43.615294-06	2	[22328] IC 336A-outB	[4] DLarrabee	[21062] a	\N	\N
2298f776-0ef9-4890-a7b5-c3e39aba691e	2018-03-04 21:02:43.620295-06	2	[22329] IC 337A	[4] DLarrabee	[21062] a	\N	\N
e6969aea-b2b3-4da4-af11-53f833449519	2018-03-04 21:02:43.627296-06	2	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
da698e58-7800-42c7-9f19-80031d8ddcee	2018-03-04 21:02:43.632296-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
a60f8e70-ec08-40e6-bda9-93667714cc2e	2018-03-04 21:02:43.636296-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
fbbbb2c5-1386-4b2b-a88b-4416849b6366	2018-03-04 21:02:43.639297-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
edc5d535-b178-4782-b456-5bb1b2bf67dd	2018-03-04 21:02:43.642297-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
5b9b5d58-76f6-4cd1-a10b-4af37fb99f93	2018-03-04 21:02:43.647298-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
a9826690-5f5c-47ce-b1dd-df5a92f4838d	2018-03-04 21:02:43.652298-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
27c8bdd1-4007-4c7a-8db5-366ab402ed34	2018-03-04 21:02:43.659299-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
97946f96-7404-4035-b623-cbb4d820209b	2018-03-04 21:02:43.662299-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
1b171d3b-160e-4799-b577-bfcc78bd35b9	2018-03-04 21:02:43.6683-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
b4541907-de24-4165-9b0b-59b52dc0a151	2018-03-04 21:02:43.6723-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
4f072c51-60de-4ded-897c-33a452ea4b19	2018-03-04 21:02:43.677301-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
f93c6da8-3c2e-40e1-918d-be965c26643e	2018-03-04 21:02:43.681301-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
ce737553-1a8a-4667-8d67-922e96ec9c18	2018-03-04 21:02:43.685301-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
db0ba9ca-3f7f-4fdf-ab6c-79f699e85cdf	2018-03-04 21:02:43.689302-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
6ca61e0e-bbd3-484b-98dc-e6eed5e4c6ab	2018-03-04 21:02:43.695302-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
8f7dd85a-9863-4586-8b91-33193459aea3	2018-03-04 21:02:43.698303-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
4f9d75ea-3e2b-446e-a06a-f5dad3a414e5	2018-03-04 21:02:43.702303-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
ef16da44-48c8-4ae0-bf52-e88009e6525e	2018-03-04 21:02:43.706303-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
2c5144b8-8962-490e-a682-4d470478db20	2018-03-04 21:02:43.711304-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
b6917024-ba9c-4bee-99ff-7a0366984091	2018-03-04 21:02:43.715304-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
f53630c9-7f6a-4bc0-9acf-d2db749504d4	2018-03-04 21:02:43.719305-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
ce124456-331b-4bf4-acfe-43a7c3cc9066	2018-03-04 21:02:43.726305-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
b2b9adba-b432-4100-8d28-04da32b97c94	2018-03-04 21:02:43.730306-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
c836d846-5bb8-40dd-a052-2040cf8b0e7f	2018-03-04 21:02:43.734306-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
61ba6c8e-f304-4c9c-82a3-65ce2fe314ab	2018-03-04 21:02:43.738307-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
851e0ece-ab47-457c-ae30-49e99e34a9c3	2018-03-04 21:02:43.741307-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
e8e958bc-f034-47be-9211-93d36e283610	2018-03-04 21:02:43.745307-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
c2da39f2-4d0b-4c3f-82f5-696bf1adcb3e	2018-03-04 21:02:43.748308-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
f8e09854-7a17-41a0-a30b-1b17d466d505	2018-03-04 21:02:43.755308-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
c011b665-55ad-4afe-acd5-d517c2d1f0dd	2018-03-04 21:02:43.760309-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
e90be65e-5869-4960-971f-ff558e1813e0	2018-03-04 21:02:43.764309-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
1d95384d-8f9f-4639-b53e-f93a215b1420	2018-03-04 21:02:43.76931-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
19830a8d-dae4-4bd0-81bb-0df0edf5ce3e	2018-03-04 21:02:43.77331-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
4cf15649-5883-42bb-9f69-784d61eca7c1	2018-03-04 21:02:43.778311-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
bcffc4b0-3346-4206-8380-2c5b0eaea056	2018-03-04 21:02:43.782311-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
e1264cc1-f701-47ed-a1f9-93c23fe2e62e	2018-03-04 21:02:43.789312-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
72d6ee84-73f4-416f-ac96-354debe4986c	2018-03-04 21:02:43.793312-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
8e4fdda4-aaa3-49ee-90db-eae59989912f	2018-03-04 21:02:43.797313-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
e85b8ca4-bde0-4693-bf78-d1d91b61226c	2018-03-04 21:02:43.800313-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
92e4ecf6-e206-4c12-a068-89642e4e44ef	2018-03-04 21:02:43.805313-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
f320a40d-9242-4e7e-846d-b979ca8166b3	2018-03-04 21:02:43.809314-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
8a7f3be2-e4b1-41d5-9fc1-f6be5708b4fa	2018-03-04 21:02:43.814314-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
3a417111-b52e-41d0-8bce-d9024d900bd8	2018-03-04 21:02:43.818315-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
c89a05ed-8fa0-4c8a-80a2-8b5babdcab8c	2018-03-04 21:02:43.823315-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
835a344f-c697-43f4-94ff-8200f65595ca	2018-03-04 21:02:43.826315-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6d23c3e2-42d7-4c20-af76-18413b2647b9	2018-03-04 21:02:43.829316-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4a93795a-337e-43a5-8185-c67719522476	2018-03-04 21:02:43.831316-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5e3be2c8-0015-4de8-98bb-be4654dcc47d	2018-03-04 21:02:43.834316-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f9f8ba78-47a7-4cff-a33c-ada6be270bfc	2018-03-04 21:02:43.837317-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cdaa00e3-178f-4cea-946e-68fd60c6d1fa	2018-03-04 21:02:43.841317-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
25abb15f-d44d-45a2-8ae4-8a9ecc9ddb99	2018-03-04 21:02:43.844317-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a5c843c9-0af2-4c18-884d-539584e65bc8	2018-03-04 21:02:43.847318-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5eed2bf9-dfc8-40c7-9ca2-8a49bbe8c7e5	2018-03-04 21:02:43.851318-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e5816de7-d63d-4754-a7a0-444fc94f05d7	2018-03-04 21:02:43.854318-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
00999282-2c81-4107-856a-8b34f36b42fc	2018-03-04 21:02:43.858319-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
00f34f64-dd25-48e3-b354-d65f355ae48b	2018-03-04 21:02:43.862319-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ae0a8fdc-fa32-4954-ad8e-70e59707d897	2018-03-04 21:02:43.865319-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
dc903e20-714c-488e-93c5-8e9b3755617c	2018-03-04 21:02:43.87132-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
17438b21-de3d-4a9b-9000-6e84a33281e5	2018-03-04 21:02:43.87532-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7830fab6-d58c-476a-8d28-a94991c6aa9f	2018-03-04 21:02:43.878321-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
272de41e-e91e-4fc8-9122-c980344980db	2018-03-04 21:02:43.883321-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b7b57ce9-a688-498e-a7f1-99cafd0b5a1b	2018-03-04 21:02:43.886321-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
9c9292f0-88c7-4878-a462-519b7bc807ff	2018-03-04 21:02:43.888322-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
100ffe9c-f8b3-4bff-8bee-bf263c487649	2018-03-04 21:02:43.891322-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
8c3f4c59-b4b0-4ad7-8eb6-5b4d22754751	2018-03-04 21:02:43.895322-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
101acb36-208a-4f1e-92c7-93b6513dca46	2018-03-04 21:02:43.898323-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
9215635e-92d6-4057-a3af-851fcad20ab4	2018-03-04 21:02:43.902323-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
164ec902-2800-41c5-9a2b-a271ba5b3eb0	2018-03-04 21:02:43.905323-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
f072d2b9-c415-444c-bbc3-f6277809ec53	2018-03-04 21:02:43.909324-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
c05f4c81-ddcc-4b2f-a3a3-258c86f62c4f	2018-03-04 21:02:43.912324-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
5922efb5-e660-4f62-a937-b62c7f794738	2018-03-04 21:02:43.916324-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
1305f376-104f-47ec-971a-69abd0973e32	2018-03-04 21:02:43.922325-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
4a1c3fe7-211f-4b37-90ea-fd0088f3f595	2018-03-04 21:02:58.938827-06	3	[22323] IC 334A	[4] DLarrabee	[21062] a	\N	\N
ee840495-9769-454a-88a3-7d605b53d2a1	2018-03-04 21:02:59.231856-06	2	[22324] IC 334A-outB	[4] DLarrabee	[21062] a	\N	\N
128bfddc-79a2-4bd3-b662-3d4e7087f928	2018-03-04 21:02:59.235856-06	2	[22325] IC 335A	[4] DLarrabee	[21062] a	\N	\N
31a9b49e-3126-4ec3-bb5a-80a7db310648	2018-03-04 21:02:59.240857-06	2	[22326] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
ba2babd6-decf-4e94-b84a-68789b67341f	2018-03-04 21:02:59.244857-06	2	[22327] IC 336A	[4] DLarrabee	[21062] a	\N	\N
a7913dd1-da58-4d3f-8296-bff6a3d6f2af	2018-03-04 21:02:59.249858-06	2	[22328] IC 336A-outB	[4] DLarrabee	[21062] a	\N	\N
f80722c8-98e6-41d9-860b-d725d88fa3d7	2018-03-04 21:02:59.252858-06	2	[22329] IC 337A	[4] DLarrabee	[21062] a	\N	\N
67c1e722-bc53-4bce-ae79-29cc5689c160	2018-03-04 21:02:59.257858-06	2	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
86d2a7a3-1461-49e8-812a-bd90866eecb6	2018-03-04 21:02:59.261859-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
7b1a661a-e741-4650-8774-973131ca0909	2018-03-04 21:02:59.265859-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
e190a211-2c30-4821-877c-cd8760164670	2018-03-04 21:02:59.26986-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
8a321e2a-5ab4-4ad5-997e-f1f6b8ad9b13	2018-03-04 21:02:59.27386-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
39e14b52-393b-4a12-9764-056c3b2b447c	2018-03-04 21:02:59.27786-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
53b1135c-7036-4dc4-addd-5c709d463917	2018-03-04 21:02:59.281861-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
13a33219-265a-4d01-9ec5-2a47dfe5568d	2018-03-04 21:02:59.285861-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
6ceb7690-0df4-4a15-8ea6-96ddfd2939c8	2018-03-04 21:02:59.290862-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
cd38a653-c166-4cf9-be56-2e722e03a7c8	2018-03-04 21:02:59.294862-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
e3751627-6fb2-4c22-a1a3-10c4a7a2e8d7	2018-03-04 21:02:59.299863-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
7792807a-3827-408a-8bf2-abfb4f44a84d	2018-03-04 21:02:59.303863-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
8bdf0ca5-ef35-4d57-b65a-4abeccead996	2018-03-04 21:02:59.308864-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
f13c7e18-2d35-433e-bf5c-26051ef31676	2018-03-04 21:02:59.313864-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
ebde80ea-76e8-4782-bd60-e71526c45bf1	2018-03-04 21:02:59.316864-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
0b9b70b4-ec80-4620-a201-7baab296713a	2018-03-04 21:02:59.321865-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
f9a5616e-81cd-402d-8a94-ed7cf5cf0b91	2018-03-04 21:02:59.326865-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
90688ca1-416c-4817-b500-f24eebf3e1ed	2018-03-04 21:02:59.331866-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
e921cb6d-ab98-4065-ad6f-13154c32d7e3	2018-03-04 21:02:59.347867-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
71eb9266-5337-4d32-9e8e-9e47c630f541	2018-03-04 21:02:59.351868-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
d9c2149d-d71a-4ef8-9e29-9a95da9839b3	2018-03-04 21:02:59.355868-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
d6da396f-ef93-4b0b-adf4-aef59115079d	2018-03-04 21:02:59.360869-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
c965ffe3-37e4-4d03-ba30-d842e920a627	2018-03-04 21:02:59.366869-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
679d5ee3-2458-4aa9-81c9-dffb4d4a81cb	2018-03-04 21:02:59.37087-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
f90228c1-4e0f-415f-b0b7-7b7247b231ee	2018-03-04 21:02:59.37587-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
495d17a8-8c48-4680-9995-aa0564ec5c1f	2018-03-04 21:02:59.378871-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
3dc98ab2-eb9d-4737-b2cb-23572370f611	2018-03-04 21:02:59.383871-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
a3e70e26-9731-444e-95d9-2c7350d1785d	2018-03-04 21:02:59.388872-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
a1b52740-07bc-41dc-b473-d17a645315d3	2018-03-04 21:02:59.392872-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
fd304b29-07c6-477f-9acb-ef37f4ddf4e7	2018-03-04 21:02:59.398873-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
619f4fc9-3970-40e7-9b79-3cc6cc5a1a03	2018-03-04 21:02:59.402873-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
12c524a1-c8da-4d20-97cb-373bc77746d0	2018-03-04 21:02:59.405873-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
8fbbac6e-6f74-484e-99f4-28cb42ee8861	2018-03-04 21:02:59.409874-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
c9334992-6467-4f88-b1dd-508de8c85011	2018-03-04 21:02:59.413874-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
d2639955-a30c-4be4-a8a6-35f85dd0ebcd	2018-03-04 21:02:59.418875-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
3c1f92f3-b37d-44b0-9c4c-746ff5792103	2018-03-04 21:02:59.422875-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
b594a1ba-10e3-4e27-ace0-2004ea0bf20a	2018-03-04 21:02:59.426875-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
98694dfa-956e-46bf-9e06-73f99f32bd98	2018-03-04 21:02:59.433876-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
bfb7eda9-4388-49a3-b1c9-525c65da5bd3	2018-03-04 21:02:59.437876-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
3f2a133c-9350-44db-aeea-96c98ae296d6	2018-03-04 21:02:59.442877-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
b77a0c4d-8cff-44c9-baab-4b7b90daa7a8	2018-03-04 21:02:59.446877-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
3636cbd9-5a3b-4d78-b2c1-e1b0cbfa3d5d	2018-03-04 21:02:59.450878-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
b73ba077-7e86-4be5-b8d2-8f17c03e2c5f	2018-03-04 21:02:59.455878-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
90220a04-a00e-4724-8ca9-59c8b9f6dfc5	2018-03-04 21:02:59.459879-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
9253762a-b602-4438-a84c-bcd1b3671c93	2018-03-04 21:02:59.465879-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3ea843b9-fda2-4055-a40e-15fc33cb51c8	2018-03-04 21:02:59.46888-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
90407eec-531b-4d89-942e-fa860cd222a8	2018-03-04 21:02:59.47288-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ae30d28b-4c12-4e1a-bee6-44608a45234e	2018-03-04 21:02:59.47588-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1073c17d-5ec9-4de7-8763-3c3f86aee341	2018-03-04 21:02:59.479881-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
277d4505-7167-41d6-a46c-33340e3a1e72	2018-03-04 21:02:59.482881-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
26b05f79-240b-4f17-b29f-91d39ec6246c	2018-03-04 21:02:59.486881-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
16dce5a5-4c58-41e5-9612-8ebcd11a2fc9	2018-03-04 21:02:59.489882-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c2210a11-a753-402a-a4bc-59a29b5313ab	2018-03-04 21:02:59.493882-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b3aaf3f9-84ec-400b-8783-693471f68a3a	2018-03-04 21:02:59.496882-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
94103463-db68-4427-b724-7202f1e1dab1	2018-03-04 21:02:59.500883-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9605b4d7-bd0b-4cc3-ad30-37c514063d5d	2018-03-04 21:02:59.504883-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6693cc37-1977-450f-bbfb-3fc0f4b19958	2018-03-04 21:02:59.507883-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a1991cf9-3a93-418b-8f30-4747d12cc1c8	2018-03-04 21:02:59.511884-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2ff372eb-6357-4d6f-8fb1-7a82cb36964c	2018-03-04 21:02:59.515884-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
32365f9b-6a0d-4c47-9d9f-cd6c839c5055	2018-03-04 21:02:59.522885-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a59a85a7-fbb8-40c8-84b2-440f64632807	2018-03-04 21:02:59.525885-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8cb05d70-c516-4e83-a486-928e6a205075	2018-03-04 21:02:59.529886-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ade26217-4274-4303-b7b1-a86d20e0f0ec	2018-03-04 21:02:59.531886-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
3873d282-ab7e-4c13-93d2-3366d861a19a	2018-03-04 21:02:59.534886-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
00471673-f259-4074-a0d1-f29ce528bbd6	2018-03-04 21:02:59.537886-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
f01fe4ed-4b6c-42a7-ad5e-aeef3abe7b2b	2018-03-04 21:02:59.541887-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
beb92742-e425-45cc-b7f6-259b4d48223c	2018-03-04 21:02:59.544887-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
03ba1299-6b90-4254-afa9-af88f2fef2ab	2018-03-04 21:02:59.547887-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
156ff8b9-c33d-4cf4-92b9-7dab6085e4af	2018-03-04 21:02:59.551888-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
bf659b27-f4ed-440a-a4d5-70bcbe51681f	2018-03-04 21:02:59.553888-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
d78a0922-b57f-430c-8ecc-7bef652d0916	2018-03-04 21:02:59.556888-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
47a3a5aa-a5d0-433c-93f4-886117e10dd2	2018-03-04 21:02:59.559889-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
456150d3-1853-49b4-9367-89ecc415704c	2018-03-04 21:02:59.564889-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
5a1e98a6-b9d6-4096-b884-9745cfd6ba9b	2018-03-04 21:03:12.031136-06	3	[22324] IC 334A-outB	[4] DLarrabee	[21062] a	\N	\N
7f36535d-3595-4f66-893c-0de5d11211b9	2018-03-04 21:03:12.300163-06	2	[22325] IC 335A	[4] DLarrabee	[21062] a	\N	\N
05ef1064-d663-4228-9c08-4efb914ed257	2018-03-04 21:03:12.309163-06	2	[22326] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
aeb7a62f-4023-4c76-a651-83cf58466af6	2018-03-04 21:03:12.314164-06	2	[22327] IC 336A	[4] DLarrabee	[21062] a	\N	\N
afb427ea-332a-404b-8f57-7b5846eab358	2018-03-04 21:03:12.318164-06	2	[22328] IC 336A-outB	[4] DLarrabee	[21062] a	\N	\N
35fec710-1265-4a61-8fdb-8568fc848a59	2018-03-04 21:03:12.323165-06	2	[22329] IC 337A	[4] DLarrabee	[21062] a	\N	\N
1a26d7c4-ca4c-4c20-a896-32597bef731f	2018-03-04 21:03:12.327165-06	2	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
2fea5ab9-e265-4f94-8e42-90dd89e38cc1	2018-03-04 21:03:12.335166-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
81b60d94-2953-40d0-8e0e-54382798741e	2018-03-04 21:03:12.339166-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
d8433672-49c0-4095-809c-5f02c149e48d	2018-03-04 21:03:12.344167-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
ecc61d4a-950e-4fe5-8730-0625f34782bd	2018-03-04 21:03:12.350168-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
6aa3068d-02a9-4e65-be4a-30c9d71b7d3c	2018-03-04 21:03:12.354168-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
20e46d6a-6385-40b4-92d2-ad43651800ad	2018-03-04 21:03:12.359168-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
ea3acbb3-4450-4786-999b-fa48cf029ece	2018-03-04 21:03:12.363169-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
16b29cc3-d8a8-4e0a-aa77-eb67b2389199	2018-03-04 21:03:12.368169-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
8f21f961-84ef-41da-8115-e1ae36e6d3d8	2018-03-04 21:03:12.37517-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
59a3c10a-4ba9-4b24-9b4b-e8e9a70fb4ed	2018-03-04 21:03:12.37917-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
1d345313-c011-4868-8a3e-3532e3b447a0	2018-03-04 21:03:12.384171-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
2fc676f4-890a-474a-bbef-690328669e30	2018-03-04 21:03:12.388171-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
92182393-f912-4c8f-9562-3ea546119506	2018-03-04 21:03:12.392172-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
a3456bf5-3d1b-4d20-8f9b-0a646927c573	2018-03-04 21:03:12.396172-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
a67b4f48-035b-423c-aa79-7f39af8a77fc	2018-03-04 21:03:12.400173-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
2306c2df-e287-4a1b-88d9-fe3ccb1579a6	2018-03-04 21:03:12.405173-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
e21a4393-eb16-46a1-9d33-3d1146b3bc06	2018-03-04 21:03:12.409173-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
9ebed5d5-2424-4378-9f10-602fa7821e70	2018-03-04 21:03:12.414174-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
f8d7ee43-9429-4019-9779-aac1cacf6aa1	2018-03-04 21:03:12.418174-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
bca20bf0-2055-4526-b8f8-cbe1479e7b6f	2018-03-04 21:03:12.423175-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
69019c72-b506-463c-afeb-08ae08b90fc1	2018-03-04 21:03:12.427175-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
d15d3ba5-52b2-4513-93f3-197ffcc8b153	2018-03-04 21:03:12.431176-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
94943ad8-0409-497b-b10d-a4dc84a45949	2018-03-04 21:03:12.438176-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
0f96467f-7f5c-4caf-8453-ad71a0dda224	2018-03-04 21:03:12.442177-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
dfaf7d2c-f00b-4ea6-b26b-5fda0bcd9b40	2018-03-04 21:03:12.446177-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
7b2a6457-2119-4bd0-9585-7ef6a473cf23	2018-03-04 21:03:12.449177-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
a771028c-c9d7-48e4-8cef-27144aee3ee0	2018-03-04 21:03:12.454178-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
699059b9-ef5c-4079-9551-77189efb5d03	2018-03-04 21:03:12.459178-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
8dc0a824-b67c-42e9-9860-a76f08f0d259	2018-03-04 21:03:12.463179-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
02d1e781-6eb1-4dcf-99d9-da24de8b1992	2018-03-04 21:03:12.469179-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
db470be6-34ce-49ab-9a68-6cbe4988d316	2018-03-04 21:03:12.47318-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
020cda7e-ea40-42bd-9815-3f3f9852bbd1	2018-03-04 21:03:12.47718-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
38ce7c63-c7b7-4f31-bb1f-d445b0725b36	2018-03-04 21:03:12.482181-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
913e12d6-a700-46bb-87c0-7165db090ff1	2018-03-04 21:03:12.486181-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
647186ef-072e-440a-ae4d-945d577c3fd4	2018-03-04 21:03:12.490182-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
1149a438-01b2-49b0-9462-2ba496cec21d	2018-03-04 21:03:12.496182-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
1ffd2d1d-96ae-49e4-a128-a80538b7d809	2018-03-04 21:03:12.501183-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
de22fafa-356c-40d8-9eb1-814cab05a8c2	2018-03-04 21:03:12.506183-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
c174cb5b-6af8-4896-83a0-3f15274c9f82	2018-03-04 21:03:12.511184-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
8259cecd-6fb5-443c-9a2b-a443f1a0c7c8	2018-03-04 21:03:12.514184-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
2e85e30c-d686-41b4-8735-04e5bee41f10	2018-03-04 21:03:12.519184-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
643b7fea-b419-4be0-8326-05d1e077d7b8	2018-03-04 21:03:12.523185-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
819f10b5-b147-4f03-bf2a-d0230efa39df	2018-03-04 21:03:12.527185-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
3daf2584-b3f1-4984-95f7-9b239d12903c	2018-03-04 21:03:12.530186-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2a2baf00-cf3e-4cf2-ba26-3eb25d0a0632	2018-03-04 21:03:12.534186-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a744d244-8991-4523-b9e9-35cca0f43953	2018-03-04 21:03:12.540187-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
af914730-1547-48ba-86e6-8b1c8f1d2880	2018-03-04 21:03:12.543187-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6da39f57-c79a-4699-bab4-c37499a979b4	2018-03-04 21:03:12.547187-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4d1c1fea-b196-4c51-83e3-14809e9393b4	2018-03-04 21:03:12.551188-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
efe75804-d25e-4edf-b698-7fb13efcb13d	2018-03-04 21:03:12.554188-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
316abd46-8ea0-483a-925b-e30a48470d57	2018-03-04 21:03:12.560189-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a9756bef-92f0-4dac-926a-ce5680b27f91	2018-03-04 21:03:12.563189-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7f0de716-74b3-4ddd-ae8d-665048bd659f	2018-03-04 21:03:12.565189-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f549628d-1582-4fd4-be76-54f1ad636ab1	2018-03-04 21:03:12.569189-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
307f1e86-edba-4a63-9827-aaeea3dcd1cc	2018-03-04 21:03:12.57319-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ff64d322-28a1-413d-9625-eae8cc3d911d	2018-03-04 21:03:12.57619-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8da42324-e5ee-4191-97bd-1172c65e9c09	2018-03-04 21:03:12.580191-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
bd1e09e9-c73e-4b98-a66d-9fc249df52f1	2018-03-04 21:03:12.584191-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b9bbbac4-5050-4fcf-9ca3-f7ccc1e38115	2018-03-04 21:03:12.588191-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4d21bc5a-63dc-4b5e-9c3c-3e04caaa5d9c	2018-03-04 21:03:12.591192-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f14935d1-212d-47cf-b853-b97015ce2363	2018-03-04 21:03:12.597192-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
20746e78-80fe-4791-ba42-5dd259f58b46	2018-03-04 21:03:12.601193-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
8a1b5ad7-da1b-488f-854c-f3ae1ec403c2	2018-03-04 21:03:12.604193-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
04b0df36-13fe-427e-8f9a-89bb2043cbd5	2018-03-04 21:03:12.608193-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
476ffbfa-6df5-41f6-93f1-0841698065ff	2018-03-04 21:03:12.612194-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
4a897cdb-ec5f-44ed-a34f-48d61d1b4567	2018-03-04 21:03:12.614194-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
3f5498ed-441b-49fe-b06c-b917c9417959	2018-03-04 21:03:12.618194-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
4c2a55aa-8958-4d3b-88dd-35e1fb67ecac	2018-03-04 21:03:12.621195-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
a591f7c4-412b-4be9-aa21-3ca450ac941c	2018-03-04 21:03:12.625195-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
f4122255-a75b-4289-b5e0-9ddcdd083054	2018-03-04 21:03:12.628195-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
f7ece486-697f-48ba-b6ec-33fa62bfeb21	2018-03-04 21:03:12.632196-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
374b0073-8c41-44ff-9ca7-1ac50fff78db	2018-03-04 21:03:12.635196-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
1fa3e05d-313f-4e6d-82e3-03f053dc16dd	2018-03-04 21:03:26.77561-06	3	[22325] IC 335A	[4] DLarrabee	[21062] a	\N	\N
63cb0d6e-6d5c-4e5b-b0aa-0be6b1dfaf0e	2018-03-04 21:03:27.061639-06	2	[22326] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
4fd6d366-c3c5-4931-b3cd-5d68776088ea	2018-03-04 21:03:27.065639-06	2	[22327] IC 336A	[4] DLarrabee	[21062] a	\N	\N
2f080544-2d65-4e0a-8067-b9b9840902b0	2018-03-04 21:03:27.069639-06	2	[22328] IC 336A-outB	[4] DLarrabee	[21062] a	\N	\N
89950144-f5e1-4e48-8d9c-496dcdc5652f	2018-03-04 21:03:27.07364-06	2	[22329] IC 337A	[4] DLarrabee	[21062] a	\N	\N
3c329e6c-e3d9-472c-8944-4ce99df1740f	2018-03-04 21:03:27.07864-06	2	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
02eb2fe6-d71d-4300-840e-d87aa0986f03	2018-03-04 21:03:27.083641-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
b1171619-c0f1-4783-ac7d-f13246294da0	2018-03-04 21:03:27.087641-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
4e5771e0-f899-4fe8-81e0-deadf5cc4147	2018-03-04 21:03:27.092642-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
e528a745-9932-4cd7-8ee1-d273677d3129	2018-03-04 21:03:27.097642-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
1c8c9185-e61b-4eea-8e28-b161c17d5014	2018-03-04 21:03:27.100642-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
2098a336-28e8-46f1-824c-5aa8ed8f08d3	2018-03-04 21:03:27.104643-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
5a04d0bf-9891-4467-afcf-42a9852b1d62	2018-03-04 21:03:27.109643-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
e4fa1f61-891c-4d58-9b40-6165c2957b98	2018-03-04 21:03:27.114644-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
8f08a3f7-5c47-42f3-a7e2-eb3889efb1f7	2018-03-04 21:03:27.119644-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
42d14986-3887-487c-aaa6-b122e23abce6	2018-03-04 21:03:27.123645-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
6b4a3ba4-94d4-4c65-be6d-db4a2ad88966	2018-03-04 21:03:27.130645-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
3edb3f02-1030-46e5-b401-90a6921dcf1b	2018-03-04 21:03:27.134646-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
7c271943-2b3d-4d28-af17-4764b68740e7	2018-03-04 21:03:27.139646-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
f32123dd-2718-404b-8093-ae622b28727d	2018-03-04 21:03:27.143647-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
2eb615b1-54e7-44e9-b357-6e360ca85a40	2018-03-04 21:03:27.147647-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
9015f0b8-dedc-4b2c-be94-7468c08daecd	2018-03-04 21:03:27.150647-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
25546961-8fd5-468b-8150-5b33c6d44738	2018-03-04 21:03:27.154648-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
cb7488f9-9985-4dd4-9d18-73791ce2a3e5	2018-03-04 21:03:27.160648-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
d16c4dab-448f-4476-8fd0-118103ba711c	2018-03-04 21:03:27.163649-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
54710697-0f75-4fcc-9f87-7b5a3f7ff6ac	2018-03-04 21:03:27.167649-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
4ca7ac9a-c765-4216-adde-7e2ef5b26756	2018-03-04 21:03:27.17165-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
bdc6217c-a1ca-4c48-b03b-e9f56cff1a83	2018-03-04 21:03:27.17665-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
49ab72d6-a299-450f-a1b6-3112fbcc1466	2018-03-04 21:03:27.18065-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
8e21bc4b-4d16-4ac6-9be9-2ddfe3cfadf6	2018-03-04 21:03:27.184651-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
71b584d3-b1c8-4674-ba79-c8ac3eae9cca	2018-03-04 21:03:27.190651-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
d44d5af1-e7a0-461a-bb84-89be873f2d90	2018-03-04 21:03:27.194652-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
4b670d94-767d-4ce8-8029-4cb5814c5279	2018-03-04 21:03:27.199652-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
20251398-94b1-491a-abdb-2921d08447e0	2018-03-04 21:03:27.202653-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
82f3a6b5-fa7f-420e-bbef-4bf438592d8b	2018-03-04 21:03:27.206653-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
ba00dc77-0d4e-4da8-a7ae-7e5eec453f95	2018-03-04 21:03:27.210653-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
61f8bf6c-8cc9-4046-816c-b6023ea6a10f	2018-03-04 21:03:27.214654-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
683650fd-6b7a-46f1-a60c-b35e75790815	2018-03-04 21:03:27.217654-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
130dc599-8207-4744-92d8-a0c21ce41045	2018-03-04 21:03:27.222655-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
69962e2e-06a4-4f73-a3f6-4b13405ad683	2018-03-04 21:03:27.226655-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
bfedd3af-2ad6-469e-93d7-ddd97a1b8800	2018-03-04 21:03:27.230655-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
0ca737a9-d1d9-472d-a8d1-388deb601f18	2018-03-04 21:03:27.234656-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
f87f71d4-69ca-4cf8-9caa-820efcf18215	2018-03-04 21:03:27.239656-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
c22ed67d-3844-4994-a940-55074fe44a9e	2018-03-04 21:03:27.243657-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
4c446251-c081-442e-80c5-53a2ef95510f	2018-03-04 21:03:27.248657-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
894a8dc1-b02b-4fad-b375-98d41a816ed7	2018-03-04 21:03:27.255658-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
653c2d23-1beb-4a5e-9390-a7f4ecabb6a2	2018-03-04 21:03:27.259658-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
eb530bf3-f384-4e07-b40a-5539a715ee30	2018-03-04 21:03:27.263659-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
109a058b-f711-431d-9719-f1c4ad8d11f2	2018-03-04 21:03:27.267659-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
5487dc9d-c8c4-490e-bb80-138278382886	2018-03-04 21:03:27.270659-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1c25c765-5451-48c0-9215-7a812fc6b920	2018-03-04 21:03:27.27366-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
040670b7-2987-4d49-9d58-dd681be86b5f	2018-03-04 21:03:27.27566-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c6a7e476-4ed9-4f61-b634-6cbf958346f2	2018-03-04 21:03:27.27866-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
875ee236-9bbf-4023-b5d9-bfbed114cf6a	2018-03-04 21:03:27.282661-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
69ae36bd-bdeb-4c5c-9941-3c792e0d34e1	2018-03-04 21:03:27.284661-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b3f4f607-37d0-4147-af0a-1f69a0ecfc22	2018-03-04 21:03:27.287661-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2e7c9728-2b13-4450-a8b5-c76ee3307300	2018-03-04 21:03:27.291662-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ca4c5466-3cfb-4b07-99f4-0e2802b13365	2018-03-04 21:03:27.295662-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7a390e5b-4e6e-490b-ada0-f651bb8e89a9	2018-03-04 21:03:27.299662-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4adcd925-3ec5-42dc-a60e-eabd4bf80200	2018-03-04 21:03:27.303663-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fc14b663-1792-4b81-a635-66d57e1e9c06	2018-03-04 21:03:27.306663-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2c29dde6-f6c3-4e89-aa50-b89307752227	2018-03-04 21:03:27.308663-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f5565e50-0726-47b4-b141-84e509b14b9d	2018-03-04 21:03:27.311664-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
175b19d7-cb15-46de-af06-2bfb0f6bda14	2018-03-04 21:03:27.314664-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2749af42-899b-4e1b-9567-2f5838b6bfc2	2018-03-04 21:03:27.316664-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
28407e44-7e1c-4d2f-8ff4-fd6e4809d357	2018-03-04 21:03:27.319664-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5bc2c52f-dd05-4d96-9287-3f8795945fea	2018-03-04 21:03:27.323665-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
79161806-94e6-468e-a67f-0d194b57e8f5	2018-03-04 21:03:27.326665-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
6a782e6c-3dce-4fd0-9005-9ee6bde5ccea	2018-03-04 21:03:27.330665-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
e9f9565f-6d6b-4aa5-a90b-aeb511281bab	2018-03-04 21:03:27.333666-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
33759583-4bf9-43e2-bfed-2b2bcc1e94d6	2018-03-04 21:03:27.339666-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
18905b18-6026-4e38-a4d5-7b83651021b4	2018-03-04 21:03:27.342667-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
958599e0-8664-42b1-91cf-bcda2d5608c0	2018-03-04 21:03:27.345667-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
ba5c109b-712e-4be5-8f03-18e3ee6e5118	2018-03-04 21:03:27.349667-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
2ab4bd14-ede2-4a7f-abbe-adc25888b36a	2018-03-04 21:03:27.352668-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
050b563b-5c52-48f5-ba94-3f024f86d175	2018-03-04 21:03:27.356668-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
38909431-b399-4eaf-98bf-60b5696fb9b8	2018-03-04 21:03:27.360668-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
989cf827-4d5f-4424-b71c-7e5b0b6519d7	2018-03-04 21:03:27.363669-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
6b29b0f5-1e36-4d4a-85f1-f92170b46085	2018-03-04 21:03:31.994132-06	1	[22314] Area-B.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
5b9137c4-fc58-4e84-a608-5c9f27c8156b	2018-03-04 21:03:34.250357-06	2	[22314] Area-B.png	[21041] OSSI-DNOVAK	[293] master	\N	\N
fae7c0d2-a9ef-433a-87b2-f868e0f217a3	2018-03-04 21:03:43.486281-06	3	[22326] IC 335A-outB	[4] DLarrabee	[21062] a	\N	\N
2e746faa-193c-4011-b015-5e4e2544ae5b	2018-03-04 21:03:43.752307-06	2	[22327] IC 336A	[4] DLarrabee	[21062] a	\N	\N
d224686f-186c-4644-b1d0-11ff7897798b	2018-03-04 21:03:43.756308-06	2	[22328] IC 336A-outB	[4] DLarrabee	[21062] a	\N	\N
c432e8cb-1b82-4a45-a468-546b5724b06a	2018-03-04 21:03:43.760308-06	2	[22329] IC 337A	[4] DLarrabee	[21062] a	\N	\N
133a4c06-96ee-41c4-9f20-2376d6dfd74f	2018-03-04 21:03:43.765309-06	2	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
8063d669-6697-4e67-8427-26d5d681b9af	2018-03-04 21:03:43.770309-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
7f5eb901-a65f-440c-b46f-3a553d762339	2018-03-04 21:03:43.77531-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
db6361e2-ebf2-4444-978c-808b0d1b5c34	2018-03-04 21:03:43.77931-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
33fdf249-2d00-41ad-9533-392df2457ec0	2018-03-04 21:03:43.783311-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
42596274-c254-4128-9905-8376ef075b4c	2018-03-04 21:03:43.787311-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
28b84bcb-dadc-40ee-948e-59112a23d07c	2018-03-04 21:03:43.791311-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
76e73765-292f-493a-bc6e-01f337320aac	2018-03-04 21:03:43.795312-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
5f4e30ee-51c7-4a6f-a18f-b6889b980d9f	2018-03-04 21:03:43.799312-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
c796aae0-3c60-4f03-9a75-0b04a9a31ed2	2018-03-04 21:03:43.802312-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
3ba217b5-df18-4d72-9f30-fb22e598b071	2018-03-04 21:03:43.806313-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
fc65db91-fdae-4104-b8a6-5a01d04ea796	2018-03-04 21:03:43.809313-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
611ea724-971b-4ab8-b66c-7f74216084ec	2018-03-04 21:03:43.812313-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
9988fb37-99f1-4ce5-bd86-9b3d3576e379	2018-03-04 21:03:43.816314-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
0d4b2c40-e010-44e4-b4de-b357589cb0a1	2018-03-04 21:03:43.821314-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
c392d183-a68e-43a4-b98e-65aca09e0e8d	2018-03-04 21:03:43.826315-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
ac6bdd8d-b978-40e7-a20f-2dc5d0c614ab	2018-03-04 21:03:43.830315-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
f43a551b-c999-4aeb-8bf4-8793416886b9	2018-03-04 21:03:43.834316-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
90a39015-6c70-4407-ba21-6748c84cf2e6	2018-03-04 21:03:43.838316-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
a26b5298-098e-436c-8527-2baf8e565188	2018-03-04 21:03:43.841316-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
9cfd54fb-78db-4965-ab7c-d6e95c92e77a	2018-03-04 21:03:43.845317-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
00de5f85-d9c6-44a4-b89e-797e4c2c8bd0	2018-03-04 21:03:43.848317-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
a1ca12cd-ffff-4cfa-81ed-9111641e60c6	2018-03-04 21:03:43.851317-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
9264d5b9-f83b-485a-b2b4-f877553f7359	2018-03-04 21:03:43.856318-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
2c5c71e4-bf97-42b5-9619-f8ea9c7d0c53	2018-03-04 21:03:43.860318-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
d62ac856-f75f-4ed3-8b8d-eb42b020dd1e	2018-03-04 21:03:43.865319-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
bb7a4e9c-102b-4bd6-913e-f09443aa750f	2018-03-04 21:03:43.869319-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
8676ff79-5d34-4b15-816a-509d8614dd2b	2018-03-04 21:03:43.87432-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
96e313ed-26cc-4ed8-8bfb-cb3fb8178bd1	2018-03-04 21:03:43.87832-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
b725b5b7-091e-478a-95b3-6f6dcfb5f546	2018-03-04 21:03:43.88232-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
70203e5d-4dc6-4949-9748-937b6dfb0594	2018-03-04 21:03:43.886321-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
bf766992-c8e1-4c9c-85f5-82dfe802d7a2	2018-03-04 21:03:43.890321-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
a228c51f-e824-4cc5-a6b2-10678b017484	2018-03-04 21:03:43.893322-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
4fe9d78a-1273-44b7-9f31-76e58c38e3dc	2018-03-04 21:03:43.897322-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
e3dabe1b-de28-409b-b5ac-971b0c970951	2018-03-04 21:03:43.901322-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
2063cb1b-e9ad-4e71-a03c-e4e58cdefca8	2018-03-04 21:03:43.905323-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
0009553a-74b5-485c-b26c-001e0eaa468c	2018-03-04 21:03:43.909323-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
31153a96-41f2-420b-b975-d65dcb56fc0c	2018-03-04 21:03:43.913324-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
846ff8ca-f74a-4902-abf1-149c2ab87778	2018-03-04 21:03:43.917324-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
150bd003-5f8d-40c0-a7c4-f009dfdda894	2018-03-04 21:03:43.921324-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
119f4eec-46a6-4d7e-a534-b02b36a0a6bc	2018-03-04 21:03:43.926325-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
c76b5fbf-b0ce-4745-b894-81d16b66b6e1	2018-03-04 21:03:43.930325-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
96531a41-294c-4b75-8485-618bbe4c5cd8	2018-03-04 21:03:43.935326-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
c3091e25-d3a6-4ce7-8d27-d32407840159	2018-03-04 21:03:43.939326-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
23945017-16c5-45a7-923e-0d7be4fd6561	2018-03-04 21:03:43.941326-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b3e45644-e8d9-4d62-a0a1-a3ad4e5958df	2018-03-04 21:03:43.944327-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
872c571b-8a64-45e4-9b87-501dd726489e	2018-03-04 21:03:43.946327-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
047fdd5f-8baa-4bf1-9875-0b73af4c6842	2018-03-04 21:03:43.949327-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
01275b54-f1f0-44bb-aef8-c31b6218b0f8	2018-03-04 21:03:43.953328-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
039c101f-34fe-45e5-83ad-b22101a33d62	2018-03-04 21:03:43.956328-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6c3a19b9-a18d-4947-ae58-a83619326558	2018-03-04 21:03:43.959328-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d96845d6-5501-4d53-8f53-8a81b436e306	2018-03-04 21:03:43.962328-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9a627ff1-1a7b-4acb-8f2a-2e797c71b116	2018-03-04 21:03:43.965329-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1790e05a-9830-4c14-a781-9c61bcd7ed59	2018-03-04 21:03:43.968329-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
aaa1925d-2ea5-478d-85ae-75ef66067b98	2018-03-04 21:03:43.972329-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
141d6a4b-bcb7-4da4-ba65-1db789e9e055	2018-03-04 21:03:43.97533-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d56eaac1-fe5c-41b0-9821-4df71d2b8a8f	2018-03-04 21:03:43.97833-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
dcd03def-d8ba-4a04-9467-08ceb32cc727	2018-03-04 21:03:43.98233-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9b66832e-0203-4623-ae6a-5e5e08f21b13	2018-03-04 21:03:43.985331-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b2aa45a6-77a1-4296-ac47-11d8a14dba3a	2018-03-04 21:03:43.988331-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
beaeb0d0-72c0-493e-a2f8-28d3fb87ea3c	2018-03-04 21:03:43.990331-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b53b563f-a318-4aff-a41f-5b5da3ab2c17	2018-03-04 21:03:43.994332-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b76f070d-8190-478e-b71d-d053a07c8bbd	2018-03-04 21:03:43.997332-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
f95f27f3-52d0-4ba4-a012-5b95c1c42165	2018-03-04 21:03:44.001332-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
e9f9a23f-e539-4f1d-a33f-9fecf06ebd7c	2018-03-04 21:03:44.005333-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
1e62c71a-b66f-4836-ac63-00778ce24174	2018-03-04 21:03:44.008333-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
3f9c0465-a3bf-410b-a2f9-463784f1882f	2018-03-04 21:03:44.012333-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
858e8612-157c-45b0-993f-398e4d22ea36	2018-03-04 21:03:44.015334-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
ab5ede7a-75cd-4b3e-b814-a8dfc977ef30	2018-03-04 21:03:44.018334-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
a00d66d7-a4f3-4ea3-931e-7b10500bfa06	2018-03-04 21:03:44.020334-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
1a6ac085-5c6e-4bb2-a7a5-6ac96c9859fa	2018-03-04 21:03:44.023335-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
bd08a7bb-7a25-4e58-95d6-049687991893	2018-03-04 21:03:44.027335-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
b0b1f34d-ed23-43d0-b1f5-2f1d382deb66	2018-03-04 21:03:44.032335-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
eed41811-9369-437f-8974-a873d440eb26	2018-03-04 21:03:55.039436-06	3	[22327] IC 336A	[4] DLarrabee	[21062] a	\N	\N
b97caf19-de9f-4a21-8401-5adf4d27e4fc	2018-03-04 21:03:55.327465-06	2	[22328] IC 336A-outB	[4] DLarrabee	[21062] a	\N	\N
2b335d61-65e4-4c00-a29b-7d8f81418dae	2018-03-04 21:03:55.331465-06	2	[22329] IC 337A	[4] DLarrabee	[21062] a	\N	\N
b4606de7-89cc-4cf4-bdfa-410f6e326c7d	2018-03-04 21:03:55.335466-06	2	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
acb9c5da-5648-45fc-b2fa-0114a0297f6a	2018-03-04 21:03:55.339466-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
7de75ca5-3b29-4533-ba78-30d56b081019	2018-03-04 21:03:55.343466-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
b94a302b-2314-4ca3-aaf9-faa19762367d	2018-03-04 21:03:55.348467-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
76e2a424-1b0a-48c6-9b16-519a8f239dc0	2018-03-04 21:03:55.352467-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
3dbb39c2-9c61-449f-8b43-0000fb1245a7	2018-03-04 21:03:55.357468-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
1b5164f0-d4bc-4cf4-a037-abf86fcfe8b3	2018-03-04 21:03:55.367469-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
57ed5426-8c96-49e4-aa70-a5b78339f2a7	2018-03-04 21:03:55.371469-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
16d67ffe-00ca-4023-b853-7238205bb120	2018-03-04 21:03:55.37547-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
16f9db3d-ce62-4d1f-8471-e8c1642ae7f4	2018-03-04 21:03:55.38047-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
9689bdc2-35ca-4fdb-b68e-1006edc6eab4	2018-03-04 21:03:55.384471-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
fab007df-6754-4684-915f-b66e7c08ea00	2018-03-04 21:03:55.389471-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
30f09493-e065-44f7-a19b-e7d862adc947	2018-03-04 21:03:55.393471-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
3059950f-1351-46c1-a17e-c02ee62c169d	2018-03-04 21:03:55.397472-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
b53b415d-c003-42a3-92ab-ec6df5ebb816	2018-03-04 21:03:55.402472-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
c36dcbf8-d319-483a-bada-8928b6bcf756	2018-03-04 21:03:55.407473-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
9c9c97c9-fe7b-4784-811a-3a485266ee9d	2018-03-04 21:03:55.416474-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
4b7be66c-89cc-4d33-ba34-9262110a3ae5	2018-03-04 21:03:55.420474-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
f3e69fd1-9eb6-474c-95ca-d2fc6a03c923	2018-03-04 21:03:55.424475-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
d5e54a8f-6dc6-48b4-9398-d50d4e232298	2018-03-04 21:03:55.428475-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
d3866fce-a22d-41e3-bac6-75cf8030eb11	2018-03-04 21:03:55.431475-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
df0459b7-b0ab-4165-967b-c031dde6464f	2018-03-04 21:03:55.436476-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
d04ece7f-eeb9-4ff4-a38e-3af44c1ee203	2018-03-04 21:03:55.441476-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
7e6136cc-ae30-44c1-96f6-961f72564476	2018-03-04 21:03:55.446477-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
5f003efd-b9d0-46f2-97bc-4dc1a9e9da95	2018-03-04 21:03:55.450477-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
eca97868-7b17-4b0b-8b5d-30720ce7dcb6	2018-03-04 21:03:55.459478-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
149909e4-bd66-4398-8250-3fd32ae4e3ea	2018-03-04 21:03:55.463478-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
c87dd1af-db9f-4917-8d66-d64fa731166f	2018-03-04 21:03:55.467479-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
53f64da8-561f-4584-bdaf-30545516bd4e	2018-03-04 21:03:55.471479-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
7c2a1759-e01a-4947-8e86-3df4e2738cd3	2018-03-04 21:03:55.47448-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
657bd981-7c6f-48c0-886b-d86271cb0fab	2018-03-04 21:03:55.47848-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
7f80f285-edb0-47ff-abc9-0e39b93cfb8a	2018-03-04 21:03:55.48348-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
54239649-1bf2-4ec5-bf25-e9cfc6cc8c5a	2018-03-04 21:03:55.487481-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
089fc042-c79f-49ec-9232-83937b22bd8f	2018-03-04 21:03:55.492481-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
6dbda20a-994d-49a9-96c7-b4dce279105a	2018-03-04 21:03:55.505483-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
d0125a86-c5f7-4e6b-ae02-25e702399740	2018-03-04 21:03:55.526485-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
c09bd286-acbd-4594-beb5-19e5e167ea12	2018-03-04 21:03:55.530485-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
3a1ab387-42e9-4ec7-9d22-826592a6f14f	2018-03-04 21:03:55.535486-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
55c11e87-1340-4979-b0ed-81621f8789c3	2018-03-04 21:03:55.539486-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
7f3edd6f-8889-4a9b-b480-6a533abcc339	2018-03-04 21:03:55.543486-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
37326f9f-b040-4b07-9b75-9844e35f1d82	2018-03-04 21:03:55.547487-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
2cd4a2a9-7a29-4a36-b585-2cdbe9514040	2018-03-04 21:03:55.552487-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
14a2e207-99be-4747-8eb5-415d919711ce	2018-03-04 21:03:55.556488-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
662c927e-e387-424f-a4ad-1f140aa5f46e	2018-03-04 21:03:55.567489-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
d33757c7-8675-4ab4-a1f0-d73a3f9115f8	2018-03-04 21:03:55.571489-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b8598c4c-3529-47f7-9e8e-0ca85f82bf40	2018-03-04 21:03:55.57449-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2bcc7d1f-0f7b-4ce9-ac52-4e30e97179d6	2018-03-04 21:03:55.57749-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1f701255-ffea-42ba-a9fe-ebf3750f1b1a	2018-03-04 21:03:55.58049-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f58e279d-56e1-4702-a76e-ffa7508fa4c6	2018-03-04 21:03:55.58249-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b035075d-06db-4af3-a44a-e6f3b1fe7023	2018-03-04 21:03:55.586491-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6ba04c67-0aed-4469-aa91-221d39785268	2018-03-04 21:03:55.588491-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
beb6c41b-1b30-4a40-8557-207869acc306	2018-03-04 21:03:55.591491-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ebf272ce-43f8-4f81-9eee-ea782a17ab23	2018-03-04 21:03:55.593491-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cc3fcbfc-0224-4610-afc5-5c49b8660eee	2018-03-04 21:03:55.596492-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2eb58502-7e38-4cfd-b077-d19ada1c0e9e	2018-03-04 21:03:55.599492-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
807555c1-67de-4db6-a857-4088a2b27070	2018-03-04 21:03:55.602492-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
60eea0cc-f86e-4b71-91f9-a8843d66b59c	2018-03-04 21:03:55.605493-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8611eafd-d94e-4ed7-8720-318abf807da6	2018-03-04 21:03:55.608493-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8fe8aaf5-465c-45ab-a916-2fe7111d6c71	2018-03-04 21:03:55.610493-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f78832f5-4242-434c-b88c-fe77fd56ec5e	2018-03-04 21:03:55.614494-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
01cf35ca-11ef-44af-95ef-1f33a7e20115	2018-03-04 21:03:55.617494-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a4f64d54-30e8-4ee0-af96-864ff3565255	2018-03-04 21:03:55.622494-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
da6f1865-1c54-4a4b-9fe1-6eab74bf13c2	2018-03-04 21:03:55.626495-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
ef247009-474d-49f6-82c7-090b0d5dfe60	2018-03-04 21:03:55.630495-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
a6106e5d-287e-4994-b696-327b495944db	2018-03-04 21:03:55.634496-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
2a54c1b8-062c-4904-b2d4-262bf2408a26	2018-03-04 21:03:55.638496-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
36a3e6c0-01da-44eb-aae0-8a97f686c873	2018-03-04 21:03:55.642496-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
65cafc32-1dec-4fd7-bebe-1a6ff8e70eee	2018-03-04 21:03:55.647497-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
d050ae9c-bf12-4400-bef7-2c743624e93b	2018-03-04 21:03:55.651497-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
f3855088-75d0-4729-be9b-2a16374b8f1e	2018-03-04 21:03:55.656498-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
61588332-a6a5-49ec-a4f7-727b270347da	2018-03-04 21:03:55.6825-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
1b60f61f-5290-4a4f-bdaa-deb26d9c5fa8	2018-03-04 21:03:55.686501-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
b8ac081b-89e3-4112-860d-50b340a1f0e3	2018-03-04 21:03:55.690501-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
a633b427-42f2-4e3d-ad4b-4b19ef9769f7	2018-03-04 21:04:07.061638-06	3	[22328] IC 336A-outB	[4] DLarrabee	[21062] a	\N	\N
aa0de0b0-a14a-4380-93ea-4337fbb65408	2018-03-04 21:04:07.338666-06	2	[22329] IC 337A	[4] DLarrabee	[21062] a	\N	\N
c6376b24-429b-4a60-bf2f-fd670a3c0567	2018-03-04 21:04:07.343666-06	2	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
5d9a8411-f0ac-43d0-96cf-214cee5b0e94	2018-03-04 21:04:07.348667-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
9eac8d45-8958-4434-963b-a4729486fbd7	2018-03-04 21:04:07.353667-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
b9191551-f790-4e1b-abea-65c9d6f72f66	2018-03-04 21:04:07.357668-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
a5351ccf-c551-4860-bdaa-35bd7842ccd7	2018-03-04 21:04:07.360668-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
607a0df5-f3e9-4075-a1a4-bf1595c7ecd4	2018-03-04 21:04:07.365669-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
e020f68b-e128-4b59-85a5-19c91ab4ff12	2018-03-04 21:04:07.368669-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
2bdd181a-ba2d-4cb8-9347-6f19aeda5ba3	2018-03-04 21:04:07.373669-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
51ddff5e-4ddd-4359-84bf-bb802c21c5d8	2018-03-04 21:04:07.37767-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
d97594f9-4686-404d-859f-c0be122fedd9	2018-03-04 21:04:07.38267-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
1087e0c8-bf77-460d-981c-ac6c5fa32dba	2018-03-04 21:04:07.386671-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
dedc958a-1403-4096-99c1-50a3283fa150	2018-03-04 21:04:07.391671-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
44e20726-6a91-411b-a38a-d2fcc3254e88	2018-03-04 21:04:07.396672-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
7db38c5e-d1ec-4161-a84f-b6c80200d8da	2018-03-04 21:04:07.400672-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
2026a3ff-33da-436e-8f59-95f10ec30c9e	2018-03-04 21:04:07.406673-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
1a32ae64-9aa3-44bb-a211-7cda10cc690e	2018-03-04 21:04:07.410673-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
a0907326-0e8a-4e56-a27e-c158b5f7efe2	2018-03-04 21:04:07.413673-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
edf946a2-7023-4f2e-a00e-8c6a48e9c4ed	2018-03-04 21:04:07.417674-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
3370a62e-ddf8-4757-b543-c4735f2b3c54	2018-03-04 21:04:07.420674-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
522ae59a-fdc2-440e-94fe-668a8f13f310	2018-03-04 21:04:07.424674-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
4a9c8f49-a70f-42e2-8423-5cf01cd1ff6e	2018-03-04 21:04:07.428675-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
82509193-3058-43f4-977c-d0ec2dad353f	2018-03-04 21:04:07.432675-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
59f0fc71-0373-403e-b247-6fa157749dac	2018-03-04 21:04:07.436676-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
a80b6fe6-1405-4ce5-9705-d95f005f7765	2018-03-04 21:04:07.441676-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
54923405-2495-4748-94a1-a3d9ba4d1793	2018-03-04 21:04:07.451677-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
2e4b9d69-0fd4-4525-a49f-479d63f7bacd	2018-03-04 21:04:07.459678-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
cfbc5ba8-7afc-4511-a2ee-fd4d7c5edeb6	2018-03-04 21:04:07.463678-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
da419c0f-283f-4d3f-af8a-3a068fe30a1e	2018-03-04 21:04:07.468679-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
b6103351-3e6e-436d-a397-71cb40c48913	2018-03-04 21:04:07.471679-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
2bb16276-aec3-4eb8-b318-c58a4dca9442	2018-03-04 21:04:07.47668-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
53b63272-9966-4b7b-a0b4-46ee1792deaf	2018-03-04 21:04:07.48068-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
a3f5eb32-6497-4d52-a87c-5588d7b656d8	2018-03-04 21:04:07.48468-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
5e0f94c9-04d6-48d2-8e94-dd3ea061521e	2018-03-04 21:04:07.489681-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
184b3267-4e96-456f-87f4-e8dd7155e4dd	2018-03-04 21:04:07.492681-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
f02bee9b-80b7-4785-a7ef-6aa79c586b37	2018-03-04 21:04:07.496682-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
7ac2a83c-4c4a-4b99-88cd-2a8dc4bb59c5	2018-03-04 21:04:07.500682-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
41fa6e37-a286-4cfe-855f-c52fa21b62b7	2018-03-04 21:04:07.505683-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
6750decb-5e46-4b74-9f6c-9622cb0321a5	2018-03-04 21:04:07.510683-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
f8816700-e98d-4f7e-9c1a-08f302b2a88f	2018-03-04 21:04:07.514683-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
cb053e7c-b408-490a-b00c-8165aa691b18	2018-03-04 21:04:07.520684-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
f5b79856-e1d8-4839-9a40-ca5ed02bdc74	2018-03-04 21:04:07.524684-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
c01c2850-4e8b-40f8-94e5-670270f28fd1	2018-03-04 21:04:07.529685-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
822e417b-545f-4ce1-8910-8dbec4284e63	2018-03-04 21:04:07.533685-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
afb15ce5-0915-424d-8603-c783b3de015f	2018-03-04 21:04:07.538686-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
d385ae86-6faa-4290-96c0-5f8dcfa126fc	2018-03-04 21:04:07.542686-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7d76bcb4-59d6-4bfe-b6ec-d76e133e8f01	2018-03-04 21:04:07.545687-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
10cb9729-79f9-4cae-9c8d-6a425607e36b	2018-03-04 21:04:07.549687-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
54b68261-7197-4852-9b1f-6b1a766c55d4	2018-03-04 21:04:07.552687-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
522b25cb-ed28-4686-9ce6-7d90c097a562	2018-03-04 21:04:07.554687-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
dd0379b0-018c-4613-942e-45263e51f702	2018-03-04 21:04:07.557688-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8477f831-ecf3-4294-a179-b729ba274e2a	2018-03-04 21:04:07.561688-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ad1c0aa2-0d18-4b4a-b15a-70c20830c015	2018-03-04 21:04:07.564688-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4c18e20b-72ae-4487-8c16-6c94eeb7f967	2018-03-04 21:04:07.567689-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fe50107f-8ab3-47a8-bd11-2c272a2d732e	2018-03-04 21:04:07.571689-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e359b559-cd9a-48ac-9889-b9c01c77dd1e	2018-03-04 21:04:07.574689-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d2932f04-f532-4df6-83b6-4b9a08c6b044	2018-03-04 21:04:07.57869-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
406bb684-8fee-4c60-b77c-1c62c88e69b4	2018-03-04 21:04:07.58169-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3512ac28-2e0b-47b3-8a94-4106bd9e2473	2018-03-04 21:04:07.58369-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cd85d766-cf0f-488f-ab5c-772df2dcfa29	2018-03-04 21:04:07.587691-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
67818e69-87a5-404b-8296-5aa38add481b	2018-03-04 21:04:07.589691-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0df0cc79-4477-4b31-9e56-860c5bb745ed	2018-03-04 21:04:07.593691-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6a407c9a-addd-48e6-8699-e7e8595583a6	2018-03-04 21:04:07.596692-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
60dda34e-5e1e-43c3-abdb-bdc804be11fa	2018-03-04 21:04:07.599692-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
a170e452-0c85-43eb-a321-b6083674c878	2018-03-04 21:04:07.602692-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
3cd52298-a38b-4130-8f38-b42452edc2c6	2018-03-04 21:04:07.605693-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
2c4e422b-4476-46de-9177-10f9d3450e77	2018-03-04 21:04:07.609693-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
c20e72c1-2de1-4ff0-a4a7-4ada07b2986c	2018-03-04 21:04:07.612693-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
8e95cca3-aa0f-4051-a1e8-6b6e64a44a41	2018-03-04 21:04:07.615694-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
a0236c9a-dfe0-457e-9fa8-53e8e70d55a0	2018-03-04 21:04:07.619694-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
7a5bc1d1-6616-46c7-9b1e-36b19931f9dc	2018-03-04 21:04:07.622694-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
fd69b246-88ce-4684-924d-9638821f86c9	2018-03-04 21:04:07.625695-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
1793fb72-3cd9-4b72-91f5-b8f4ebd29656	2018-03-04 21:04:07.628695-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
a61d06c8-e847-41da-acd3-b8ef391dbb83	2018-03-04 21:04:07.632695-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
d22947d3-2a20-4b70-902a-578a9825a2e1	2018-03-04 21:05:00.549986-06	3	[22329] IC 337A	[4] DLarrabee	[21062] a	\N	\N
efd45a44-1e24-4d47-bb49-ee97c4deae16	2018-03-04 21:05:00.808012-06	2	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
84d4c694-a4f3-47ca-ae30-5b52e2dde631	2018-03-04 21:05:00.812013-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
cf26333f-480f-4470-a4f2-817cc4e171c3	2018-03-04 21:05:00.817013-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
5c0ba2b6-2d4e-4ff7-aff6-732e75e4613b	2018-03-04 21:05:00.823014-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
7502a223-86d7-40ba-a684-4b0d6ba38a22	2018-03-04 21:05:00.827014-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
0b427e3e-a771-470c-aaf4-66be480a0006	2018-03-04 21:05:00.842016-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
743a1169-edd4-43cf-99f2-3bd229859438	2018-03-04 21:05:00.847016-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
54cb87e6-04c4-4093-bf54-062dc7dc4c36	2018-03-04 21:05:00.852017-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
c12269da-8278-42f6-aeed-b4ea83b0c58c	2018-03-04 21:05:00.855017-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
cb5c7a69-2354-4278-8f85-ec28cbdbebc8	2018-03-04 21:05:00.860017-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
6780a433-9b8e-4a6a-beda-5d957acb4e2d	2018-03-04 21:05:00.864018-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
39c671a8-0922-478b-8398-efe9afd9b456	2018-03-04 21:05:00.867018-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
64f71943-b527-4aca-b8b8-080d31a384f2	2018-03-04 21:05:00.871019-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
ced8a3af-f79c-4cb5-a47b-891cf6ff1c4f	2018-03-04 21:05:00.876019-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
73e44dd8-a6e5-41b6-8cd4-1ebb45ba26ec	2018-03-04 21:05:00.880019-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
36d92f74-beef-4d43-b81f-ca7535ba9231	2018-03-04 21:05:00.88302-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
aeb7b250-794d-4043-9045-0afa213dc4be	2018-03-04 21:05:00.88602-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
d3398def-cbe5-4f2b-8787-90822954e959	2018-03-04 21:05:00.891021-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
b46ea261-7049-404a-84a4-c88322c9a7fe	2018-03-04 21:05:00.896021-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
7c2bc268-06cd-4757-9de7-8759fdd7d271	2018-03-04 21:05:00.901022-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
a0d5ac14-3091-4ae7-a606-c584af6d0258	2018-03-04 21:05:00.906022-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
8ebd1e8a-a99d-48eb-ae48-a78b766b0443	2018-03-04 21:05:00.909022-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
5dfaa0b3-4b38-424b-9aea-736f32332296	2018-03-04 21:05:00.913023-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
5aecd846-f215-49e2-b0f6-74bb809fcdf7	2018-03-04 21:05:00.917023-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
014c9fb5-39de-40a8-a6ff-91f1ee7c3909	2018-03-04 21:05:00.921024-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
fe00622c-b963-4714-a4a0-a075509ee18a	2018-03-04 21:05:00.926024-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
5a080ccf-0494-4397-94c4-30b9fe015e7d	2018-03-04 21:05:00.930024-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
398906d7-7679-4c4e-95aa-2254d70990a8	2018-03-04 21:05:00.934025-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
7cdeef00-7cbf-4e71-bc5a-c31706b4681c	2018-03-04 21:05:00.940025-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
be70787b-3636-4cdc-8370-3015be96ee23	2018-03-04 21:05:00.945026-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
dc966059-91b3-4a47-92ad-d7279e39f6d6	2018-03-04 21:05:00.949026-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
15ede81b-dba1-479e-8875-f0316da420dc	2018-03-04 21:05:00.953027-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
1c1d71a8-98dd-4f53-b6d9-ea0e63a9ea8a	2018-03-04 21:05:00.957027-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
d87e1080-b370-44f7-9c28-10cadec1310a	2018-03-04 21:05:00.962028-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
d8e13d62-70b1-447a-97e7-7ac5d95a32d0	2018-03-04 21:05:00.966028-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
cc9beb7a-3190-4993-9093-52317fffe5e6	2018-03-04 21:05:00.970028-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
657ec54e-a993-49ba-9f41-b5b8272088f9	2018-03-04 21:05:00.974029-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
bc873005-07f1-43d2-97ac-b80b397f417b	2018-03-04 21:05:00.979029-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
43139999-e361-4950-a5f3-4a2d0ec297e8	2018-03-04 21:05:00.98303-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
f862c128-7175-41ca-870e-c874426828fc	2018-03-04 21:05:00.98703-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
3cf22d24-3830-44b2-8878-f774c35c89dd	2018-03-04 21:05:00.991031-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
d077da98-cdff-446a-abdd-1bd068f6c9d2	2018-03-04 21:05:00.995031-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
e6b12c8b-13c2-4f62-87dd-a3041733df48	2018-03-04 21:05:00.999031-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
e1984d16-f121-47a2-8f46-b64865049906	2018-03-04 21:05:01.003032-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
e0bba1cd-ecd7-4961-8b78-8c063ac7dd90	2018-03-04 21:05:01.007032-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9e7b04bf-1d90-452e-894d-083149b2060c	2018-03-04 21:05:01.010032-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
45069296-808a-4246-a97c-b69f77965f28	2018-03-04 21:05:01.014033-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9b54d811-2c87-4e4c-85e6-70ad4a8ee091	2018-03-04 21:05:01.016033-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3d45edb2-08c4-48f1-846c-dad5f9daea73	2018-03-04 21:05:01.020033-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c97e26fa-5099-4deb-8975-170d0e4d5495	2018-03-04 21:05:01.023034-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
94db9cab-a917-4ec3-b839-03011095bb10	2018-03-04 21:05:01.027034-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
92dde7a9-9a25-4938-b147-6baf7db37885	2018-03-04 21:05:01.030034-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a6127103-03c3-4cc5-a8f8-25c08b3287e4	2018-03-04 21:05:01.033035-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1f4cf73c-1378-4650-bbfa-9f281d3c42ab	2018-03-04 21:05:01.037035-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
342f3b55-1fd1-4ab6-89b3-32b22ccb21f6	2018-03-04 21:05:01.040035-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7b5b5ab5-a1cd-4049-849d-aa86e90edbb5	2018-03-04 21:05:01.044036-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
740d9692-c1c4-4108-bed0-bb7e592cc7bb	2018-03-04 21:05:01.048036-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6ee258a7-cd5f-4168-93dc-6db8ececa297	2018-03-04 21:05:01.051037-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e809dcb6-c8c1-4d86-b5d4-a7882f5bbdb1	2018-03-04 21:05:01.056037-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
22b01bbb-7528-4908-8c37-0b36539c177a	2018-03-04 21:05:01.060037-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
83eeb8bd-603b-4c9a-b54d-fd3e9c72df9e	2018-03-04 21:05:01.063038-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
934b12e6-d997-4a8a-a799-c99a1ec1e7dc	2018-03-04 21:05:01.067038-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d2159094-159c-44a5-8b9e-10dc77996863	2018-03-04 21:05:01.071039-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
acaa1d62-e898-47b0-9f67-7a0d48614584	2018-03-04 21:05:01.074039-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
810cdab2-1211-4582-a47f-efe2b6156f71	2018-03-04 21:05:01.078039-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
52328620-8797-4287-b868-2b20477fa51b	2018-03-04 21:05:01.08204-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
e1552920-21a4-4123-bc41-32c3f90a2f50	2018-03-04 21:05:01.08604-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
7ea72d46-9e66-4428-b580-8e5ed4eee821	2018-03-04 21:05:01.08904-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
ddd281b1-fba8-482b-834b-1fb8851476b4	2018-03-04 21:05:01.094041-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
44be30ab-d242-4b7a-9f08-106c7d4b0c4c	2018-03-04 21:05:01.098041-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
b68874fb-b0a2-4df7-b897-5154f5512449	2018-03-04 21:05:01.102042-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
db719212-c726-4ee9-b658-fa05980e9c9d	2018-03-04 21:05:01.106042-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
772e35f6-36e8-436b-95c7-9a42018397ed	2018-03-04 21:05:01.109042-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
8bceddf3-648d-448d-b0b7-568232e32eec	2018-03-04 21:05:13.468278-06	3	[22330] IC 337A-outB	[4] DLarrabee	[21062] a	\N	\N
4c54bc1e-343e-46f8-9054-bc50ce7ecce2	2018-03-04 21:05:13.733305-06	2	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
ec2a918e-35e8-4f16-80f9-c5536a17de08	2018-03-04 21:05:13.738305-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
0dbd8113-6893-4ecd-871d-32d7bd746459	2018-03-04 21:05:13.743306-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
e3389f38-ba80-437a-a71c-ae4d8761e6c6	2018-03-04 21:05:13.748306-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
8968e04f-1ff4-4dcd-899b-6e364129b049	2018-03-04 21:05:13.752307-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
6ef98433-8287-46f0-8528-a2a878626cb6	2018-03-04 21:05:13.757307-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
95e93090-9e8f-4a0b-9ab6-ec7bc65c004e	2018-03-04 21:05:13.761307-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
2c02062b-a500-4768-a0fe-118e8ada5518	2018-03-04 21:05:13.765308-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
94dc8a04-c758-4f48-b328-ff0d8ef7ea0e	2018-03-04 21:05:13.769308-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
d28014b3-52bc-46f3-9d59-f10f5b78a482	2018-03-04 21:05:13.772309-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
d484772e-b55c-481a-ab57-6a9928b74559	2018-03-04 21:05:13.776309-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
9788874a-49f5-4681-9a05-48232e635127	2018-03-04 21:05:13.780309-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
c7109e48-26dd-4b80-a1e4-d8be3d9c4e50	2018-03-04 21:05:13.78431-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
1b017cc7-de4f-4093-a1aa-308bbc12189a	2018-03-04 21:05:13.78731-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
5cfa47fe-e849-488d-9598-ac770a1d1eba	2018-03-04 21:05:13.79131-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
cf4f3936-e306-409d-89bd-46fe9a098fc6	2018-03-04 21:05:13.795311-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
fc053da8-e111-4ec8-9b08-4bdd24c7f4f6	2018-03-04 21:05:13.800311-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
1773151e-82d1-406a-b7bd-e653935afe2c	2018-03-04 21:05:13.805312-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
ec0dc9e5-3e1b-43bf-8207-6694ed69c271	2018-03-04 21:05:13.809312-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
1f8c9cb9-7655-46e6-9694-2fa12a78e89a	2018-03-04 21:05:13.814313-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
4df385fd-1c76-4966-8a22-58c412755f39	2018-03-04 21:05:13.819313-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
0dbf0f92-27ef-40da-a412-672dd46a7e22	2018-03-04 21:05:13.824314-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
7df4e5d1-5408-48c1-99d6-9364718b2e16	2018-03-04 21:05:13.829314-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
fb20ea6b-d132-4650-b036-b8364054fd05	2018-03-04 21:05:13.833315-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
f14bd884-ed51-4e5a-aec4-617900086c63	2018-03-04 21:05:13.838315-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
0dd5edeb-039a-4d46-b3b3-e144e5f17cc1	2018-03-04 21:05:13.841315-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
f2b78adb-81a0-40f4-8149-c29c4440e266	2018-03-04 21:05:13.845316-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
15f5c6b4-c5a6-441e-a135-6dcf75d4d2e1	2018-03-04 21:05:13.850316-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
22d51c28-89e3-41dd-a634-375d0be66baf	2018-03-04 21:05:13.854317-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
eb57cd18-21ae-4742-b938-646c75152815	2018-03-04 21:05:13.858317-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
58b83362-eca3-4f10-bba2-f7b6819c7dfd	2018-03-04 21:05:13.863318-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
4caf5cab-ecec-4224-b799-5864d87139d2	2018-03-04 21:05:13.867318-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
f3ad702a-dbdd-4b60-9f87-e9a08097cf4f	2018-03-04 21:05:13.871318-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
1c04dd45-772c-463c-8823-5807d012f884	2018-03-04 21:05:13.876319-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
dd9500ff-424d-4f4f-95da-d4de0ade68a5	2018-03-04 21:05:13.880319-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
1be3a440-e9a4-476f-92ee-62431cf260e0	2018-03-04 21:05:13.88432-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
6e4f760d-7459-447d-a706-0838008bc58b	2018-03-04 21:05:13.88832-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
b2b93476-1525-458c-b207-a4df08b343f8	2018-03-04 21:05:13.89132-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
a3f8916c-514d-4982-aef6-f9f96a9fcd61	2018-03-04 21:05:13.896321-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
3801add1-b7d5-4486-a058-55e72d6f18b7	2018-03-04 21:05:13.900321-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
2b03a406-023b-44cd-a965-693db9b69676	2018-03-04 21:05:13.905322-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
64d7650b-b7b7-476c-a178-cd8e10323220	2018-03-04 21:05:13.910322-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
cd780ed3-1615-4094-ace8-b8d1e26bccd8	2018-03-04 21:05:13.914323-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
a4f498d4-05a9-49b7-ab01-c49cccce2442	2018-03-04 21:05:13.917323-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
316e7c17-5a9c-4fd9-a395-b9862c2447b6	2018-03-04 21:05:13.920323-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2247b137-457d-4f05-8213-c0eb829aefdd	2018-03-04 21:05:13.923324-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
707a0c7f-66e5-43f4-bd29-0594d862899e	2018-03-04 21:05:13.927324-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
37aa469a-98a2-428a-bb14-72ae495462b0	2018-03-04 21:05:13.929324-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e0ac101d-bf79-49a0-abd0-bec4db803fb2	2018-03-04 21:05:13.933325-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2e36c376-19a3-4829-957d-c310a5752261	2018-03-04 21:05:13.937325-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9c526faf-d9b8-4c09-9f36-6a2b1a54ab8e	2018-03-04 21:05:13.939325-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f2ca6719-5639-462c-be2b-a9a6d1fe0c8f	2018-03-04 21:05:13.942326-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
31599165-baa6-41b6-ab1c-4e18271c4d56	2018-03-04 21:05:13.944326-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
447ef2e2-65a1-4415-bc9f-4ed4acb7c4d0	2018-03-04 21:05:13.947326-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
16064a02-069c-4e05-ba9b-ffce201f0143	2018-03-04 21:05:13.951326-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
303d5a58-7f88-400e-b90f-28ef918ad3a8	2018-03-04 21:05:13.955327-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
199d5587-d780-44ca-b62a-bea40aabc089	2018-03-04 21:05:13.958327-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
059fcd91-f23e-4f73-b57d-8125b3278e3e	2018-03-04 21:05:13.960327-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
02a575a3-a2ef-4f28-94fc-8ba19d7251bc	2018-03-04 21:05:13.963328-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
dbe6a1e4-3a4a-4937-ac00-60eaf85b118e	2018-03-04 21:05:13.966328-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8e04583c-4737-490f-b422-8a057158810a	2018-03-04 21:05:13.969328-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
971d076a-f574-492d-b2d4-47240addb5fa	2018-03-04 21:05:13.973329-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
c7ee49d1-4d88-46e7-bfb3-849e39fe83f3	2018-03-04 21:05:13.976329-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
2b0411b6-3eb3-487c-b2e9-3239a959b4db	2018-03-04 21:05:13.979329-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
2fd01902-f5d5-4bab-92b7-80f74da36d40	2018-03-04 21:05:13.98333-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
b439bf1b-9963-49c4-9e80-7ef7638fcf5f	2018-03-04 21:05:13.98533-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
8987cb38-5c2e-42a0-9eb2-cdebe4895aa9	2018-03-04 21:05:13.98833-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
6d5e06df-6397-49f0-ad6d-c40cdd2a68c3	2018-03-04 21:05:13.992331-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
c637d6fd-6714-49c7-9bf3-453446d8b6b8	2018-03-04 21:05:13.996331-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
83296ce0-1ab2-4292-a9ce-4f05e236112b	2018-03-04 21:05:14.000331-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
f3791546-40c0-4e11-be4f-03e9cd5ca64b	2018-03-04 21:05:14.003332-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
362ddeeb-9af9-4871-89cb-fddfe1a023e5	2018-03-04 21:05:14.007332-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
b086fd8c-66db-443f-ae66-e134279af131	2018-03-04 21:05:24.743406-06	3	[22331] IC 338A	[4] DLarrabee	[21062] a	\N	\N
1317b371-f1b8-4345-b55b-213d79101c26	2018-03-04 21:05:25.002431-06	2	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
0ffcde66-73d8-47e6-9ae3-3c6211cbf088	2018-03-04 21:05:25.007432-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
3d29a9ab-23f6-4ff6-840a-e49510f6f66c	2018-03-04 21:05:25.011432-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
71b45cb9-e910-4c32-bae3-bccc2e219c77	2018-03-04 21:05:25.016433-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
8e5a43f4-129c-4cb5-ba4b-6e25c8bc2e45	2018-03-04 21:05:25.020433-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
8f667b90-2607-422a-a12e-e6d175516fd4	2018-03-04 21:05:25.025434-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
b73b3eb4-f5fa-466c-88b5-a75ced2811bd	2018-03-04 21:05:25.029434-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
ec0751f7-7d7f-43b8-9b00-a33149876bb0	2018-03-04 21:05:25.033435-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
4d9d3c40-924f-445f-a9f1-3449632e42bf	2018-03-04 21:05:25.038435-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
3da9a085-c6d3-4fd7-976a-b05692f9623d	2018-03-04 21:05:25.041435-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
2e440bfc-6d55-4a9a-9dc1-2418764b86b5	2018-03-04 21:05:25.046436-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
8e58d56b-a0b4-4047-9752-ec4b7a51bd24	2018-03-04 21:05:25.050436-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
d74fa557-8528-4ea0-9368-8a5ddfe3f930	2018-03-04 21:05:25.055437-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
ec64aed4-142c-4b7d-8ee6-02394e3036dc	2018-03-04 21:05:25.058437-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
c5ad1697-b72e-433d-918e-15a6b6361965	2018-03-04 21:05:25.063438-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
833583e9-4cd2-4a50-a2ee-ab853380c074	2018-03-04 21:05:25.067438-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
61b60b71-f5d5-4f49-82d8-d285d8e51871	2018-03-04 21:05:25.071438-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
3de6b0cd-13e5-4937-9a49-e79501e458b8	2018-03-04 21:05:25.074439-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
6cd4f5df-fc9f-4474-93ec-8ec2eedd0e84	2018-03-04 21:05:25.078439-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
de3a21d3-e1f0-40c9-80c2-9c30df5a465b	2018-03-04 21:05:25.082439-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
55eec16c-f499-481d-8731-ded569592841	2018-03-04 21:05:25.08744-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
4365bc5d-1cb8-4874-9ab6-0b1744d24d6b	2018-03-04 21:05:25.09144-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
79b55563-c902-4d19-b653-e0419eccf005	2018-03-04 21:05:25.096441-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
b2283737-4791-4b01-8528-612de0c06fa9	2018-03-04 21:05:25.100441-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
2c7973db-9b34-4b13-887e-5dfc9657e0a4	2018-03-04 21:05:25.104442-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
b921af98-09ac-48a2-b0c2-abd1fa86da95	2018-03-04 21:05:25.108442-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
fdefd049-01c9-4278-a78e-cf6469d43fda	2018-03-04 21:05:25.112442-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
50e9f132-39f7-493b-bb9d-47c024d3f24d	2018-03-04 21:05:25.116443-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
454810c7-8dea-4245-9246-37d018bfa785	2018-03-04 21:05:25.120443-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
3c463323-7fc7-4384-9fbe-7dae148b1b0d	2018-03-04 21:05:25.124444-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
7b73e459-5658-49e0-a30a-fe45e838260b	2018-03-04 21:05:25.129444-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
f7ce9d1e-5312-4dc8-98a2-c7d55a59a332	2018-03-04 21:05:25.132444-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
138bf6ed-563c-4f4c-8ac4-cea0c2bbbc38	2018-03-04 21:05:25.136445-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
c73026ae-225f-45c5-8a8d-d6ebe65dd4ac	2018-03-04 21:05:25.139445-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
f50d5a1c-88c3-4f3d-93d9-d324edc722e6	2018-03-04 21:05:25.144446-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
b745e9ed-8737-4e3b-a3b9-e8a05de94867	2018-03-04 21:05:25.149446-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
87790462-f29b-4498-913f-464a56dfff7d	2018-03-04 21:05:25.153447-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
51b346ff-f3ec-450b-99b0-5a3253d6893d	2018-03-04 21:05:25.159447-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
0b166af3-e2a2-4d0b-9833-270b2692bd4a	2018-03-04 21:05:25.163448-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
8e1cd988-68fd-45d0-847d-f3f7dca542c6	2018-03-04 21:05:25.167448-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
8e81e438-2e14-46ec-82e6-eafeb414f05f	2018-03-04 21:05:25.171448-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
34be964f-2bba-461c-95fb-b6eb6c9f068d	2018-03-04 21:05:25.176449-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
51d740c3-cf4e-4a7c-acf5-b01919df49f2	2018-03-04 21:05:25.179449-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4df6fbb0-7158-494b-bb88-39b0a205d304	2018-03-04 21:05:25.181449-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2a1bd52c-5ef6-4706-b0dc-9e9d4ae6885e	2018-03-04 21:05:25.18445-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c03c3829-4f99-4bc5-9ece-1517abd02f52	2018-03-04 21:05:25.18745-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
55e3c282-d9cd-4d15-8524-c6675811b4a3	2018-03-04 21:05:25.18945-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3ca250f3-4fd0-492a-b986-b1bff023b7d2	2018-03-04 21:05:25.19245-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c9535736-3352-4879-b7dd-9c5c276ba65b	2018-03-04 21:05:25.195451-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4f8dab49-d8ff-4788-b562-a1caff2b442a	2018-03-04 21:05:25.198451-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7a7aa7a2-aebb-43d0-8b6c-f932c7552584	2018-03-04 21:05:25.200451-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
876760ba-e443-4623-b237-03638b806310	2018-03-04 21:05:25.202451-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
36b24369-393c-4ea4-812c-b18e3cebf338	2018-03-04 21:05:25.206452-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f2ff31b9-fc6d-4aa8-9a01-19a003c95714	2018-03-04 21:05:25.210452-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6a12f9d9-2968-4d6f-8d95-95720eaf78c3	2018-03-04 21:05:25.213453-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a9c28e70-a5a0-462f-8c14-a4095e8ec4e3	2018-03-04 21:05:25.217453-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9592b9c5-f41d-4aa4-8895-a347480c0cce	2018-03-04 21:05:25.220453-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6178b994-a79e-4900-81a3-f358d8cc17bc	2018-03-04 21:05:25.223454-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5d3b57e8-ac37-43f0-bc3a-fc73c269c12a	2018-03-04 21:05:25.226454-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
953ad535-465e-4749-add0-2ea59138f956	2018-03-04 21:05:25.230454-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f8d6218f-0cc9-41fc-b9d1-170afdfec4a5	2018-03-04 21:05:25.234455-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
c416b9d3-081f-420a-bad5-1aa5f5a8c537	2018-03-04 21:05:25.236455-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
74398cc2-688c-4002-9550-d40257d385c7	2018-03-04 21:05:25.239455-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
0b30db0b-f80c-4d65-bfdf-90308d7ed279	2018-03-04 21:05:25.243456-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
749a71d7-c951-4b58-a873-ff94ef99b4ad	2018-03-04 21:05:25.246456-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
81885b49-c961-46ef-9ac9-0b1517d36040	2018-03-04 21:05:25.250456-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
26fb7f37-5476-4de9-a417-687ba32429f2	2018-03-04 21:05:25.254457-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
24000707-a666-47eb-81be-c4f4e2dea973	2018-03-04 21:05:25.257457-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
8a3bf89e-419d-477c-86c0-079b4b370e53	2018-03-04 21:05:25.259457-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
fea9f5b6-b5dd-4807-a9f3-a5e6a4de660c	2018-03-04 21:05:25.263458-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
0df0adc1-8212-4481-96f6-750f7ae856eb	2018-03-04 21:05:25.267458-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
60d514b9-791c-46e7-a494-f9581731e4c0	2018-03-04 21:05:54.982429-06	2	[21216] Floorplan	[21041] OSSI-DNOVAK	[293] master	\N	\N
1d0b8f79-9875-4746-92fa-419912b7e90b	2018-03-04 21:06:15.49748-06	3	[22332] IC 338A-outB	[4] DLarrabee	[21062] a	\N	\N
3d30ba87-b5b2-49ac-ad78-a54f933f605c	2018-03-04 21:06:15.767507-06	2	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
5e85ae02-be9c-40e0-9c96-0ab75778e61f	2018-03-04 21:06:15.772508-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
077646b6-04c6-439d-b805-1c7bf9105952	2018-03-04 21:06:15.776508-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
c96919be-2598-4e11-a598-c507efab5642	2018-03-04 21:06:15.780509-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
8fa435cf-11be-420b-9f82-3b5bd9b8bce1	2018-03-04 21:06:15.785509-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
1a103320-cca2-4489-8b46-25f839f0cab5	2018-03-04 21:06:15.78951-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
725d899e-1049-4acd-9253-6463e26ce996	2018-03-04 21:06:15.79351-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
cbd43d11-0449-4ce0-9a1e-b412ad0af28a	2018-03-04 21:06:15.801511-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
a95bddc3-90ed-41d0-86ea-b2d7d04add3b	2018-03-04 21:06:15.805511-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
5b82978f-0299-4c02-beed-77efb3bce2a1	2018-03-04 21:06:15.810512-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
2a185764-1715-44f2-9cd9-8e582f7bfca1	2018-03-04 21:06:15.815512-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
1e6a1c44-ac80-4d29-bb12-8fb59f8c53b8	2018-03-04 21:06:15.820513-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
12f09f1f-3022-4d88-acf6-4097e4b7b65b	2018-03-04 21:06:15.824513-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
a6e9f798-3111-4ae5-8550-3cf4dbdfbe3f	2018-03-04 21:06:15.829514-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
26cd818f-5cfe-4215-915c-3ca51461a4ef	2018-03-04 21:06:15.833514-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
4d74fc42-23d3-4020-a0c9-2404420a6aa7	2018-03-04 21:06:15.840515-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
af6d50f2-54cd-4747-92a8-a5bafb6487fe	2018-03-04 21:06:15.844515-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
b0c4939c-e17b-44e3-a41a-1ceddae846c3	2018-03-04 21:06:15.849516-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
0f60f6c9-48ae-4158-b8c9-8d71bee25032	2018-03-04 21:06:15.853516-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
db72aebb-d6d1-4f81-9221-52f624c281ff	2018-03-04 21:06:15.858517-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
182fbb2c-7ef4-4e34-b5b6-ff39b6d02112	2018-03-04 21:06:15.863517-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
543713df-6925-4217-93ec-3b326fff06d7	2018-03-04 21:06:15.866517-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
d1735af9-14b5-41f9-8bfa-4e49f3c779da	2018-03-04 21:06:15.873518-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
ac4baaf1-2ac5-4e89-8678-85edc8b1118b	2018-03-04 21:06:15.877518-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
6c03a618-6508-4b64-a801-cfbfb3671ea2	2018-03-04 21:06:15.882519-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
736318d3-54c4-46d1-8cbe-953eff26473c	2018-03-04 21:06:15.886519-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
ab0faa77-c4cd-4ebc-81e4-d18f751bd96a	2018-03-04 21:06:15.89052-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
76a71bae-25b7-47e2-ba23-428f53db2afc	2018-03-04 21:06:15.89552-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
463ec82a-02b1-4f39-8baa-a6cbca36f8aa	2018-03-04 21:06:15.900521-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
9ad51eb4-2a2a-441e-ab95-2e20b109b113	2018-03-04 21:06:15.907521-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
e5c06bcb-06e3-45c4-b8a9-e1b56932fad0	2018-03-04 21:06:15.911522-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
7b175b55-6747-4b6e-9423-c42d568c7095	2018-03-04 21:06:15.915522-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
5c7be157-26ec-4712-b4fa-888371297d79	2018-03-04 21:06:15.920523-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
1962ee3a-fba0-49ca-988b-67dc34818332	2018-03-04 21:06:15.924523-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
ee93a13a-29be-4123-b5ca-42fd54b5aecb	2018-03-04 21:06:15.929524-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
d02d0657-7e62-40df-bb9c-3eeae5fa7f46	2018-03-04 21:06:15.933524-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
a280caaa-1698-46ff-8e79-4144ccb0f257	2018-03-04 21:06:15.939525-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
bee899ee-a761-49ba-a1fa-b32075171c53	2018-03-04 21:06:15.942525-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
d175adf6-baf7-487b-b3ed-2d5cb6af2493	2018-03-04 21:06:15.945525-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
abb3fff7-bb2d-4fc8-aaf1-d58a6ebe04b4	2018-03-04 21:06:15.949526-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
bdc305fc-8b2b-4f22-b0c0-05478704da25	2018-03-04 21:06:15.953526-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
e4cabc57-7d4a-4c31-8113-228dc260fc60	2018-03-04 21:06:15.955526-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
34a8b356-1e78-45f9-bd45-3ae7818b1be4	2018-03-04 21:06:15.958527-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
beeeb702-01f1-4c45-9b6c-0e6aee6bebab	2018-03-04 21:06:15.962527-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cfb677d4-34ff-40df-9af9-3585c47dd455	2018-03-04 21:06:15.965527-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
99f3412a-7100-4f83-a071-e4ed2ba8f073	2018-03-04 21:06:15.969528-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ab2e87fc-5044-43ca-9468-e7a694c96ff6	2018-03-04 21:06:15.972528-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
75d59f00-c6e9-40e2-bb6d-593630bc0b7f	2018-03-04 21:06:15.978529-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
289ca376-0c37-4f0e-8bcd-0ae2ad435a5f	2018-03-04 21:06:15.981529-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
07e75b15-6ab3-40c8-b46a-556a730f4371	2018-03-04 21:06:15.985529-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
592acd45-ce8e-4dc9-81ab-0a032b8981d5	2018-03-04 21:06:15.98853-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
77ffa7dc-b2fb-4473-8a38-16cae13f8460	2018-03-04 21:06:15.99153-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4a8f3648-4e4e-45ce-a006-da3d6fc74663	2018-03-04 21:06:15.99453-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2d08fa6a-f2dd-4c2c-a70e-6c005b87e9df	2018-03-04 21:06:15.998531-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
72410d6f-cd94-4712-ae68-3799f818b5cc	2018-03-04 21:06:16.001531-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2efc2a50-7849-40bd-b514-057782d6b760	2018-03-04 21:06:16.003531-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
bd4f9adf-2dc1-4eb8-b63d-af9298ae78f1	2018-03-04 21:06:16.007531-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1d8eb2e7-e4a4-49cb-90a5-3ca0ed88af44	2018-03-04 21:06:16.010532-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c7bfa3de-9b8e-43e4-a1ed-2ca3b5b2b384	2018-03-04 21:06:16.013532-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
11e07e6c-eaa2-4db8-80ac-aee52468d826	2018-03-04 21:06:16.017532-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
a74502e5-dc2a-41b5-b907-70a67ca2c4c8	2018-03-04 21:06:16.020533-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
f89304b1-ad94-40c9-9ca7-ad0ec35e3610	2018-03-04 21:06:16.025533-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
adbebc84-4aa1-4aff-a035-f947578b3153	2018-03-04 21:06:16.028534-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
8a0f5cd3-c02e-4a31-933b-eb6dff206734	2018-03-04 21:06:16.032534-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
0a07d6d4-3366-455a-90d5-c55cedf6cea3	2018-03-04 21:06:16.036534-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
87c9fc34-51f2-409b-9376-44713e190563	2018-03-04 21:06:16.039535-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
4286264d-b50b-4435-bd2d-36845fac02c0	2018-03-04 21:06:16.042535-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
4d3b357d-2859-463b-8d17-ef5774041444	2018-03-04 21:06:16.046535-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
5676f979-00a1-4e11-819e-2c73accc7dde	2018-03-04 21:06:16.049536-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
621deda8-bd28-49a8-9870-4c05b4224a30	2018-03-04 21:06:16.053536-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
587a44b6-4864-4e5c-a6fe-4d8068e613be	2018-03-04 21:06:34.89042-06	3	[22333] IC 343A	[4] DLarrabee	[21062] a	\N	\N
6ed89fe9-5646-4575-8405-850dd7f874a4	2018-03-04 21:06:35.184449-06	2	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
e27af1a0-77ba-45f9-b0e0-fbd2cb84e769	2018-03-04 21:06:35.188449-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
a24c07fb-fe2b-40ca-a2a6-79a7671c36eb	2018-03-04 21:06:35.19345-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
78d09f05-02ad-4924-9738-71098e4b65fb	2018-03-04 21:06:35.19845-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
7f677738-6be8-4d9b-9bc7-5709a89dc28c	2018-03-04 21:06:35.202451-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
dd2344e8-06da-40d3-a269-aa27ff24f144	2018-03-04 21:06:35.206451-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
2f74e13f-2fe6-481c-93fa-760ded88eeeb	2018-03-04 21:06:35.209451-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
7c66496e-f011-4561-ad5b-4d5ca7064553	2018-03-04 21:06:35.217452-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
40e5aa87-4f44-4805-84e0-173343d6f7f0	2018-03-04 21:06:35.221453-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
2ea7e563-7661-4527-ac14-ec3d4d4b5c91	2018-03-04 21:06:35.226453-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
cda96f99-0817-48da-b60f-0c04b27d9e53	2018-03-04 21:06:35.230454-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
e3bc7149-e411-4eeb-a024-3e42548af4c0	2018-03-04 21:06:35.236454-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
76fd98cd-20d9-4347-a0d8-eb8c7699fcca	2018-03-04 21:06:35.240455-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
fbac140e-44a5-4e41-b35b-60f99e097207	2018-03-04 21:06:35.245455-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
c674bdfb-c667-414f-a2aa-4f0ee759bcb1	2018-03-04 21:06:35.249455-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
1545f8d5-afae-4567-8024-20970d058ff8	2018-03-04 21:06:35.255456-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
4e238253-97da-4d03-a2a2-64dc74a526d1	2018-03-04 21:06:35.259456-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
45acbe66-5fc3-421d-b4e0-398478ebe4c0	2018-03-04 21:06:35.262457-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
c1585c3c-62d0-4201-860f-70efd1b93cd2	2018-03-04 21:06:35.265457-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
aa670543-85f9-40fc-af3b-26ec04af126e	2018-03-04 21:06:35.269457-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
3db5aece-c377-4253-90a2-e1ad27d05e46	2018-03-04 21:06:35.273458-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
98d7fb8b-7ae7-4603-b684-29d0aa28bd49	2018-03-04 21:06:35.276458-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
c8805860-7a2d-4451-826c-326cbd81c28f	2018-03-04 21:06:35.284459-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
b50bed91-315c-4239-a2f9-7dbcf7f143b9	2018-03-04 21:06:35.288459-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
7358fa71-10c4-4750-bac1-e0677678d13a	2018-03-04 21:06:35.29246-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
ce1ae142-594c-4e50-9f68-c6d0147eb07b	2018-03-04 21:06:35.29746-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
b85f5a2e-8934-4e83-91fa-37aa49196bac	2018-03-04 21:06:35.301461-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
847b6f79-3781-47b7-a154-23a89e61d25f	2018-03-04 21:06:35.305461-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
3db2a7a9-47f3-412e-a983-483e18c6066a	2018-03-04 21:06:35.309461-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
c88ba192-c00f-4442-91e0-602cdcc0a875	2018-03-04 21:06:35.315462-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
6421b05c-3108-417e-97bf-df55739b9ff3	2018-03-04 21:06:35.319462-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
4d4b7510-17b5-492d-ab5c-d833c66c5fc5	2018-03-04 21:06:35.323463-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
7219bf33-9406-4e72-a860-7beed7d741b3	2018-03-04 21:06:35.327463-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
5db1c2d5-870d-4647-b2bc-fc59f49078d2	2018-03-04 21:06:35.331464-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
075cede2-c85a-4a2d-b4df-5bb232b5194f	2018-03-04 21:06:35.335464-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
7e6b5959-8e71-4ae4-ad39-16fd3317d72e	2018-03-04 21:06:35.338464-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
ed388b03-5caf-4394-840b-c35114909904	2018-03-04 21:06:35.342465-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
c6011424-5351-4b0b-b9e9-8973dbff1f79	2018-03-04 21:06:35.349465-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
509b3aaa-a090-4127-9c06-82056f36db8b	2018-03-04 21:06:35.354466-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
253580c3-67c4-47f8-8f40-edee63207582	2018-03-04 21:06:35.358466-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
db4358a0-5844-458f-91a7-b56688f61084	2018-03-04 21:06:35.361467-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e656ed76-b129-460e-ae8b-94e347c9b035	2018-03-04 21:06:35.364467-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
06b64434-fdff-407a-be84-88d11fd6d98d	2018-03-04 21:06:35.367467-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9f791041-0709-4e8f-ace9-226d6ba4d9b8	2018-03-04 21:06:35.370468-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a29a07d5-6f7c-4a76-be83-f15cc9fb106f	2018-03-04 21:06:35.374468-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6f0fd67a-eb2f-498a-b205-f9669725724a	2018-03-04 21:06:35.377468-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
db09e26e-3162-4bc0-ba39-9963d4e0f720	2018-03-04 21:06:35.381469-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8de97406-1796-40cc-b0f2-3e330d66e309	2018-03-04 21:06:35.383469-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
96f2a25b-3eda-4429-a16a-81fcedd2701a	2018-03-04 21:06:35.39047-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7d7ec3d5-f554-48c4-a15b-cb6c8323adca	2018-03-04 21:06:35.39347-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2b76457e-25d8-4a0a-8bd6-4c7885b8467d	2018-03-04 21:06:35.39647-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
61d4059d-fe8d-4e90-b668-37fa7263965b	2018-03-04 21:06:35.400471-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9403c3d9-4887-43d5-bc6e-7ff175552981	2018-03-04 21:06:35.403471-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8f9813f3-aaeb-4c89-ac62-9b57a41b551b	2018-03-04 21:06:35.405471-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
bb087f31-343a-4d0e-aeb8-b3fdbaa9403d	2018-03-04 21:06:35.409471-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
27fc7ba4-b4f5-4978-b1be-67bf3ff07ea8	2018-03-04 21:06:35.412472-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7e1cd0c6-8b0f-4f56-bdce-59f6a06f97ff	2018-03-04 21:06:35.416472-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a621cbc7-df18-4d18-baeb-c3cb3556c44c	2018-03-04 21:06:35.418472-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a0929337-11b4-4d54-9c3f-b026bc931ed7	2018-03-04 21:06:35.421473-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
c34fe41a-e161-4236-8aa5-3f5d2c71238d	2018-03-04 21:06:35.424473-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
e3340565-c1d2-4c4e-b0a1-c3a03250e1ba	2018-03-04 21:06:35.426473-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
2d816574-598a-4211-9067-f3ae72e75180	2018-03-04 21:06:35.429473-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
0988a7cf-6469-41da-9a95-a90edb05a319	2018-03-04 21:06:35.434474-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
a12e8949-84e2-4df9-a5d5-3fd352863de0	2018-03-04 21:06:35.438474-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
f311d174-e8a5-43f8-8235-6ae3289e439e	2018-03-04 21:06:35.442475-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
ff9f1247-7165-498c-b948-4d8d249b73c4	2018-03-04 21:06:35.445475-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
12af9266-8749-4922-9e99-17506c89bf91	2018-03-04 21:06:35.448475-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
e477f207-5a3f-46e6-980b-99853018753b	2018-03-04 21:06:35.452476-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
89840c6f-31e2-420d-ac27-0f706b7e7efa	2018-03-04 21:06:35.456476-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
13e64c22-95e7-4a39-aede-3bf5bd894d38	2018-03-04 21:06:49.447875-06	3	[22334] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
316c8c18-5f0e-49a4-a6f3-8f704a163c31	2018-03-04 21:06:49.720902-06	2	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
b7a3c94b-f272-476b-91c8-54f514d07fce	2018-03-04 21:06:49.725903-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
bc57be74-0ceb-4037-8f38-52706a627181	2018-03-04 21:06:49.729903-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
5becf8a2-1172-4a90-b79b-3c6aeff83cdf	2018-03-04 21:06:49.738904-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
a91162cc-28fe-4493-a1cd-b829de43b84d	2018-03-04 21:06:49.742905-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
6dd423ed-e704-40b9-a377-1f84b0d83296	2018-03-04 21:06:49.747905-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
c1df8476-3c60-432b-82ae-65e47ae904a1	2018-03-04 21:06:49.751906-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
e481d3a9-75c8-4187-aaae-1fc176a86087	2018-03-04 21:06:49.756906-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
ae2a2bba-cb68-4e35-90bd-c82ab2c0595e	2018-03-04 21:06:49.760906-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
c5b30c15-fc85-4ade-ac2c-4bd65eb2d999	2018-03-04 21:06:49.765907-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
5dca599e-cf18-41d6-a807-c075f795faa6	2018-03-04 21:06:49.770907-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
766c9f2b-c384-4c9d-9807-f3661b51c7fe	2018-03-04 21:06:49.776908-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
634ea2e0-3aa0-488f-ba19-35e2cf77e5dc	2018-03-04 21:06:49.780908-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
5e2aeecb-cff4-44b0-bb5d-d71a73cf95c4	2018-03-04 21:06:49.784909-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
06e08c5e-ce5c-46ed-b2c0-e830e1999b8d	2018-03-04 21:06:49.789909-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
063780f2-dd94-44c0-bda7-b0b4034d94c0	2018-03-04 21:06:49.79391-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
83413bbc-60a8-41e4-b758-0b8ea0f689e8	2018-03-04 21:06:49.79891-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
ba42d222-1262-429a-ab6c-18250436b02f	2018-03-04 21:06:49.802911-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
f077fd63-1fcb-4df6-8b18-e34f718618de	2018-03-04 21:06:49.807911-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
016015f6-9045-408c-b7de-4e130a0fca79	2018-03-04 21:06:49.812912-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
0c6d67e7-e614-4eac-a9db-512a222f8ad9	2018-03-04 21:06:49.816912-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
430fde34-dde0-4c1e-afb1-9e386ea7df0e	2018-03-04 21:06:49.821913-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
c8c39a8b-198b-4231-a995-b70b01044b35	2018-03-04 21:06:49.825913-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
d3a3f692-63ab-408c-9f8b-5f2d52a01fe8	2018-03-04 21:06:49.830913-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
87bd65f8-c4d9-4443-9b4b-332d3b16dd91	2018-03-04 21:06:49.834914-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
79ee43b9-4110-4025-834c-562ffbe72d26	2018-03-04 21:06:49.840914-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
1cad6dc8-d525-4cb3-889b-f6cd4025a736	2018-03-04 21:06:49.843915-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
c288bb9b-146e-455a-b2e2-d1ea46f68e37	2018-03-04 21:06:49.848915-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
06d5f6db-1237-4ab8-adb0-b05824c090dd	2018-03-04 21:06:49.852916-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
c05e08b0-ab77-4e62-bd89-cf0aeef1ec73	2018-03-04 21:06:49.855916-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
d129c3b6-807e-40dd-8e9b-35857343e5f3	2018-03-04 21:06:49.858916-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
3a3cbbaa-95e9-43dd-bac1-49f4863ebefa	2018-03-04 21:06:49.862917-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
aac48700-48aa-4afd-ab54-628ef4bd7343	2018-03-04 21:06:49.867917-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
500df7be-45de-49f1-8f8c-548d97672d25	2018-03-04 21:06:49.875918-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
f84f1316-f279-4104-a782-ba8b0d849f5b	2018-03-04 21:06:49.878918-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
a5690c10-af84-4ec7-8cb9-7f6b450d35a6	2018-03-04 21:06:49.882919-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
2e2fdb9b-ca45-4246-9163-d5d5f40e717e	2018-03-04 21:06:49.886919-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
e49e3ec7-4ab4-4994-b4a8-8e2506c09ba8	2018-03-04 21:06:49.889919-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
c64d5293-e566-411c-b810-90cb0c3d3f3b	2018-03-04 21:06:49.89292-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
22219598-54f5-471f-a8cb-4fffb2cf7700	2018-03-04 21:06:49.89592-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7044e3eb-1aa5-4ce8-b4b2-601d76449fcf	2018-03-04 21:06:49.89892-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f8d22d72-94de-4dee-993e-cfde2a7f9af1	2018-03-04 21:06:49.903921-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fd8da770-46a4-4e4a-a250-775cee8cc734	2018-03-04 21:06:49.905921-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
be84ac15-4285-49e8-85d7-5e09053d29d6	2018-03-04 21:06:49.908921-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1a1d97d9-71b2-441d-b521-ad674cf5337f	2018-03-04 21:06:49.912922-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
08675cfc-1342-4236-91fa-6f607059325e	2018-03-04 21:06:49.915922-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
73de605d-eeaa-4d61-bdde-a01bfd6d3eb2	2018-03-04 21:06:49.919922-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
12116058-9d66-42d6-9dc8-8e9cdc5197f0	2018-03-04 21:06:49.922923-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8ef78a87-1b29-42aa-a475-8495bf31e966	2018-03-04 21:06:49.925923-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
de0aac36-0785-46b4-9bfb-2334ba73ac54	2018-03-04 21:06:49.929923-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
24881e70-82c0-45bf-b087-17747aa6e510	2018-03-04 21:06:49.931924-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1099a9a4-d898-49d4-bac2-00406a87c1b1	2018-03-04 21:06:49.934924-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
49ad3dfe-fd23-4881-b78c-df790372e9b3	2018-03-04 21:06:49.938924-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0d0c2d34-bfaa-4a12-8c9e-61a8ef730cac	2018-03-04 21:06:49.941925-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5c018511-74d4-4c78-91a5-5b75c3770f03	2018-03-04 21:06:49.945925-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
357a5a37-7f0a-4ee6-bf39-32b16ece71c6	2018-03-04 21:06:49.948925-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
71902a44-d32c-4624-b58f-6fa19a0f9849	2018-03-04 21:06:49.954926-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
30798e12-178c-4478-a504-c01c944737e8	2018-03-04 21:06:49.957926-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
2b1b772b-f2b3-4deb-92f9-369de3bc4504	2018-03-04 21:06:49.961927-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
585c12a8-6c61-4016-bc33-fb443f424da9	2018-03-04 21:06:49.964927-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
17880957-3e15-478f-9e28-4dadef13ac5d	2018-03-04 21:06:49.966927-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
7084d8d5-5ef9-48a2-858b-3bfcf27b2bed	2018-03-04 21:06:49.969927-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
259e28aa-fc21-4362-b1d9-2991449a72c3	2018-03-04 21:06:49.973928-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
968d264b-1f4a-4efc-9fa1-2c3fd85e225e	2018-03-04 21:06:49.977928-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
0f774087-d982-4d78-b1ea-8722249e3063	2018-03-04 21:06:49.980928-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
912d48ca-16ed-4fa7-b275-eaaa7e311914	2018-03-04 21:06:49.984929-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
be297499-03a3-42a9-b81c-7ce6fe919fd9	2018-03-04 21:06:49.987929-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
0319774a-0efc-400b-bfd3-592f46d9adc3	2018-03-04 21:06:49.990929-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
6402a238-8fda-494b-85ef-2bb6d6895f72	2018-03-04 21:07:04.276358-06	3	[22335] IC 344A	[4] DLarrabee	[21062] a	\N	\N
e356b5b6-453e-4586-908d-a0429b1e9a68	2018-03-04 21:07:04.542384-06	2	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
1a9e012d-8afc-40e7-b0d8-4afaf2b44f48	2018-03-04 21:07:04.546385-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
d07f178c-addd-422c-b215-b68b885b3b2a	2018-03-04 21:07:04.552385-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
0bee9759-e6ec-492b-8f65-c67111156711	2018-03-04 21:07:04.557386-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
75efc251-34ca-4d73-a459-4a2ead07ac95	2018-03-04 21:07:04.561386-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
44f17700-5cfd-4de5-88cf-a662116f70c1	2018-03-04 21:07:04.566387-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
d1007158-1942-4901-956b-6d7ed3f55488	2018-03-04 21:07:04.570387-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
a402e0d9-5e1e-443c-a14d-d6ae2cb4c8ac	2018-03-04 21:07:04.574388-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
11ae5806-6a13-4266-a012-2275db46fd20	2018-03-04 21:07:04.580388-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
5eeaed56-e5e7-4c32-a122-589aab3f2f54	2018-03-04 21:07:04.584389-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
23b2f99e-5838-4014-ba17-d395ff653db2	2018-03-04 21:07:04.588389-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
54403eb8-aa20-4313-8141-4a6687e5639e	2018-03-04 21:07:04.592389-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
49a71c91-8e9f-4501-8381-41cc4f6d70cb	2018-03-04 21:07:04.59639-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
59f15078-7f2c-49c6-b549-c306152be375	2018-03-04 21:07:04.60039-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
518f7fc5-6754-4414-9ee9-10a5635c8d81	2018-03-04 21:07:04.604391-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
ab49a823-fd0e-4859-a651-b53aa42f6185	2018-03-04 21:07:04.610391-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
0912deef-81fc-4000-8407-90c51e7cf33b	2018-03-04 21:07:04.613392-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
d4f29f4b-b0cd-4e0a-bc5c-a050d359d03e	2018-03-04 21:07:04.617392-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
869441d1-f0d4-49b6-aec3-95af51252333	2018-03-04 21:07:04.621392-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
a8b8f1ad-a83b-46f8-b493-bb705521d119	2018-03-04 21:07:04.625393-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
db04b46e-3152-423d-85ae-2e01d050ca31	2018-03-04 21:07:04.629393-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
33a880a5-698c-4d87-a62b-94726f0c237a	2018-03-04 21:07:04.632393-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
c5d2db5b-4e59-468a-ac3e-baa9dffa6f5e	2018-03-04 21:07:04.640394-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
d1f1d170-bfba-4f9c-9e71-54aa57f0a0f0	2018-03-04 21:07:04.645395-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
52d3503a-4844-4ac2-bb56-8fac2c7f1c25	2018-03-04 21:07:04.649395-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
8e1472d1-f6c7-498d-9ab7-441e4187d66e	2018-03-04 21:07:04.652395-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
d0452566-0af0-4300-a12f-51f2e831cfd7	2018-03-04 21:07:04.657396-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
fc38065e-a791-4065-80f3-7bd1365435eb	2018-03-04 21:07:04.661396-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
eef33935-bbe5-4e50-86f7-c60004665816	2018-03-04 21:07:04.665397-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
6433293f-9d9c-4572-b57e-e17bdac35a58	2018-03-04 21:07:04.669397-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
cb8bd8d5-314f-4a48-b0e1-720d3f1aafcf	2018-03-04 21:07:04.675398-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
4dbeb40b-9752-4bf7-96d0-68e5181abe35	2018-03-04 21:07:04.679398-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
9e2e194a-6e05-4158-bf3c-798b420876a1	2018-03-04 21:07:04.683399-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
80627b3b-417c-4c5d-9b81-92d841587e91	2018-03-04 21:07:04.688399-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
19781c56-ce05-41bc-9322-4bb13fa828c9	2018-03-04 21:07:04.692399-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
f817f587-05c5-4232-a78d-cb3beefe8927	2018-03-04 21:07:04.6954-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
bc121c6d-18b1-4026-83de-5f85e36da924	2018-03-04 21:07:04.7004-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
814c151f-1fd2-4224-ba55-7d78967abd57	2018-03-04 21:07:04.707401-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
190a3fc7-a848-4e01-a035-940343483d67	2018-03-04 21:07:04.710401-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
af4d9b9c-fb23-438b-a2ff-331c19086c23	2018-03-04 21:07:04.712401-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c56ae62f-ca22-40f5-866a-b7fda0b3424f	2018-03-04 21:07:04.715402-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
68b9d3c4-5882-4b1a-bfc2-1ec6e60c093d	2018-03-04 21:07:04.718402-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
989f42ef-e03b-455d-8f8f-e9e98d7f2379	2018-03-04 21:07:04.721402-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
af9e271e-f7e3-4797-97e4-dfec7dbebf4a	2018-03-04 21:07:04.724403-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fb356105-42c6-4126-b988-0f5f70e69a4d	2018-03-04 21:07:04.727403-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4d02d9d9-4dfe-497b-84c0-509d487b05c0	2018-03-04 21:07:04.729403-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2426b74d-1386-4d76-8b31-1ced760ac301	2018-03-04 21:07:04.732403-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
712a12c8-7208-47de-835e-d52ba1b4cea0	2018-03-04 21:07:04.735404-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
76d6d8a4-2fbf-41be-9c55-aa7cdfca167e	2018-03-04 21:07:04.738404-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3638d7d5-a94c-4692-b264-de6371975c6b	2018-03-04 21:07:04.741404-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e5edfb26-c545-4c25-8885-0725e4ddf8dd	2018-03-04 21:07:04.744405-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
29bc63db-3a69-4999-b613-9cf46d937efd	2018-03-04 21:07:04.749405-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f4172a93-508a-4125-a236-b990e9baeafd	2018-03-04 21:07:04.752405-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
252d81c9-6e63-434a-803a-4e81cf1c9d48	2018-03-04 21:07:04.754406-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
db669a85-29ff-4813-823a-c957bf47bdce	2018-03-04 21:07:04.757406-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0b04560d-6d14-4b82-a6d7-9637740d6b92	2018-03-04 21:07:04.759406-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
343a1691-60e6-46c6-ab15-7f08cf87b2d9	2018-03-04 21:07:04.762406-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
e7b4bc24-f893-40ec-a23b-fd422818766e	2018-03-04 21:07:04.766407-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
c0a37fd6-34c6-45e0-ae33-c64abbe66e06	2018-03-04 21:07:04.770407-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
573e5468-97c4-49e6-b18d-bc785384bc8f	2018-03-04 21:07:04.774408-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
fe971941-ec2e-4c2c-94a2-1e2ca51aeaf0	2018-03-04 21:07:04.777408-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
245b49eb-8b6a-4eef-8ec8-e51f303f7539	2018-03-04 21:07:04.781408-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
3dafb0fa-8952-4f39-9863-c061ea074972	2018-03-04 21:07:04.784409-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
ad73b45a-3770-4780-a635-520b2c465713	2018-03-04 21:07:04.788409-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
59552e29-72dc-4ea5-970b-bb25fd3da5ba	2018-03-04 21:07:04.792409-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
b0501a17-a898-4e83-be3d-25d96d4bf507	2018-03-04 21:07:04.79841-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
d223df22-3a5e-4244-ab4d-0c51eeee9592	2018-03-04 21:07:04.80241-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
bede7cd7-c545-4504-988c-50cc256ddff8	2018-03-04 21:07:15.978528-06	3	[22336] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
04612641-e2f3-445a-892f-e1ec346ab68e	2018-03-04 21:07:16.242554-06	2	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
978fd284-e58c-4ccf-817f-4967a9e24b37	2018-03-04 21:07:16.246555-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
c5babe44-7654-4b7a-a904-f89a3e9956d8	2018-03-04 21:07:16.251555-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
6cfae18a-f0e7-45af-8568-a338138a37c9	2018-03-04 21:07:16.255556-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
9cacd515-6b0e-4b1b-9adc-b4063e6bb59d	2018-03-04 21:07:16.259556-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
9f187244-eeda-4715-9192-4e47400622cc	2018-03-04 21:07:16.266557-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
f5145731-b60d-4992-a6a3-b0c0337f45e3	2018-03-04 21:07:16.270557-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
65e6eae8-5280-413f-9d22-dafb000dc97b	2018-03-04 21:07:16.274558-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
a627707e-a739-41be-a9b1-2158a5a397b2	2018-03-04 21:07:16.279558-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
a6b9a3b6-d16d-4e4d-bf09-ab72ce08993e	2018-03-04 21:07:16.283558-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
368e9085-4804-4075-a886-03f82e4cbf0d	2018-03-04 21:07:16.288559-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
21628575-1705-4f23-b25f-067999b3e4ae	2018-03-04 21:07:16.291559-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
3e1bf3c9-c760-49f0-bd23-e876d6c9df81	2018-03-04 21:07:16.29956-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
977251be-d6ae-4ee8-b8fd-3853d96e2ee1	2018-03-04 21:07:16.30356-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
2734166d-c6be-43f6-9087-bace9f29e0b0	2018-03-04 21:07:16.308561-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
21e3a7d8-9366-47e4-8ebb-58e2b99dcb4e	2018-03-04 21:07:16.311561-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
ec587ddf-b293-472f-9806-518386244869	2018-03-04 21:07:16.314562-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
89ea186e-71e1-4593-80ba-6e164b1534b8	2018-03-04 21:07:16.317562-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
e65a78f4-9b1d-4124-99b6-accb76f3dc73	2018-03-04 21:07:16.321562-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
f39f113a-6b21-4b13-b1da-7f87f4f36b22	2018-03-04 21:07:16.324563-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
8e5d6ff3-ee29-4d94-89e9-55da48dce5b9	2018-03-04 21:07:16.332563-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
82077a5b-efbf-42b1-b63b-dfdf03913281	2018-03-04 21:07:16.336564-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
cda51b89-1e04-4412-8017-fd6a538b0220	2018-03-04 21:07:16.341564-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
89ba5db3-43aa-442a-b071-2f656b860c85	2018-03-04 21:07:16.345565-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
c99e55ad-11d2-4423-afc3-428e9ffc0e38	2018-03-04 21:07:16.350565-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
620c9a03-7e9c-4046-af80-417ea30f7f59	2018-03-04 21:07:16.353565-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
5fc7a045-22db-43c8-8a52-6a58f6dce8a0	2018-03-04 21:07:16.357566-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
7dddf539-833e-4cbb-87b3-281160be5459	2018-03-04 21:07:16.363566-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
1d9283f9-a61b-4b88-b02c-855a12139567	2018-03-04 21:07:16.367567-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
e1bd1ab6-644e-46bf-8170-c9e1aa96086e	2018-03-04 21:07:16.371567-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
466aaaa4-49fe-4df6-885c-0c2ac7b1d18c	2018-03-04 21:07:16.376568-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
daf90f36-12ac-450f-a168-ab9a50173b7b	2018-03-04 21:07:16.393569-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
d951e5f3-96bc-4b1f-8341-69fa55288256	2018-03-04 21:07:16.39757-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
bc6d1560-6bac-4c1b-81c8-cb896f679592	2018-03-04 21:07:16.40157-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
a841133b-1f17-4a4f-98d1-06fd87d61276	2018-03-04 21:07:16.407571-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
76aee6b5-2e00-4f49-85f8-5a987a1272d0	2018-03-04 21:07:16.411571-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
1581b05c-9ddb-489a-b0d4-b08388e43eab	2018-03-04 21:07:16.414572-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
bbdaa647-7e03-4a5a-88ec-f56cc7a3acac	2018-03-04 21:07:16.417572-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
52061096-a761-41ba-bab8-d90afa20103f	2018-03-04 21:07:16.420572-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
47b43c3f-bbd8-4ceb-ad2d-5c9a7ba8f52d	2018-03-04 21:07:16.422572-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
28d83bac-a7eb-4926-82fe-f6452f168e35	2018-03-04 21:07:16.425573-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6cb69c79-eda0-49bf-9cb6-4fc179b746f2	2018-03-04 21:07:16.429573-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
77e0019a-f1ec-4489-8cb4-cb399fcc9e1e	2018-03-04 21:07:16.431573-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
57020c1a-7e33-4b1e-9ebb-fd7a4f67bce1	2018-03-04 21:07:16.434574-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7c371f96-6620-49f5-b01a-eca3271bd5a1	2018-03-04 21:07:16.437574-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7a38da6d-f2fd-4543-828a-594aec5db837	2018-03-04 21:07:16.441574-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fa5d7e6a-5d86-444d-a9a7-8e9eb44cdbe8	2018-03-04 21:07:16.447575-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7e63c7ba-b196-497d-8641-868a34602ae2	2018-03-04 21:07:16.451575-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f7744af2-3c60-4c47-8d9f-b03de1d9b693	2018-03-04 21:07:16.454576-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
92ebc168-6723-41fd-a9b0-537d7e2ee414	2018-03-04 21:07:16.458576-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
94c12d9a-9f83-4f1f-ab74-edf11981c2d7	2018-03-04 21:07:16.461576-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0d65f1e2-7ed9-4f93-9368-9553961737d5	2018-03-04 21:07:16.465577-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4d6a8ed0-f4ce-4f35-97ca-7f0472ad3d5f	2018-03-04 21:07:16.468577-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f3b65105-0963-4f70-a1a0-2cb85d4601b1	2018-03-04 21:07:16.472577-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9724694a-9fce-49eb-9a39-a807249f5b18	2018-03-04 21:07:16.475578-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fc702c35-4fde-4205-804b-4aba6ff5744c	2018-03-04 21:07:16.478578-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
a375b8f3-7dbc-444d-9518-b372202eedcb	2018-03-04 21:07:16.481578-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
efb28858-34e1-44e9-b68d-5d8489787656	2018-03-04 21:07:16.485579-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
da24d64f-2fcd-4cd4-8957-c1fac5a32f15	2018-03-04 21:07:16.489579-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
2926dc12-0edd-4e4b-a069-3d8c7a4648ae	2018-03-04 21:07:16.493579-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
d2e75f47-5977-428b-8614-b4f381ab3707	2018-03-04 21:07:16.50058-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
aaa1d00a-3f51-4a12-ba67-7913d336bf40	2018-03-04 21:07:16.50358-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
d3c2f596-4b28-4cce-b31f-0d328757f0d5	2018-03-04 21:07:16.507581-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
0159e8f2-ce54-4814-9148-182c634b6c2c	2018-03-04 21:07:16.510581-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
6ca8463e-1ead-4120-b8f5-01ac2bc5e13f	2018-03-04 21:07:16.514582-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
c3089dae-e1c0-42fc-851f-2b4b08994286	2018-03-04 21:07:16.517582-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
63badef0-bb2a-47ea-a5fa-fbe7474afbca	2018-03-04 21:07:33.464276-06	3	[22337] IC 346A	[4] DLarrabee	[21062] a	\N	\N
f443d335-111e-498e-9844-f10c60d0bf88	2018-03-04 21:07:33.729303-06	2	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
b06add33-b5d6-4639-816f-797d9e2281dd	2018-03-04 21:07:33.733303-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
d2e9ae3b-d280-4771-979c-e43ab413eecc	2018-03-04 21:07:33.738304-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
2dbb833c-9dfc-4fb7-a929-8d68ff5bb72f	2018-03-04 21:07:33.745304-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
6913f5c3-7a4b-4431-b96d-c3cc9dc78078	2018-03-04 21:07:33.749305-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
2784dd4b-dcad-4a42-8858-1a007cf9fbb4	2018-03-04 21:07:33.754305-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
bc9df250-8d0e-46f2-970b-f4dfa40dbb63	2018-03-04 21:07:33.759306-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
7d01b5ae-f5e6-4c04-94fc-8b0fa5eb68b4	2018-03-04 21:07:33.762306-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
449e8ed8-3cb6-4a17-a2e0-ff9a57d393da	2018-03-04 21:07:33.767307-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
041b6d68-b717-4bb9-be65-a3e239be6413	2018-03-04 21:07:33.771307-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
b42f7cd7-73a1-4df7-b2c8-38660073b267	2018-03-04 21:07:33.776308-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
997574a7-0767-4a4d-b630-429123f791b5	2018-03-04 21:07:33.782308-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
799f1ec9-66ca-40c9-ab84-0ef8e6064a88	2018-03-04 21:07:33.787309-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
e284a1df-463c-4d58-88e3-79b63e472d80	2018-03-04 21:07:33.791309-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
932e4b31-dad0-4793-bb9a-d8e55dc88235	2018-03-04 21:07:33.79631-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
625fd5b0-9b1b-42af-867d-5f34ca20374c	2018-03-04 21:07:33.80031-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
3ca6f9b1-3b82-4710-a17a-5d149c0324b9	2018-03-04 21:07:33.80431-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
e6825204-cdad-458d-ba1b-fc518e15a54e	2018-03-04 21:07:33.809311-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
2116d48e-c7c1-4527-9cae-cd64fd59428e	2018-03-04 21:07:33.816312-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
d78e9ef4-338c-414e-877e-f065a465d754	2018-03-04 21:07:33.820312-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
825754a0-0e08-4d10-bfde-4e1463f9b361	2018-03-04 21:07:33.824312-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
e9c70038-361a-4123-a963-292578afe365	2018-03-04 21:07:33.828313-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
e9da4f47-4e1d-4bd7-b6ae-10e2bf91c28a	2018-03-04 21:07:33.831313-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
5f62ff00-ed9c-4179-8ae0-959458c144d3	2018-03-04 21:07:33.835313-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
9cdd16cf-93b7-4fc3-903e-4869be2b1e24	2018-03-04 21:07:33.838314-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
580e80ec-30bb-4529-ae11-9abceff4b47b	2018-03-04 21:07:33.845314-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
c5887b5e-f1c9-477c-8037-6ebd072c58c0	2018-03-04 21:07:33.849315-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
a6781f9c-6bb6-4a24-8bfe-d146a3e59f70	2018-03-04 21:07:33.854315-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
fad0f158-016e-417a-9778-b690712b0046	2018-03-04 21:07:33.858316-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
ea540359-86d7-4187-884f-4b2b0cef79d2	2018-03-04 21:07:33.863316-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
37386bc5-537c-46c0-a19c-c290006bb6a7	2018-03-04 21:07:33.867317-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
e0142ed8-7717-4070-8024-3d255a3c2302	2018-03-04 21:07:33.872317-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
596ce957-c768-42a0-a0fd-531e63e9597e	2018-03-04 21:07:33.879318-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
188da050-168c-4e8d-880d-df7da05b7438	2018-03-04 21:07:33.883318-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
b5c93f98-56d9-46bb-8131-beb13e4b5631	2018-03-04 21:07:33.888319-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
8b3024e9-b804-4ac2-9f0e-98ede09be4f8	2018-03-04 21:07:33.892319-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
3a04f118-0564-4d8a-bc9f-de119456d92a	2018-03-04 21:07:33.895319-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1beafb85-5cbb-48db-9ff5-791b96c68b4a	2018-03-04 21:07:33.89932-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a8f5e3b8-c74e-476a-8b8c-489d76121020	2018-03-04 21:07:33.90232-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9119c9dc-29cf-4037-80c7-c1327325f93e	2018-03-04 21:07:33.90532-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
766441ec-2f89-4501-bec6-e89ee5ce61e1	2018-03-04 21:07:33.907321-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
594a27d3-5080-433d-b69c-0c6c3f6aebb5	2018-03-04 21:07:33.910321-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8a45c30b-aa5c-4c3c-ae13-5469e6cafd39	2018-03-04 21:07:33.914321-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5b1c7fe7-f608-4d47-a050-e73272e43c17	2018-03-04 21:07:33.920322-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
81518c9d-a386-4fb9-8475-d38940af0508	2018-03-04 21:07:33.923322-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c916bca9-6432-490c-9779-998772ab5030	2018-03-04 21:07:33.927323-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
839975c8-b72b-435e-9369-73feddba29cd	2018-03-04 21:07:33.930323-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7f375e04-bd49-42c1-a61b-7edc95fd81b1	2018-03-04 21:07:33.933323-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
47bdae02-103f-4950-ac95-fdd431d26f4f	2018-03-04 21:07:33.937324-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f590ea01-679a-4c7a-8a68-6d116be8c836	2018-03-04 21:07:33.940324-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
72838f5e-c016-439d-b6b6-75a03360aa43	2018-03-04 21:07:33.944324-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ea1711a7-96c3-4393-90f0-be4aaebd3a19	2018-03-04 21:07:33.947325-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a09b9ffe-4a97-4a9b-9510-220e9baeb2dc	2018-03-04 21:07:33.949325-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ec8b239d-4ee7-4b7f-9f3f-e549d7cb1da5	2018-03-04 21:07:33.952325-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
52f35288-6ff0-4269-8b23-52167946e1c3	2018-03-04 21:07:33.956326-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
0824d496-70ae-4a81-b2f6-f6ac093ae65e	2018-03-04 21:07:33.959326-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
69c9ef9d-53ce-4784-96a5-575175579167	2018-03-04 21:07:33.962326-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
120862a5-7a2a-4ca5-b099-c14749ee37a3	2018-03-04 21:07:33.966327-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
7736ee1c-0060-4023-80f9-1178417b1bbe	2018-03-04 21:07:33.972327-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
2a3bf0e5-04bc-4568-9e83-aacabeed55d2	2018-03-04 21:07:33.976328-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
55218099-c85a-499a-94f0-d9a5e6939f92	2018-03-04 21:07:33.979328-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
824f1cfe-6864-4eea-a0a0-f0e6f9e7bb7c	2018-03-04 21:07:33.981328-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
6ad851a1-1533-465b-8476-a749c824926b	2018-03-04 21:07:33.984328-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
87a387a8-f07e-4995-98be-35593c7c9130	2018-03-04 21:07:33.987329-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
e7e29ce9-f5da-4cce-92fb-de8cd17c9efb	2018-03-04 21:07:33.990329-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
1b3af3ba-b8f1-4409-a5ab-06f725e657ae	2018-03-04 21:07:51.567086-06	3	[22338] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
6770951c-b5f4-49c3-a2b4-8838d369182f	2018-03-04 21:07:51.851115-06	2	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
6a75565b-4ef2-4aa3-90d5-7f28a3e88c78	2018-03-04 21:07:51.856115-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
8bd3329b-19ff-4881-bf6d-00e067a532bd	2018-03-04 21:07:51.861116-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
a7bb6234-7ce6-499b-ac88-28b1b9840df6	2018-03-04 21:07:51.866116-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
f9b0cc03-a9f5-4856-ab9d-381c2aab0532	2018-03-04 21:07:51.869117-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
e2fa6246-3868-4b6c-a1dd-ff32e9320902	2018-03-04 21:07:51.872117-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
ad21a753-7868-47fc-9c1b-a0994b0b9620	2018-03-04 21:07:51.877117-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
4abb8803-9d6f-4a3c-bd63-f911c6986d82	2018-03-04 21:07:51.881118-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
bc03e8f5-2bc7-4838-9a75-1ef062625ada	2018-03-04 21:07:51.885118-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
298ed317-9baf-4ff1-aeb8-3a8bb55ea53c	2018-03-04 21:07:51.890119-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
986d3ab0-5f60-4419-9d36-63a444798f0e	2018-03-04 21:07:51.895119-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
1bb4932e-8b3e-4973-83aa-e72ae08846da	2018-03-04 21:07:51.89912-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
9f8fe10f-81e9-4ece-bc30-22c2aaf59cc4	2018-03-04 21:07:51.90412-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
3579210f-7a53-4e67-8581-f0dcb41e62e7	2018-03-04 21:07:51.908121-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
6b48d666-7fe2-4f63-859b-cb70b5dea466	2018-03-04 21:07:51.911121-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
6b80832b-2cc9-4766-868b-f5c77cf887a3	2018-03-04 21:07:51.915121-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
03dde5ef-75a6-4730-bec1-6213c6a84ef2	2018-03-04 21:07:51.918122-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
54df1d1c-6a3e-40db-a8c1-a25209fc0906	2018-03-04 21:07:51.923122-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
5427a57a-a6f1-4a06-8a19-68a3b045cf8b	2018-03-04 21:07:51.927122-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
5d5a036f-8c38-43c8-843c-d7b92852b44a	2018-03-04 21:07:51.932123-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
035c34b6-41c0-47eb-ae12-2e3be976e1d2	2018-03-04 21:07:51.936123-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
27a6f3ae-c89d-49dc-af02-d50e0adf2607	2018-03-04 21:07:51.939124-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
badc94b8-f433-4a9a-9a79-b583080bb3dc	2018-03-04 21:07:51.944124-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
f83f5fb9-5262-449c-b639-63cfcd4347dc	2018-03-04 21:07:51.948125-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
09de8213-172c-408f-9b57-da31471687b7	2018-03-04 21:07:51.952125-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
1e7659c3-31af-4a1b-aad5-ad8a7f699aca	2018-03-04 21:07:51.956125-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
8f756832-755d-4c2f-ab06-50fe1826901e	2018-03-04 21:07:51.960126-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
2b0856c9-b16c-4e2a-acff-541744735b04	2018-03-04 21:07:51.964126-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
f64de586-905e-40c9-b2a8-b11269e5dc54	2018-03-04 21:07:51.968127-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
83cc4fcb-1f03-460f-a22c-bdd232f1b7a3	2018-03-04 21:07:51.973127-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
17377aa1-9e59-438d-adec-427cd9e10383	2018-03-04 21:07:51.976127-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
3a4ceb0a-e62a-4993-aeb8-6ed34f7b3484	2018-03-04 21:07:51.980128-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
5bd16f07-146f-4e8b-af96-4e58df2d2df4	2018-03-04 21:07:51.985128-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
a72f662b-532d-406b-9359-0bbd0605c862	2018-03-04 21:07:51.990129-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
d370d081-e31a-45e5-a9ee-06d875aeee38	2018-03-04 21:07:51.994129-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
4e15938d-1dd4-4af9-ae48-41170cb0eb19	2018-03-04 21:07:51.99813-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ccb7ed73-e606-4726-9811-ed0aea64fb1a	2018-03-04 21:07:52.00113-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
101d1eb2-e6e5-4334-a347-fc96607e6129	2018-03-04 21:07:52.00413-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
36dc7f51-9247-41d1-b240-8af7c0b8df4b	2018-03-04 21:07:52.00613-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7c157bbd-5203-4b3a-ab3e-332e9e119f5d	2018-03-04 21:07:52.009131-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
94f2f98b-94cd-447d-9159-d011b975f013	2018-03-04 21:07:52.013131-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c25c567d-efd5-4c38-a610-19b628d45fc8	2018-03-04 21:07:52.015131-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f668878b-402e-4695-89cb-703a5b3c6b7f	2018-03-04 21:07:52.019132-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ab5e3f33-52d3-45c5-ab68-6c09f3ab8930	2018-03-04 21:07:52.022132-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
27eeeaf0-81d5-49d3-af87-3cf7bc41b4ab	2018-03-04 21:07:52.027132-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5d943488-3b20-4ee9-ad34-49128ba53f51	2018-03-04 21:07:52.030133-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9324d565-4cfa-488b-8ac1-bb6a4227a4bc	2018-03-04 21:07:52.034133-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2d388e9b-fd6d-4d1c-8453-2b962ffe7e9c	2018-03-04 21:07:52.037133-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
34b23180-cedf-4ba6-a3f8-95e40c3057ed	2018-03-04 21:07:52.040134-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
61d76fc5-c3d4-40de-a4d3-74cc55d67106	2018-03-04 21:07:52.043134-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5a5d4e09-be93-443e-953a-25975021cd2f	2018-03-04 21:07:52.047134-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e9cc5b80-6eed-46f2-9629-6021ebf59847	2018-03-04 21:07:52.049135-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
49ba19aa-8a4a-4305-829f-677727f6a56d	2018-03-04 21:07:52.052135-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4f2ec765-f249-4988-8bbd-66ed98a9fcfd	2018-03-04 21:07:52.056135-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
0e13bac0-3d02-441d-91b9-c4450cb64243	2018-03-04 21:07:52.059136-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
7dde0a85-c967-4f69-bbf8-8b7483f9d7be	2018-03-04 21:07:52.064136-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
5f460cb9-73d8-40e8-97d4-1fdc44bab5ae	2018-03-04 21:07:52.067136-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
30e1f9a7-4f14-41c5-aca5-f35b460fecba	2018-03-04 21:07:52.071137-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
883896f9-15dc-4a5e-a536-0122136f7b0c	2018-03-04 21:07:52.075137-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
3b567ea6-4583-4cac-b946-c738b8f4a612	2018-03-04 21:07:52.079138-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
30f5e780-36ac-45f0-b74d-9358d101e353	2018-03-04 21:07:52.082138-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
e839c1b1-4900-4f40-9474-b5144c348cb5	2018-03-04 21:07:52.086138-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
e8e46bcb-f8dc-4133-9533-73c34de3fb14	2018-03-04 21:07:52.090139-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
0db9cedc-756b-40f3-b58c-cff3be2d29d3	2018-03-04 21:07:52.093139-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
29637bb8-7c22-439e-a200-545afa5b0fc8	2018-03-04 21:08:09.336863-06	3	[22339] IC 347A	[4] DLarrabee	[21062] a	\N	\N
2f6a67ae-427b-4250-ae07-6adba6b0c3c3	2018-03-04 21:08:09.620892-06	2	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
6c8cfeab-67ab-469c-9d5e-f096030e4141	2018-03-04 21:08:09.624892-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
17ac5690-2e27-4ef4-9a79-7e5c70c964ca	2018-03-04 21:08:09.629893-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
57ba1ed4-902a-42f5-9973-826d6c9aa38d	2018-03-04 21:08:09.632893-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
e67b9f84-317a-4519-be06-44c6a4f98d0e	2018-03-04 21:08:09.636893-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
4fdd6f80-01ec-4216-86ec-3cb7f4e172a7	2018-03-04 21:08:09.644894-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
cfbab11b-274a-4d2f-b703-4a1aefe13a8f	2018-03-04 21:08:09.648894-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
d680d892-588b-43df-bf6a-94f791a50e16	2018-03-04 21:08:09.652895-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
204d417d-f6ad-49f3-b94a-3eed95827989	2018-03-04 21:08:09.656895-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
255714d9-7dec-42b1-a205-542d35fc0ed0	2018-03-04 21:08:09.659896-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
3ec29e27-6a31-487d-b762-02adee941819	2018-03-04 21:08:09.664896-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
5fa2e91f-65a2-440e-8090-0a77e2914161	2018-03-04 21:08:09.667896-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
af12be2a-7c86-4276-ac74-1c3ed39c48b0	2018-03-04 21:08:09.673897-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
c4d95514-75cd-4cc0-b252-e2e3d8348d0a	2018-03-04 21:08:09.677897-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
97b0b854-7af4-44f5-aba6-9868c95f001b	2018-03-04 21:08:09.680898-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
4a1e4a8f-70df-4b43-a05c-b2f141b102d4	2018-03-04 21:08:09.684898-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
0b10fb4d-9704-4512-967f-c0fae4934099	2018-03-04 21:08:09.688898-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
c4bd9c83-dcba-4359-bd6f-1e5ad507bffe	2018-03-04 21:08:09.692899-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
819247c6-f132-4a0a-8125-cf058a30bfc0	2018-03-04 21:08:09.697899-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
b4cda0ab-7126-43bb-8a6b-9f650ef3411b	2018-03-04 21:08:09.7029-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
7e9653d4-7fda-4ffb-8bf7-4b00e656df7f	2018-03-04 21:08:09.709901-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
6dc33bd3-0325-4f01-81d3-8df01856ec26	2018-03-04 21:08:09.713901-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
8413bc38-4772-495d-8b91-8d212b409343	2018-03-04 21:08:09.718901-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
6a8b54cd-f5e0-4ddf-a589-23e1c8ab7d03	2018-03-04 21:08:09.722902-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
f1a27871-78ed-45dc-b477-9396e3289a67	2018-03-04 21:08:09.725902-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
c5cb6d62-2347-4343-b602-b57c9eb913d2	2018-03-04 21:08:09.729903-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
4338b8fa-5f73-4ccd-80eb-ebf65063522a	2018-03-04 21:08:09.733903-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
be5c3784-5a4a-43dc-8e00-0e7ba934f9eb	2018-03-04 21:08:09.740904-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
813d5f6b-2d81-45c0-b348-a9087e7682ac	2018-03-04 21:08:09.743904-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
214767ca-fbc4-43ed-9316-d9981b0d8d04	2018-03-04 21:08:09.748904-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
92753a69-d90b-4807-9b24-4af920909eaa	2018-03-04 21:08:09.752905-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
a5420b52-09c9-40da-a69c-22873a267cff	2018-03-04 21:08:09.757905-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
4268e4a7-947c-4503-b62e-62bc78a92ad7	2018-03-04 21:08:09.761906-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
60b2ed79-3db0-4893-b6a3-ffe62a7b1fab	2018-03-04 21:08:09.764906-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
6086484d-2f49-4567-87fe-4664f46df1ee	2018-03-04 21:08:09.767906-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7e13b197-6c80-4274-89c1-55a354c76fe0	2018-03-04 21:08:09.772907-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1adc6f20-be2a-4909-abf5-e41aaff5aa0b	2018-03-04 21:08:09.775907-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
be07d23d-57a1-484f-99c3-9ee600de1144	2018-03-04 21:08:09.779908-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
32f970e4-73ee-4d30-b40f-5aa5d40d3091	2018-03-04 21:08:09.782908-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
05d4493d-c451-477d-8fb9-59b70312b33e	2018-03-04 21:08:09.785908-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9eadc2d5-23bb-4b1c-bc1d-b528a46ae3b4	2018-03-04 21:08:09.788908-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1863a0c3-6e40-4012-b819-28f7fb692968	2018-03-04 21:08:09.791909-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8f800b38-23c0-4426-aec4-87fd62d55647	2018-03-04 21:08:09.794909-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4e3bf4fb-c098-4b80-af51-734f0f60aac8	2018-03-04 21:08:09.797909-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e87c31ca-7c30-4a35-9cc5-6e40c972afb7	2018-03-04 21:08:09.80191-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
47aedeb0-1eb4-41da-8bbe-5b03332ec0f0	2018-03-04 21:08:09.80591-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cdd2c10b-0ec6-43ad-b4f2-26780a46f5ea	2018-03-04 21:08:09.80891-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3b876764-e049-40dc-8c30-2645194d5e23	2018-03-04 21:08:09.812911-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e1fae43f-f59a-45da-9131-95b68a8adf52	2018-03-04 21:08:09.815911-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9f14faea-1df9-47f7-b729-772e2fba303a	2018-03-04 21:08:09.819912-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
30807b94-50d8-49d0-a5c3-6b0923c87854	2018-03-04 21:08:09.825912-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cb85053a-caaa-48a4-bddb-35779b91bf81	2018-03-04 21:08:09.828912-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
28acabb9-d739-4d70-9fa1-667479832add	2018-03-04 21:08:09.832913-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
5b1356cf-b31e-4a06-9a1f-9755ebfd9b45	2018-03-04 21:08:09.835913-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
a68da5c4-d7de-4461-b858-42464a1179dd	2018-03-04 21:08:09.839914-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
6b5b4a40-b56b-47eb-9461-8d00fb79b1ac	2018-03-04 21:08:09.843914-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
4841950c-3d0f-4345-9cef-ab2b16abaef7	2018-03-04 21:08:09.846914-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
5391e3ec-411b-4046-98f1-4c7bf13ab38d	2018-03-04 21:08:09.850915-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
52ad2d23-9539-415b-be30-1e5356a39470	2018-03-04 21:08:09.854915-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
50fba886-5e0d-4688-88f5-2b8976b84256	2018-03-04 21:08:09.858915-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
12d8c85f-07f3-452f-9845-e34d0aafced2	2018-03-04 21:08:09.861916-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
465949c0-83b7-4c69-8a84-34b68201bc22	2018-03-04 21:08:09.864916-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
c7e0a6dc-cde0-4f96-8864-fea55ca6558d	2018-03-04 21:08:09.867916-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
76c1ea9b-ecce-49fe-82bc-8891a0bcf98d	2018-03-04 21:08:23.940323-06	3	[22340] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
3db685de-d086-4031-a044-12f81bf2961d	2018-03-04 21:08:24.221352-06	2	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
aa129e30-fa26-4c99-b126-b1e281d24045	2018-03-04 21:08:24.225352-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
5b0ee171-6899-48a5-a89c-7d004b89954e	2018-03-04 21:08:24.230352-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
83119338-5b81-433e-ae09-fc1bfcda120f	2018-03-04 21:08:24.235353-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
58aa7a0f-6401-46ed-af1c-ee5eccf463f0	2018-03-04 21:08:24.239353-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
982cc91e-c0e8-489e-b347-4d28e273c4e4	2018-03-04 21:08:24.242354-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
985860d9-9437-4d51-a0ae-7dfb4ffcef6c	2018-03-04 21:08:24.246354-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
ec0300cb-69e4-41b3-867c-8badd7ca8fe5	2018-03-04 21:08:24.251355-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
9ee47a50-1cb2-4df0-a542-08addae832af	2018-03-04 21:08:24.254355-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
a1060b7d-3a56-4b9d-9939-7ccb75706d1f	2018-03-04 21:08:24.258355-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
4101e80e-12df-452c-8c74-b84cbc6718e9	2018-03-04 21:08:24.263356-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
4d221081-59d3-4d58-b919-897a3bf16c8d	2018-03-04 21:08:24.268356-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
5b25ed95-d575-446c-9e41-fbcdfa16a878	2018-03-04 21:08:24.272357-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
145dfff5-fd93-4787-b9ab-541dcf0c9ba1	2018-03-04 21:08:24.277357-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
3324014b-71b0-4ee9-806d-fc3dd0126e35	2018-03-04 21:08:24.283358-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
20c197b9-6d8b-4c48-8c1d-f95562c28a13	2018-03-04 21:08:24.287358-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
d559e39b-2af1-4011-9628-5e9a66760fb6	2018-03-04 21:08:24.291359-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
c2a89ca3-7a25-402a-a8c6-7aadb81b8879	2018-03-04 21:08:24.296359-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
fab0f753-c6cd-4e9f-af3c-daec630f9a40	2018-03-04 21:08:24.300359-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
b5272a4c-80da-4907-a749-72c58205b227	2018-03-04 21:08:24.30436-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
6e6025ac-4ddc-4ff9-8de9-9d207ecfee7e	2018-03-04 21:08:24.30936-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
f5779146-adce-472d-b564-177c6f7110ec	2018-03-04 21:08:24.316361-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
a7af415f-4dbc-4bad-9d96-1439a1038b0c	2018-03-04 21:08:24.320361-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
6774cb13-0be7-4e85-8732-d816016b69fd	2018-03-04 21:08:24.325362-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
b2bba0c9-392f-4912-96d7-9cb84f57e665	2018-03-04 21:08:24.329362-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
9356ea68-531b-437d-85b6-00ff15dc44c0	2018-03-04 21:08:24.334363-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
8d1a1eff-ccd3-4243-9343-abac80c1528c	2018-03-04 21:08:24.338363-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
edd9d17e-8160-4652-8414-bbb325115f93	2018-03-04 21:08:24.343364-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
7f031e3d-281d-4f4c-b057-c63168a7bbc0	2018-03-04 21:08:24.350364-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
dae7b1bc-5a15-421d-90f0-fb1015d6eeb2	2018-03-04 21:08:24.354365-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
d2a1bd7c-ea3f-47f1-b527-2b81b9122928	2018-03-04 21:08:24.359365-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
900b6d75-ea33-4666-ba7f-8b165afd3708	2018-03-04 21:08:24.364366-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
55cb941c-ca17-44c2-9ba8-2dc47b93437f	2018-03-04 21:08:24.369366-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
ec638124-fbfc-4074-9bfe-d5ff330d1e4d	2018-03-04 21:08:24.372367-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d362b2af-a4d5-4382-b74b-68b5ccd1098d	2018-03-04 21:08:24.375367-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3e517de6-d4eb-4f8b-8e98-c0e02bfddf5d	2018-03-04 21:08:24.379367-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a442e5a3-0e20-4335-9df3-f2d32e04d3bc	2018-03-04 21:08:24.383368-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9e4162ee-b689-47a9-aab9-810c5d864b67	2018-03-04 21:08:24.386368-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0de4586f-508c-480d-83fb-b4f6ee920063	2018-03-04 21:08:24.390368-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9ff22fff-b9d1-41ec-a043-ca34c3e63af5	2018-03-04 21:08:24.397369-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5023d232-3df2-4f05-bdf9-1c05628fc143	2018-03-04 21:08:24.400369-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f686306a-8972-41d2-b28e-7261ba7de427	2018-03-04 21:08:24.40337-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a3375e92-3898-4bd7-8188-2365358cc779	2018-03-04 21:08:24.40737-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3fa55ee2-403d-4bee-8cea-2f92a15442c0	2018-03-04 21:08:24.411371-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8e256212-bf97-4423-96d6-6fd9f3d25a94	2018-03-04 21:08:24.413371-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
07786ac4-0293-4f76-9312-b3ebdee9ed13	2018-03-04 21:08:24.417371-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
45379c51-2c7b-4b93-8b5e-993697df0f23	2018-03-04 21:08:24.421372-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b3eb3e75-1f16-47e6-9ec3-7d6fc4269b22	2018-03-04 21:08:24.424372-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
565c5c57-02c7-4783-9613-a705f5f49115	2018-03-04 21:08:24.426372-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9e54d799-f5a2-4878-9fc7-700074d5ae63	2018-03-04 21:08:24.429372-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c89a28b7-50a0-44a1-b786-4f6e726f1e70	2018-03-04 21:08:24.432373-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d3a68952-f4ad-46b6-8da3-9f0d4e7b468c	2018-03-04 21:08:24.436373-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
ffc66ce8-009c-4eda-8217-ffa15483af6f	2018-03-04 21:08:24.439373-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
91d4611d-2b93-4f2b-9813-f119d36f2ee4	2018-03-04 21:08:24.444374-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
d1f5a3da-ec10-410c-8f63-55eb6551f06c	2018-03-04 21:08:24.448374-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
6b554007-7726-4f41-a752-079708197a6f	2018-03-04 21:08:24.451375-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
00d6c907-2f22-4777-8696-d899ca3ab7a7	2018-03-04 21:08:24.453375-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
59aac221-32fa-4ecf-adbf-c8a8db29434d	2018-03-04 21:08:24.456375-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
96f41b27-1696-4898-be90-9978c31cf5e1	2018-03-04 21:08:24.459375-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
1d9548ea-ae61-477d-bc3b-6fbd9edd72c9	2018-03-04 21:08:24.463376-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
9a9ecbb9-b4e7-4e06-902b-8217d684dc20	2018-03-04 21:08:24.466376-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
aa0f9d2f-d2ac-4ff3-bfc0-b6357c822f0e	2018-03-04 21:08:24.471377-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
4d901fcd-f3b7-4981-9ae5-f66164a18294	2018-03-04 21:08:37.30566-06	3	[22341] IC 348A	[4] DLarrabee	[21062] a	\N	\N
9831d6a8-bb63-424a-9847-102c4d5669df	2018-03-04 21:08:37.571686-06	2	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
c9a8029a-fd91-44f9-a31b-875a5cef4bcc	2018-03-04 21:08:37.576687-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
973e8bee-e72a-40d9-b924-f5be844dbc5b	2018-03-04 21:08:37.584688-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
eb4a9bcf-71ad-43c9-915f-b4c29e20af49	2018-03-04 21:08:37.588688-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
6d3359bc-8975-46b1-a5c4-510e7b6357f2	2018-03-04 21:08:37.592689-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
730fa402-7e21-4fca-8fbb-37c2605e4427	2018-03-04 21:08:37.596689-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
ae7a9a90-134b-49cf-86cb-42532e2d7da1	2018-03-04 21:08:37.600689-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
3cbfca11-3339-42be-aae9-a1f9f2ff06e6	2018-03-04 21:08:37.60569-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
5b7d7a48-954b-44be-bba0-e907e3df64bd	2018-03-04 21:08:37.60969-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
cbf88340-7d81-4029-9f75-f261295cda71	2018-03-04 21:08:37.616691-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
366d9996-6fc4-4b26-bd8a-797bce8c6d7e	2018-03-04 21:08:37.620691-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
50bbae14-6eb8-4bf8-b37a-957155b7600c	2018-03-04 21:08:37.625692-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
3942e439-78b5-40e2-a136-9922220ce83e	2018-03-04 21:08:37.629692-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
cb8a2362-796d-46b3-81ca-19a93e70151e	2018-03-04 21:08:37.634693-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
d26f160e-2b97-4ce9-90cb-80f0ae8f4010	2018-03-04 21:08:37.637693-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
e585ef03-3738-4e26-920f-e4bfffd36937	2018-03-04 21:08:37.642694-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
ab628ed9-2fda-4781-960a-051bf0d5effc	2018-03-04 21:08:37.646694-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
d9a00767-d9ab-4914-98da-2d3d5128e5da	2018-03-04 21:08:37.653695-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
14dbe638-a1af-4a16-9dda-698e339d131b	2018-03-04 21:08:37.657695-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
dcd36170-5a22-4e0d-8492-e9375bcc83df	2018-03-04 21:08:37.662696-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
6a896ad4-b8b8-4ea5-9e05-86f225349c64	2018-03-04 21:08:37.666696-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
26476db5-adfb-440f-9949-2e98b52edd0f	2018-03-04 21:08:37.670696-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
e68b720e-8c6b-4484-8ee0-ba3040c0c18c	2018-03-04 21:08:37.675697-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
92b0dd15-09f6-4c0c-a030-6fdd8a1399b0	2018-03-04 21:08:37.679697-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
a422b123-4577-430d-a536-3bd014547a2b	2018-03-04 21:08:37.684698-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
f4e6871f-6481-4da2-ba99-9638a7b6fffc	2018-03-04 21:08:37.688698-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
83164b9a-21d4-4476-ac74-bb41cda14e8b	2018-03-04 21:08:37.693699-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
95bc131d-2aec-4d64-ac42-a2933fd08153	2018-03-04 21:08:37.697699-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
7753e3f9-a294-4b27-9f62-fc15b904861e	2018-03-04 21:08:37.701699-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
5a6ec5a9-fc7c-4f4e-99ae-42731aa27b8a	2018-03-04 21:08:37.7057-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
7d762c2d-a365-487f-bdab-6cc1c056e351	2018-03-04 21:08:37.7097-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
fb384839-7d37-4efb-b8ea-ace901d2cb7a	2018-03-04 21:08:37.715701-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
9986f8e2-e864-437b-a222-115df9981204	2018-03-04 21:08:37.718701-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cda6727c-776b-4a0e-b61d-2582615df1c8	2018-03-04 21:08:37.720701-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
736180b1-c12c-4615-ad80-b38670fabee3	2018-03-04 21:08:37.723702-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
59f5ce4e-d8d5-4724-8a31-ab0be2af3753	2018-03-04 21:08:37.726702-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9645b925-474f-412a-a64e-9f13d85743bc	2018-03-04 21:08:37.730702-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
465f965a-c39f-4ccc-9e25-eac3701e23c1	2018-03-04 21:08:37.734703-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d3f9f9a8-2372-4af1-82f6-ae61622714a1	2018-03-04 21:08:37.737703-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6063f19a-ee04-4040-bd0f-6c47888ef282	2018-03-04 21:08:37.741703-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
814a962e-f9a0-48a4-847c-367bf6d3f418	2018-03-04 21:08:37.744704-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2f66f470-0e35-4680-8af4-99eb2f49dccb	2018-03-04 21:08:37.747704-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ec51c4d7-5478-4474-8388-7e918996b0a1	2018-03-04 21:08:37.749704-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5ff3b671-2010-4c50-88e3-5cfb0330e748	2018-03-04 21:08:37.752705-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
07442bd5-3323-4cc5-9bd9-5efe7253e59f	2018-03-04 21:08:37.755705-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3fa36732-1f71-42ad-a79a-3b02d8216fe3	2018-03-04 21:08:37.761705-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0f7d9737-77f6-4151-b5f7-6dbb581ff028	2018-03-04 21:08:37.764706-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b3acc606-b47c-4065-b1e6-5ad8401ef9df	2018-03-04 21:08:37.768706-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
daa81497-29a4-4bb6-909b-b7eab34c9b9f	2018-03-04 21:08:37.771706-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c91c8f3d-afc4-47fc-9b25-639ee768ec64	2018-03-04 21:08:37.774707-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
837093b5-f921-4a1c-ae34-cde100688aee	2018-03-04 21:08:37.777707-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
e6bce132-0b61-4775-bb6e-32ef4247e219	2018-03-04 21:08:37.781707-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
cc948906-57c0-4c35-9c40-6215afa4b239	2018-03-04 21:08:37.784708-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
7e6a4eb2-5126-4bf7-9738-a49d59039cf7	2018-03-04 21:08:37.788708-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
eb4cb71d-6a01-4749-98b4-b484b2ed7ee5	2018-03-04 21:08:37.791708-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
88543686-8b93-4532-82ca-8d330649ac47	2018-03-04 21:08:37.794709-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
2fa7ccc5-fd20-4cd5-b60f-4c25af4a8732	2018-03-04 21:08:37.797709-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
9de92b5f-6c8c-497b-bb74-30aa190c33b0	2018-03-04 21:08:37.800709-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
df593282-a8e2-47db-9af7-5f6e83a62259	2018-03-04 21:08:37.80371-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
fb1dc661-3d3d-452b-8039-c58129203936	2018-03-04 21:08:37.80871-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
d08a97a5-417b-4977-b7d2-4f17b1cfc2ec	2018-03-04 21:08:37.81171-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
ce235856-22d3-4e03-a40c-9e330d78facc	2018-03-04 21:09:04.861415-06	3	[22342] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
4fd901f1-5fdb-431d-94d8-8dafcb7124e5	2018-03-04 21:09:05.120441-06	2	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
663fd1f6-5f70-4264-b4a4-a477ba4c1854	2018-03-04 21:09:05.124441-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
d156fa19-923d-48ba-9827-db14bb7e19ea	2018-03-04 21:09:05.128442-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
648020bf-e198-405c-b931-be9da92600c8	2018-03-04 21:09:05.137443-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
1ce27f96-4f84-49d3-8302-2285d0e6ea11	2018-03-04 21:09:05.142443-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
3f8f78df-4a0a-4f75-91a1-a16a03ad762d	2018-03-04 21:09:05.148444-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
3b87f5c8-156d-4769-9adb-78aee1998ccf	2018-03-04 21:09:05.153444-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
27a98c67-a5f7-40f9-a126-ea8ab3adcb29	2018-03-04 21:09:05.157445-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
30e60da9-62fd-4f05-8835-9374117545cc	2018-03-04 21:09:05.161445-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
3b28a87e-5212-4d92-be1e-45b172bb3cf1	2018-03-04 21:09:05.165446-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
ebb0a809-3f96-4e42-978e-15acbf91a0f0	2018-03-04 21:09:05.169446-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
e1a70c85-b1eb-46da-88aa-2dff641212f6	2018-03-04 21:09:05.173446-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
d12fe72a-56cd-4cb4-84e4-b6089d9ee3c8	2018-03-04 21:09:05.179447-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
94270a1a-30a5-46c9-bbf2-66e4a19b18c0	2018-03-04 21:09:05.183447-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
1494bcb6-c113-4c06-8d37-dfef9271a97e	2018-03-04 21:09:05.187448-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
5e8eccda-db3d-489c-8180-c7734e2f0a11	2018-03-04 21:09:05.191448-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
e9ac41a6-8231-44f4-9c6f-f4559a26ceb3	2018-03-04 21:09:05.196449-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
3e9f1be2-caec-4332-9569-622b17b61cbf	2018-03-04 21:09:05.201449-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
47f03382-3734-4b61-8a54-56104ed8211a	2018-03-04 21:09:05.204449-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
3c864058-5d1d-4a18-aa7e-5ba3a3a1fcb7	2018-03-04 21:09:05.21045-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
e2ea229e-0593-49e3-b261-2ca9096a8db4	2018-03-04 21:09:05.21445-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
0fa478fa-61fe-4db8-a5f7-5dc855d4c49f	2018-03-04 21:09:05.219451-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
83eee75e-7959-4cd5-b5e6-77608561d44b	2018-03-04 21:09:05.224451-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
1162399f-a3e4-413d-a7bf-070a59bf02f5	2018-03-04 21:09:05.228452-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
ed3e7882-1af3-4df5-9cc2-9f04ae6d719e	2018-03-04 21:09:05.233452-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
d222cdcb-b17c-4787-9358-ff2f11ee237e	2018-03-04 21:09:05.237453-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
fbab9476-af4d-4363-b51f-5abd61fbc149	2018-03-04 21:09:05.242453-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
27276818-f742-4dea-bda8-5780839bb6cb	2018-03-04 21:09:05.248454-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
0cd63db2-c774-4d6e-8d82-1206e81117b5	2018-03-04 21:09:05.253454-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
c1adc92c-e98c-4e8f-af84-b806b4433bac	2018-03-04 21:09:05.257455-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
0953c3a6-8f2a-4424-9211-132d0a4a1264	2018-03-04 21:09:05.261455-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
12502dc5-9ff1-4b8a-b48b-24c22aafd929	2018-03-04 21:09:05.264455-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6085ca2e-3bc7-4ae2-87c5-6003d46f5588	2018-03-04 21:09:05.267456-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
605b51fe-1a8f-4070-bc92-aa339f795b8a	2018-03-04 21:09:05.270456-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
83987e99-6e06-46cb-aa01-835b7cae3714	2018-03-04 21:09:05.274456-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e13a86ef-ed48-499e-bd69-42f770a60513	2018-03-04 21:09:05.278457-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c1fb2281-7a52-4ccc-a0db-96808d26c16a	2018-03-04 21:09:05.281457-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1fa6ce6f-be59-4975-8e7a-0acb42a2877a	2018-03-04 21:09:05.287458-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f2d796c1-8f6c-4df6-90b1-5645629b0daf	2018-03-04 21:09:05.291458-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b4c727f4-ac9e-4e55-81c4-95d522f08ea3	2018-03-04 21:09:05.294458-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c4bdc6be-f753-421a-bb5d-ccabb7ac6041	2018-03-04 21:09:05.297459-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1758ce2f-671e-4b6d-ac54-04b731f486e0	2018-03-04 21:09:05.301459-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a2865658-8d9c-4f5b-945a-a41601bec50e	2018-03-04 21:09:05.304459-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b7d87b5d-86b6-4ea3-9cd5-79985f725973	2018-03-04 21:09:05.30746-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
32a4b37a-a7d4-497d-9df2-a23549aed5f1	2018-03-04 21:09:05.31246-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2d9b7493-f2ae-4d78-bb5c-d506f30d22e7	2018-03-04 21:09:05.315461-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
495b5b6d-5d08-4a17-9609-cf5ebebead58	2018-03-04 21:09:05.318461-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5251d6c7-04e4-47ea-8ba5-d4412e9c48f3	2018-03-04 21:09:05.321461-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4e02b11d-add4-48b0-b223-41f2a4bf69c1	2018-03-04 21:09:05.324461-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ec926e80-c25c-449b-aa4f-22d3c4162484	2018-03-04 21:09:05.326462-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
68009d50-289b-4662-bdb3-272f34df00c8	2018-03-04 21:09:05.329462-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
44ed96f6-2c00-4aab-8d81-02534715e753	2018-03-04 21:09:05.332462-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
bc6c5b56-1a90-4c32-a3fe-b7780cc5ba48	2018-03-04 21:09:05.337463-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
fe7b37b3-1710-4b78-a187-ed3b07523a3f	2018-03-04 21:09:05.341463-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
085ece26-fc7f-456d-9e90-848373f39ce1	2018-03-04 21:09:05.344463-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
a32dda7e-7b3b-4a68-a36b-ef475839dc90	2018-03-04 21:09:05.347464-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
c93123a4-b8fb-4c03-be77-589e432b31b4	2018-03-04 21:09:05.350464-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
e37ceb30-70b9-4d90-8539-d9250b98045f	2018-03-04 21:09:05.354464-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
2d2afd58-5b19-46cf-a690-0d395cfafd0a	2018-03-04 21:09:05.358465-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
af5ef630-4b99-4e58-b5b6-447e195a2137	2018-03-04 21:09:05.362465-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
7ab7b125-3b92-482a-adf9-46e9c864eabe	2018-03-04 21:09:32.7112-06	3	[22343] IC 349A	[4] DLarrabee	[21062] a	\N	\N
628e1b9c-d6ad-4abc-a278-98b79b6f723c	2018-03-04 21:09:32.995228-06	2	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
3e166ee4-a167-411a-a887-b2f425de3f59	2018-03-04 21:09:33.001229-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
65c5abcb-c423-4b1c-a790-75528f3fc15f	2018-03-04 21:09:33.005229-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
69be07f6-f793-49c3-97f7-1283d4db95b6	2018-03-04 21:09:33.01023-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
6a203669-e9c0-4b03-a20f-3248a742a625	2018-03-04 21:09:33.01523-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
682b07fc-74f8-4e91-93bb-27d6897fe8e7	2018-03-04 21:09:33.020231-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
33f9c6fa-668b-4b7b-bcc1-4b374fa4590f	2018-03-04 21:09:33.024231-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
57071174-7fed-4705-a936-0399df5e9638	2018-03-04 21:09:33.029232-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
536a75e2-0883-4803-a68e-145facde2abd	2018-03-04 21:09:33.034232-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
4175be21-dd1a-4691-b92b-7438020f2ea7	2018-03-04 21:09:33.037232-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
ff2129b3-e7e0-4297-a20c-beca7913a702	2018-03-04 21:09:33.041233-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
9bec7312-7fb8-4df0-8311-bca21019ccad	2018-03-04 21:09:33.047233-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
83c1dac7-091c-4bca-9a4f-c1b7d8394f97	2018-03-04 21:09:33.051234-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
8f20c521-5287-4c9a-9af5-fe07b2e8f83a	2018-03-04 21:09:33.055234-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
ad0e91f0-b308-4560-a7a5-89a9578eb917	2018-03-04 21:09:33.059235-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
7742f463-97de-4d7b-a33f-70151b853196	2018-03-04 21:09:33.064235-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
5a5687a8-7e9c-44ad-85ff-e10cd0031b01	2018-03-04 21:09:33.069236-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
bfa8d39f-9d46-4e69-a449-c9a16b5ca02b	2018-03-04 21:09:33.073236-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
d53e4f9a-b41c-48e4-bc84-6c5f2b0cc238	2018-03-04 21:09:33.077236-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
aa77b5a3-cecd-4567-8de5-bcb7901432a3	2018-03-04 21:09:33.082237-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
5ca6d96a-19d5-4a36-8ed2-e3bb6b7f6505	2018-03-04 21:09:33.086237-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
3d6dc1b7-9da8-4779-8a15-8b38e008ae7e	2018-03-04 21:09:33.090238-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
34f090d4-480d-441c-82ae-a50959cb9aba	2018-03-04 21:09:33.094238-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
372da580-4e8f-458c-8a77-3af21fe9c03a	2018-03-04 21:09:33.097238-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
ff888792-c5f9-495a-ae7e-18d12b90faf6	2018-03-04 21:09:33.101239-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
047bceca-ac49-4222-a237-85eadc937b65	2018-03-04 21:09:33.104239-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
58f72b21-6310-4021-9591-960d2132c18a	2018-03-04 21:09:33.10924-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
5fda321a-7db9-496e-985e-62e5fcb2e42e	2018-03-04 21:09:33.11324-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
cc26c75d-d7b9-4e76-baff-c988f2123a97	2018-03-04 21:09:33.11624-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
936a1010-ee1c-4f14-b0e9-8a946652b66b	2018-03-04 21:09:33.120241-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
ab6a2b59-c7fe-45c0-a172-1f1d605dbf83	2018-03-04 21:09:33.123241-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
09b54ae8-fc3f-4bc0-a5ea-6b4782075d9f	2018-03-04 21:09:33.126241-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
41b172ba-5dd3-4ec3-a559-06f06c77168e	2018-03-04 21:09:33.129242-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
90094863-9138-4b1a-91cc-6203ab099594	2018-03-04 21:09:33.133242-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
84395a9f-b77c-4334-9308-ccc7f1e0b074	2018-03-04 21:09:33.135242-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0edd457a-b9d7-4991-80f3-7d091de06e84	2018-03-04 21:09:33.138243-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0285d261-c629-4bf7-b5fb-2264f45bcc24	2018-03-04 21:09:33.141243-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e7dae751-d9dd-47c5-93b7-c54ded04a5c1	2018-03-04 21:09:33.144243-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0cff0fc4-7261-4e73-b4c6-451a1af538e6	2018-03-04 21:09:33.147243-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b7250d39-a53a-4b02-905e-02352ca406fe	2018-03-04 21:09:33.150244-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6a5af339-2163-440d-a12f-10ef340191c8	2018-03-04 21:09:33.152244-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1cb2e31f-fef9-41e1-aa7b-400489521f47	2018-03-04 21:09:33.156244-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7b2f4bda-144b-4d5b-83f4-ef4e60153247	2018-03-04 21:09:33.159245-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c6706c6d-17aa-493c-9135-27a8838e34f0	2018-03-04 21:09:33.163245-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
91e1949a-f13e-471b-b9b1-7d408f1deee6	2018-03-04 21:09:33.166245-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a29ac03a-56b7-4173-9f22-f5521d46adee	2018-03-04 21:09:33.169246-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8630622b-15da-494c-a7f2-d76778e64e78	2018-03-04 21:09:33.173246-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5c4105ce-9525-4672-90ee-1327d3d89228	2018-03-04 21:09:33.176246-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
51906e5c-9aa6-4a23-abed-0143925ecc0a	2018-03-04 21:09:33.179247-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
d6b51b0d-28c6-4f7c-b504-5d8b77c4c13b	2018-03-04 21:09:33.183247-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
34f5e6c2-4345-4065-8295-14bf2304ea8d	2018-03-04 21:09:33.186247-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
94e5b2fe-0b44-4026-8858-6a85c4dd9a83	2018-03-04 21:09:33.190248-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
440166c7-d545-4620-91f4-ce7ccb978b6e	2018-03-04 21:09:33.194248-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
555b597f-0a6f-430d-b0ed-77f82344dead	2018-03-04 21:09:33.198249-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
f37fe82e-4a1f-467b-b431-86d378623eb1	2018-03-04 21:09:33.201249-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
44809b61-a6f7-471b-8927-6de8355ba012	2018-03-04 21:09:33.205249-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
36d88cb1-b0dd-4c51-bb45-896b7f76b9ea	2018-03-04 21:09:33.20925-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
0e7f0286-6216-4b83-987f-f99593c33db1	2018-03-04 21:09:33.21325-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
a0f83378-1ef8-46e5-8f52-abc575ece5fc	2018-03-04 21:09:33.21725-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
f082a6c3-eea6-4912-8c5a-0716b37abf28	2018-03-04 21:09:48.589788-06	3	[22344] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
6a75753c-becf-48fc-b622-91e8c6b8f011	2018-03-04 21:09:48.850814-06	2	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
e043acb5-49e3-49ac-9dbd-9306f3d84e5b	2018-03-04 21:09:48.854814-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
f4d73d61-431b-4f11-99fb-ae25ffe01c09	2018-03-04 21:09:48.861815-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
9cc8c896-c359-4e03-b66f-040b3fd0ef8e	2018-03-04 21:09:48.865815-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
e1587629-bde1-4868-b819-4877f486c5d9	2018-03-04 21:09:48.870816-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
7d078809-4949-45a5-b340-48029e5888d1	2018-03-04 21:09:48.874816-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
9e261085-a1fe-4be1-9e2e-1d34d06b16f0	2018-03-04 21:09:48.878816-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
cc65dd9b-c2da-4bc7-bd7c-35939188535f	2018-03-04 21:09:48.882817-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
a3a9ae90-91d6-4a0a-bef0-289cc28c21fa	2018-03-04 21:09:48.886817-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
3c6e4579-6622-49d1-b3ca-67930ff9536d	2018-03-04 21:09:48.889818-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
a46e2078-54b2-40e0-811b-b4e828cee5e6	2018-03-04 21:09:48.893818-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
247ad875-1f0f-4698-bfca-2309b743e1b8	2018-03-04 21:09:48.899819-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
0610f73a-a31e-4e6a-b5e0-74e1e18f1cc6	2018-03-04 21:09:48.903819-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
6b7d1724-f700-4745-9a1e-6bcaf1b99563	2018-03-04 21:09:48.907819-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
292094ba-f792-4a79-a296-0fc3bda229d1	2018-03-04 21:09:48.91182-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
87b9548b-15d2-403b-982f-dd1b19f1f638	2018-03-04 21:09:48.91582-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
49d6bc7f-38c1-44f7-bd78-55f874949c80	2018-03-04 21:09:48.919821-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
a8d4ba8e-f25b-4615-9384-59e995711afa	2018-03-04 21:09:48.924821-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
1b73dfc8-6180-4a49-bac8-992bbe1a0537	2018-03-04 21:09:48.929822-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
58ca358c-dd12-4fbc-8b38-df185cb491a5	2018-03-04 21:09:48.932822-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
76ba8187-055b-43db-9c98-302f8aa9b025	2018-03-04 21:09:48.937822-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
087606d2-3530-4399-b2dc-ac387afbc2d2	2018-03-04 21:09:48.941823-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
1ae69c17-1109-4368-89ff-b9af26cf6295	2018-03-04 21:09:48.946823-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
a227db5f-aa44-4266-92b4-a38b9e1673c3	2018-03-04 21:09:48.951824-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
80b68b6c-427f-43d1-8ac1-25bcb5d3ec8e	2018-03-04 21:09:48.955824-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
23941002-1b81-4fd9-8320-47e760baa0b3	2018-03-04 21:09:48.959825-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
dfe9775f-e7f5-4f8c-82f4-07dfe77c2d2b	2018-03-04 21:09:48.964825-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
254afffd-f214-46d6-aaaf-993119356ef8	2018-03-04 21:09:48.969826-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
0291fcbf-9f57-4da8-8fca-d7eec82d77fa	2018-03-04 21:09:48.973826-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
a2b7221d-278b-4de8-b2ce-3fe2c0c6ae8d	2018-03-04 21:09:48.976826-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5ab693ac-e8df-4752-b4b7-e12660d87dd3	2018-03-04 21:09:48.978826-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
eee976fb-48fe-4eb2-9329-3e2709acf5fd	2018-03-04 21:09:48.981827-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
15b713a1-910f-428b-ae26-088f3eba39f2	2018-03-04 21:09:48.984827-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8013d23a-2dc8-434d-9071-2e022b61dc97	2018-03-04 21:09:48.986827-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9494ca81-9782-4e1f-9419-fa816ed859c9	2018-03-04 21:09:48.989828-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e067d226-7819-4824-8125-a39c23fbd065	2018-03-04 21:09:48.993828-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
124ecfb0-152d-4802-8069-066603d6aeba	2018-03-04 21:09:48.996828-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1dee2b3e-338f-43dd-b6b7-4427e51daa00	2018-03-04 21:09:48.999829-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2692f6c6-fcbe-4ae5-86fc-636acccde6d6	2018-03-04 21:09:49.003829-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e2705e36-3d3a-450b-824f-577ae58fd43c	2018-03-04 21:09:49.007829-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
37582b8b-3401-40a6-9134-0dfd215da76a	2018-03-04 21:09:49.01083-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
124048b9-0806-4e2a-acb0-516bdab0062c	2018-03-04 21:09:49.01383-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f8dce54a-bdba-4936-8cb3-90ea95206f9e	2018-03-04 21:09:49.01583-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4bfad0cf-bb8d-4023-a7b5-6c8e1a1fdceb	2018-03-04 21:09:49.019831-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
35a887b6-4402-4120-af37-2ee276bb5160	2018-03-04 21:09:49.021831-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1f394694-7b63-4b4b-8574-476eaf6a9eb6	2018-03-04 21:09:49.024831-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
03c8adc9-3c5c-4eff-8508-08b9b6bd423f	2018-03-04 21:09:49.028831-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1068e8f0-5d3d-474b-8658-4f644cfaf8f8	2018-03-04 21:09:49.031832-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
a55b5ce0-d301-4f55-8af0-223c46370a5b	2018-03-04 21:09:49.033832-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
4a9ff570-d49f-4ec5-8606-215f9ee23633	2018-03-04 21:09:49.038832-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
8a4750cc-2ac8-4be5-977c-4a007fd8db44	2018-03-04 21:09:49.042833-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
74e2d7a2-c762-4b0e-a4df-9a641b605540	2018-03-04 21:09:49.046833-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
5fc16815-5ee0-4985-8b2d-e2b975aa7b96	2018-03-04 21:09:49.051834-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
010a4f33-b61d-444c-83fe-562952f8d361	2018-03-04 21:09:49.055834-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
e619a3a8-30c6-42f3-b2b2-2077b3f8441e	2018-03-04 21:09:49.058834-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
0a61f842-2fd4-449a-8eed-ee31a40ac7db	2018-03-04 21:09:49.062835-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
a9da3357-4ecf-48b2-b22c-18ee6b1239ef	2018-03-04 21:09:49.065835-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
5ebf7b7c-fa71-45e3-a5ee-9d72a8b65f09	2018-03-04 21:09:49.070836-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
2c3bd111-9471-4502-a0d6-0bab261e68c3	2018-03-04 21:10:07.293658-06	3	[22345] IC 351A	[4] DLarrabee	[21062] a	\N	\N
852a9f3f-50d6-425a-8244-7e5246bac42b	2018-03-04 21:10:07.551684-06	2	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
79913fb4-1e56-4c7d-afc1-8e4a8771a76c	2018-03-04 21:10:07.556684-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
ac668d30-9bf7-41e8-8dc6-1b4c70cd6826	2018-03-04 21:10:07.560684-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
600ca5d7-9ac5-4af8-8e55-12b711b8b372	2018-03-04 21:10:07.565685-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
bef040a5-79d4-4824-ad8d-b9d816504332	2018-03-04 21:10:07.569685-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
cb439c2e-f56a-4f3b-9d49-35ce21d24610	2018-03-04 21:10:07.574686-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
5d2dfdcc-1ebc-4ce6-8f54-08e47b81c45b	2018-03-04 21:10:07.578686-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
6659738b-560b-4d2c-bc19-a6ac5eae3dff	2018-03-04 21:10:07.583687-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
086892ca-1d17-492e-86d8-779660b9ad0b	2018-03-04 21:10:07.586687-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
b3da674b-44a4-428a-bf72-8e764726208a	2018-03-04 21:10:07.591688-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
011fda28-5f50-42d2-9f6a-3fb2de483dda	2018-03-04 21:10:07.596688-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
f12dff44-0cc7-483b-aeb3-46eadc4a287e	2018-03-04 21:10:07.600688-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
66f9240a-fa72-4b20-8664-8d6fdf9476e4	2018-03-04 21:10:07.604689-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
28ccc506-d32c-4df5-934f-34e01bd8b0a7	2018-03-04 21:10:07.607689-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
431e2478-6cb9-45c9-90e5-a1a7f451cc71	2018-03-04 21:10:07.61169-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
fad9ccb4-e55b-41bc-a696-c53ad88b0d62	2018-03-04 21:10:07.61569-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
b6649f4f-64e8-4e33-8964-67ce9dc7405e	2018-03-04 21:10:07.61969-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
b7f649d9-85e2-4e4d-bb60-e9493cea5cac	2018-03-04 21:10:07.624691-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
40416808-420e-455d-89ed-3ef49c806142	2018-03-04 21:10:07.628691-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
cc126c47-cb7a-4f80-ab24-ab04d631ca83	2018-03-04 21:10:07.633692-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
7fc70ade-f543-46a4-8a21-51090d346c92	2018-03-04 21:10:07.636692-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
de519293-98bd-4a6e-9fdc-bafd44927d90	2018-03-04 21:10:07.640692-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
424a7947-1ad1-420f-879c-b4085f400f5d	2018-03-04 21:10:07.644693-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
95c6deeb-73a8-49e7-97ed-723d751def88	2018-03-04 21:10:07.647693-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
98c12fdb-8cfc-482b-94a1-f63ab2029448	2018-03-04 21:10:07.652694-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
26ef4a0f-68fe-4dcf-ac2b-5856ec6d7c4f	2018-03-04 21:10:07.656694-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
5f280a48-1002-447a-9614-961838e5e364	2018-03-04 21:10:07.661695-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
84f08398-490f-414f-81b4-9374305cb03a	2018-03-04 21:10:07.665695-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
6fe3ece9-9a93-4814-a479-cd76fe2cb353	2018-03-04 21:10:07.668695-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
51f24b9d-5ff7-4f31-8a20-316ffc89657b	2018-03-04 21:10:07.671696-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
17c3ea9e-3e2b-4760-9efe-827243c26ef2	2018-03-04 21:10:07.674696-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
aa2c0137-4b12-4845-904f-543b9909eeaa	2018-03-04 21:10:07.677696-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
46406174-0ebe-4e69-9884-3869660b656e	2018-03-04 21:10:07.681697-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
373fd732-36c9-439e-9a77-a8768f4697ed	2018-03-04 21:10:07.684697-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9070181e-c471-4506-93da-f63e9b626401	2018-03-04 21:10:07.688697-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9480736d-939e-4fa9-85fb-ed5174aab9e8	2018-03-04 21:10:07.691698-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3bee1bd3-4dc6-45e7-9d89-76e8d523dec0	2018-03-04 21:10:07.694698-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0c92e653-7afd-404a-8ba3-9a9be05ca49d	2018-03-04 21:10:07.698698-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
60f7c6c3-d417-43a1-875f-2effff9e18c9	2018-03-04 21:10:07.700698-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d5f88b23-d3b6-44b7-93e0-ef8bad90d332	2018-03-04 21:10:07.703699-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c57ad144-b875-453c-8b86-5a7870455bcf	2018-03-04 21:10:07.707699-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
768284cf-7d0d-475f-b180-43a1be1379c9	2018-03-04 21:10:07.710699-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fb0b3288-46f5-4e71-8c5a-8198392cc4ae	2018-03-04 21:10:07.7137-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
378a7e8d-2a5c-4fb5-a6d0-886bdbe2ef47	2018-03-04 21:10:07.7167-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b72ae72c-c29b-4a26-9a61-c88ea0b3bcbb	2018-03-04 21:10:07.7207-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1651ed46-2c59-41ba-a8f0-c9ec069fcc50	2018-03-04 21:10:07.723701-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c78fc53e-c589-438f-8de0-e02a8db4afd0	2018-03-04 21:10:07.726701-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
b05f1a22-6ece-45ce-847d-89df34316eaf	2018-03-04 21:10:07.730701-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
5bbdb6f2-f75c-410f-8a41-3790262597c4	2018-03-04 21:10:07.733702-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
0b9c7b97-fed8-4c5b-b5f9-b71e21421c01	2018-03-04 21:10:07.737702-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
cb6f61c3-d8ad-4d67-a0cd-39c13f588589	2018-03-04 21:10:07.740702-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
2aa52b04-5ab1-4a54-b982-a1db9569c9ae	2018-03-04 21:10:07.744703-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
daa7e4e6-a39a-412e-a582-5853b8b5ce30	2018-03-04 21:10:07.748703-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
23f82c1f-e875-4eaf-94d4-ee4167c4e2a0	2018-03-04 21:10:07.751704-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
c2b81161-a346-4248-8785-d0edd4eeb2d2	2018-03-04 21:10:07.755704-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
f1eecf2c-d21a-4347-96b9-2aef13e12ac8	2018-03-04 21:10:07.758704-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
8bff90d9-cd82-4f67-b208-3737dc0eacd5	2018-03-04 21:10:07.762705-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
0b94fc5c-8dd3-473c-a2be-4a73778c62ee	2018-03-04 21:10:22.643193-06	3	[22346] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
edf78412-319a-4059-a3e1-073fcb5b5632	2018-03-04 21:10:22.929221-06	2	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
37c12875-eaf8-41f4-925c-a4bb6f407b0d	2018-03-04 21:10:22.934222-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
9bcd6037-d897-4ddf-9d29-faab4032c647	2018-03-04 21:10:22.938222-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
e7a94d69-28e2-4c36-9a53-dd02dc8af700	2018-03-04 21:10:22.941222-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
c6c4f320-b026-4e7f-9cc9-e8c153d3f861	2018-03-04 21:10:22.946223-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
feb698d7-af26-4081-88dc-b35ea007a385	2018-03-04 21:10:22.950223-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
f9a44c08-4ea7-474e-b38a-6101f05d86ec	2018-03-04 21:10:22.953224-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
5d021f6d-e08a-432f-8939-cfd17a9ff308	2018-03-04 21:10:22.957224-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
899d82d2-7ba2-423d-b610-f9dba12fd90d	2018-03-04 21:10:22.962224-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
dc4d83ff-7927-4dbb-9e84-620387fa6d74	2018-03-04 21:10:22.965225-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
8ac9ec7a-87f4-4133-97c9-b57a6eae5418	2018-03-04 21:10:22.970225-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
57f8edf3-0952-4996-8e39-a36fb3b2ed6b	2018-03-04 21:10:22.973226-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
f48b0a5c-096f-4ad3-9662-d6a9ceac2109	2018-03-04 21:10:22.977226-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
94cae15e-3151-43cd-b7ee-0807db157061	2018-03-04 21:10:22.981226-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
2b704b3a-d4ee-4baf-b75a-827dc2ed2c36	2018-03-04 21:10:22.984227-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
200b40f4-2b8d-408e-8b22-5eebc7330489	2018-03-04 21:10:22.989227-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
7ba4df77-f061-4ef6-97f3-97e1332d5554	2018-03-04 21:10:22.994228-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
bec42af8-7aef-4558-b07f-63b96c017c91	2018-03-04 21:10:23.000228-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
0bc9d71f-7dd6-44c6-8fb4-0ec0ba671957	2018-03-04 21:10:23.009229-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
c82694bd-c314-4f10-baf3-f8d307f214c3	2018-03-04 21:10:23.01423-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
cb3d054f-bbd5-4244-8839-b0e95bfb482d	2018-03-04 21:10:23.01923-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
b81a1e42-c3ad-4de0-800c-ac057aa16954	2018-03-04 21:10:23.023231-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
121dcf35-f43d-4df1-852e-0dcaced45d64	2018-03-04 21:10:23.027231-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
610d5e9c-877c-4d42-8538-9ea77a5cc574	2018-03-04 21:10:23.034232-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
b79d8f41-52eb-4c62-85e8-d4a470ecde34	2018-03-04 21:10:23.038232-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
287a3c78-d119-45b8-8609-31f80c3d42c1	2018-03-04 21:10:23.054234-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
2b69c32e-7196-4a76-8deb-f94545f58960	2018-03-04 21:10:23.058234-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
a8c0a986-18bf-4792-8d8c-6f6842c0ab3c	2018-03-04 21:10:23.061234-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
890f81b6-8c05-4e3f-a009-75ea21e226b7	2018-03-04 21:10:23.063235-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f37e0e17-3645-4a61-b9fa-cef2376c5def	2018-03-04 21:10:23.066235-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f53d9d73-aa5c-414c-890d-defeec03bb28	2018-03-04 21:10:23.069235-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ae9cac91-9a69-4e82-b412-94ac1e99fc15	2018-03-04 21:10:23.074236-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
13d4ba60-8eba-4eb0-8d2f-b690eb4145a5	2018-03-04 21:10:23.077236-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ccad530d-862d-4940-a1b6-9986d43be480	2018-03-04 21:10:23.081236-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8a88b619-2993-402f-812c-ba78497500d6	2018-03-04 21:10:23.085237-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9b64a4a1-4e38-48b7-8df4-3bf085a32338	2018-03-04 21:10:23.088237-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a0a07bf7-3199-4065-b3ef-aec32060e967	2018-03-04 21:10:23.091237-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c01ae4f8-9e4d-4603-aa75-60740e0e8774	2018-03-04 21:10:23.095238-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7eb3cdc5-3b69-43b3-a846-2a5e2410b057	2018-03-04 21:10:23.098238-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2c69fd48-5637-474f-b98b-f840105cb4e2	2018-03-04 21:10:23.101238-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
034934d7-91b0-4830-8051-50a4121d5ec7	2018-03-04 21:10:23.105239-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
67ebd8cc-5feb-4140-9e66-3a0fe7c807bf	2018-03-04 21:10:23.108239-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0c4d8636-e008-4196-948b-cbc8174debc8	2018-03-04 21:10:23.110239-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3f6e3fda-b89e-4ba3-940c-d960cbaa11fa	2018-03-04 21:10:23.11424-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4a6f1a9e-a66f-4c9f-9cb1-805ad0aedbfc	2018-03-04 21:10:23.11724-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5969cfde-54ce-4460-8c6c-c002f1dab757	2018-03-04 21:10:23.12024-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
b497593c-0f4b-4274-901f-130a182959e8	2018-03-04 21:10:23.123241-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
0db7865d-f8c6-42bd-ba26-37049e912ffb	2018-03-04 21:10:23.127241-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
a8db3c45-8d78-4b7d-ad27-7368b46a0585	2018-03-04 21:10:23.131241-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
9d5188b4-74e7-4c92-977e-02268d48fd9d	2018-03-04 21:10:23.135242-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
d4aafa13-bc82-45b9-be25-12e4b7ae2a37	2018-03-04 21:10:23.138242-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
09f5b4e9-c52e-4357-8212-7d8d58926db5	2018-03-04 21:10:23.142242-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
8d37601f-e451-42ad-92d2-2cae7a9d53af	2018-03-04 21:10:23.145243-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
3213e94b-6838-47b5-a37c-12f4948096e2	2018-03-04 21:10:23.149243-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
9897c5d1-e466-4017-9a9b-ab75cbcc6f99	2018-03-04 21:10:23.152243-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
d51f23c9-616f-4fe7-b730-c439d2472448	2018-03-04 21:10:23.155244-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
b0154869-c70f-4d92-89da-14a16423bd15	2018-03-04 21:10:40.033931-06	3	[22347] IC 351B	[4] DLarrabee	[21062] a	\N	\N
870d463e-af8d-4bc7-9c61-5a690eef17ed	2018-03-04 21:10:40.299958-06	2	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
dc9b1e99-78d3-4a9d-a6d5-10fbdc902c0e	2018-03-04 21:10:40.303958-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
00fa445c-5d78-491e-896d-4a8dadd5ef62	2018-03-04 21:10:40.309959-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
c75460c5-168c-4428-8b56-2db8963ad1c1	2018-03-04 21:10:40.312959-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
5ce1ec22-a402-476f-b639-350dfb832886	2018-03-04 21:10:40.31696-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
964daf63-65bf-4085-90d0-c3b851a07264	2018-03-04 21:10:40.31996-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
f483855d-dc31-455e-8bb8-589faa892aa0	2018-03-04 21:10:40.324961-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
a3bea0bf-2688-4266-be53-3501e2f1ce6c	2018-03-04 21:10:40.328961-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
30ed5d95-f7e9-4104-b3c9-15281ae2b0a2	2018-03-04 21:10:40.333961-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
cc1b3fcb-c556-4603-8731-c68300e19364	2018-03-04 21:10:40.338962-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
7651e671-ee03-4c69-8190-7e7a30e0a263	2018-03-04 21:10:40.342962-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
cd8a61ac-3c5f-46ac-b393-b3cdc0438079	2018-03-04 21:10:40.347963-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
e132434e-6998-4a04-a3d5-708961e53ad4	2018-03-04 21:10:40.351963-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
28a73216-33ea-4f1d-9c07-1e59df6018e9	2018-03-04 21:10:40.355964-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
cc62be24-0e49-4031-b302-ff143863954c	2018-03-04 21:10:40.358964-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
2be8e013-9eff-4325-b747-89987e2774aa	2018-03-04 21:10:40.363964-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
7e01058e-680b-4896-97e7-fd0f7be2bd07	2018-03-04 21:10:40.367965-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
79294f84-9916-431f-8785-cf3878bb2c00	2018-03-04 21:10:40.371965-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
5de97b4a-b84f-41ba-b300-ef4a96be3719	2018-03-04 21:10:40.376966-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
30681ca0-411a-4d71-a4eb-750b9f9f51a7	2018-03-04 21:10:40.380966-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
69003284-5c06-4c61-a916-3e881cd09bfe	2018-03-04 21:10:40.384967-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
9dbad87b-5212-46c3-adbd-f9ad8307a180	2018-03-04 21:10:40.388967-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
a4a4aca1-c476-4dff-98c8-33620e730a41	2018-03-04 21:10:40.392967-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
55d48f45-9878-494f-a466-f0fce7cccb80	2018-03-04 21:10:40.396968-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
9023bcbe-bb76-47d0-a942-f180a8e63943	2018-03-04 21:10:40.401968-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
6e6bf4a0-611d-4fba-af3c-aba432e65a60	2018-03-04 21:10:40.405969-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
cc7c0c19-0b8a-4d7a-bf6f-1d9027ab4d55	2018-03-04 21:10:40.408969-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1b204203-01e9-4d0f-88c3-3a6f6adac8f0	2018-03-04 21:10:40.411969-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
99ce8e43-0fa7-4ad6-bc70-65b55071467f	2018-03-04 21:10:40.41597-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f90a2d9e-c8aa-4bdc-a273-7b73506a45ad	2018-03-04 21:10:40.41897-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ff25cca2-57f8-480d-b95e-c6f88470c3b9	2018-03-04 21:10:40.42297-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
24ab7d52-6b78-49b6-b044-33d81e163458	2018-03-04 21:10:40.425971-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
eac20105-a6f9-4351-b256-bc5dd328b854	2018-03-04 21:10:40.428971-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f44c7480-cad1-436a-8213-643fcecf39e2	2018-03-04 21:10:40.432971-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4638809c-0ae4-48ef-8110-e867f334663b	2018-03-04 21:10:40.435972-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a413d2b4-bcda-48c3-80c1-cdb76ebfd4e4	2018-03-04 21:10:40.438972-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3382d6f0-851c-4738-b52b-e3c2314531a4	2018-03-04 21:10:40.441972-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
205770cd-882a-491a-aacb-8d1b251a328c	2018-03-04 21:10:40.445973-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
36b6eb19-5b88-4b7f-b48f-b14138e2c63c	2018-03-04 21:10:40.447973-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8ce0ce14-1ea5-441f-bae8-b10ba77fee13	2018-03-04 21:10:40.450973-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6ad63833-8e5e-4500-a339-aef453d64b83	2018-03-04 21:10:40.453973-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
15a89b04-0582-4e3c-adfe-6c9ad1825640	2018-03-04 21:10:40.457974-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e779b7f7-e906-429b-b07d-dd373b7b570c	2018-03-04 21:10:40.460974-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b098aded-abd4-406c-b82f-8d0132c9538a	2018-03-04 21:10:40.464975-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
84527e9c-a9f9-4e08-9c2f-067e66a321d1	2018-03-04 21:10:40.467975-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
544229af-2b7e-4c97-95cf-7f7ebb09c797	2018-03-04 21:10:40.471975-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
6318dd9a-7333-42e8-906d-3daecc781d09	2018-03-04 21:10:40.474976-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
ac07319f-a5ca-4e91-bf5b-99d0bb285f4d	2018-03-04 21:10:40.478976-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
85098206-0013-45c5-8338-a5060b964912	2018-03-04 21:10:40.481976-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
2f2417ce-62f6-439b-8373-27b8924a6da2	2018-03-04 21:10:40.485977-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
de911c2f-1bda-4817-b96d-0f9ea992095e	2018-03-04 21:10:40.488977-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
30658072-c078-4801-bed4-fc7fb90ea5a6	2018-03-04 21:10:40.492977-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
246381d1-4cd9-4422-8d40-88bca2003a7c	2018-03-04 21:10:40.496978-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
40755fe8-5f03-44a7-8407-7f4a6ebdb6d0	2018-03-04 21:10:40.499978-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
16acaaea-04a4-4c9b-a6f0-747c54c90743	2018-03-04 21:10:40.502978-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
bc7e430d-a731-4192-898d-799df7178f33	2018-03-04 21:10:53.569285-06	3	[22348] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
59637685-375d-4ed7-acd6-ca0bb669fcaa	2018-03-04 21:10:53.82131-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
d7e950fb-b67c-4c92-ac03-b3da0efa3b1c	2018-03-04 21:10:53.826311-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
7f888ed5-ef80-4653-b28f-85717a1e00eb	2018-03-04 21:10:53.830311-06	2	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
cb9351e8-9fa0-4848-a29f-46287dfb4c1b	2018-03-04 21:10:53.835311-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
c4ac6483-696c-4124-bd30-2a54f76ae9a7	2018-03-04 21:10:53.840312-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
02fd3a1e-0b26-4288-933c-5407044f2de9	2018-03-04 21:10:53.844312-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
2f42bc76-6e42-43cd-97cc-12f6b1a97854	2018-03-04 21:10:53.848313-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
6826a734-a356-4609-971c-803a88e5f957	2018-03-04 21:10:53.852313-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
9a206c38-31e5-4aad-9a86-12728b37379f	2018-03-04 21:10:53.856314-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
00f98d7a-eeaa-4316-8c93-4ccb66a50b47	2018-03-04 21:10:53.861314-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
b2387175-1696-4f3f-bc96-53a31ad553a7	2018-03-04 21:10:53.865314-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
b2e67018-15d4-43b6-8faa-e3b2801c9936	2018-03-04 21:10:53.870315-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
ab1faf79-dc50-4d52-a95c-c24ebe880ca6	2018-03-04 21:10:53.875315-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
ad051116-c14a-48af-b03d-adacbd383d28	2018-03-04 21:10:53.880316-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
c257e0fa-688c-4c8a-8e29-a9ca7306fabc	2018-03-04 21:10:53.885316-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
c44f1d62-eaf9-42f4-9e3b-1d9a149b04a6	2018-03-04 21:10:53.889317-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
38830d72-d1f7-44da-a2d7-41983f125454	2018-03-04 21:10:53.893317-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
cea35451-4444-417a-88f7-39b1a5ac4293	2018-03-04 21:10:53.898318-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
c0a04587-fa49-4766-8579-a0697a3dab62	2018-03-04 21:10:53.902318-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
eb8042e2-4498-456e-b69f-cecb495ae727	2018-03-04 21:10:53.906319-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
4b52f390-e9d6-4533-9cab-e2e824a43113	2018-03-04 21:10:53.910319-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
a514f54d-fbaa-4d70-a924-58e51e65860e	2018-03-04 21:10:53.914319-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
86d11743-8bcc-44ac-80d1-1544423c3cb6	2018-03-04 21:10:53.91832-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
b7bef7c5-3ca8-42cf-b451-b7df249685ba	2018-03-04 21:10:53.92232-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
50315f9d-9a90-478c-aa50-a8553b859258	2018-03-04 21:10:53.927321-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
a0bd9d59-f055-4df1-a623-99ae7f38a9e6	2018-03-04 21:10:53.929321-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
47e7b78d-9145-4728-9189-83a5284e4e5e	2018-03-04 21:10:53.933321-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f254d2e4-5200-4f54-b13b-b234479a2907	2018-03-04 21:10:53.935321-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8d5661bf-20fd-41af-a6de-5629f91e792e	2018-03-04 21:10:53.938322-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1c65c8af-abda-463d-b7c5-0e85220c4af0	2018-03-04 21:10:53.942322-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1c0d4c78-e62b-404f-9462-9d62304c7dc0	2018-03-04 21:10:53.945322-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6bf3bb36-9ff0-4454-b166-dbeb3bb60932	2018-03-04 21:10:53.949323-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
820e0579-cd73-4c06-8636-05d0a262b104	2018-03-04 21:10:53.952323-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1b7a634c-b701-43d9-8453-b47be3588fe6	2018-03-04 21:10:53.956324-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f9395099-4593-42df-9509-3aeba2e802b8	2018-03-04 21:10:53.959324-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
66e6c398-130a-446e-958b-e8e09f767edf	2018-03-04 21:10:53.963324-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f4dd221a-4a24-4f6e-87e9-080659d02c31	2018-03-04 21:10:53.966325-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b7f77041-f287-41a3-aa88-18bbb4aa703d	2018-03-04 21:10:53.970325-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5d7e18c6-0e62-449f-859c-c873e1f269a9	2018-03-04 21:10:53.972325-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d75eccda-21f8-4835-b6a6-440daf4bbc71	2018-03-04 21:10:53.975325-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
30229c39-e788-433e-983e-b766e0a1c1e1	2018-03-04 21:10:53.979326-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f82fa18c-8a0e-44a7-b7bc-6138f0223d03	2018-03-04 21:10:53.982326-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9085e694-d151-460f-b419-1378955f7177	2018-03-04 21:10:53.986327-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0d5368e4-aef8-4552-962f-7eeaafb7fa33	2018-03-04 21:10:53.990327-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
846a0b03-bf5a-4fb8-b4c5-59bbc5b05b68	2018-03-04 21:10:53.993327-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
a995f8cb-635a-4e91-897f-dff513ad072c	2018-03-04 21:10:53.996328-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
fb496192-debb-42b4-bde4-224e2cea58a8	2018-03-04 21:10:54.001328-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
0e7e20ab-aecf-46e4-804a-1a0255dfeaec	2018-03-04 21:10:54.004328-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
aa61e06a-9761-4595-b09a-a3c6ad71b934	2018-03-04 21:10:54.008329-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
d8842caf-9e5c-483f-877d-3db0d2186294	2018-03-04 21:10:54.011329-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
eef68650-bc97-4f8d-9878-0d36a29feeba	2018-03-04 21:10:54.015329-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
04bd6232-b7dd-4ee2-b2dd-f9dce03a53da	2018-03-04 21:10:54.01833-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
32d546c8-3a98-4dca-9064-76ff7a3e189d	2018-03-04 21:10:54.02233-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
c2374f7c-b6ae-4c51-8418-26a1fb75b675	2018-03-04 21:10:54.02433-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
ccb24089-f357-40f1-ae0c-bbf0a84f15a4	2018-03-04 21:11:45.934521-06	3	[22351] IC 326A	[4] DLarrabee	[21062] a	\N	\N
61f518c6-ae6d-49d7-9be2-101707b9ece3	2018-03-04 21:11:46.207548-06	2	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
e0301bb0-0f0d-402e-8d39-aa49266427f6	2018-03-04 21:11:46.211549-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
f77419d1-25f8-4f47-af28-f26b54314e2b	2018-03-04 21:11:46.22355-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
a6e944c7-8a5a-4f39-902c-c7e2545a0e34	2018-03-04 21:11:46.22755-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
2984bae8-42a8-40ff-bc9d-8e7989e9b62e	2018-03-04 21:11:46.234551-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
81cfb7d9-a75d-444a-8007-150e06734e47	2018-03-04 21:11:46.239551-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
36ef9535-b8ff-4094-80b7-a80f84303dd5	2018-03-04 21:11:46.244552-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
2b05cea1-7a78-4357-91ea-55a886af4464	2018-03-04 21:11:46.248552-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
6cedf8a4-1b6b-4512-a0f2-c6b5542e644e	2018-03-04 21:11:46.253553-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
85d47e87-3264-4df6-82f1-53495bb5a63f	2018-03-04 21:11:46.258553-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
3181bf61-894a-4c15-9967-901ed0327e07	2018-03-04 21:11:46.263554-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
7168424f-454b-43c0-83e0-084ecde08ff2	2018-03-04 21:11:46.268554-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
2c06b462-75ac-465c-bdf5-1a5fd6cf1024	2018-03-04 21:11:46.274555-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
07e2f637-f846-486c-aff3-8d8c11846666	2018-03-04 21:11:46.278555-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
cddbd638-3efc-4ea0-bc39-0f5ed2795c61	2018-03-04 21:11:46.284556-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
c896111b-a5e4-4525-afe0-660b07d97e45	2018-03-04 21:11:46.288556-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
c19a348e-3bc2-4245-a5d7-1f0bf4e55e3f	2018-03-04 21:11:46.292557-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
4f8d7146-a9c6-4707-a5c8-3514d723a06b	2018-03-04 21:11:46.297557-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
567e39d5-af49-4ea1-b066-4898e703b1d9	2018-03-04 21:11:46.301558-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
06664228-8037-4cb7-9865-10790467ed90	2018-03-04 21:11:46.307558-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
a0cd02db-ce96-4c5b-a871-150c018a87ab	2018-03-04 21:11:46.312559-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
da18a251-e3ea-4347-9571-94f1ba94c73d	2018-03-04 21:11:46.317559-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
828ca6b8-e0ec-482c-86d2-02c9880e9bb4	2018-03-04 21:11:46.320559-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
eca184c3-b4e3-4896-82f4-633107b18afd	2018-03-04 21:11:46.32456-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9a79b002-2752-4f1f-b8db-d3d65ede336d	2018-03-04 21:11:46.32856-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4c670c75-e360-4301-a269-4f9f151fd9d8	2018-03-04 21:11:46.331561-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fe192f89-ebd6-4091-bb33-5f65881cf3d3	2018-03-04 21:11:46.335561-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a4e4f103-7a1d-4db3-9cc5-c718fb67ecca	2018-03-04 21:11:46.338561-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
943d3bda-29f2-4296-94e4-5fab12b60f7d	2018-03-04 21:11:46.341562-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
80c9d091-ad57-4bab-a188-f23ba9c27371	2018-03-04 21:11:46.344562-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2f8a7bfc-2ae1-4c53-bc4e-a6324c88bc49	2018-03-04 21:11:46.348562-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2800477b-fef3-4d00-a777-5a9ef6a3899e	2018-03-04 21:11:46.351563-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7075a857-1ec7-47dd-9756-d5153ecb221b	2018-03-04 21:11:46.354563-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a3149b69-ee52-4ff7-b69c-fff5295819be	2018-03-04 21:11:46.358563-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a77f08eb-1045-4857-a8d3-4e5f16e77bfe	2018-03-04 21:11:46.361564-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
db986057-4a00-4857-98da-a63b2034335b	2018-03-04 21:11:46.364564-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
dc4ed788-a9ee-4450-a951-72011cbbe172	2018-03-04 21:11:46.367564-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
06a73698-3e09-4541-971f-f741f7efc6eb	2018-03-04 21:11:46.370564-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ebb2e792-912e-455d-9973-e397b19bad3e	2018-03-04 21:11:46.374565-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
852566a4-6519-4ecf-96ec-4c0624cf7b0e	2018-03-04 21:11:46.376565-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1fcb601e-08fa-497b-a14e-184a92608f93	2018-03-04 21:11:46.379565-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
199972a7-3cbd-4af1-94fe-b322f96ff817	2018-03-04 21:11:46.382566-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
a9d1686f-af67-4b7c-bf63-8930f55c8ad9	2018-03-04 21:11:46.386566-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
e58b452a-7d09-4c2d-97a9-e2223774184c	2018-03-04 21:11:46.390566-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
5e8a9cfe-6069-4690-ac6f-f7caf0e174de	2018-03-04 21:11:46.393567-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
5ac643c2-3273-40f7-8606-31874b384e39	2018-03-04 21:11:46.398567-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
e91bc1c6-ef3f-4ab3-901a-b724843a603e	2018-03-04 21:11:46.401568-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
0b19574f-7965-4e32-aa0f-6ab4a894089a	2018-03-04 21:11:46.405568-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
d5d539fa-0a19-495b-9c55-c24832ffb418	2018-03-04 21:11:46.408568-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
cee6ea86-9f6f-4d71-825b-81b56caa53f6	2018-03-04 21:11:46.411569-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
33709df6-0324-4183-8f84-9e673beb8dcd	2018-03-04 21:11:46.415569-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
ec8a36b8-69c0-4297-8ce7-c0f3fb260a28	2018-03-04 21:12:09.987926-06	3	[22352] IC 307-InB	[4] DLarrabee	[21062] a	\N	\N
c6c25679-2d13-402e-b052-047fe812f979	2018-03-04 21:12:10.261953-06	2	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
c5996f3e-a0a0-45be-bcee-d1ea54bf0075	2018-03-04 21:12:10.265954-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
e4626091-c1bd-48a3-9968-92de61d726aa	2018-03-04 21:12:10.270954-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
0f2e1a42-ec5c-4c71-bc45-e15e2143b1b0	2018-03-04 21:12:10.274955-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
efbf4422-2582-4909-a868-375b8dd46fda	2018-03-04 21:12:10.278955-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
e4dea4e6-e3dd-4e26-878f-51878b66bcc4	2018-03-04 21:12:10.283956-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
bb17988b-be58-422a-9355-00686434d74d	2018-03-04 21:12:10.287956-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
ac49c90f-e7cf-43f7-ab96-463dbc716de1	2018-03-04 21:12:10.291956-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
345bda12-ff78-4915-89d2-97dcb4dc3d1b	2018-03-04 21:12:10.296957-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
cdf694f0-7947-477f-bad7-021b0df708cd	2018-03-04 21:12:10.314959-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
e253801c-e005-47a0-865a-a5dc0d8a7a2b	2018-03-04 21:12:10.319959-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
2797b8a6-d5e7-4f70-8460-dbbf5b305ff0	2018-03-04 21:12:10.32496-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
42a4f31a-dcd2-410b-ac15-0d2a55cee95b	2018-03-04 21:12:10.32996-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
180f3a66-34ff-4134-9cab-84b9a3dc3aed	2018-03-04 21:12:10.333961-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
00795a40-3caa-4266-b227-5e7aebf89c33	2018-03-04 21:12:10.337961-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
2750a11a-3e2b-4a2f-aa69-f50f230c48ef	2018-03-04 21:12:10.342961-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
52bdcee3-b6cc-4b32-b7d6-71b3c23a264b	2018-03-04 21:12:10.346962-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
c70eaef4-62f3-4d83-b5cb-911c813565f6	2018-03-04 21:12:10.350962-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
6818b4d0-5038-4159-9beb-341ca22b8322	2018-03-04 21:12:10.354963-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
2cd24ca2-4616-4df3-8b82-d71d9d9b7c7c	2018-03-04 21:12:10.359963-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
46e3fbe1-79d2-4e96-8b0a-032791e238a7	2018-03-04 21:12:10.364964-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
fd81f471-ad07-426f-9d94-2577f4378543	2018-03-04 21:12:10.367964-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2a589780-ef41-467a-a2e6-5193066ff81f	2018-03-04 21:12:10.371964-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0cd30596-013f-4136-8045-71ffd26dfdb7	2018-03-04 21:12:10.374965-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d303c0b0-7d4a-4f38-adbc-7023a2c01c41	2018-03-04 21:12:10.378965-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ce9cf6df-b6e7-4d41-9405-909acde69500	2018-03-04 21:12:10.381965-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a1007cb4-c71d-4fc9-9943-c7d081d120a6	2018-03-04 21:12:10.384966-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
228c1ea7-c728-4619-8a66-a2bc215bc681	2018-03-04 21:12:10.389966-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3f3e1118-27c2-46ed-8a14-1bf17cdce8eb	2018-03-04 21:12:10.392966-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7e161c82-763b-4b8d-a327-e4ce922d7ae6	2018-03-04 21:12:10.395967-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f2485e06-d47d-48e2-8995-d590cccd42b2	2018-03-04 21:12:10.399967-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
87089e07-f83a-4cab-a226-d2eca08ae48a	2018-03-04 21:12:10.403968-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6478bf9f-eac2-41c5-aad6-443e8c4add78	2018-03-04 21:12:10.407968-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a412f1c6-e03a-4d3f-bdbb-4de1b2c5abdb	2018-03-04 21:12:10.410968-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4233ee4a-752b-4ce5-94ee-0fb2f55a03c7	2018-03-04 21:12:10.414969-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
eee4ddb3-7d20-44b5-b746-3060d3093279	2018-03-04 21:12:10.417969-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fb9aa82f-ce06-4747-a5e9-0fd07562b7a0	2018-03-04 21:12:10.420969-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2a77c13d-95e9-4cb6-89d5-87ea1abe3f5d	2018-03-04 21:12:10.42397-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8ef6faba-f7ec-4bb7-a842-a83bd19e594c	2018-03-04 21:12:10.42697-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
dcea1f2b-c92e-4409-b7e6-f6266494982e	2018-03-04 21:12:10.42997-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
3493c092-ca9d-4255-a1e3-cc454c7580cc	2018-03-04 21:12:10.43297-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
0f672775-eae1-4d8c-98f0-205eaf9b57aa	2018-03-04 21:12:10.436971-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
20fd0bf6-3a59-4e7a-a323-fc36dc0c0ec2	2018-03-04 21:12:10.439971-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
b421303a-0f32-4c18-989e-96919a2ad3d3	2018-03-04 21:12:10.444972-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
ff02378c-f9d2-4661-a787-2915982757a3	2018-03-04 21:12:10.447972-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
6c5c55bd-7794-466b-b26d-054f69ceedf7	2018-03-04 21:12:10.450972-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
911aaa7e-b372-428e-bef3-c988f841c636	2018-03-04 21:12:10.454973-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
b2f3e6ed-ef77-4276-8cec-4c414909e347	2018-03-04 21:12:10.458973-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
300b13a3-7ddd-402c-885f-74a45a7e703c	2018-03-04 21:12:10.461973-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
0836f34f-17bf-4b7a-b104-cc2ff073182f	2018-03-04 21:12:10.465974-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
322d1ef5-6ec2-4984-a800-81f9df824714	2018-03-04 21:12:24.115339-06	3	[22353] IC 307-OutB	[4] DLarrabee	[21062] a	\N	\N
0ab5992c-29aa-4926-a861-8e15629f5496	2018-03-04 21:12:24.398367-06	2	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
bfd05027-d91c-43c8-8109-b1a090087bb8	2018-03-04 21:12:24.402367-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
1cc87008-8979-4545-9747-c0351a2263b1	2018-03-04 21:12:24.407368-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
be091071-1fbc-4a2e-bd4a-8a7461747e61	2018-03-04 21:12:24.412368-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
705034b6-d0b8-4374-8d79-e7d146292118	2018-03-04 21:12:24.417369-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
f851b224-a2ea-4edc-b19d-0961778a9705	2018-03-04 21:12:24.423369-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
2d8db19d-edc8-4b18-8a05-b33a4e09a8ed	2018-03-04 21:12:24.42737-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
5c1c1305-9719-412e-ac84-5fd63d4c6122	2018-03-04 21:12:24.43237-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
a51faace-8f7a-4f44-aebd-fadf19893516	2018-03-04 21:12:24.437371-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
2027bb56-c397-4ea9-b933-6dcfc808f1da	2018-03-04 21:12:24.441371-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
221222b3-2fa7-4e73-ba2b-5a06c4e4490b	2018-03-04 21:12:24.446372-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
81314240-c933-41b9-a3d4-894d44befad2	2018-03-04 21:12:24.451372-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
f41e4359-cd98-4b6e-aa73-8647af84a1f7	2018-03-04 21:12:24.454372-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
f9b35f7f-fd51-41e5-a15f-b571e8bc9d03	2018-03-04 21:12:24.459373-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
9d4041c5-6696-49a0-9ba9-1e0c0ec1e107	2018-03-04 21:12:24.463373-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
d8436bd0-c145-4965-8e3b-dc8d1892a713	2018-03-04 21:12:24.468374-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
c069ea8c-ff1c-4cee-8181-da7163259ba2	2018-03-04 21:12:24.472374-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
a63664f4-0605-4725-8777-d3d5757efa84	2018-03-04 21:12:24.476375-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
50799421-8575-454f-a484-a6021ac4d155	2018-03-04 21:12:24.481375-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
334e5f41-c2c1-4e51-86e1-d4a509fc8aee	2018-03-04 21:12:24.486376-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
008f53b8-54ee-4bd1-968a-4e7783d18718	2018-03-04 21:12:24.489376-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
052af4a7-e061-4770-a415-6d94b110d657	2018-03-04 21:12:24.492376-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1b5b2342-6201-40fd-b3c2-c4ec988faefd	2018-03-04 21:12:24.495377-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b1c3f79c-d658-4fda-b5b3-db159a98cf59	2018-03-04 21:12:24.497377-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0475d1d3-452b-41d2-9445-2a2fae7e9f4d	2018-03-04 21:12:24.500377-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1c494acc-a5f5-4a08-bace-2bd0bdb9cc32	2018-03-04 21:12:24.503377-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3e362828-9776-47e7-942d-d5d35501cd36	2018-03-04 21:12:24.507378-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7cfa8724-3688-4e4c-ab81-685650c08ebe	2018-03-04 21:12:24.510378-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f3c507a7-5579-4cb2-807f-8fbcfa5cf556	2018-03-04 21:12:24.514378-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
bd5b89df-8dfb-4b4f-8cb2-18e66811f8b7	2018-03-04 21:12:24.517379-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c2a30fa7-d03a-40d9-8d71-0f9a66a84b16	2018-03-04 21:12:24.521379-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b21aad9b-1a9b-4e45-8fff-f451688ee1d9	2018-03-04 21:12:24.524379-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d17c17ea-9839-4daf-b34b-25703dcc6992	2018-03-04 21:12:24.52838-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
10ee366a-ec11-4f2d-9856-8e5fef8ca7f8	2018-03-04 21:12:24.53138-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
76f00570-e2ca-4951-8d58-d16fb3961df4	2018-03-04 21:12:24.53438-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5874dafa-8c31-44b8-ac74-6d1693ca6d58	2018-03-04 21:12:24.537381-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
12a2b077-0cc8-4299-8720-1428d294f832	2018-03-04 21:12:24.539381-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0cb7d88c-e42a-40b8-8ec0-3d3df52aa70f	2018-03-04 21:12:24.542381-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a9ac9196-ff59-4c40-9a2b-d1cca68c7f82	2018-03-04 21:12:24.545382-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
9e96044a-0279-4ff1-8ac1-20dcbb9bf858	2018-03-04 21:12:24.548382-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
d0c7ce62-1e7e-4a6f-87f4-dee80429e616	2018-03-04 21:12:24.551382-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
bac00811-d300-475f-99ef-69f71012eaf1	2018-03-04 21:12:24.554382-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
cf57ee38-bb6d-4354-bb42-811d4d13af07	2018-03-04 21:12:24.558383-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
1c0b69c8-c7b1-4174-aa5b-05834b35196a	2018-03-04 21:12:24.560383-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
c9bd0fd5-f977-4817-aac6-5bc17b2f4415	2018-03-04 21:12:24.563383-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
d820fc5c-7c32-436e-83bb-d07958945e91	2018-03-04 21:12:24.566384-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
e66dbb2c-fdaf-42ac-9e09-b0b08461cc34	2018-03-04 21:12:24.570384-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
cc1a0a99-30df-48ac-a76d-ff784111007b	2018-03-04 21:12:24.573384-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
614e2f16-6933-4e76-90d8-d382cb8bc525	2018-03-04 21:12:24.577385-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
62dd59e3-d616-4a4d-8718-ca089fa33bf2	2018-03-04 21:12:39.983925-06	3	[22354] IC 309-InB	[4] DLarrabee	[21062] a	\N	\N
d2ad1f17-e830-4c43-ae34-47d07225121b	2018-03-04 21:12:40.240951-06	2	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
db98531d-1878-4ddf-84b3-d081b351b1fb	2018-03-04 21:12:40.245951-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
a01f4a94-376e-4343-8a0c-73894ebc6ab2	2018-03-04 21:12:40.249952-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
c5f7fabb-f68e-4ca4-82b6-06783177c61b	2018-03-04 21:12:40.254952-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
315ea9ce-ddc4-4dcc-8850-8c34c05454fb	2018-03-04 21:12:40.260953-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
c68bc501-6a8f-4e21-94f4-252b91bf99e5	2018-03-04 21:12:40.264953-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
bf757fe9-c9f8-4e2c-bc06-d9aa09f79558	2018-03-04 21:12:40.269954-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
4320905c-c829-42ad-bb34-22ab24816097	2018-03-04 21:12:40.273954-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
1716ff2d-00e1-4f3f-8d99-03720b43f002	2018-03-04 21:12:40.278955-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
da15cb31-1cdf-48b0-896b-f7aba56ee7e2	2018-03-04 21:12:40.281955-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
0aa52571-c9b1-4401-ba3c-3275ff1e23e2	2018-03-04 21:12:40.285955-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
797c8bf5-b5f6-48d9-8e39-c60d5ee81dfb	2018-03-04 21:12:40.290956-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
d12f55b3-a43e-4a03-9ca5-4d1dd4623266	2018-03-04 21:12:40.294956-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
46351e3b-8927-499a-a632-4784646df598	2018-03-04 21:12:40.299957-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
1992ec76-2e1a-4c79-8dd3-f0f7e27adbc4	2018-03-04 21:12:40.303957-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
59ad64a8-e416-46c1-bb20-a0ebf1a7f827	2018-03-04 21:12:40.308958-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
caab1ade-a16c-4f90-838c-8bbc7d8023e2	2018-03-04 21:12:40.312958-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
7744705b-79d4-4355-abd2-98b92926aa91	2018-03-04 21:12:40.317959-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
13d0bfe0-6d7a-4258-8156-7e8e5a3dd1ee	2018-03-04 21:12:40.321959-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
6ba47499-f75e-43b0-96bc-945754c46586	2018-03-04 21:12:40.324959-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
dfa45250-8611-4be4-aeaf-0d40d6cb86c3	2018-03-04 21:12:40.32796-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e9b5fce6-adad-4cf0-a55f-1c5f9080d359	2018-03-04 21:12:40.33096-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6c737b12-1f09-465f-9f8a-5bb01dfe729f	2018-03-04 21:12:40.33396-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
bd62410e-b1a6-44d0-96a1-1726d71e4d33	2018-03-04 21:12:40.337961-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cb338be3-499e-49af-b59a-7f3036d23530	2018-03-04 21:12:40.341961-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e27467ce-5bc6-45b5-bd12-7e7007170e99	2018-03-04 21:12:40.345961-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2423ec63-1ff4-43c6-9fbd-d038065983db	2018-03-04 21:12:40.349962-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b7e12d23-3a06-41be-a920-8fd7ff74e40b	2018-03-04 21:12:40.353962-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fde26233-72f7-4560-afe7-2770afd3c61e	2018-03-04 21:12:40.356963-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
377fcd0b-0733-4806-8209-befdeb5378a8	2018-03-04 21:12:40.360963-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2d8f1a8f-c237-45c6-98ac-45a0f96315b2	2018-03-04 21:12:40.363963-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5edb6f60-eadd-4290-af22-87d153a0ce34	2018-03-04 21:12:40.367964-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0737df79-c13f-4c54-ba6e-e4a941ba2f6e	2018-03-04 21:12:40.370964-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2bf05ad2-4395-432c-99c8-3b1081a8aee0	2018-03-04 21:12:40.373964-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ec7c4eab-3e56-4c84-962f-7aaafe6c588d	2018-03-04 21:12:40.377965-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
51f1d705-e320-4fea-bfec-8f146da98ee1	2018-03-04 21:12:40.380965-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9027c15f-d1f5-4917-8bc1-506924c36731	2018-03-04 21:12:40.384965-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8e4a0986-9ab7-4f45-8a82-478f535aeb26	2018-03-04 21:12:40.387966-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
6508bcf6-214e-47f5-ba21-dc13c2c79a01	2018-03-04 21:12:40.391966-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
a616f410-ec6e-4c3b-ba2d-c62f8e7ead5f	2018-03-04 21:12:40.395966-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
87481158-0faa-48a1-b03a-1ff02d12ff86	2018-03-04 21:12:40.398967-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
e422a16b-37d0-4018-b1c9-21c0bece9bf5	2018-03-04 21:12:40.402967-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
4e829ae4-290d-4d04-aa1c-31b8b740f32f	2018-03-04 21:12:40.406968-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
b9f5a0e9-153d-44e1-b866-fe36b7704a80	2018-03-04 21:12:40.410968-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
5e5d1ef9-740f-4b18-ac0f-107d8d857320	2018-03-04 21:12:40.414968-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
53787a45-75f6-4106-bc38-5b542cdfdee0	2018-03-04 21:12:40.417969-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
b8d141ec-0fde-404f-b870-77a9fa03cff2	2018-03-04 21:12:40.421969-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
288dbc36-80aa-4245-8987-e66fc340dc21	2018-03-04 21:12:40.425969-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
3e81c143-2cb2-4eb5-b761-053db7cc3597	2018-03-04 21:12:49.366863-06	3	[22355] IC 309-OutB	[4] DLarrabee	[21062] a	\N	\N
b172c812-22fa-4d9b-b268-cd09f02fa0e3	2018-03-04 21:12:49.638891-06	2	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
4481b33d-b014-43a8-9d97-004507075389	2018-03-04 21:12:49.643891-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
96e2b46d-e3a2-4c3d-ac7b-a4899e8edd61	2018-03-04 21:12:49.648892-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
a72d016e-3b8e-4667-80d8-48bf27040e34	2018-03-04 21:12:49.654892-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
bf40bd20-917e-4821-9b45-980acc7955ae	2018-03-04 21:12:49.657893-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
8da6f149-6fa1-4a8f-acf5-5038099e8c50	2018-03-04 21:12:49.661893-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
c3773d26-4ced-4a43-8caf-84a2dfc40876	2018-03-04 21:12:49.665893-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
d0267d8b-b9fe-416f-a696-34bbe3f5ada9	2018-03-04 21:12:49.668894-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
46b5ae01-79ce-4c11-b703-8ee0a9829992	2018-03-04 21:12:49.673894-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
0df0fef6-616c-46bb-99dc-85d6a45b1b5c	2018-03-04 21:12:49.679895-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
5f135eac-d1a0-418a-bc78-592daf8d4a6d	2018-03-04 21:12:49.685895-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
79dae269-27a3-4eee-8c13-8fecbf794d72	2018-03-04 21:12:49.690896-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
5b083c03-4bc3-475d-80b0-8399c05e12c6	2018-03-04 21:12:49.695896-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
14a49d80-ee37-46d8-afc7-6931e03e9b40	2018-03-04 21:12:49.701897-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
eba8f154-ec19-4bc2-af38-ac60825061e0	2018-03-04 21:12:49.706897-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
445d9cea-79bf-4b76-9313-a969a8791422	2018-03-04 21:12:49.710898-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
bd6ead20-8f00-4c29-942e-39633b439100	2018-03-04 21:12:49.714898-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
d64d4b75-c088-4650-bb57-74e575ac29ce	2018-03-04 21:12:49.718899-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
96e8ddfa-acfb-464d-8f4c-eef5a5d3a259	2018-03-04 21:12:49.722899-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fb83d7fe-cf95-4911-9719-a14787bb6fdf	2018-03-04 21:12:49.725899-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
310367cf-f8eb-461d-8dc5-2cda14757b4f	2018-03-04 21:12:49.7299-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
87bf5619-0df3-4f52-8d31-1b715c46f37f	2018-03-04 21:12:49.7329-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
84d4ce1a-feaf-4c96-9c89-f7a757f4ebff	2018-03-04 21:12:49.7359-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ed1cde92-0b38-49c7-b592-49c8b895d892	2018-03-04 21:12:49.738901-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c955bd98-c7e8-4e96-9582-c57c360db3d1	2018-03-04 21:12:49.741901-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4c157db6-2f99-426c-a57f-c2a71ba6858d	2018-03-04 21:12:49.745901-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
11cebceb-cbce-43e9-8d9f-bd3be3952a1b	2018-03-04 21:12:49.748902-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f0137fd5-a077-43f4-8eeb-99c029c99279	2018-03-04 21:12:49.752902-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
69c34e38-827e-42b6-aa25-fae9ed98aa97	2018-03-04 21:12:49.755902-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1731542b-9e34-4ac4-8eaf-e46cd981f1e5	2018-03-04 21:12:49.758903-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
633625b5-6b1c-41fa-b023-3ff3b5134867	2018-03-04 21:12:49.762903-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0ffa845f-8984-497c-ba8a-d76cf7affd9c	2018-03-04 21:12:49.765903-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
59dee529-a645-45ed-95d8-d698ab684178	2018-03-04 21:12:49.768904-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
468694f0-9f2b-4b76-a21b-34600824699b	2018-03-04 21:12:49.772904-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
dd35abd3-4d8d-43e7-b0be-9c30e3c4b0e4	2018-03-04 21:12:49.775904-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
302f13ee-25b1-4640-a129-7b9882742ce2	2018-03-04 21:12:49.778905-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
bfc5153d-8144-4132-8305-dee08df917e1	2018-03-04 21:12:49.782905-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
17cbe7aa-aef9-4c53-8845-0a9101180e5b	2018-03-04 21:12:49.785905-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
03c4187c-c464-4e7a-92e6-2a26f82af5c3	2018-03-04 21:12:49.789906-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
36f3a51d-1cf5-44c0-8480-b25a5a425d64	2018-03-04 21:12:49.791906-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
f03bb66e-f7e2-4703-8576-5d266c954140	2018-03-04 21:12:49.795906-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
3e6cbf13-7c68-473b-9610-ffd96343b849	2018-03-04 21:12:49.799907-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
127ac84a-571a-4f5e-97e9-cf2e01fdaa0d	2018-03-04 21:12:49.802907-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
b06e3e34-60a8-46f5-bfba-e9cc532335b7	2018-03-04 21:12:49.807908-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
f44013fa-3f60-48eb-88ad-f1b9653e116c	2018-03-04 21:12:49.811908-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
acaf2af5-f83e-438c-9914-d8e00453f7c4	2018-03-04 21:12:49.814908-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
75610b6a-ff17-4c2b-a7eb-4fbabd7bfe0d	2018-03-04 21:12:49.818909-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
ef621f96-c2df-4d1c-992d-3c387568b116	2018-03-04 21:12:59.653892-06	3	[22356] IC 314-InB	[4] DLarrabee	[21062] a	\N	\N
a3b7a336-f245-430b-bb95-ff244298ee38	2018-03-04 21:12:59.93192-06	2	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
616b8e15-5d80-4bd1-a60d-758e3cb5f10a	2018-03-04 21:12:59.93692-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
0a6cdbf0-9fcc-4d6c-b092-2081b3da2297	2018-03-04 21:12:59.940921-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
621e78a7-6bb5-4927-b69a-195a863632b7	2018-03-04 21:12:59.945921-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
180531fa-0b53-4025-8c67-7c58eb3f19a2	2018-03-04 21:12:59.949922-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
80ff34c6-0c2f-4218-9874-21042f812019	2018-03-04 21:12:59.966923-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
a0d0bd67-7511-4a87-a08e-3302463d9808	2018-03-04 21:12:59.970924-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
67efa1db-e605-4911-92dc-013fc4f420c7	2018-03-04 21:12:59.975924-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
30e48b07-e471-44f3-9e49-503e2e4302b9	2018-03-04 21:12:59.979925-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
077443af-f5f9-4a19-9062-5d5266370f57	2018-03-04 21:12:59.983925-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
a7540301-b4bd-4573-b1fd-8b9daff58fea	2018-03-04 21:12:59.987925-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
cce9cd5e-036d-42ed-be3f-e9b2247455c3	2018-03-04 21:12:59.992926-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
6251fb1c-85af-45a2-a119-70f961bafd65	2018-03-04 21:12:59.996926-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
f2f7a359-cd52-4360-ba29-d7d21cf4b881	2018-03-04 21:13:00.000927-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
112863fd-7b33-4bf0-9a6d-5a3bd0a5260c	2018-03-04 21:13:00.003927-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
19453e9b-be20-4e38-8e51-408f8d432298	2018-03-04 21:13:00.007927-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
2185c3e9-07ed-4713-8d80-faadc41b6693	2018-03-04 21:13:00.011928-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
bc825e94-b3cc-44b8-a927-778e8deaa8b8	2018-03-04 21:13:00.015928-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
989ed37c-b79e-4344-88bb-00898421c8bc	2018-03-04 21:13:00.018929-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
407e57f2-ea12-408a-96c2-a40ef28f5dca	2018-03-04 21:13:00.021929-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
742cccaf-4c0c-42ff-bb54-d7a2f5582981	2018-03-04 21:13:00.025929-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6a35e0f0-0dd1-4c08-a972-d48ac32b641d	2018-03-04 21:13:00.02893-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
862bc6bc-15dd-4b5b-bb6e-7fa40ff37374	2018-03-04 21:13:00.03293-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d759e87d-6d6f-4beb-9643-d412fb53e964	2018-03-04 21:13:00.03693-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7c720d39-6de8-4458-b357-29b73a64858b	2018-03-04 21:13:00.039931-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
dfb56685-c78c-4b4e-97b8-abcb26411f69	2018-03-04 21:13:00.042931-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
bf4339a9-3e16-46a3-a421-862c64363370	2018-03-04 21:13:00.045931-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d6e0321a-17d5-48a9-852e-aa7eb2d67e0e	2018-03-04 21:13:00.048932-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6cd71e73-b9c9-4fc8-8ebf-7af7282f87e4	2018-03-04 21:13:00.051932-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
bbba97a7-47d5-425e-9bf7-75507f63791c	2018-03-04 21:13:00.055932-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
869e43a6-03b9-421a-8720-29333c9ca002	2018-03-04 21:13:00.057932-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fbfbf499-644a-4fd5-b6ae-56635649a186	2018-03-04 21:13:00.060933-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8c745cb3-eea0-4b29-a6c8-aa59659486fe	2018-03-04 21:13:00.063933-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
be089f3b-3153-42f9-9e99-c63241d3a5ea	2018-03-04 21:13:00.065933-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1f79fbc3-784c-40d0-9bcb-5a4816f3709c	2018-03-04 21:13:00.068934-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c28050c8-9650-41ad-94f3-5d337fde8f74	2018-03-04 21:13:00.072934-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
df6e7278-b64e-456d-84be-508f93fd46af	2018-03-04 21:13:00.075934-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
88603a07-328d-4cc2-bcda-7a5eac1fc2fc	2018-03-04 21:13:00.078935-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
4f4a1773-a723-41d4-940e-77f91fae0cdb	2018-03-04 21:13:00.083935-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
7c515323-ee11-4e0c-a305-f13e33885427	2018-03-04 21:13:00.086935-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
caa67f2b-4498-4144-bbcf-81b58d39598b	2018-03-04 21:13:00.090936-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
7beb3a76-4971-4072-8849-d705b3e1f751	2018-03-04 21:13:00.093936-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
abda16aa-0bf0-48cf-9e2d-0f3539e6ec00	2018-03-04 21:13:00.097936-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
a7a8cef2-36ce-4783-a135-65f16b7f5818	2018-03-04 21:13:00.099937-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
35240cdc-dfcb-41cd-ada1-3c99463a271e	2018-03-04 21:13:00.103937-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
e05a7fe9-dfb4-425d-9ae0-48b37bc43f30	2018-03-04 21:13:00.106937-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
7c1cc473-2085-43b1-8d43-8339a8ee834f	2018-03-04 21:13:15.378464-06	3	[22357] IC 314-OutB	[4] DLarrabee	[21062] a	\N	\N
0063df90-a1ad-4d45-908c-f38a4e839a9b	2018-03-04 21:13:15.63949-06	2	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
3b375a53-4157-4135-9a60-7fe056abc6dc	2018-03-04 21:13:15.644491-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
a7a677bb-dd6a-44c1-bc70-ce4881d079e0	2018-03-04 21:13:15.649491-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
a7c73b17-865d-4127-8d41-24870f5fed83	2018-03-04 21:13:15.653492-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
f66d5165-2448-4ece-a58e-41158d9f0694	2018-03-04 21:13:15.657492-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
2388dc25-9ac0-44cf-a89f-08b8a91c4aec	2018-03-04 21:13:15.661493-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
4e427cdf-97d1-4f35-8a25-75490e6fcfd3	2018-03-04 21:13:15.666493-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
1dd01234-c7b3-4f73-aadc-bf160afbe368	2018-03-04 21:13:15.671494-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
bdd149a0-725b-4e09-8db3-6728217e46a6	2018-03-04 21:13:15.675494-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
6b71df8a-4fad-4a0b-be0f-58095be048d3	2018-03-04 21:13:15.679494-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
a90898bc-57c5-4abd-8479-c8917cb2c1d8	2018-03-04 21:13:15.683495-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
1dd69a91-11ce-49ed-9f79-ec5aa6fb9add	2018-03-04 21:13:15.688495-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
f3adba5b-7eb1-424b-8108-5b8d793bb7b5	2018-03-04 21:13:15.692496-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
db77f53c-9905-48ee-b2e5-5da971ebceef	2018-03-04 21:13:15.696496-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
8dd7eeef-d429-4774-a46a-1983d5dc51dc	2018-03-04 21:13:15.701497-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
4f9520f9-df64-4f5e-beb4-5dee8ce1f7fb	2018-03-04 21:13:15.706497-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
8d8ddf76-05ce-4888-aaf9-b2c87f277cf3	2018-03-04 21:13:15.709497-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e170897b-bc0d-40cd-b07e-d2db36d73f30	2018-03-04 21:13:15.713498-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1a010aa2-d712-4b1c-ab8a-4d417fedaea0	2018-03-04 21:13:15.7305-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ce0e45e6-8407-428a-9e5a-b9b1d7f0050b	2018-03-04 21:13:15.7345-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ac2bb606-adad-4a9c-9828-50621a17bb3a	2018-03-04 21:13:15.7375-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f57ef02f-81a7-427b-9ba0-4210a148032a	2018-03-04 21:13:15.741501-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4b2e15bf-6525-4d1f-96b8-8e7a0a4a12c8	2018-03-04 21:13:15.744501-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5586fd98-17dd-4288-b4a2-3b5d8ede277f	2018-03-04 21:13:15.747501-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4d69127c-5ce1-42c2-9b54-f90e1a87fda7	2018-03-04 21:13:15.751502-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2c956a06-bd6b-4019-831b-06a623708216	2018-03-04 21:13:15.753502-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3cb895ea-5068-4a86-9ec4-9de47e584f5e	2018-03-04 21:13:15.756502-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
56958dc2-787a-448a-b08e-661bf045fbc0	2018-03-04 21:13:15.759502-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cf46e023-e828-41f9-89fc-99dc5e440eeb	2018-03-04 21:13:15.762503-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3bc81486-da73-42a9-aaf0-c0087f23caf0	2018-03-04 21:13:15.766503-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
77c42541-1b90-4eda-a8a0-2f3ad7eff2b0	2018-03-04 21:13:15.770504-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
10c4b7a9-1d4c-468e-9d87-de4d13c56528	2018-03-04 21:13:15.773504-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d14dd8f8-f82b-4fad-bcd4-c6fab522f558	2018-03-04 21:13:15.776504-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e064506e-da36-433b-b4a1-5af5373057f1	2018-03-04 21:13:15.780505-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c88ea048-54d4-4d39-bdea-27986bc8f1a0	2018-03-04 21:13:15.784505-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
eab6c0d4-1cbd-4abe-8157-8486ab9458a1	2018-03-04 21:13:15.788505-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
c6ec0fe3-2f2e-44f3-813a-487d18edf53f	2018-03-04 21:13:15.791506-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
8f5c6605-c17c-49a4-a179-7e4f6edf2ef1	2018-03-04 21:13:15.795506-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
6118610f-c9d0-4fee-8c37-2b77fa8eeeed	2018-03-04 21:13:15.798506-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
977a2a9b-9b45-4b7c-83cb-7a70b2ebe632	2018-03-04 21:13:15.802507-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
10ba79b3-441c-4735-a62e-c4482f0e3610	2018-03-04 21:13:15.806507-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
bceba6a4-8925-48d2-b55e-9066b2a353e1	2018-03-04 21:13:15.809507-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
2f0213d0-c175-4e5e-9092-a43c37fb71a3	2018-03-04 21:13:15.813508-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
5f108627-e4ef-4388-a066-51fe0b7b368a	2018-03-04 21:13:15.817508-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
ddd8eb07-eafb-4398-9e1e-e447a8a37f5f	2018-03-04 21:13:15.821509-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
7bcb3982-b589-460d-85f8-4397e9fea303	2018-03-04 21:13:25.569483-06	3	[22358] IC 322-InB	[4] DLarrabee	[21062] a	\N	\N
20ccc003-26cc-4653-af1e-ef25761a6a90	2018-03-04 21:13:25.822509-06	2	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
1ca47bfe-e6bf-44e3-baa0-1380643dccf8	2018-03-04 21:13:25.826509-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
5f067ded-508f-4113-9bc1-b640d8310b7f	2018-03-04 21:13:25.83251-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
7e73183c-5233-4085-953b-f3ee3ce4bdb7	2018-03-04 21:13:25.83651-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
4c68bd79-159d-48eb-90eb-b56a66c9d1c8	2018-03-04 21:13:25.84051-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
96512110-67ca-4e71-92c7-80a708bdaa63	2018-03-04 21:13:25.845511-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
15ffffae-4ac8-4671-b2ca-4b676f605d4e	2018-03-04 21:13:25.849511-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
4865bc0e-bdfa-47a5-a397-fb2209a7e555	2018-03-04 21:13:25.854512-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
ae1076b1-1160-4ba2-9bd5-1884b32add5d	2018-03-04 21:13:25.858512-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
38c170f7-5961-436f-972b-2e0a787aa56f	2018-03-04 21:13:25.863513-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
ccf2da18-e378-4327-9ad3-00683fb3c998	2018-03-04 21:13:25.867513-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
d438469c-55be-4bb0-a0c3-3bf8eb3ef9c1	2018-03-04 21:13:25.872514-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
4f07a4dd-51ec-422e-b9db-fbd27b1eedf3	2018-03-04 21:13:25.876514-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
b3b0370b-6653-448c-97b3-58a3ebca611d	2018-03-04 21:13:25.879514-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
d0761837-eb71-4f16-aaa3-b45c8d5db743	2018-03-04 21:13:25.883515-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
04a14774-2277-4e9c-b7a9-3ba8adb9c7bb	2018-03-04 21:13:25.885515-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e37e7087-4fb5-4a10-809c-bc9955d00966	2018-03-04 21:13:25.888515-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ebaaa716-4d05-4483-b76c-85478ce035cc	2018-03-04 21:13:25.891516-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7f2c347d-2d53-4a85-8103-267398e34c86	2018-03-04 21:13:25.895516-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2359cf1f-f35f-4875-9309-1f328e2b09fa	2018-03-04 21:13:25.898516-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d1ef936e-b0f8-4769-ac16-4a43595d65ce	2018-03-04 21:13:25.901517-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4a7893ac-0d83-43ff-936a-fc5c00334b06	2018-03-04 21:13:25.906517-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1170bf9d-727b-46a1-b7d7-f4633a9d024e	2018-03-04 21:13:25.908517-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f5dd237e-5671-447f-93dc-5998c663916d	2018-03-04 21:13:25.911518-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7c455f47-ac6c-4098-90bb-de62e8aaad77	2018-03-04 21:13:25.913518-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
dd355b06-c370-4728-9146-77493627d1dc	2018-03-04 21:13:25.917518-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
715048ef-e1ad-4863-a506-e29565da9ad7	2018-03-04 21:13:25.919518-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5f286ea4-9eac-45b8-b0f3-8e9bb2a3c30d	2018-03-04 21:13:25.923519-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b86da382-a4d6-4768-b1a5-e5bec3bcba1e	2018-03-04 21:13:25.926519-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
accd56f7-22fb-4468-b9dc-f215c86e8126	2018-03-04 21:13:25.929519-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
82679d8d-aace-45c7-a2c4-83c1c5cb0852	2018-03-04 21:13:25.93352-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
61a7e71b-8f38-499b-9a9b-a8991defb3a1	2018-03-04 21:13:25.93652-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
487ac1ef-13f9-458f-a638-301995f8f29e	2018-03-04 21:13:25.93952-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
24b321aa-3088-4e37-a5fc-ed62df427424	2018-03-04 21:13:25.942521-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
50787d64-dd26-4de9-bdbe-73bf0bbb13d7	2018-03-04 21:13:25.945521-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
796e08ed-fd7a-4d54-8361-4f9d628f7eff	2018-03-04 21:13:25.949521-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
b4e14705-b2ee-4e72-b18c-87d4be6b928e	2018-03-04 21:13:25.953522-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
8295bd91-8de2-4d62-8d05-7fb2dceb9b51	2018-03-04 21:13:25.957522-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
caa8cd2d-dc9c-4a49-9a31-dd67e0ea7af2	2018-03-04 21:13:25.960522-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
5404bf2e-0d7e-4361-9362-cadd6cb8b5d3	2018-03-04 21:13:25.964523-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
bd39d632-2318-482d-bd15-5c187e4ddf76	2018-03-04 21:13:25.968523-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
0eecc3f0-068a-4b04-8652-39ccf60d7e06	2018-03-04 21:13:25.974524-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
f2e98556-80ef-4770-a076-476068f08105	2018-03-04 21:13:25.979524-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
967897ee-fa85-4902-b26c-5e25aa363631	2018-03-04 21:13:25.983525-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
4c8049a4-f210-4ff6-9e28-1c098befe10e	2018-03-04 21:13:35.394466-06	3	[22359] IC 322-OutB	[4] DLarrabee	[21062] a	\N	\N
72b15bd2-f423-45ff-a8eb-5cb652c7c651	2018-03-04 21:13:35.662493-06	2	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
79fa6f8a-fc8d-4625-81b6-2e4a4c9afc89	2018-03-04 21:13:35.667493-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
f3650a69-9930-40a0-a12f-50aa0b8a3d04	2018-03-04 21:13:35.671493-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
6709af5e-d5fb-4096-bcfd-c667a8a207b5	2018-03-04 21:13:35.676494-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
ecebab1f-629e-4b44-baae-5072d7db07ed	2018-03-04 21:13:35.680494-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
8527cf6a-6c81-4959-ab34-48c850230dbd	2018-03-04 21:13:35.685495-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
01f0ed3b-f7f1-49aa-a28a-16bf58aefd92	2018-03-04 21:13:35.689495-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
c8805b00-7b91-4c16-ba23-4cfc5ed40a99	2018-03-04 21:13:35.694496-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
10151a98-e0a2-4ef1-b318-d432e1e9aa00	2018-03-04 21:13:35.698496-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
d6e93feb-e030-4955-920f-c170e02c1250	2018-03-04 21:13:35.703497-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
7d10ee2e-c476-4391-9f3a-4d2e2fe2d2a9	2018-03-04 21:13:35.707497-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
3517a593-c1b6-4e75-8fce-0688bf887e58	2018-03-04 21:13:35.712498-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
51d286eb-2bac-4036-b35a-6ec2f75859ac	2018-03-04 21:13:35.717498-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
6140d22c-6b34-4280-9b8a-f78168378ffb	2018-03-04 21:13:35.722499-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
fdeaaee0-0460-4c51-ab4e-060bfb2a9e0b	2018-03-04 21:13:35.725499-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f5d91467-f361-439e-8e4e-36e297a2a9eb	2018-03-04 21:13:35.728499-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d2a89ef0-e93d-4152-8bc1-efde9c9bf1ce	2018-03-04 21:13:35.731499-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
05011727-a8a4-4847-9d9a-9c1ec7337923	2018-03-04 21:13:35.7355-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
53c993ee-1a08-40c0-a0ba-64e47ed04eec	2018-03-04 21:13:35.7385-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7c4f1235-d070-4bc5-9da9-865fdc6a166c	2018-03-04 21:13:35.7415-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
649d4bf2-9fbc-471b-a699-d6dffc55a8fc	2018-03-04 21:13:35.745501-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
126c9e77-af80-47ae-bbd2-c5ddc9b6fed7	2018-03-04 21:13:35.748501-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
10dfe6db-19b4-4694-80bd-c7276147c1f4	2018-03-04 21:13:35.751501-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
307f3d9c-9c4b-4946-819b-0dfb2eefa08c	2018-03-04 21:13:35.754502-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c63edda5-95fd-47ee-bcda-7f4e644ac8d0	2018-03-04 21:13:35.757502-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4e8defdd-f815-415c-9498-a02576fff979	2018-03-04 21:13:35.761502-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3f57829f-dbd4-4772-9eb0-fa60569cbabe	2018-03-04 21:13:35.763503-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8ca15089-7a32-4eda-8625-960d7ddc12b8	2018-03-04 21:13:35.767503-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
10fff0c8-c265-424b-a193-988c33bde545	2018-03-04 21:13:35.769503-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4f91f6da-8abe-4283-b014-fab1b8c92014	2018-03-04 21:13:35.773504-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
44f39bbe-b480-47ec-8ae0-5c4375db8939	2018-03-04 21:13:35.777504-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
69b8b5e6-32b0-4efa-b396-5776b6bcfea2	2018-03-04 21:13:35.780504-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b9d58284-ae66-4b94-8c38-fd282845d85e	2018-03-04 21:13:35.784505-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
e0fa8c63-39ca-4bbe-a27d-8052d36b1cb3	2018-03-04 21:13:35.787505-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
2cca033d-61fa-4b60-af8a-c111b02e4987	2018-03-04 21:13:35.791505-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
5e56eaae-34b8-40dd-b734-d29cd45e9844	2018-03-04 21:13:35.794506-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
f615bab4-c47e-48ab-aa28-6713c0dc37d3	2018-03-04 21:13:35.798506-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
b13442fa-1807-4d6b-9611-9ac77aae69ff	2018-03-04 21:13:35.801506-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
5fbc561c-8185-48b4-b7ff-59d4a9593a0a	2018-03-04 21:13:35.805507-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
3a2d4deb-5b53-4171-afde-4754b0b5033a	2018-03-04 21:13:35.808507-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
aa8db792-db9c-4e5b-b0a3-9fb153d9b319	2018-03-04 21:13:35.812508-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
624681f4-e387-42b5-bf80-15f079ac1f61	2018-03-04 21:13:35.816508-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
c661c482-26d7-4a84-a555-492260970fd1	2018-03-04 21:13:35.820508-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
f0542b6b-4560-4c86-b7c8-bbd5f7e15b46	2018-03-04 21:13:43.221248-06	3	[22360] IC 324A-InB	[4] DLarrabee	[21062] a	\N	\N
fedd110e-022d-42a4-a260-0cf3b21a062b	2018-03-04 21:13:43.502276-06	2	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
d49d754f-6f4e-4e44-b8df-179e30819777	2018-03-04 21:13:43.506277-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
02e66670-88ca-412c-a4b3-aff997208be1	2018-03-04 21:13:43.511277-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
29e1ec7e-db1c-45e0-8510-5324c98ed894	2018-03-04 21:13:43.515278-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
6653dd8a-1b56-4952-8d77-60df9e047cb9	2018-03-04 21:13:43.520278-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
6f48f071-aec7-47e4-af9e-a307bc184a45	2018-03-04 21:13:43.525279-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
d9cac88c-b0a3-4e13-aab4-d33eead8b03b	2018-03-04 21:13:43.529279-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
9d3af1cb-56a7-47f5-b30e-d3017cef6433	2018-03-04 21:13:43.53328-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
d1caa2b8-29fe-4df2-9854-313d73af3a7a	2018-03-04 21:13:43.53728-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
5c7a44ee-2ad0-48d0-b3c2-20b2caec0dfe	2018-03-04 21:13:43.54028-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
282e0059-2a40-47f6-9f3d-3ede66610efe	2018-03-04 21:13:43.544281-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
a13ccd9c-fbca-4a91-bb7c-95bc3007a051	2018-03-04 21:13:43.548281-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
0a13bf9c-be20-4a74-9dd1-1c33bbc05e6f	2018-03-04 21:13:43.553282-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
9449a27c-640e-4bb4-867e-cad13b2cf4db	2018-03-04 21:13:43.556282-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cc586783-6b32-4a55-8d18-d25af4e23b82	2018-03-04 21:13:43.559282-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
98a87bf6-fdd1-4661-a545-ca6a9d7a2b7e	2018-03-04 21:13:43.569283-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
924b12d6-4827-4844-993d-6be185f73a47	2018-03-04 21:13:43.572283-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
73b57bdf-9566-4f67-a841-929248c97bd8	2018-03-04 21:13:43.575284-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8f236d97-7158-442d-8bbc-7e64c34b1a1e	2018-03-04 21:13:43.577284-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2759870c-4cdb-4fbf-ade5-852de095f4f9	2018-03-04 21:13:43.580284-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4bb0a937-b53f-442e-b92d-7f7d7e81ea2e	2018-03-04 21:13:43.583285-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e4bafdf1-6818-4197-9104-b55955005e6e	2018-03-04 21:13:43.586285-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d41ff88a-2290-4c20-8a3d-baf6394e1880	2018-03-04 21:13:43.590285-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2d2f1bdf-1270-4d76-93a6-498e24268b5e	2018-03-04 21:13:43.593286-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
dd0eba7e-1e35-41e4-970a-3dfdcc166894	2018-03-04 21:13:43.597286-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6dcc9c11-55aa-4e50-acc5-7963bfbd0f61	2018-03-04 21:13:43.600286-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c2478c54-0b66-4947-a79b-090c3739c0b3	2018-03-04 21:13:43.604287-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d77d2238-d2fb-4815-96fd-8901293ba4f7	2018-03-04 21:13:43.607287-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e6f89a42-090d-4313-a1ae-cc1bafa415b4	2018-03-04 21:13:43.611287-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
48b4ad26-d984-4489-ac6d-006cf0ec6ed9	2018-03-04 21:13:43.614288-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3e7ec659-67c4-4cc9-af14-a1660c9f752c	2018-03-04 21:13:43.617288-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d29cac06-8259-4ef8-b5f1-076066dbc57a	2018-03-04 21:13:43.621288-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
a79cbcad-6088-4d7b-81b3-786f65c3258d	2018-03-04 21:13:43.624289-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
37ae0d61-9282-4efc-b2af-cec7e6be0bdf	2018-03-04 21:13:43.626289-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
cbaa9788-48ef-407d-8ce4-f3a2e19b03fa	2018-03-04 21:13:43.630289-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
d33acfe8-df1d-40c4-a050-24b4b3fcf6c6	2018-03-04 21:13:43.63329-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
f0d5fd78-88f2-4ff2-874f-501bf7870413	2018-03-04 21:13:43.63629-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
bc6b9c85-bab6-4268-9f37-80b79078d30e	2018-03-04 21:13:43.64029-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
56ab9d3a-51f0-47e5-9343-d762719c83c9	2018-03-04 21:13:43.643291-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
b35b54b8-f2dc-4517-9a44-b56643073c3a	2018-03-04 21:13:43.646291-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
a3532017-ac44-43e5-9a29-3e174ab9f91f	2018-03-04 21:13:43.650291-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
561d5c54-6d02-4a21-a01d-b0e6347dc9d1	2018-03-04 21:13:43.654292-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
4063b0c2-1096-4737-8c12-a89a31295534	2018-03-04 21:13:58.792805-06	3	[22361] IC 324A-OutB	[4] DLarrabee	[21062] a	\N	\N
b65305b9-6251-465c-ab0c-2a6147442011	2018-03-04 21:13:59.047831-06	2	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
6cd61768-bee7-4062-a5af-d5b851dcd0e8	2018-03-04 21:13:59.052831-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
dde1e8e3-a0c7-491f-bcf1-2d03fc1cc655	2018-03-04 21:13:59.057832-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
8e5b8a8b-9390-4f71-8291-14050c7d9285	2018-03-04 21:13:59.061832-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
eb84ad66-dfd3-4eff-80ab-afb43482fd15	2018-03-04 21:13:59.066833-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
6cc3f859-1f44-41e7-9443-3175cc46356a	2018-03-04 21:13:59.069833-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
40081974-f370-4101-a61f-53bf007e5b35	2018-03-04 21:13:59.073833-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
71c74814-e055-4119-bb61-4aba292220c5	2018-03-04 21:13:59.077834-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
7bfeb1a2-9136-41d0-abde-3b2d14794e55	2018-03-04 21:13:59.082834-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
7c64f786-5a8f-446a-91b6-8d1fc31a3bdc	2018-03-04 21:13:59.087835-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
14f8860e-f524-4b42-9f32-2084ec7649c2	2018-03-04 21:13:59.090835-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
781c959f-7451-4d66-84c9-9b0dbb28e18d	2018-03-04 21:13:59.095836-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
96c6d881-adfd-4939-aea2-6a4a7a738e9b	2018-03-04 21:13:59.098836-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e2d5e302-a132-4b6c-8b25-aa35b668ddd1	2018-03-04 21:13:59.103836-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
15ffc874-838f-4e5f-a84b-0f7dbbe9b962	2018-03-04 21:13:59.105837-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
915a7d2b-7bf1-4ca3-996f-857ed22d7ebd	2018-03-04 21:13:59.109837-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6be5f09a-ff0e-42b0-b65d-be458bdca134	2018-03-04 21:13:59.111837-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4772cca1-03b8-42b9-ab33-c178abb2217c	2018-03-04 21:13:59.114838-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
639fa46e-9343-4511-80a8-00eaba5fa318	2018-03-04 21:13:59.117838-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
93161e3e-ec0f-49e5-b91f-85939a4f6167	2018-03-04 21:13:59.121838-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0523064e-33ba-4663-8261-4a1bd60b840e	2018-03-04 21:13:59.124839-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
878d8ed4-9821-4f85-9fc2-99054819eded	2018-03-04 21:13:59.127839-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
35f704b9-852c-4b7f-b350-f25d4cdd7076	2018-03-04 21:13:59.130839-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cc1ff834-1afe-4ad0-b8b7-f362baed092d	2018-03-04 21:13:59.13484-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1de0839e-70be-4e7c-b613-153f619825b3	2018-03-04 21:13:59.13784-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d71499f5-6a1e-4325-9e18-933a1f1c4a5f	2018-03-04 21:13:59.13984-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f91395df-e3c4-420a-9250-e91dd1ad979e	2018-03-04 21:13:59.14284-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
09ed3b16-d46b-462a-b54f-929cd12566d8	2018-03-04 21:13:59.145841-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
de4a6458-83da-413c-ad96-d7826b83e3b4	2018-03-04 21:13:59.149841-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
919943cd-e507-47b9-9e4c-b7deaeab7615	2018-03-04 21:13:59.152841-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c4e2005d-610f-4f0b-b042-d84787f588a4	2018-03-04 21:13:59.156842-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
243e202d-47c7-4cac-a2e2-e8000908a0f3	2018-03-04 21:13:59.159842-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
64871edb-4928-4522-b30b-cf73f831a9c4	2018-03-04 21:13:59.164843-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
e843f6f6-6168-4ee6-8232-69cf4df09d56	2018-03-04 21:13:59.167843-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
703626cc-e476-4f06-b12d-28dd11244ac8	2018-03-04 21:13:59.171843-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
c245e0af-b927-4ffa-8802-925d11396657	2018-03-04 21:13:59.175844-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
9b4a4ba9-a912-402f-8605-a9f9182a3030	2018-03-04 21:13:59.178844-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
61b34753-f7f6-48e3-bf1f-43a1af884541	2018-03-04 21:13:59.182844-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
8924bc13-04d5-44c8-becc-037c825105f6	2018-03-04 21:13:59.187845-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
15bce1db-7f5c-413f-817b-ebbaf6ad77c3	2018-03-04 21:13:59.190845-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
d16569f6-7c20-4ffb-837d-3f898b2c64ac	2018-03-04 21:13:59.194846-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
ffacd9e2-b6e1-49c9-b869-8d97f1229880	2018-03-04 21:14:10.217948-06	3	[22362] IC 324B-InB	[4] DLarrabee	[21062] a	\N	\N
2e01fdc9-a5aa-4fb6-91d9-304d34e12ff5	2018-03-04 21:14:10.475974-06	2	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
1c12d32d-76d3-4e31-afe1-7d6f77921e42	2018-03-04 21:14:10.482974-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
d8300ad1-c636-4650-85b7-f718910bc2e7	2018-03-04 21:14:10.487975-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
9670fae3-1fce-4687-b199-9db39d513558	2018-03-04 21:14:10.490975-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
0ea416e4-2566-4f2b-b18b-0b7d1c93dc55	2018-03-04 21:14:10.494975-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
8fa8a917-99e6-4105-b302-87de74f8b7ba	2018-03-04 21:14:10.498976-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
d28d049c-be7f-4fda-a582-104883336e38	2018-03-04 21:14:10.502976-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
2cdb8a7f-33a0-4e6b-b2c5-1e963292ddce	2018-03-04 21:14:10.506977-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
bc9070fc-a7f4-428b-9f0b-bd7d1eece524	2018-03-04 21:14:10.511977-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
36903eef-ed85-4972-a19b-6b698f43091a	2018-03-04 21:14:10.515978-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
5039ba6d-d10e-440f-bec2-95c7a8b82cee	2018-03-04 21:14:10.520978-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
7748ca22-5e4e-4c2b-98ef-d5770421ab6d	2018-03-04 21:14:10.522978-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3174c1d3-cf48-4136-b1cd-85e563e573d1	2018-03-04 21:14:10.526979-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ccbfef23-2c68-4582-a0b2-85d32a89d055	2018-03-04 21:14:10.530979-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b4ef35ff-8ffb-465a-8de3-a7ff253cfe2a	2018-03-04 21:14:10.533979-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3a9e2eda-bda5-472e-b498-0120567916c7	2018-03-04 21:14:10.53798-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
128efcd3-2549-430a-aa99-cb8ddc7243cb	2018-03-04 21:14:10.54198-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
20ee695b-d1de-4738-bb60-2baf7effb21c	2018-03-04 21:14:10.545981-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ac2a9982-9722-438f-91ad-8cc4d07804c5	2018-03-04 21:14:10.548981-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6d270c0a-42d4-4fb5-8031-d263b93313ba	2018-03-04 21:14:10.552981-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6f5a5117-795e-4692-b3f5-3b18a01169e3	2018-03-04 21:14:10.556982-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
aacd7953-535f-4844-9bd4-b36be909cb38	2018-03-04 21:14:10.559982-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
80170961-58e8-4859-bb91-dd2a6fc615c4	2018-03-04 21:14:10.563982-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
341d41c0-391d-4d4a-9755-e960366d93da	2018-03-04 21:14:10.566983-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0d8a5caf-7825-40f4-91bd-1e84e38f5cc0	2018-03-04 21:14:10.570983-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
88673a14-a077-42d7-a040-8d78521acdcf	2018-03-04 21:14:10.574983-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9ed1edc8-3b04-473f-bb2a-eea34fa2284f	2018-03-04 21:14:10.578984-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e9a3efe9-bbca-4a68-94d8-cb987332e921	2018-03-04 21:14:10.581984-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cc77b836-b525-4819-843c-780f1ff79454	2018-03-04 21:14:10.584984-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
bc9cfe13-8cae-4ea5-93a4-93c01ca0dfe4	2018-03-04 21:14:10.588985-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
f68f8522-f4ce-4610-920e-b622e7989fc2	2018-03-04 21:14:10.591985-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
5c985c45-31a0-4e40-8203-019ce05815bb	2018-03-04 21:14:10.594985-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
c5f87ee5-eaa9-4183-9423-8d32c30fc15d	2018-03-04 21:14:10.598986-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
517cea5e-6fdf-4b95-b4f3-b0ff6eba1ed0	2018-03-04 21:14:10.601986-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
a5ddd2d8-77e8-4ded-8da8-8e9eafee0fd3	2018-03-04 21:14:10.604986-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
9d630f97-ecf1-4439-a151-537596b295b3	2018-03-04 21:14:10.608987-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
24e86a50-3fe9-4f30-bd20-b32fd3f5c59f	2018-03-04 21:14:10.611987-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
39371536-9754-4347-9c88-4ef2c53fa068	2018-03-04 21:14:10.616988-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
8cb0a112-d533-4220-96ef-4b73b55fd07d	2018-03-04 21:14:10.620988-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
7d0bd23d-2adf-4a99-8f26-950093a73f27	2018-03-04 21:14:10.623988-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
69bed10a-7409-4d97-8ec5-14c61b2cc84f	2018-03-04 21:14:22.484174-06	3	[22363] IC 324-CInB	[4] DLarrabee	[21062] a	\N	\N
672254fb-8a5a-428d-bfd4-98475e163aa6	2018-03-04 21:14:22.760202-06	2	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
6bdb3efe-b410-41bf-9035-1dc5efcff880	2018-03-04 21:14:22.764202-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
42a96cf9-48ca-43d7-81d9-232c326c467c	2018-03-04 21:14:22.769203-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
602d274a-6243-4af4-8860-3322163dabfc	2018-03-04 21:14:22.773203-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
c09e5a4f-5596-4864-8161-94bec8a616fe	2018-03-04 21:14:22.778204-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
f08eccf7-9bf7-4967-bc4c-f84768e4884e	2018-03-04 21:14:22.782204-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
19420149-0191-41dd-9bcc-08bbcd70d37f	2018-03-04 21:14:22.787205-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
8a830577-1233-4b67-a705-bbb6a3df516c	2018-03-04 21:14:22.791205-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
cbe074bb-ec2b-43e5-b238-cd9de67d38d9	2018-03-04 21:14:22.795205-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
694a4729-470f-4106-b0ba-7293897c450e	2018-03-04 21:14:22.799206-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
1a64c6f6-d3f4-473a-bd43-26dac25ae9b8	2018-03-04 21:14:22.803206-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9862c5bf-55d9-47a6-9c8c-a4a53e961b50	2018-03-04 21:14:22.807207-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c0c473ce-cd77-48b5-8a09-c0513451fa7d	2018-03-04 21:14:22.811207-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8f4e8651-4d9e-494c-94e2-72d96cee5eaf	2018-03-04 21:14:22.815207-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6d3d5209-bfa2-4fb6-844d-9d56af5b40e2	2018-03-04 21:14:22.818208-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
be15d6d4-9d93-40a8-93a9-7931f4e1737f	2018-03-04 21:14:22.821208-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
aeec25f2-27a0-4d3d-bb0d-5f892ffce6ae	2018-03-04 21:14:22.825208-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4097700d-65a1-4fdb-9457-f2ccc4b7edb0	2018-03-04 21:14:22.828209-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
eed80fe5-75c3-4a23-a288-7735b2eb3893	2018-03-04 21:14:22.831209-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cb87739b-b071-44d9-8dc5-e95ddb75d59f	2018-03-04 21:14:22.834209-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4c5d85ab-56de-4f77-8b5f-6f11b2c8f8d3	2018-03-04 21:14:22.83821-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4e052437-8517-4ae0-b778-67d4e0c5e2fd	2018-03-04 21:14:22.84121-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b65fce70-d7b0-4355-89fe-7341629a7b66	2018-03-04 21:14:22.84421-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
57bc6dbd-2899-4fe6-9597-4047a21db802	2018-03-04 21:14:22.847211-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2605f7ad-a065-4d4b-8881-547bac1b00ae	2018-03-04 21:14:22.850211-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9ca4a5f0-cf75-48e1-88fa-6e7053b5e4f6	2018-03-04 21:14:22.853211-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a5ecd061-8f08-481e-ab5c-e3dadec65879	2018-03-04 21:14:22.856211-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
dd0e30f4-2d73-4c59-a809-88fdb473b09f	2018-03-04 21:14:22.860212-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
effb4ade-fedf-43d8-99e1-844d65383568	2018-03-04 21:14:22.864212-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
d03db298-5e8e-4c33-a694-5e8c67c7ddd8	2018-03-04 21:14:22.867213-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
d3b7253e-1a02-4661-8da3-419138cab790	2018-03-04 21:14:22.871213-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
dcce4653-1bbd-4bbe-b988-9eb99bda18f7	2018-03-04 21:14:22.874213-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
317c457e-baf3-4c13-94cd-50fd1d692bed	2018-03-04 21:14:22.877214-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
f28d7410-f49e-43bb-9c41-1827dc05c5d2	2018-03-04 21:14:22.881214-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
5cd3e4f5-2ef9-4b10-b82a-b1b368122e77	2018-03-04 21:14:22.884214-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
266fe754-5c29-4f59-90c1-87b75227179e	2018-03-04 21:14:22.887215-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
7da414a4-cad7-4468-9754-948826517af0	2018-03-04 21:14:22.891215-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
a329a2c1-cd5a-4fa2-b330-4566c1a00d00	2018-03-04 21:14:22.894215-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
1c461393-bbc5-4693-af39-f9454a8b2b3c	2018-03-04 21:14:22.898216-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
90a383d1-f34b-4390-882b-d0e8f7a70a00	2018-03-04 21:14:30.403966-06	3	[22364] IC 324C-OutB	[4] DLarrabee	[21062] a	\N	\N
806d95f6-4fc4-40df-bc20-7990b988e7f5	2018-03-04 21:14:30.671993-06	2	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
61e512b0-1df8-42f8-ade7-5e40168de0c8	2018-03-04 21:14:30.676993-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
304b0513-79d4-4ade-874c-1a90fa6f2a43	2018-03-04 21:14:30.681994-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
b496cf4b-16d3-43fd-95aa-067c00e09046	2018-03-04 21:14:30.685994-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
88d480b0-c6ad-4572-8494-9a017d321a83	2018-03-04 21:14:30.689995-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
6b20a73d-1b56-4a20-961a-d8b1ac6c9d46	2018-03-04 21:14:30.694995-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
a92c28a2-1c97-45b2-8b2d-f808474bd63b	2018-03-04 21:14:30.698996-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
e1d27f96-d732-4103-8a71-5f790566c2b9	2018-03-04 21:14:30.703996-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
2af79305-d479-42aa-a557-ef7c4ad15da5	2018-03-04 21:14:30.707997-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
218ceeb1-bbdd-4d06-b0f0-ab2cbfa91447	2018-03-04 21:14:30.711997-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
129fe0ea-b5ed-4dfd-b26e-f627664e6bbd	2018-03-04 21:14:30.714997-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
da31ed1c-1bb9-498f-8cf8-884697b2093b	2018-03-04 21:14:30.717998-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ecf5aeaa-6c66-4622-ae62-09cd047ab006	2018-03-04 21:14:30.720998-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ba0b01aa-53d8-48d6-bc9c-afaefcaa1ba8	2018-03-04 21:14:30.723998-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6ec65eb9-3ae5-4955-851c-5b305fc00e5a	2018-03-04 21:14:30.726998-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
39122f4f-d49d-44b5-b11c-0e33e00c7a3a	2018-03-04 21:14:30.729999-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
00143edb-57bc-4036-b4b5-5a217654dfe9	2018-03-04 21:14:30.732999-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8eae5f5d-78fa-4123-8cb1-219ad692596a	2018-03-04 21:14:30.735999-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c6ab4def-6d97-452b-a4fb-bf9ff9881007	2018-03-04 21:14:30.739-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
18dc4a5b-c413-4859-b4e5-25af29f33dae	2018-03-04 21:14:30.742-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
bdf193f4-0240-4dca-b20f-2f4c49dd9125	2018-03-04 21:14:30.745-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ced87238-a74f-4735-99cc-be003e4d8929	2018-03-04 21:14:30.749001-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3874e9a0-646b-4db2-b1a9-e07eee3bc438	2018-03-04 21:14:30.752001-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b583e261-ff2d-4d9b-99d1-6657aae6ec4f	2018-03-04 21:14:30.755001-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
63c149de-21cb-4857-8413-3da5d091d0fa	2018-03-04 21:14:30.758002-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
97969682-02b8-41de-8644-1eb2ac9329c1	2018-03-04 21:14:30.762002-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
77301500-be74-44e4-9c2a-b0598c9589e1	2018-03-04 21:14:30.765002-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
230682c0-4fe2-43b5-91fd-2cada6f02991	2018-03-04 21:14:30.769003-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
fdf4cb21-2a84-4a93-a2c7-633a8ea9d78f	2018-03-04 21:14:30.773003-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
3a6530d4-26e6-4f39-bcd5-c0978482d0a5	2018-03-04 21:14:30.776003-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
0bd937c6-0837-4e6f-a6cb-0721b04cea31	2018-03-04 21:14:30.779004-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
26100ded-d896-4414-b2d6-f808b80b740e	2018-03-04 21:14:30.782004-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
240af94c-bf61-4a13-bfc8-56d2e67354dd	2018-03-04 21:14:30.787004-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
c3bad09e-de59-44c8-8b11-d68e2c4e0ea5	2018-03-04 21:14:30.791005-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
3d070d16-1f82-4320-97f8-873628c35bed	2018-03-04 21:14:30.794005-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
fbc86b72-1253-4db0-83d4-64a76ee303cc	2018-03-04 21:14:30.798006-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
000bee85-c8ce-44d5-9314-0c89af72342b	2018-03-04 21:14:30.801006-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
447d0118-e659-4ad9-87b6-ad02913f48a9	2018-03-04 21:14:30.805006-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
738e9b20-cf98-496f-98e0-b68bf7a747ce	2018-03-04 21:14:42.317157-06	3	[22365] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
53703d97-6eba-49b0-a0e4-c6bc153eac2f	2018-03-04 21:14:42.578183-06	2	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
20e5dc03-11f5-40ff-8700-8b28a2084dfb	2018-03-04 21:14:42.583184-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
e5e03123-2d68-411a-a6a4-a643561b8aaf	2018-03-04 21:14:42.588184-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
43843440-1f05-467e-ab4f-70a78adb2380	2018-03-04 21:14:42.591185-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
ac9e8d31-dbd0-40ed-a4f7-c73bbacaf379	2018-03-04 21:14:42.595185-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
e8bc7d83-a3cf-41f0-bb99-fe813f6c0b3d	2018-03-04 21:14:42.600186-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
9769d4f1-72b5-4872-8c2e-84a402796bc3	2018-03-04 21:14:42.604186-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
fc94c6d7-a40f-4d97-b184-c59d5cac04c3	2018-03-04 21:14:42.609187-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
110b6bfb-ec97-4e58-9367-4d958c6303ca	2018-03-04 21:14:42.612187-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
14e94bd5-ee67-4056-a3bd-4ce1d5a77412	2018-03-04 21:14:42.615187-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1d7ddc2b-19c5-4247-8976-8713b7f7bba6	2018-03-04 21:14:42.619188-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1283df90-e61b-4a92-ae17-903f71cb4924	2018-03-04 21:14:42.622188-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f21046fa-c422-4f67-a944-f50e6e87336e	2018-03-04 21:14:42.626188-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
78c25df7-9d2c-45e7-9459-0bb38a864cbc	2018-03-04 21:14:42.628188-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a35ad5eb-cdd8-4065-93a9-36752ed744a7	2018-03-04 21:14:42.632189-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7241eeee-5eda-49be-a498-b901dfa65f04	2018-03-04 21:14:42.636189-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
136386d9-a72a-4a61-89f0-91d1e189396c	2018-03-04 21:14:42.638189-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
856bb419-0f81-4ef7-9151-52a49915d9f9	2018-03-04 21:14:42.64219-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fb714582-3efe-4fb1-a3d3-ce52dd002326	2018-03-04 21:14:42.64619-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e475db36-dd2b-4774-a0c4-f084c0a34aea	2018-03-04 21:14:42.650191-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
61e071a4-7cb6-4b51-b083-652c118e1fb5	2018-03-04 21:14:42.653191-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b59ac1da-d38a-4c68-bdd3-ef127f713d41	2018-03-04 21:14:42.657191-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9cf0fa72-cdc1-467f-a82a-381c7c8ce8ee	2018-03-04 21:14:42.659192-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e83126b1-db0d-4b79-b448-ab53f64be6f4	2018-03-04 21:14:42.662192-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8761e793-3e4a-4fb0-bfe6-271798502e50	2018-03-04 21:14:42.665192-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
86d6f2e1-2390-4197-89f3-e8dd30e47445	2018-03-04 21:14:42.668192-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e17adb45-23af-4210-a4f4-e7aa4f901c39	2018-03-04 21:14:42.670193-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
d6a015f2-893d-4110-a790-40fab0084e8a	2018-03-04 21:14:42.673193-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
122097e5-c5dc-4848-81f2-0a4a1726149b	2018-03-04 21:14:42.676193-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
2ab5399e-761d-43f5-a02e-728a28e4f155	2018-03-04 21:14:42.679194-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
76ad7f35-85da-44d7-a06c-142a72a61c89	2018-03-04 21:14:42.683194-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
1928b99e-4807-4acf-8fba-151420eab02c	2018-03-04 21:14:42.686194-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
53298bee-e85a-4ee8-af7a-5e028eb4dddd	2018-03-04 21:14:42.690195-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
8df5adc5-7720-4306-b16f-2123bc92713b	2018-03-04 21:14:42.694195-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
09690615-ab7f-4359-a16d-850042b6b701	2018-03-04 21:14:42.697195-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
c925baa5-588d-445e-8fec-8b8b8d1d2018	2018-03-04 21:14:42.701196-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
3c733369-27ec-4449-8d0c-593d640a8fb0	2018-03-04 21:14:42.705196-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
58ee220b-a31c-4020-a550-c5194efd88b1	2018-03-04 21:14:50.674993-06	3	[22366] IC 333-InB	[4] DLarrabee	[21062] a	\N	\N
701a9be1-99c5-41ea-a839-4d57ee05d23d	2018-03-04 21:14:50.934019-06	2	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
c17f6797-0801-44c3-aab5-6fd5de9b58f6	2018-03-04 21:14:50.939019-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
5670d697-0792-48a3-8a00-820b9002195f	2018-03-04 21:14:50.94402-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
89eb1b21-4732-46bb-8d04-3b163bc31e98	2018-03-04 21:14:50.94802-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
90cfac61-8d5f-4b9f-82f7-526a8686745f	2018-03-04 21:14:50.953021-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
c78409a1-57d0-40dd-bcf4-d2c78e43974a	2018-03-04 21:14:50.957021-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
a166b4ee-c46f-4592-aa34-3025ad433497	2018-03-04 21:14:50.964022-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
40f5112e-3fdf-4a83-b74f-23f8a45a0ef2	2018-03-04 21:14:50.967022-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2cbfbba1-9f35-4bab-9ae7-d69d1789d6c1	2018-03-04 21:14:50.971023-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b103099d-aec2-4e51-a8f7-468d3cf05eb0	2018-03-04 21:14:50.974023-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0f5623f2-054f-48a3-a2cf-c31b19f8cdfa	2018-03-04 21:14:50.978023-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7cd38ce2-1f1b-43ba-b702-fb72f4b600a3	2018-03-04 21:14:50.981024-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9a27c90d-eae7-41ee-9fc9-5214b6b9d20c	2018-03-04 21:14:50.985024-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
eabd553a-7ae6-4aff-8984-499e725b14e4	2018-03-04 21:14:50.988024-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f178fc7f-7169-4815-bb34-29775183ed4b	2018-03-04 21:14:50.992025-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c42a0121-2a0a-4edd-b729-625e6f207b07	2018-03-04 21:14:50.994025-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c69deefc-66e2-4ed1-b14c-c326db66a3a0	2018-03-04 21:14:50.997025-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
19c85bcc-9232-464d-ac5a-bebafc14bca9	2018-03-04 21:14:51.000026-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d1c1b486-aa16-447b-b97a-e7f3032a300d	2018-03-04 21:14:51.003026-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
dd37f933-79c4-4513-a665-833588702713	2018-03-04 21:14:51.006026-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
498b23de-de4c-47f8-b9f0-ccacf6c86d96	2018-03-04 21:14:51.010027-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d5101f15-0d97-4bbd-bb8a-a0f0392703ea	2018-03-04 21:14:51.013027-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
aba18f77-a32e-4425-b5a0-954dcc7c6667	2018-03-04 21:14:51.016027-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
34fa067f-16a3-4f93-8b4b-86de4f88f8c1	2018-03-04 21:14:51.020028-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
39b23085-f8e9-47ed-9adb-a6be6627c43f	2018-03-04 21:14:51.023028-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f9d95e17-e409-40c0-84c3-e2a28af0d538	2018-03-04 21:14:51.027028-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
cd172fea-5c13-418e-95e9-12b7a6206ea8	2018-03-04 21:14:51.029028-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
f34354f0-4108-43c5-b7d2-2a135515ed32	2018-03-04 21:14:51.033029-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
e3adb08a-747a-4b3c-91cf-82b7a6c45467	2018-03-04 21:14:51.037029-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
79d6ff38-6e18-48b7-8d45-bc954cfd3d59	2018-03-04 21:14:51.04003-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
a0ce546a-a8ea-47c1-aab5-878b41f20c3f	2018-03-04 21:14:51.04403-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
23d0b4e2-1eb1-4e63-be9e-d40bc4f289e2	2018-03-04 21:14:51.04703-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
123ccf64-fb50-4c8a-ba71-ac46c01ce09b	2018-03-04 21:14:51.050031-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
bf8aa893-fe82-440d-bc0b-cc9188a64d8b	2018-03-04 21:14:51.054031-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
14eb7cbd-7079-42af-b654-11eeac23b938	2018-03-04 21:14:51.058031-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
205f9967-6e32-41a8-bcd5-9c133762afd5	2018-03-04 21:14:51.061032-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
90d4f45f-bec3-44cd-b2d2-199eb86b6904	2018-03-04 21:15:17.140639-06	3	[22367] IC 333-OutB	[4] DLarrabee	[21062] a	\N	\N
69f6fbdc-4ce7-494d-9a3b-f13d749e2850	2018-03-04 21:15:17.398665-06	2	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
4534b402-cb8a-4697-addc-7e378682fcff	2018-03-04 21:15:17.402666-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
d2054ad9-aaac-45ff-81ec-6673bd235af0	2018-03-04 21:15:17.416667-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
1b0bfbb8-0356-4a26-bff2-2265fede2002	2018-03-04 21:15:17.420667-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
9b196a91-b0f5-4df2-a702-6b7d2fdb5d69	2018-03-04 21:15:17.425668-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
00d04386-5ee5-46f9-b357-263fba3cda69	2018-03-04 21:15:17.429668-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
309a89ca-3817-4a8e-ad3f-64a2935974f8	2018-03-04 21:15:17.434669-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
683b6f19-eda0-4fed-89c4-a62fdc7b3e9d	2018-03-04 21:15:17.437669-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
51ba2840-9ae2-4e67-8db3-ba478db0329d	2018-03-04 21:15:17.440669-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8e731a42-eb38-46bd-a2e0-58fdcba69c96	2018-03-04 21:15:17.44467-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5cb996e7-20bb-4c6f-9b5c-e396352c2ab7	2018-03-04 21:15:17.44767-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
faeccc2a-fe88-4bff-9ad2-fdbb6956ed95	2018-03-04 21:15:17.45067-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fbfd90df-78da-4940-b34d-a1352ec76c2e	2018-03-04 21:15:17.455671-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
45c9ba3b-b9ea-427b-934e-f76cb91fe483	2018-03-04 21:15:17.459671-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
10f9b6c3-60cd-479a-82ac-77160e4f582f	2018-03-04 21:15:17.463672-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5d2d9f90-70b2-4667-b389-271e363c9698	2018-03-04 21:15:17.466672-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0fb295ed-09d3-44e5-91ab-cf8fc6769c27	2018-03-04 21:15:17.470672-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
de2ae598-b975-4c01-aaea-5e3e6651ff72	2018-03-04 21:15:17.475673-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f114edba-4e69-4538-8d03-d76f96cf8024	2018-03-04 21:15:17.478673-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8add2837-cbfc-4c1a-a774-99c2ad55721b	2018-03-04 21:15:17.482674-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ce50406d-4675-4315-8bfb-0c53ef585d72	2018-03-04 21:15:17.486674-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e179dd23-a40b-4319-ba03-fad8e1863ff3	2018-03-04 21:15:17.489674-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5c3e4e28-5683-4ba6-b825-8998e55d2957	2018-03-04 21:15:17.493675-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cc31c37b-6155-475e-8387-74489c85bddf	2018-03-04 21:15:17.496675-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5c2bd778-4e01-42d3-9d7d-9791264dff2d	2018-03-04 21:15:17.499675-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
37429f2a-480e-4b5b-97f1-9f5df72f38e2	2018-03-04 21:15:17.503676-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
b5351adc-b776-4bf1-983d-76136ccee2e3	2018-03-04 21:15:17.507676-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
e68058f8-2fd8-4e84-b721-4905e84d1a7c	2018-03-04 21:15:17.512677-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
28aca522-57b3-48fe-9618-7aff29974a95	2018-03-04 21:15:17.517677-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
2b83241c-a012-4d50-9b20-edc1f73a1405	2018-03-04 21:15:17.522678-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
c41002bf-1913-4abe-9b66-d354cf2beaf0	2018-03-04 21:15:17.527678-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
91ef02c5-b5a0-4550-abaa-5b8b99e7deb9	2018-03-04 21:15:17.531678-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
d0e7d48b-5219-4d16-89db-e32cdc3e630c	2018-03-04 21:15:17.534679-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
9ccc1c9f-9a7c-4e8e-b309-ab7e6d3265eb	2018-03-04 21:15:17.538679-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
0aa664ee-2528-4bb5-8321-2d67bdba6277	2018-03-04 21:15:17.54268-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
167f533e-3453-48df-b3f5-461ede0ab3fa	2018-03-04 21:15:30.989024-06	3	[22368] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
10d124d6-fcac-4231-b7b8-a3c10006f4bf	2018-03-04 21:15:31.24605-06	2	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
eff4ebce-ba15-44ec-ba9b-476274e19ec6	2018-03-04 21:15:31.25105-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
596d1527-cd1c-4ce7-9451-6a10eaf0cf53	2018-03-04 21:15:31.255051-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
8b169d6b-20d5-4b4f-bf15-ad96f985ccc6	2018-03-04 21:15:31.260051-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
943e3b66-9bf4-41e2-8848-beba33dbd0b1	2018-03-04 21:15:31.264052-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
40551f90-3537-49ce-906a-7e2a2db31f30	2018-03-04 21:15:31.267052-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
53ac463a-4f1d-47e4-974b-6d75c49c0928	2018-03-04 21:15:31.271052-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
710cb569-39f6-4408-b160-52eda0c0d5da	2018-03-04 21:15:31.275053-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
af3010e2-7e2d-42d8-aa99-be82c633ca2e	2018-03-04 21:15:31.278053-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4b2fe159-4554-4855-a9a7-f9818515df97	2018-03-04 21:15:31.281053-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
af1fdf2e-e28e-480b-8cd1-99ff0cb374b7	2018-03-04 21:15:31.285054-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3ffa79d5-13e7-4eef-9490-324f423a6ee2	2018-03-04 21:15:31.289054-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7f055646-eab3-4b22-9d9a-500cf6eee3dd	2018-03-04 21:15:31.292054-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2c70c3f5-c108-4048-a035-620b4e237994	2018-03-04 21:15:31.295055-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
aa8746fc-0d5a-454e-abe2-7c79106a15e3	2018-03-04 21:15:31.299055-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c63adc71-f61d-4042-8066-96f054cd3f1f	2018-03-04 21:15:31.302055-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ac9199cf-b962-4b8f-9bb4-dca3e3c7e7e0	2018-03-04 21:15:31.305056-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0f8c7dc2-8814-4b0a-8bb0-0bb23f1af9d1	2018-03-04 21:15:31.309056-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ba46c662-f92b-4aab-8c47-1db39918e841	2018-03-04 21:15:31.311056-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
85b2b849-aae4-4652-bb7b-c9003c829f8d	2018-03-04 21:15:31.315057-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b5278446-5fc5-4687-b86b-c4f6abfd80ea	2018-03-04 21:15:31.318057-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c9ca5c09-717c-43c6-9e9a-1becf06d17dd	2018-03-04 21:15:31.322057-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
aca7350f-b503-434a-a61e-33142a98cd62	2018-03-04 21:15:31.325058-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
557be833-fd65-4e6a-b5a3-d855262f989d	2018-03-04 21:15:31.329058-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
058cb293-83ef-4c5c-937d-a40f59ed89a6	2018-03-04 21:15:31.332058-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
5097f61d-67dc-4fa4-93b4-c2a0aaa7beab	2018-03-04 21:15:31.335059-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
b1397c35-2220-4319-b3df-283fe3686ad2	2018-03-04 21:15:31.339059-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
5aa49e16-82db-4904-a7c3-55dafb4fdb0a	2018-03-04 21:15:31.341059-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
76bdc3cd-4621-43d6-a97a-6688d9da19ab	2018-03-04 21:15:31.34406-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
531b26fc-93f5-4bd1-97b0-e8584d2914b8	2018-03-04 21:15:31.34706-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
98bfe850-9f0e-45a6-883d-77521df12fb0	2018-03-04 21:15:31.35106-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
dc42a14b-a6e5-4023-bb21-101311ca66be	2018-03-04 21:15:31.354061-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
14ac27c1-13f1-4ec9-af96-a0a4565734f2	2018-03-04 21:15:31.358061-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
65113291-0ef9-44e9-a49f-c6b98110464e	2018-03-04 21:15:31.361061-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
239ab0d9-40f0-45ee-baeb-91a3a65e3062	2018-03-04 21:15:42.34716-06	3	[22369] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
d978311f-61b6-4168-b3a4-a21452806c2a	2018-03-04 21:15:42.624187-06	2	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
09e492cd-62c5-4f23-8fe3-431e9ec171a9	2018-03-04 21:15:42.629188-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
9d639cee-2aec-47c6-89a6-7aadb24f9a79	2018-03-04 21:15:42.634188-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
6f12b782-bfc0-460a-9e58-43928a44ee95	2018-03-04 21:15:42.638189-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
472f159a-3530-4864-b20f-5ec3b1ad7bd8	2018-03-04 21:15:42.642189-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2511e1b3-1dd4-4b4d-9a6a-e9d39d4397f7	2018-03-04 21:15:42.64519-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
97d9810b-b349-411c-bcba-1bc458305e4e	2018-03-04 21:15:42.64919-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
03cfc6e6-5986-4e5f-be1f-800b1b43b250	2018-03-04 21:15:42.65219-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
af81bf50-0b83-4ca2-ad63-350965375728	2018-03-04 21:15:42.656191-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c8d193b3-b14d-4561-ba48-1cf6230418d8	2018-03-04 21:15:42.660191-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6abbbaf0-aa3c-4541-b569-455bc95dda8a	2018-03-04 21:15:42.663191-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0752a8c8-ae0c-4ba0-8c71-924bece54624	2018-03-04 21:15:42.666192-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ea12f92a-1040-402f-a01c-0f4f2cf8847c	2018-03-04 21:15:42.670192-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c180d777-3bf4-4d15-af1f-c18b1afd560d	2018-03-04 21:15:42.673192-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
29d7e7b3-82a3-4a0a-b617-ce196e07e26e	2018-03-04 21:15:42.676193-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
22db444f-87f6-492f-ba97-9c6f5e0199e7	2018-03-04 21:15:42.679193-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
099c0e8a-ab8a-443d-a803-c1628629d2ed	2018-03-04 21:15:42.683193-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7b74da09-9f3c-427b-82c2-eeb610a399ed	2018-03-04 21:15:42.687194-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
01b9f751-7ff6-4afa-a6a8-2b8cd4d75c34	2018-03-04 21:15:42.689194-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
545afc7e-9906-4152-89ef-36eccb8a01f7	2018-03-04 21:15:42.693194-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a0be3242-25a9-4b74-86a1-2a78d4fe2bc4	2018-03-04 21:15:42.696195-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
56eaaf3c-e351-4395-97fe-0764e515c58a	2018-03-04 21:15:42.699195-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4a664a59-534f-4d6d-b186-942c062dcbfd	2018-03-04 21:15:42.701195-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
d07b2b98-dc71-4d67-8b3f-df8715f59d63	2018-03-04 21:15:42.704195-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
961b5695-9498-445e-b179-f45ae4b1cc20	2018-03-04 21:15:42.708196-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
1f8fbb1c-f36a-4afb-b899-d0e7ac605c36	2018-03-04 21:15:42.712196-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
38e04b9d-0fde-4366-aee4-2030185aa070	2018-03-04 21:15:42.715197-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
9a5e8855-f5f1-4a97-9f8b-c672f24a28ba	2018-03-04 21:15:42.719197-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
f946f48f-f20d-456c-9037-f7c894d3ed69	2018-03-04 21:15:42.723197-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
2277f7a0-638a-40a5-a318-157a343bc9c6	2018-03-04 21:15:42.726198-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
d68df0f5-7cf5-41f4-be22-76a6b88aee4e	2018-03-04 21:15:42.729198-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
bae2d7da-bbe9-4218-99fb-f8c9ca46ba29	2018-03-04 21:15:42.732198-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
e88cb805-a3ef-4808-9613-61426230b52b	2018-03-04 21:15:42.735199-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
1362fce3-8120-40ce-9580-9bdf1f2278fe	2018-03-04 21:15:52.95122-06	3	[22370] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
028ef78d-26fe-44cc-b883-769a242c52c9	2018-03-04 21:15:53.241249-06	2	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
41d432a8-f420-46cb-b740-5df160ee5d18	2018-03-04 21:15:53.245249-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
b269fc6e-7c54-4751-afa9-d07dd94b4ae1	2018-03-04 21:15:53.25025-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
6753c5a7-29c5-469d-94d4-d8fd2664b637	2018-03-04 21:15:53.25325-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
972b3614-a9e0-4aeb-8415-eb9ce2e3f58a	2018-03-04 21:15:53.25525-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d56760c1-7025-498b-b008-119a7344c102	2018-03-04 21:15:53.258251-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9bb82261-e33d-4929-889d-432fff5d95a6	2018-03-04 21:15:53.260251-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1444e04f-e445-4eca-a1f7-261d18fb0ea6	2018-03-04 21:15:53.263251-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e5495997-a81f-409e-94dc-d0777d961e68	2018-03-04 21:15:53.267252-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
32d50cd7-bb76-482c-9101-95b426d416d6	2018-03-04 21:15:53.269252-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
babf83f6-e39f-4d18-b2b3-d2ece48797ac	2018-03-04 21:15:53.272252-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4c1cdbfc-b558-4ae2-a638-fa9d70bd9432	2018-03-04 21:15:53.277253-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1c3d7700-5e20-4071-bc50-809798e9c70c	2018-03-04 21:15:53.281253-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
05f47b9e-a5d0-4438-b42c-3755de7bd1d5	2018-03-04 21:15:53.284253-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a810fcd9-c4e6-460d-a1c6-a4aa8b104f8a	2018-03-04 21:15:53.288254-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
574a3432-26ef-46b4-b827-17ed987faeab	2018-03-04 21:15:53.292254-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b41a4777-78eb-4cd0-af9c-63047a7526a4	2018-03-04 21:15:53.296255-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5f4c1e85-695f-4f26-8d57-56977881beb5	2018-03-04 21:15:53.299255-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6a15ffce-3017-4cd9-9c65-4b2b8a141b51	2018-03-04 21:15:53.302255-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7f08a9a2-237a-405b-8557-e78481ccbbc0	2018-03-04 21:15:53.306256-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a84ba384-40b5-4d9a-bb2b-92a65076010a	2018-03-04 21:15:53.309256-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b527e3bd-989f-4633-b543-def2730c6aed	2018-03-04 21:15:53.313256-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
84d35733-dc3a-4a40-88e0-69efec248ec3	2018-03-04 21:15:53.316257-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
35e313ae-8a23-4f12-a000-3586a9b1e9bf	2018-03-04 21:15:53.320257-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
fdcd8d78-8fba-4167-9893-ec146814e172	2018-03-04 21:15:53.324257-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
75545d2c-df20-41ab-b034-33d32f4f11d9	2018-03-04 21:15:53.327258-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
2ef02d3e-c6de-425e-8ddf-c27fa705d18f	2018-03-04 21:15:53.330258-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
cfbfae1b-54c7-411f-887f-f5f0850d16c1	2018-03-04 21:15:53.333258-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
4c5cdb74-84ce-4449-b95b-b00d4e164bc9	2018-03-04 21:15:53.337259-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
2335e754-dcbe-471a-bf91-d610a12c1d40	2018-03-04 21:15:53.341259-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
f538355e-5386-4d65-ad18-3fa5ef19ac35	2018-03-04 21:15:53.345259-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
a06a367f-d5c3-4352-9027-0a74d00c645e	2018-03-04 21:15:53.34926-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
d1a188da-2077-4e42-b7d6-ad368204d158	2018-03-04 21:16:05.019427-06	3	[22371] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
8ee626d2-11e4-4187-a52c-49c7371f61ea	2018-03-04 21:16:05.274452-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
c2d3613c-ca69-422e-98a9-06ab8747ca34	2018-03-04 21:16:05.278453-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
e280250c-1641-4b63-baee-4b38a33eb609	2018-03-04 21:16:05.282453-06	2	[22394] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d4ad2b96-74d9-4645-8235-0d51053379e8	2018-03-04 21:16:05.285453-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
25c1cb30-1037-4f41-bf5e-eca22f8bd2a8	2018-03-04 21:16:05.289454-06	2	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d440ff60-9d2c-474c-bcba-bf76970c70d1	2018-03-04 21:16:05.293454-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8656c5f3-cb6b-4653-a9ff-72a896621370	2018-03-04 21:16:05.296454-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
940af17c-6a30-48ed-b2d2-808650e80eae	2018-03-04 21:16:05.300455-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0457953d-aebe-4141-b4ad-8f22177dc804	2018-03-04 21:16:05.303455-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c3201d57-82ec-42c0-8181-c526fe661d6f	2018-03-04 21:16:05.307456-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1c5f17ad-b519-4d80-8701-8b8c7a112174	2018-03-04 21:16:05.310456-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
422ba017-417c-40bf-9bd9-50021006d924	2018-03-04 21:16:05.313456-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
06885d4c-b96e-4b30-8e97-96173959fc45	2018-03-04 21:16:05.317457-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
343a0222-7cf0-456d-9351-34dc89fdb329	2018-03-04 21:16:05.320457-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
eb895c98-8af0-4685-936a-583b7e8d88c9	2018-03-04 21:16:05.324457-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7fc66fed-947c-4fd0-9ddf-58b921ce67f1	2018-03-04 21:16:05.326457-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0f785d8e-0342-425a-ad69-f6d5f70dcd74	2018-03-04 21:16:05.329458-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1b678abd-5625-4a42-9064-3820da4edad6	2018-03-04 21:16:05.332458-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f9b08890-ccca-410f-b898-736550e1d540	2018-03-04 21:16:05.334458-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
44ced2dd-32af-406a-a87e-380f3b34dea0	2018-03-04 21:16:05.337459-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
79cf262a-49c0-4133-84c6-eceafd5d839c	2018-03-04 21:16:05.341459-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
577eaeed-b6c9-4d55-bf68-cab544cffc7f	2018-03-04 21:16:05.345459-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
21dd5f4a-9866-4c18-913d-d3573605e1a9	2018-03-04 21:16:05.34846-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
8aec032d-18b9-40b2-86b4-9b8691846008	2018-03-04 21:16:05.35246-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
3f18a644-8f4d-4c6d-a502-384646c1debc	2018-03-04 21:16:05.35646-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
bfece9ba-a8f4-460b-8eea-d165df1c7aab	2018-03-04 21:16:05.360461-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
9c44efe0-ca8a-4e8f-aec6-d877c15cfea0	2018-03-04 21:16:05.364461-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
1e6da7c1-7c7d-4f5c-b987-f257371ad675	2018-03-04 21:16:05.366461-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
d72c84cb-704c-4dd4-b716-c3a1a315701a	2018-03-04 21:16:05.370462-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
5bfe3e62-3186-4bad-93d6-fbd9b91b8991	2018-03-04 21:16:05.373462-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
dbdc2ff1-e728-445e-a3aa-557b0b17af07	2018-03-04 21:16:05.377463-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
4a66a549-3624-4166-97f7-e7afd4b3790e	2018-03-04 22:02:43.63526-06	3	[22258] Door 323OHD OPEN	[4] DLarrabee	[21062] a	\N	\N
60a6a6d6-a95c-4d63-b1ce-2c2b764b92fa	2018-03-04 22:02:43.946291-06	2	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
91374447-f8e7-4808-a41d-170e0a9733ec	2018-03-04 22:02:43.962293-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
a19a20da-2f04-4e36-a210-1fd1a37c4573	2018-03-04 22:02:43.977295-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
ff866fbf-27be-4450-a341-6493ab683b7e	2018-03-04 22:02:43.990296-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
86bac056-438d-4d86-b964-1cc6cae84f2b	2018-03-04 22:02:44.000297-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
a3fd0516-b538-4374-93d0-231c04749fc1	2018-03-04 22:02:44.012298-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
b88092e2-3a01-43f3-82e6-b3970062fd0e	2018-03-04 22:02:44.025299-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
e4adce5a-fbeb-491a-acc0-446db4d94cb6	2018-03-04 22:02:44.0353-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
1de4c517-cac5-4861-9b55-cd674d9c5daa	2018-03-04 22:02:44.048302-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
68a4c98a-c990-4fc4-b616-b4d8327c192e	2018-03-04 22:02:44.064303-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
7198dbe3-f77f-42d3-bf36-f1d577708bb3	2018-03-04 22:02:44.075304-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
c631cc4c-636d-4111-983c-cf64b48a5528	2018-03-04 22:02:44.089306-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
d91bf105-bc62-434c-aaff-bd00f0e6588a	2018-03-04 22:02:44.103307-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
ff928089-eaf3-4d6d-a194-075a13158a9b	2018-03-04 22:02:44.118309-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
9fd1984b-afa2-4015-b092-c52a17e19ca2	2018-03-04 22:02:44.12831-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
a436d18b-7d3b-4691-aaf1-6a4282b81f78	2018-03-04 22:02:44.142311-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
b03cfc08-a7fe-41ac-bf6e-953b10eb8caf	2018-03-04 22:02:44.146311-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
07f9b808-b3b2-42cb-b0b7-3f31d402a88e	2018-03-04 22:02:50.790976-06	3	[22259] Door 324OHDE CLOSE	[4] DLarrabee	[21062] a	\N	\N
f1ce3d2a-20a6-499d-92f0-a86b2ca0be05	2018-03-04 22:02:51.061003-06	2	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
f1c9eac1-583f-47c7-a6fb-aec54f0e3017	2018-03-04 22:02:51.074004-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
decd9549-1d9a-44ad-b297-390c73b59e2c	2018-03-04 22:02:51.085005-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
3b445c16-a302-4eb1-bcfe-12baee850ca7	2018-03-04 22:02:51.096006-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
96ca36fe-6b64-451f-b10d-784174d9e07d	2018-03-04 22:02:51.110008-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
794d3f6b-6e47-4222-8032-f04ec3cfcd27	2018-03-04 22:02:51.121009-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
962e2f24-cc61-4add-8624-d4866fca5c71	2018-03-04 22:02:51.13401-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
208d7c39-23d1-4b6c-b8cc-6edb73a18395	2018-03-04 22:02:51.146011-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
eeffb132-2981-41e3-869d-f55af5b191e2	2018-03-04 22:02:51.159013-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
989964a4-3a43-41d4-8cc1-590301018063	2018-03-04 22:02:51.172014-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
0ca717e5-864e-46b8-8575-12151f4653c1	2018-03-04 22:02:51.183015-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
c5eca4d0-af53-41de-a03a-328f5651cc73	2018-03-04 22:02:51.195016-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
0ac99b5b-0831-4280-812a-6ea7caa77c18	2018-03-04 22:02:51.207017-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
6bb94860-e17a-46cb-a9a9-19d549de3e4e	2018-03-04 22:02:51.222019-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
76e75090-5c91-4c96-9564-ccd90e9cc9a5	2018-03-04 22:02:51.23602-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
b82b4f1f-e121-48e4-9b01-2c59e41d504d	2018-03-04 22:02:51.239021-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
5bc05679-604a-4e5d-97ce-2e514eeb2efb	2018-03-04 22:03:04.168313-06	3	[22260] Door 324OHDW OPEN	[4] DLarrabee	[21062] a	\N	\N
f87f86e2-4801-4b7e-ad7e-bb56b9e07691	2018-03-04 22:03:04.450342-06	2	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
f6bde9b1-4590-45d6-8fe5-644f3a8e7f04	2018-03-04 22:03:04.470344-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
73668cc3-8352-4c68-a99e-f2af82e3a2e3	2018-03-04 22:03:04.483345-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
a7510691-0b64-45de-8504-7a4874ec7630	2018-03-04 22:03:04.495346-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
5b9e2012-10d4-4b4a-a2fc-e5879746434f	2018-03-04 22:03:04.507347-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
cc25031f-0a6f-45d5-8ba9-983c3c607a48	2018-03-04 22:03:04.519349-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
bda4d408-c843-4ea0-b1e8-574e12d8c548	2018-03-04 22:03:04.53335-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
2a568e5e-cbdd-4adc-8c53-73cdf70f7327	2018-03-04 22:03:04.546351-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
c151733d-6bd8-4f89-98d8-88af9a2b0cfc	2018-03-04 22:03:04.561353-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
8aeb838a-136e-4157-b973-28aad77772b4	2018-03-04 22:03:04.575354-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
566effa1-f0ad-483d-b9ff-7b5d1ae8aa3e	2018-03-04 22:03:04.588355-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
9e49a480-4e1e-4eff-a397-3cd14ad1f2bb	2018-03-04 22:03:04.601357-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
5f058133-7376-4237-8ebb-2bfbc848b646	2018-03-04 22:03:04.613358-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
c0e4a170-8948-466d-b4cd-e0c2b67142c1	2018-03-04 22:03:04.625359-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
3f418f4f-3932-4a72-900f-29db597e73f3	2018-03-04 22:03:04.628359-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
c197d151-472b-4602-a674-b3b7d475c60d	2018-03-04 22:03:10.857982-06	3	[22261] Door 323OHD CLOSE	[4] DLarrabee	[21062] a	\N	\N
9ec68769-0f72-46f9-abb4-cc23b9dd0467	2018-03-04 22:03:11.117008-06	2	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
fda94a39-eb58-40ba-a870-d52432f7e692	2018-03-04 22:03:11.129009-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
2322596c-f874-4d45-84b3-8e89054baac4	2018-03-04 22:03:11.141011-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
e541c033-a448-4bcf-b068-0714f6192d5e	2018-03-04 22:03:11.155012-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
fbc90b9c-73ad-4168-a41c-88c004fd80af	2018-03-04 22:03:11.166013-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
5f38cbe5-d2b6-43fb-835b-94fbd6e84748	2018-03-04 22:03:11.179014-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
13b9291e-5667-4c36-a6e1-b5986d73b0fd	2018-03-04 22:03:11.194016-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
098f044e-7e07-4894-91e3-e2a5ee1c62fc	2018-03-04 22:03:11.208017-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
c39ad883-7698-469d-bd3d-16f15751a943	2018-03-04 22:03:11.222019-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
59cf2666-d0d3-4f94-a26b-4c210032c253	2018-03-04 22:03:11.23802-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
497085d6-7754-4246-95ff-bdfdb4e07379	2018-03-04 22:03:11.251022-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
1e5e55a9-a6d2-4f70-83d4-ec53e057c3c9	2018-03-04 22:03:11.264023-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
c62e984e-2d17-488f-a91a-ffd3fd4f309c	2018-03-04 22:03:11.279024-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
9a0060e8-1e11-4b70-8988-0f865799e053	2018-03-04 22:03:11.287025-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
c21c61c5-dc1d-4f34-8758-59ce2d319b5d	2018-03-04 22:03:17.792676-06	3	[22262] Door 324OHDE OPEN	[4] DLarrabee	[21062] a	\N	\N
89714a06-00db-40ae-bcd9-90afc5467c02	2018-03-04 22:03:18.065703-06	2	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
79bc36f7-e892-474e-bee1-8ddd083c6707	2018-03-04 22:03:18.078704-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
b88d0bd9-ccf0-4b88-9e4b-99feccbcf6b6	2018-03-04 22:03:18.088705-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
c93fd5d5-c401-475f-9fa2-fe664efa0ae9	2018-03-04 22:03:18.102707-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
9b3d0076-dd7a-4bc0-b9e5-887137dc956f	2018-03-04 22:03:18.112708-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
06a6bec9-078b-4a18-9e48-c49493b5b8e2	2018-03-04 22:03:18.125709-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
c7d1e46a-484b-49b5-a051-62c99d683b75	2018-03-04 22:03:18.13671-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
838f95bb-543b-45db-a488-4261a995fcf0	2018-03-04 22:03:18.146711-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
c416cac8-dfaa-4d31-a24e-273332cfc574	2018-03-04 22:03:18.169713-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
d1abdb7f-f184-4027-b978-14a2dc3e2470	2018-03-04 22:03:18.183715-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
283fcab1-9699-4691-9d4d-2358ba79da2a	2018-03-04 22:03:18.198716-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
da973903-130a-4d79-94aa-baa63f7eeaa1	2018-03-04 22:03:18.208717-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
651daa00-2739-44d3-ae6f-fc9c958dde96	2018-03-04 22:03:18.212718-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
bfdd0502-bd53-4952-9fa6-5d821423509f	2018-03-04 22:03:30.076904-06	3	[22263] Door 324OHDW CLOSE	[4] DLarrabee	[21062] a	\N	\N
8fb6ffce-ade3-401c-92ce-8fd4057957c2	2018-03-04 22:03:30.343931-06	2	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
be00ced8-8d2c-41b7-930a-c5cc590002bd	2018-03-04 22:03:30.356932-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
1c547498-1406-4878-a7cf-1a062d59f1a9	2018-03-04 22:03:30.368933-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
d1107dda-8352-4574-aad0-315fdcedea0f	2018-03-04 22:03:30.381935-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
9d536326-d40b-4b9a-bcd8-d6be2841f7a2	2018-03-04 22:03:30.393936-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
be79dad7-0c54-4fbe-a918-880f59ad6507	2018-03-04 22:03:30.407937-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
175a6de4-b6a6-4889-ac50-ad032dac7c27	2018-03-04 22:03:30.421939-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
c1c88b31-2c44-4dd9-9cab-2114eda9ad9c	2018-03-04 22:03:30.43294-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
fcc1e8b7-aeae-4bb2-955d-94bf9f98aac3	2018-03-04 22:03:30.442941-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
1cb74433-09f4-4b5b-aa60-282117f8dc7c	2018-03-04 22:03:30.454942-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
e9501e8d-c204-4f7b-b3d4-6a78f2e61e63	2018-03-04 22:03:30.465943-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
45e000ae-c848-4d39-8b65-c397fd66aabb	2018-03-04 22:03:30.468943-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
033d1807-c536-4b0c-a5e0-ee16b93e93f2	2018-03-04 22:03:57.871683-06	3	[22264] Door 307	[4] DLarrabee	[21062] a	\N	\N
b2bb2abd-5de6-4128-9501-0b5c7c6be9a8	2018-03-04 22:03:58.23472-06	2	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
0c4d5b7d-4877-49de-b084-1c5a35fbe323	2018-03-04 22:03:58.250721-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
bd3b550f-8f6a-48d0-9f9c-8deb209b2b95	2018-03-04 22:03:58.265723-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
7a572f1b-5f59-4b0b-8f1a-7929a9e6c586	2018-03-04 22:03:58.280724-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
5e490600-e6c5-499e-b36b-f496b10737c1	2018-03-04 22:03:58.294726-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
e1ff3edb-d26f-4618-8c99-39766bfb05e5	2018-03-04 22:03:58.309727-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
cd991e4e-4802-47fe-9f09-80cdd74fb01c	2018-03-04 22:03:58.324729-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
3badacf7-a907-4e39-86b2-6abe94064ee2	2018-03-04 22:03:58.34073-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
0b3faf70-22f0-42f2-a0b1-cd19de39c3b5	2018-03-04 22:03:58.363732-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
58c9f5f8-f303-4813-9928-d41d99a8aa1d	2018-03-04 22:03:58.379734-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
b8e74e78-5658-4cec-8e62-ec27691d6e8f	2018-03-04 22:03:58.384735-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
275c8a8f-6fe4-4b0c-9fa6-ec55f79072e7	2018-03-04 22:04:04.357332-06	3	[22265] Door 309	[4] DLarrabee	[21062] a	\N	\N
878ab994-c160-479d-9e05-cbd631324046	2018-03-04 22:04:04.622358-06	2	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
a0bba88b-5310-4c71-ad4f-19f5dd38ba3b	2018-03-04 22:04:04.632359-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
f47b81d7-70c8-4e15-b15c-7bd2a7f3882a	2018-03-04 22:04:04.64336-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
c201279d-e543-4cee-872d-084f7329bea3	2018-03-04 22:04:04.655362-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
5302bba5-9c95-43cb-9375-195a89756523	2018-03-04 22:04:04.671363-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
1592a0ae-c690-4dad-8fbf-513b41745d75	2018-03-04 22:04:04.685365-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
b2431a64-1460-4778-a31f-a77f38917f15	2018-03-04 22:04:04.699366-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
3b0e39bf-c27e-4bc1-972f-68fd2c0c6503	2018-03-04 22:04:04.713367-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
452f44da-70ca-490b-bd16-eeb03eb12c33	2018-03-04 22:04:04.725369-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
cf69e881-ae3f-40fe-89d5-6765e3d361ac	2018-03-04 22:04:04.730369-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
b036c445-11a5-4723-84cb-28adf46e4290	2018-03-04 22:04:12.485144-06	3	[22266] Door 314	[4] DLarrabee	[21062] a	\N	\N
aa683eb0-6a36-4313-b3c3-eabf3ddcf148	2018-03-04 22:04:12.761172-06	2	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
96e20893-3fe4-4f39-99d8-2977a747962f	2018-03-04 22:04:12.773173-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
4f0b61cb-b02e-40bc-b667-1142b38ad27c	2018-03-04 22:04:12.788175-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
9fed07d9-02a3-46ea-b4da-50b7ed612879	2018-03-04 22:04:12.801176-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
8366d9e7-4287-42df-b5c3-4fd1668d2138	2018-03-04 22:04:12.815177-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
0315c776-e4a4-429b-8a16-e89adf3174c4	2018-03-04 22:04:12.826179-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
b2a33bca-5029-4c20-bd38-1a0b2f24bac2	2018-03-04 22:04:12.835179-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
2bb8822f-aaa4-479a-8804-0d8c703c022b	2018-03-04 22:04:12.84518-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
098b5f5f-5f36-43c0-b81c-370dfb0fe97d	2018-03-04 22:04:12.848181-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
1c84fe69-2a6e-4670-84d4-1deddf666338	2018-03-04 22:04:18.630759-06	3	[22267] Door 322	[4] DLarrabee	[21062] a	\N	\N
417e54df-0e3f-4526-a5cd-dec1b16ef102	2018-03-04 22:04:18.902786-06	2	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
75b35f69-db05-4044-b17b-436d048f84b9	2018-03-04 22:04:18.916788-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
7556c607-50cb-4a1a-af23-5983b636342e	2018-03-04 22:04:18.928789-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
fa421de1-3d60-4200-8f55-99ed9e04ae8e	2018-03-04 22:04:18.93979-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
da990813-2cd3-4e60-ade1-9ed8dd908679	2018-03-04 22:04:18.953791-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
e84ae215-1987-4beb-824a-18cf26188c6a	2018-03-04 22:04:18.967793-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
39f3ca70-c7f4-4959-bfce-b8371046bb33	2018-03-04 22:04:18.976794-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
211b7107-01f6-4516-a06c-ab6eb87f0416	2018-03-04 22:04:18.980794-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
88742bba-18e8-42b7-a178-f2f0c862498a	2018-03-04 22:04:32.812177-06	3	[22268] Door 324A	[4] DLarrabee	[21062] a	\N	\N
ae607057-8490-423c-8067-660aeb257247	2018-03-04 22:04:33.083204-06	2	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
e52b9150-00dd-4099-b0d0-ec46710639bf	2018-03-04 22:04:33.096205-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
8eaa3668-1b4a-4658-bfd2-1c2c3a369506	2018-03-04 22:04:33.108207-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
c55460dd-38d5-4d9d-a17f-a781bc8b5f89	2018-03-04 22:04:33.122208-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
33b97a72-c367-48ad-afe2-ea1dbb141d2a	2018-03-04 22:04:33.134209-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
4d406d65-bfbe-4e78-97f9-1d2e062a7e34	2018-03-04 22:04:33.148211-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
30ca4911-9d85-46a6-b070-f7a5f63be1f8	2018-03-04 22:04:33.152211-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
1d968d88-a708-4a3a-94b6-2c2afdb35ec8	2018-03-04 22:04:40.051901-06	3	[22269] Door 324B	[4] DLarrabee	[21062] a	\N	\N
f7e9e6a9-8a04-4a8d-88a8-49850127dd62	2018-03-04 22:04:40.327928-06	2	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
98dac0da-b72a-40a8-acd1-f2fcb51e0e72	2018-03-04 22:04:40.33993-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
058ccc11-260d-4d91-9417-f0c82ab5355f	2018-03-04 22:04:40.353931-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
e5bedb2e-03ee-41d3-9af3-f67d59c15f2c	2018-03-04 22:04:40.364932-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
1bf61e19-b2b5-486d-959e-38bfdffe202e	2018-03-04 22:04:40.376933-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
6789eca8-8b16-4a2d-ad45-35c056b57175	2018-03-04 22:04:40.379934-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
663b8283-755c-4462-8876-23257b521bb9	2018-03-04 22:04:49.403836-06	3	[22270] Door 324C	[4] DLarrabee	[21062] a	\N	\N
cce7354e-d3b7-413f-9b7a-96d4221f09fb	2018-03-04 22:04:49.661862-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
986d5747-f031-4046-8d58-6917b516d331	2018-03-04 22:04:49.674863-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
a6b3b7ef-db29-49c6-9642-3cf6b40ba704	2018-03-04 22:04:49.693865-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
d47d06ae-4024-41cb-a584-700c5f9cb7cf	2018-03-04 22:04:49.708866-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
69680ea0-8693-4cbe-8ce3-43af64abaf10	2018-03-04 22:04:49.713867-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
ed63f597-5a29-41af-a8e6-6505e9be2dd0	2018-03-04 22:04:59.632859-06	3	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
9f1a7cd5-c348-4e1b-ab2c-8a9e71f6cebd	2018-03-04 22:04:59.899885-06	2	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
501c17f7-20f4-4b28-9408-c190865a7c9f	2018-03-04 22:04:59.910887-06	2	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
af774d51-a8e0-43d5-8a64-9a8fdbc210d6	2018-03-04 22:04:59.925888-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
6ab153be-cade-449e-919b-79ddf54b0d3a	2018-03-04 22:04:59.937889-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
a4657491-bd4a-4489-a987-de172cb11034	2018-03-04 22:04:59.94089-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
54dd913e-36de-4d17-a3b8-f06ae5c09556	2018-03-04 22:05:34.993394-06	3	[22272] Door 330A	[4] DLarrabee	[21062] a	\N	\N
089c3b77-df3e-45e2-809e-48e1c2ca6a6a	2018-03-04 22:05:35.263421-06	2	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
a1fd804b-4ba7-43f8-9995-5d72013b5487	2018-03-04 22:05:35.276423-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
4a7b3e27-e8be-43a6-8d75-ead28986d5b5	2018-03-04 22:05:35.280423-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
5c4fa01a-70af-456d-aa89-0cddcb6ea797	2018-03-04 22:05:40.943989-06	3	[22273] Door 330B	[4] DLarrabee	[21062] a	\N	\N
5c227809-5d76-45b0-a1d7-4571580a622a	2018-03-04 22:05:41.232018-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
e943fb31-d524-44ce-abd3-02e157642bd1	2018-03-04 22:05:41.236019-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
e2860446-9a30-437a-8ed8-26c34e65a9b4	2018-03-04 22:06:05.618457-06	3	[22271] Door 333	[4] DLarrabee	[21062] a	\N	\N
91da52c0-a2e8-4a0c-9601-287394e9ef74	2018-03-04 22:06:05.883483-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
1c18d42f-8ee6-4f0d-ace9-96383ea41d1a	2018-03-04 22:06:05.895484-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
34e79a6a-99ee-4b2a-a502-ba0461d72782	2018-03-04 22:08:46.128506-06	1	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
a284ae65-9a2e-45ee-bc46-ae34d2391f8c	2018-03-04 22:24:21.65805-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
3a958b6b-e884-47d5-85e1-0d3353d1dedc	2018-03-04 22:28:51.847066-06	3	[22396] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
906c50bb-a641-4e96-960c-814ef4d7604c	2018-03-04 22:28:52.130094-06	2	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
bc77873f-c29b-4530-bc60-8ebe6bb6a877	2018-03-04 22:28:52.134095-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
39e69569-57bf-4dca-9e08-be14c3f58db1	2018-03-04 22:28:52.140095-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8f05f635-b372-4126-b991-537cf37197f7	2018-03-04 22:28:52.143095-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
50125189-a79f-4657-afcd-431be2e7886f	2018-03-04 22:28:52.146096-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f3f97692-ff53-4f40-b74a-846d439906d6	2018-03-04 22:28:52.148096-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2a16f561-565c-4b9c-a6c6-90127a990e48	2018-03-04 22:28:52.152096-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
253f08eb-8006-4dea-a99a-69a4bb8de37f	2018-03-04 22:28:52.155097-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
74bd344a-a9d1-469a-8265-46dee98059bb	2018-03-04 22:28:52.159097-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4e963417-1704-4153-85cf-38aa53c5ee55	2018-03-04 22:28:52.163097-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7da1742c-8911-48e9-a0fd-2aff0de5b857	2018-03-04 22:28:52.167098-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
634ed6ac-e6ad-447a-95b7-84dd63c118e1	2018-03-04 22:28:52.170098-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
06a5817f-9a61-4251-9c07-71ee8da39f2c	2018-03-04 22:28:52.174099-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
50538d00-580e-4c3b-8c28-7ca2480b4d26	2018-03-04 22:28:52.177099-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b397ba57-ea56-4d88-a6bb-d08ef41f1138	2018-03-04 22:28:52.180099-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
16745223-f7d3-48c8-acfa-9be2383c408e	2018-03-04 22:28:52.1841-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
b2526689-a86e-4c1e-a5b8-8db99d71d374	2018-03-04 22:28:52.1881-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
04a28e58-a7cc-4534-8455-7fa810a529c8	2018-03-04 22:28:52.1901-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
b0f3ec4f-a0e9-4001-9c51-46c0b18cc860	2018-03-04 22:28:52.1931-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
e8a2722d-6aaf-4eed-a213-dcef32904536	2018-03-04 22:28:52.195101-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
0214df93-cf6b-4d8c-861a-f81fc7a738c6	2018-03-04 22:28:52.199101-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
d96c2916-c5b7-4724-8965-03644e3f2c64	2018-03-04 22:28:52.203101-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
7653543f-bc5a-4afa-8ea3-ae90d2b57564	2018-03-04 22:28:52.207102-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
3d959012-a4aa-4ec4-9799-0e05bf3b9421	2018-03-04 22:28:52.210102-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
091feb24-1c13-4b32-9ba9-2024855d78a3	2018-03-04 22:28:52.214103-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
c591ed5f-5411-4710-b70e-84458f79a185	2018-03-04 22:28:52.218103-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
6b578ed6-a2fe-4db0-85e0-fab268fb28c3	2018-03-04 22:29:00.300911-06	3	[22397] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
03be036a-15ac-4e8f-a690-5d14cc456be6	2018-03-04 22:29:00.566938-06	2	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ee23bb04-5879-4a10-bcbe-5a54c2514c96	2018-03-04 22:29:00.569938-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e19c1337-d6b3-44df-87e7-568fac1123ba	2018-03-04 22:29:00.572938-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f8848f7f-3cc2-4c73-a1ec-301fc5bc78a1	2018-03-04 22:29:00.577939-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
373a2b7b-e4b7-424f-afdc-9a5df789cb63	2018-03-04 22:29:00.580939-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
83125c58-90b9-4ec9-82a4-5ead543323df	2018-03-04 22:29:00.582939-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b942ea40-0804-4c6a-9cc7-5cf881a26768	2018-03-04 22:29:00.58694-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9b38bf1e-cdb3-4fda-ac2b-91b2606342cd	2018-03-04 22:29:00.58994-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c8adbc09-f32a-4383-b353-fd40da7c5078	2018-03-04 22:29:00.594941-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ed1f7e23-0316-43f3-937f-f9bc0928df34	2018-03-04 22:29:00.597941-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7878752f-b8b7-4400-9647-ffec3a106971	2018-03-04 22:29:00.601941-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
94beaef0-2e64-4310-a950-ef3b53b2149e	2018-03-04 22:29:00.604942-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
56dad4b5-96b2-4bb7-b110-ce6b7a9a91f8	2018-03-04 22:29:00.608942-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2ec77651-8091-4699-a489-b66048b9a14c	2018-03-04 22:29:00.611942-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
05c38e50-659f-4779-9207-b12f9a84de4c	2018-03-04 22:29:00.615943-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
c2261480-c839-4720-9a88-c3949a5d7835	2018-03-04 22:29:00.619943-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
497f16bc-289a-4501-b791-2fe910f1c103	2018-03-04 22:29:00.623943-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
00f4bc22-5199-479e-be3a-b13113c1f403	2018-03-04 22:29:00.627944-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
4e4ab757-3c3b-49e2-b646-0bf1677da74f	2018-03-04 22:29:00.631944-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
a955ac2c-bb99-4a74-a013-8b021c1f4329	2018-03-04 22:29:00.635945-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
46fe0388-623a-470e-b767-1476d268166a	2018-03-04 22:29:00.638945-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
c90fc952-8105-49bd-be87-32624ad05452	2018-03-04 22:29:00.642945-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
3c624fb9-001f-46bf-8c03-c499341dba1f	2018-03-04 22:29:00.645946-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
e9b8d863-44eb-4a40-b6b6-66bd05c97b55	2018-03-04 22:29:00.648946-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
f6410fe6-b05e-4cd5-a347-59ab5b9a62b6	2018-03-04 22:29:00.651946-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
7f6f98bc-3ffb-4c57-983c-3b27875fe6d1	2018-03-04 22:30:02.223103-06	3	[22398] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3668339f-4342-4183-afe0-45701b59e251	2018-03-04 22:30:02.475128-06	2	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
48b1b2e0-e639-464f-812c-9967d5146b65	2018-03-04 22:30:02.479128-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c9d3987f-f00d-4031-8295-06145a0eec4a	2018-03-04 22:30:02.483129-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
609e41ec-b360-48f1-bd14-7a9c0f2fe372	2018-03-04 22:30:02.487129-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ed514cfb-dbfe-4e6b-acd1-b501819f7fdb	2018-03-04 22:30:02.508131-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
327f5ff8-ad47-497d-8c05-803056e9ee8b	2018-03-04 22:30:02.511132-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
50707a2a-8863-451d-9492-1b765941f688	2018-03-04 22:30:02.515132-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f8ae0915-96c9-47c8-a16a-fe76f2aeb174	2018-03-04 22:30:02.518132-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8d9d4364-2543-4c00-9649-7e4f553dda78	2018-03-04 22:30:02.521133-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
895440bd-88d2-415b-a15b-3428da089688	2018-03-04 22:30:02.524133-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
84f9eb65-6b00-467b-912c-e37a88c871b8	2018-03-04 22:30:02.527133-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ad50e61e-e37c-4e91-b098-5d64e85503e4	2018-03-04 22:30:02.530133-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c65a6bdb-928f-461b-ac2d-01526e047a55	2018-03-04 22:30:02.533134-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
aff6dbc8-bf47-47ca-b136-a92644e79286	2018-03-04 22:30:02.536134-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
4c9e67b5-23a5-4cd3-8a59-4d7fa6b9ea4d	2018-03-04 22:30:02.539134-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
876dae12-a748-4e1a-b917-1fb68a60bfe9	2018-03-04 22:30:02.544135-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
ff68e8d1-5391-454a-96e3-bed8cf0513a4	2018-03-04 22:30:02.548135-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
e971b179-a5c6-45ee-9aab-d0426cb2b1d7	2018-03-04 22:30:02.551136-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
e44087db-fa87-4e80-ab56-69df3e2b8662	2018-03-04 22:30:02.556136-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
fc81e01a-6e71-47ac-8ab8-89bffdaf6afd	2018-03-04 22:30:02.559136-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
78c7ee81-0d14-4406-a6d8-495d6f4c2f62	2018-03-04 22:30:02.563137-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
39a0483a-0f3a-4289-aac9-b9360a7840ef	2018-03-04 22:30:02.566137-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
10e0d1e5-e36f-45ae-8a5e-a647e22a7832	2018-03-04 22:30:02.570137-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
c02881d9-011f-443a-93bb-2d9750ad841a	2018-03-04 22:30:02.574138-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
c95b159c-ee43-4372-8e03-c5195427a5b8	2018-03-04 22:30:02.576138-06	3	[22399] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7b484040-6003-4b3c-873e-7c5813a31189	2018-03-04 22:30:02.865167-06	2	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9797cf72-9796-4523-a09c-1a14469fa83b	2018-03-04 22:30:02.868167-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
23ce512b-df76-40d8-a420-05106048b299	2018-03-04 22:30:02.872168-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9222711c-3111-43a2-85d3-486d1bbca559	2018-03-04 22:30:02.879168-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1f2107d1-a3d5-40f1-ad8f-9dafad200b47	2018-03-04 22:30:02.886169-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4e60ee57-7e1c-4e42-a9c3-88639ffd44d5	2018-03-04 22:30:02.89117-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
02681e9f-0471-42ad-9d75-45147b9f7ae5	2018-03-04 22:30:02.89717-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
aaa3ce73-49a5-42ec-87bc-5f5753b0a70e	2018-03-04 22:30:02.901171-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b7519ff9-c653-467c-9f06-df325bc01d10	2018-03-04 22:30:02.903171-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d07dff2a-6aa0-4c87-aa3d-5ec26bf87f52	2018-03-04 22:30:02.907171-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2b229519-5a48-4f4e-9de7-32c174bdb319	2018-03-04 22:30:02.910171-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9bc24fd2-70e4-4e49-a123-9247de27c80d	2018-03-04 22:30:02.914172-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
708fa930-c35e-4d1c-bc8b-fa2b0ee5c096	2018-03-04 22:30:02.917172-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
68a11ed7-4cec-477a-9410-fa49a52ba80c	2018-03-04 22:30:02.919172-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
40860afe-d268-406f-b903-4bcf7d9a3919	2018-03-04 22:30:02.922173-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
8a418a49-4803-4bc2-94ba-41e42fd82958	2018-03-04 22:30:02.927173-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
0fc9f274-625b-49cd-9a9c-4c54e9c2db7d	2018-03-04 22:30:02.930173-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
734740d2-6530-4813-8253-9e51aef63b68	2018-03-04 22:30:02.934174-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
3492ceb0-d4fa-43ac-bf5f-4cf1b830f8c1	2018-03-04 22:30:02.937174-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
aed3012e-dde5-4704-a023-6db54446337b	2018-03-04 22:30:02.941175-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
4b002309-5e25-47ee-9441-bb8fac39145e	2018-03-04 22:30:02.945175-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
731e60d0-fab8-43ca-9088-41b486644cf5	2018-03-04 22:30:02.948175-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
42fd3826-6e41-4b64-9834-ed479406d55b	2018-03-04 22:30:02.952176-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
758a689d-753c-42ce-8162-e56952f1fff9	2018-03-04 22:30:02.955176-06	3	[22400] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
85b5dea1-734a-4840-838c-c154ff7b042e	2018-03-04 22:30:03.241205-06	2	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9ddfa228-9d0c-476c-9dec-09b14b41565e	2018-03-04 22:30:03.245205-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e7b6c6ef-dcbd-4a03-a0f6-36f625aa2b98	2018-03-04 22:30:03.250205-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7287abd9-88f1-4b7f-aaa0-8812bbec3307	2018-03-04 22:30:03.253206-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
209af28a-97de-4ad2-b1c5-f394d019044e	2018-03-04 22:30:03.256206-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a6993a93-7dda-40f6-b1f4-998738b486c9	2018-03-04 22:30:03.259206-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
53370a0d-c528-4da4-80d2-263784008155	2018-03-04 22:30:03.262207-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5ca19720-ab33-4af3-8be7-e077f3602b7d	2018-03-04 22:30:03.265207-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7c734049-1d3e-4a02-9486-ee00af3b372b	2018-03-04 22:30:03.267207-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
308c4f49-66dc-4df5-b11a-1e3d91c0a919	2018-03-04 22:30:03.269207-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
d03e0fbb-2fb2-45ba-9767-437ad70d7919	2018-03-04 22:30:03.272208-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a7e98b7b-0884-4f13-85e1-05180e2d7002	2018-03-04 22:30:03.276208-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
a369b5b5-9017-4f4a-952c-e05c544c880b	2018-03-04 22:30:03.281209-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
347f6974-d45f-4411-9f9c-b1a3c0d21985	2018-03-04 22:30:03.284209-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
6b52dee3-eab8-4979-a322-963e888f27c6	2018-03-04 22:30:03.287209-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
e3b2ae95-c978-417c-bd25-c6e060a9d6be	2018-03-04 22:30:03.289209-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
0acbaa1e-3c2b-401f-8f83-980727eebeea	2018-03-04 22:30:03.29221-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
b6381bbf-efcf-40b3-8b52-70d224c474b4	2018-03-04 22:30:03.29621-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
f4592294-e80f-4fc9-a37a-1fe200a945d4	2018-03-04 22:30:03.29921-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
d7164136-f9ab-4997-9eb1-7c5033382745	2018-03-04 22:30:03.301211-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
2d030815-1e90-44f4-a779-08071f279675	2018-03-04 22:30:03.305211-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
e27dac6c-0497-455a-8ce5-11111eaf4c6f	2018-03-04 22:30:03.310211-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
822d24bc-567a-4ca7-a338-63b53f4dd6eb	2018-03-04 22:30:03.313212-06	3	[22401] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8fb53505-888f-4927-8726-7a1cf992ce1a	2018-03-04 22:30:03.576238-06	2	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9a69ce25-b63e-4e2a-b03a-9cb595b01f2a	2018-03-04 22:30:03.579238-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c46763f8-b37b-434f-ba2f-3c4c09a2d69c	2018-03-04 22:30:03.583239-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
19ce0375-c52f-46d9-8086-c6a2cfc1ab0a	2018-03-04 22:30:03.585239-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8cd60544-ef29-4163-911d-437bb4a27370	2018-03-04 22:30:03.588239-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1fff7c19-2c31-4d1b-9115-d213c58cd57d	2018-03-04 22:30:03.590239-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1d98cf1d-2385-4c4e-8fd6-f57a57786780	2018-03-04 22:30:03.59424-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a8a338a0-8854-4ed3-b5ed-da4c82972c19	2018-03-04 22:30:03.59724-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b8a3a462-1ae8-44ef-9ec4-053c89364573	2018-03-04 22:30:03.601241-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a50dba6f-cf51-4e4c-8ce4-2ea1738e39c7	2018-03-04 22:30:03.605241-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
306a62d8-e217-48af-bc37-28f585c6e1b9	2018-03-04 22:30:03.608241-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
749d3f31-9365-4f91-bf9b-e560d3206ed3	2018-03-04 22:30:03.612242-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
a20b2847-6369-48d3-a5d2-8cd1f5b3d6ef	2018-03-04 22:30:03.615242-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
5cf43fd7-c28e-4b51-a3ff-22511d0bbd80	2018-03-04 22:30:03.618242-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
cad8780e-28b8-4bc4-a73a-5d2b5eb0f78d	2018-03-04 22:30:03.622243-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
64a21689-1ec9-46a9-8ab6-4be0d5aef93f	2018-03-04 22:30:03.625243-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
815b0550-0ef7-4dd2-9120-0eb9ea9e56d9	2018-03-04 22:30:03.629243-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
f72aec6e-e54b-461a-a72a-fd233fd372c8	2018-03-04 22:30:03.633244-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
09e74091-3b2c-4acc-9859-9f256cd4ceb2	2018-03-04 22:30:03.635244-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
20a56174-8213-4d18-9579-d326eea51c5e	2018-03-04 22:30:03.638244-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
cfe07f0e-ee1f-4ce2-ba4c-c93d784f8778	2018-03-04 22:30:03.641245-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
fcf79c24-245e-429e-aee5-46af9c0a9eb1	2018-03-04 22:30:03.644245-06	3	[22402] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
f602f883-f82e-4846-939c-b6de6d6a4fb4	2018-03-04 22:30:03.939274-06	2	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b8642e54-0c88-4d79-91d9-1b3d399a4a36	2018-03-04 22:30:03.943275-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b5f70a60-ca5f-432b-877c-6da97bf693ad	2018-03-04 22:30:03.946275-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3b4ce730-3365-4bcb-abf1-432721c75673	2018-03-04 22:30:03.949275-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
c7fea2fc-9f09-4b08-818b-44cd2963094a	2018-03-04 22:30:03.953276-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7d11bada-2ea4-41a1-84ec-58ce679c2444	2018-03-04 22:30:03.955276-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
9ae0006b-a735-4b25-82ca-5210f756e570	2018-03-04 22:30:03.958276-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
84aa30ea-9f30-4c01-b1c6-e2d701fff2e9	2018-03-04 22:30:03.962277-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8c631ac7-bede-43c7-aaf3-bac701db9bdb	2018-03-04 22:30:03.965277-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
994f8519-6adb-42ba-800c-8d04addfec72	2018-03-04 22:30:03.968277-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
0d1c3e1d-9515-42be-b258-32ecff62cdff	2018-03-04 22:30:03.971278-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
53de4378-8f11-4dc5-aea8-c105c8683762	2018-03-04 22:30:03.975278-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
579fa16b-a0b9-4491-95cf-1f1c3f70605c	2018-03-04 22:30:03.979278-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
4e09d72d-37b5-4a16-b5da-19deda6cd7e4	2018-03-04 22:30:03.983279-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
6d623291-8671-4b56-86f2-de791b7963ad	2018-03-04 22:30:03.986279-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
3584b637-c574-42c6-8cff-62b48e29f9a5	2018-03-04 22:30:03.99128-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
2c9e8268-0d8d-4240-8f02-5fd459805dbf	2018-03-04 22:30:03.99428-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
f61670c3-84c2-4239-99ff-187f9f835ae7	2018-03-04 22:30:03.99928-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
44bb327b-4ccf-4eef-8bfa-9ed725433160	2018-03-04 22:30:04.002281-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
82088b1c-d669-4b25-9e96-8c89d6ca5568	2018-03-04 22:30:04.005281-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
7510e3d7-fa27-44dd-bb8e-fdc158a3a433	2018-03-04 22:30:04.007281-06	3	[22403] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a2c80c7f-450e-4ea2-89f7-c09305bfed2f	2018-03-04 22:30:04.29131-06	2	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
605bda24-b42a-440c-9d43-ad9526760c3e	2018-03-04 22:30:04.29431-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
19c8661d-4a56-4f58-9148-c62c55435018	2018-03-04 22:30:04.29731-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a85eb582-67e9-4c85-ad39-ea28c2747f8a	2018-03-04 22:30:04.30031-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
eefbb047-70f9-4edd-a9de-539ffa508431	2018-03-04 22:30:04.303311-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
80aef087-2c57-4a6d-b899-418bb4c0e183	2018-03-04 22:30:04.306311-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
4530b065-b4a1-4e64-b80e-dafc5f498a18	2018-03-04 22:30:04.308311-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e3718662-6a4d-4171-a5d1-8c54969a99e5	2018-03-04 22:30:04.311312-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5968b204-5df1-434b-bca2-b9cfd0dd8a5b	2018-03-04 22:30:04.315312-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
56ac1de4-c137-4f1f-8192-8613b5306eb7	2018-03-04 22:30:04.319312-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
d6972f2b-5bac-4faf-8968-8af157c47191	2018-03-04 22:30:04.322313-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
4e75d77b-1740-41f3-8598-e937c5b59aaa	2018-03-04 22:30:04.325313-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
b4f89f52-12ce-4a95-90be-11f11873ea7c	2018-03-04 22:30:04.328313-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
1dd0e3c3-f6e2-451a-b8a7-24cb33ebec33	2018-03-04 22:30:04.332314-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
daf86bed-c5bb-4143-9cf4-04e32474a685	2018-03-04 22:30:04.336314-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
052d7a3f-6f9e-451c-a55a-f00a68f95b22	2018-03-04 22:30:04.339314-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
1fdf8333-07fc-4681-b944-0b7b0aff120d	2018-03-04 22:30:04.343315-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
3eea191d-b77e-4ec9-952d-d9f272527f3d	2018-03-04 22:30:04.346315-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
af8300b1-b527-4059-b911-37244d441b62	2018-03-04 22:30:04.349315-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
4855f62f-9d09-432a-b64d-fa2f39a586e9	2018-03-04 22:30:04.351316-06	3	[22404] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
22285e6f-b1bb-4eb4-a0af-ee830b56d822	2018-03-04 22:30:04.637344-06	2	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1d9af15e-a34d-4a0d-98a0-5771a1fc0a26	2018-03-04 22:30:04.641345-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7c16881c-daf7-4d0f-ab75-d5cae37abab3	2018-03-04 22:30:04.645345-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fcbfacd2-8cc8-445a-ab18-c851ba923abd	2018-03-04 22:30:04.648345-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
5f248a8d-f7f0-4af6-a2ea-06af8faced2d	2018-03-04 22:30:04.650345-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
88ffd59d-bb03-4a3a-be45-61f59bac031d	2018-03-04 22:30:04.653346-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
0d19a6a9-ab87-4f1b-a646-8c3184dbe245	2018-03-04 22:30:04.656346-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
633b1fe4-5b4f-45bf-8407-eaa7975774ee	2018-03-04 22:30:04.660346-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
00953fec-6254-4862-b4d2-f1bddcf6e3d5	2018-03-04 22:30:04.664347-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
fc4a4112-7792-4d90-8130-4e26fd074ef5	2018-03-04 22:30:04.667347-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
7ce4f37d-f70f-4fec-a6a9-811edb768081	2018-03-04 22:30:04.670347-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
9f3ea67b-c882-4e08-9025-0f865068bd28	2018-03-04 22:30:04.672348-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
2a744630-3531-4d2e-acc6-3fd796886152	2018-03-04 22:30:04.676348-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
762997f3-fcaa-4a7c-a936-ddcf2a89b7ba	2018-03-04 22:30:04.680348-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
73482cb4-b994-4c14-826b-7ae7d3fe730d	2018-03-04 22:30:04.683349-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
1a5632cb-f91d-44b6-9b02-7416c0724662	2018-03-04 22:30:04.687349-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
584af8b6-7e0c-499d-8c7f-f7c7b39c3c53	2018-03-04 22:30:04.690349-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
a0f5fe5a-ebbb-4fd3-8cf8-ad60b9931aa6	2018-03-04 22:30:04.69435-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
9f100a80-19d5-4e1e-9b6e-3e2bb946d900	2018-03-04 22:30:04.69635-06	3	[22405] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b711a627-1926-4be6-aa2f-65efc2a0d90d	2018-03-04 22:30:04.978378-06	2	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
82bb7333-80c5-4036-a6fc-d4477c9b9820	2018-03-04 22:30:04.982379-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
cf15322a-804b-4311-b01e-5e3be560cd14	2018-03-04 22:30:04.986379-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
3ac6a7dd-c318-4bf5-8c31-f50acae55a7a	2018-03-04 22:30:04.990379-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a6d09e7e-f0ad-4922-8917-1dba030789a6	2018-03-04 22:30:04.99238-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
452ab11e-1cf6-421a-b34f-6d10210f019c	2018-03-04 22:30:04.99538-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
297bc263-2554-4c07-ad62-d1e8301630e6	2018-03-04 22:30:04.99738-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
93997fac-0c02-4729-a5c9-3c38f280ba78	2018-03-04 22:30:05.001381-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
7e89a88d-43ed-4c04-83a3-77b1e5bf246a	2018-03-04 22:30:05.004381-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
5d38cbf7-3b2a-4bee-aa2c-c4919ffe894b	2018-03-04 22:30:05.007381-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
4c57aade-394b-4b1a-bb19-4a0542a69868	2018-03-04 22:30:05.010381-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
054d3aac-e259-426f-a5bd-840c2c4d0185	2018-03-04 22:30:05.014382-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
f547b1f4-69bf-43b2-ba5e-0fe49c8c14cd	2018-03-04 22:30:05.018382-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
2283b3c8-79ab-4b5d-9f6d-09c956f9227b	2018-03-04 22:30:05.021383-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
d736fd9b-4133-42a3-867a-d26b492650fc	2018-03-04 22:30:05.025383-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
a9943774-0ad9-4e1a-b9ab-ffa69f7ed9e6	2018-03-04 22:30:05.028383-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
9c283df9-baa6-4f11-8138-0e8fa7f0c794	2018-03-04 22:30:05.031384-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
36703c96-d85a-4ade-9abf-9cb86cd18d24	2018-03-04 22:30:05.034384-06	3	[22406] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
feea5c13-0712-48ad-9c7a-e1a5f5f21afa	2018-03-04 22:30:05.348415-06	2	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
73dde258-333b-403c-b8a3-f6696c07c0db	2018-03-04 22:30:05.350415-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
b7485a2b-28ce-462c-a0b2-8b332414ace7	2018-03-04 22:30:05.374418-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
140f006d-fafb-45ad-a6fd-a85b184472a6	2018-03-04 22:30:05.377418-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ffc2aaba-7cd7-4edd-9555-424c86eb21b8	2018-03-04 22:30:05.381419-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fe20b31b-7c25-456b-94ff-5cb4e1455cd0	2018-03-04 22:30:05.384419-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
377bbc73-10b8-406d-befd-b88904ee2dfb	2018-03-04 22:30:05.388419-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
e90118f7-6e3e-4b9b-9057-0eb0010a431c	2018-03-04 22:30:05.39242-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
6b33fe53-1806-4f96-b0cd-d7e75e8fcce6	2018-03-04 22:30:05.39542-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
75346907-d524-4e37-ae8b-69dd3a425148	2018-03-04 22:30:05.39942-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
94968c31-cfdb-43e5-b1ea-d035366d6f3e	2018-03-04 22:30:05.403421-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
0101591b-512e-465f-9fe6-6d0a4639bc74	2018-03-04 22:30:05.406421-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
e32739a7-6f00-4f80-964e-d37ed49de6c3	2018-03-04 22:30:05.409421-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
e6684bf1-4dc4-4260-b94d-840634fedb64	2018-03-04 22:30:05.412422-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
9d3d6797-0ab1-4825-8afc-e0a37f5c0490	2018-03-04 22:30:05.415422-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
c9b23e5b-e829-4669-a81c-26718177e582	2018-03-04 22:30:05.417422-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
6e2f7082-6845-4e0c-91db-79d4310409ea	2018-03-04 22:30:05.420422-06	3	[22407] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fd4d9dda-fd7b-40c8-9ebf-b5a33cc1e7fe	2018-03-04 22:30:05.739454-06	2	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
2cfbb2b5-aabf-455e-9971-845c156952ff	2018-03-04 22:30:05.742455-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
670eadef-86b6-4f2b-ba57-d8bf534fc0d9	2018-03-04 22:30:05.746455-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
7aa4525b-f588-4287-9d34-4ff389427ff6	2018-03-04 22:30:05.749455-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ebd746bb-a435-4b3d-813f-5bb0812353d1	2018-03-04 22:30:05.753456-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
54608d4e-55b6-49fb-b416-a222dd4af84f	2018-03-04 22:30:05.756456-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
93c2cd57-0e43-4001-81aa-11ac154fee90	2018-03-04 22:30:05.758456-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
92df21a6-cd8f-4b86-b556-37282d13c5a0	2018-03-04 22:30:05.761457-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
4c8f7e9c-3bf4-4c3c-b615-8fd093c36e6c	2018-03-04 22:30:05.765457-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
3b60cf46-4290-433d-8da4-f55644ced1a3	2018-03-04 22:30:05.767457-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
e1c72859-eda4-4dc7-905e-92973a692967	2018-03-04 22:30:05.770457-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
3a4c3e43-e8d0-4ab4-8cfd-bd40b4c4a8c1	2018-03-04 22:30:05.773458-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
684b8137-4635-4ebe-9cf7-cee27e9c4d37	2018-03-04 22:30:05.776458-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
24a36def-2ba8-47b6-bbc2-64895b1d3cfd	2018-03-04 22:30:05.779458-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
2e789d72-d728-4f49-80a8-954db64ee222	2018-03-04 22:30:05.783459-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
8f8675b7-e2e8-4347-a51b-7df3758fb1f9	2018-03-04 22:30:05.786459-06	3	[22408] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
6a8facc5-219d-409a-856a-746d0a47ae32	2018-03-04 22:30:06.065487-06	2	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
fad185b9-8c4f-49a3-968b-0fa6fa6b41d1	2018-03-04 22:30:06.069487-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8ca5695b-2ed3-4989-9c2a-e898ee300757	2018-03-04 22:30:06.073488-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e800a9b5-b90e-4ab9-a635-3889861380a6	2018-03-04 22:30:06.076488-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
8ed61f7c-2ae1-4c74-9c3b-ef2c90877d38	2018-03-04 22:30:06.080488-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
c34633ca-0f6f-4ed9-ab42-b182d4e987b7	2018-03-04 22:30:06.083489-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
411946d4-a5ca-4ae2-a26c-e0a473637922	2018-03-04 22:30:06.086489-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
fdf829cc-15ee-48a9-a703-a4098e7c104e	2018-03-04 22:30:06.089489-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
6f8f8f17-8121-4c27-9d4e-33d84c6e073d	2018-03-04 22:30:06.09349-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
bd7f06ba-7390-4c46-bff4-4af5ffd2f9c3	2018-03-04 22:30:06.09649-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
714b982f-8680-46a0-9fab-49ac3b0bb3c7	2018-03-04 22:30:06.09949-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
b86c91fa-cee2-4bf6-84d1-346c33ead71c	2018-03-04 22:30:06.102491-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
942f7598-69f8-4685-b318-c3476e3eca40	2018-03-04 22:30:06.106491-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
a5a9d996-7f19-4b28-a7ea-d781cfd81090	2018-03-04 22:30:06.110491-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
3543b961-e4d2-4453-a669-046c92be75c5	2018-03-04 22:30:06.113492-06	3	[22409] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
1d813848-d5dc-42d2-af3b-87ffbc54a13b	2018-03-04 22:30:06.401521-06	2	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
a48f826c-8284-4be4-a663-6c09acb77235	2018-03-04 22:30:06.404521-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
ebc14749-fe9e-42f4-9c15-6818ddc34f2f	2018-03-04 22:30:06.408521-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
6e550770-45ae-4ada-9cf2-4eaa7b0690f7	2018-03-04 22:30:06.412522-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
b9393015-f715-408d-9a74-9239d7af260e	2018-03-04 22:30:06.416522-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
a91defe4-9758-4230-97dc-43a0a270c688	2018-03-04 22:30:06.419522-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
34add165-134e-4d96-8daf-0f13cd94055c	2018-03-04 22:30:06.423523-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
a9862607-9998-4894-822b-92b507d785db	2018-03-04 22:30:06.425523-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
ec26a195-2971-4b86-a7b2-83b45a0f9692	2018-03-04 22:30:06.428523-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
98cb7215-18dc-450a-b208-8faf4ab4d5aa	2018-03-04 22:30:06.432524-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
e0ca50e9-0afd-45bc-931e-3f7efee2132e	2018-03-04 22:30:06.435524-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
8b93301d-ef6f-454e-9cc4-54602ee74b52	2018-03-04 22:30:06.438524-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
325d0fe3-e2f4-4010-8aff-b1dd4dc4660d	2018-03-04 22:30:06.442525-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
d989cfcb-7451-4294-b4d2-02d530a7620c	2018-03-04 22:30:06.444525-06	3	[22410] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
22c25ba4-101e-4fd6-bf6a-42584a725c98	2018-03-04 22:30:06.748555-06	2	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
56fdecf2-b76b-48fb-91ab-8e67b7554241	2018-03-04 22:30:06.752556-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
84a28b1f-5795-4f1b-9046-c4f95dc9350c	2018-03-04 22:30:06.756556-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
044e8481-a87c-4447-8536-0216edcc9dce	2018-03-04 22:30:06.760556-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
d40640c8-6d07-4626-b52e-063b4930c768	2018-03-04 22:30:06.763557-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
c224cf13-6b68-4aac-92b0-2b4344216ed0	2018-03-04 22:30:06.767557-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
9bc60a3c-ba55-426f-83d1-7b762ad452ec	2018-03-04 22:30:06.770557-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
5ca105e5-a207-4148-bde3-1cb00443a372	2018-03-04 22:30:06.772558-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
2b935d40-ba44-4bd7-b574-3ad3103339d4	2018-03-04 22:30:06.776558-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
2e601b78-f3ed-4c53-b513-8913a4a697d8	2018-03-04 22:30:06.779558-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
34b808d8-9476-4af9-8343-d64709a27d7b	2018-03-04 22:30:06.782559-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
45d182da-9277-4f04-80ba-7c023a6796da	2018-03-04 22:30:06.786559-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
d58fe2dc-2b77-417c-bff3-2b781f4a19ce	2018-03-04 22:30:06.788559-06	3	[22411] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
8d15e7f3-c62a-455a-b16d-d0b3242a9f2e	2018-03-04 22:30:07.084589-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
d5396f5e-3c4c-4226-9f11-8828d20f2c4c	2018-03-04 22:30:07.087589-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
46f9227d-e1d7-4b25-bdb7-936169bbafc8	2018-03-04 22:30:07.090589-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
9458d9ec-2b1e-42e7-8397-9e02d1eb4775	2018-03-04 22:30:07.09459-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
32b04028-2a5e-4325-a616-7961e6b3c47c	2018-03-04 22:30:07.09759-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
b7fea28d-ba6b-400c-b10f-22de804996a8	2018-03-04 22:30:07.101591-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
9484ed2d-f73e-476f-982a-4c408e6d4c62	2018-03-04 22:30:07.104591-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
73b05092-4398-4288-9074-70c4cc8e6039	2018-03-04 22:30:07.107591-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
2b025be7-ed6b-4fc4-905d-4202addbc75b	2018-03-04 22:30:07.110591-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
f9b5f521-bd9d-4a82-a484-7628036475ae	2018-03-04 22:30:07.113592-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
f501506d-f89e-4760-a049-6ea7e359cddd	2018-03-04 22:30:07.117592-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
57827944-53b0-4ab7-8c20-f1cda888fc13	2018-03-05 07:23:29.555577-06	1	[22258] C Cameras Copy	[4] DLarrabee	[21062] a	\N	\N
14a801e7-bbc7-409f-989d-f9858639bdd0	2018-03-05 07:23:39.119533-06	2	[21478] C Cameras Left	[4] DLarrabee	[21062] a	\N	\N
a0cf2396-152b-4fac-b7b9-a213130a35cd	2018-03-05 07:23:48.881509-06	2	[22258] C Cameras Right	[4] DLarrabee	[21062] a	\N	\N
452643f6-399f-41f6-ae02-8cf3f3d51544	2018-03-05 07:23:54.605082-06	1	[22328] D Cameras Copy	[4] DLarrabee	[21062] a	\N	\N
20955ba3-26ee-453a-9877-5feac079221b	2018-03-05 07:24:01.941815-06	2	[21479] D Cameras Left	[4] DLarrabee	[21062] a	\N	\N
5dd97a29-61f0-46db-96a8-47cc025c16fd	2018-03-05 07:24:12.68789-06	2	[22328] D Cameras Right	[4] DLarrabee	[21062] a	\N	\N
da743482-fddb-49f6-b3a5-83cc99437bea	2018-03-05 07:25:41.515772-06	2	[22236] Area C Right	[4] DLarrabee	[21062] a	\N	\N
dadf545d-bf8f-4c58-ad6a-6e48f57d6da5	2018-03-05 07:25:41.531773-06	2	[22237] Fill.png	[4] DLarrabee	[21062] a	\N	\N
a8f79a9b-93f7-46c8-a59e-cdbc092fc693	2018-03-05 07:25:41.536774-06	2	[22238] Alarm Box	[4] DLarrabee	[21062] a	\N	\N
5e3942cd-895d-427f-9661-2a94a43f0d12	2018-03-05 07:25:41.583779-06	2	[22239] Floorplan	[4] DLarrabee	[21062] a	\N	\N
28740274-676d-4a01-b1df-66668708c931	2018-03-05 07:25:41.59878-06	2	[22275] Cameras	[4] DLarrabee	[21062] a	\N	\N
8c8499a8-2ae8-4da0-9ae6-390b8dc813b8	2018-03-05 07:25:41.608781-06	2	[22296] C 21 CORRIDOR 352 	[4] DLarrabee	[21062] a	\N	\N
0946d93c-ae55-4062-b158-4a589968cfef	2018-03-05 07:25:41.615782-06	2	[22298] C 23 HALL 378 	[4] DLarrabee	[21062] a	\N	\N
25b43750-a6c2-4e63-8b98-5ea20491fb03	2018-03-05 07:25:41.625783-06	2	[22299] C 24 HALL 378	[4] DLarrabee	[21062] a	\N	\N
fe1e201f-72cc-4977-869b-fe8d9cd55733	2018-03-05 07:25:41.634784-06	2	[22300] C 25 HALL 378 	[4] DLarrabee	[21062] a	\N	\N
d65c408f-a338-4dbb-a160-645c593608c9	2018-03-05 07:25:41.639784-06	2	[22304] Nav Tool	[4] DLarrabee	[21062] a	\N	\N
a991082f-8ebd-4b03-ac12-4eb2458410fd	2018-03-05 07:25:41.646785-06	2	[22305] New Shared Screen Object (link)	[4] DLarrabee	[21062] a	\N	\N
8274d23b-d665-40bd-9340-97d5d68c038d	2018-03-05 07:25:41.653786-06	2	[22306] Main Button Tool	[4] DLarrabee	[21062] a	\N	\N
086f0c3c-1eb3-4b4f-ab7b-8dfc5ca89039	2018-03-05 07:25:41.663787-06	2	[22307] View IC Control	[4] DLarrabee	[21062] a	\N	\N
d4e3090c-55e6-41a5-8a48-c3619a4fda18	2018-03-05 07:25:41.668787-06	2	[22308] Interlock Control	[4] DLarrabee	[21062] a	\N	\N
c5fc2118-b786-47da-bdc6-4fe53862bc0a	2018-03-05 07:25:41.673788-06	2	[22309] Reports	[4] DLarrabee	[21062] a	\N	\N
6b6ffa3f-34a1-4d8a-8f2f-0c1b6c5e0646	2018-03-05 07:25:41.679788-06	2	[22310] Group Release	[4] DLarrabee	[21062] a	\N	\N
eb3cb30a-fb17-44b7-a920-13043d504baf	2018-03-05 07:25:41.685789-06	2	[22311] Video Frame	[4] DLarrabee	[21062] a	\N	\N
75a7d574-c8d0-4a46-8b29-a7af14957486	2018-03-05 07:25:41.69479-06	2	[22312] C Video Display	[4] DLarrabee	[21062] a	\N	\N
955895db-c50a-4d16-bf9d-e29f3144140c	2018-03-05 07:25:41.70079-06	2	[22313] Camera Label Frame	[4] DLarrabee	[21062] a	\N	\N
fe21b58e-9a06-48f8-9f96-e583c5d73a42	2018-03-05 07:25:41.705791-06	2	[22081] 330	[4] DLarrabee	[21062] a	\N	\N
8af5d674-4628-461b-b2d8-06cac9eb8bee	2018-03-05 07:25:41.722792-06	2	[22098] Door 330A	[4] DLarrabee	[21062] a	\N	\N
ea4dbb72-0e1c-4b37-a71d-82dfe11ba419	2018-03-05 07:25:41.745795-06	2	[22173] Door 330B	[4] DLarrabee	[21062] a	\N	\N
4e62b798-eab3-44f1-9512-3cb474f3b25f	2018-03-05 07:25:41.753796-06	2	[22174] IC 330A-InB	[4] DLarrabee	[21062] a	\N	\N
aa8b1686-fdc9-404a-bbb2-80f62660d5dc	2018-03-05 07:25:41.760796-06	2	[22196] IC 330A-OutB	[4] DLarrabee	[21062] a	\N	\N
8a47757d-4ff3-407a-b154-65f808b7ca97	2018-03-05 07:25:41.765797-06	2	[22197] IC 330B-InB	[4] DLarrabee	[21062] a	\N	\N
f5200b9e-87cf-40ed-aabd-17cc39205a2a	2018-03-05 07:25:41.771797-06	2	[22240] IC 330B-OutB	[4] DLarrabee	[21062] a	\N	\N
7519e6d5-3258-43ef-b8bb-3520dd9ac9ca	2018-03-05 07:25:41.775798-06	2	[22241] 330A IC-IN	[4] DLarrabee	[21062] a	\N	\N
9be05bb8-42c9-4ae5-bcd3-e0de183d7d73	2018-03-05 07:25:41.779798-06	2	[22278] 330A IC-OUT	[4] DLarrabee	[21062] a	\N	\N
2d227e07-098b-46e3-92d2-88577e00a985	2018-03-05 07:25:41.785799-06	2	[22279] 330B IC-IN	[4] DLarrabee	[21062] a	\N	\N
489cb3b2-0c0f-4127-a763-5bbbe8eef850	2018-03-05 07:25:41.790799-06	2	[22280] 330B IC-OUT	[4] DLarrabee	[21062] a	\N	\N
51c641ee-5440-4e5f-9c9d-b9c8403a3ed2	2018-03-05 07:25:41.7958-06	2	[22281] 342	[4] DLarrabee	[21062] a	\N	\N
cb7300a1-719b-4696-9f32-e1111d00ac78	2018-03-05 07:25:41.815802-06	2	[22282] Door 342	[4] DLarrabee	[21062] a	\N	\N
7da8292b-92d7-4411-b085-568ab48734de	2018-03-05 07:25:41.821802-06	2	[22283] 343	[4] DLarrabee	[21062] a	\N	\N
4b67c855-b90a-4ebd-a17c-f7119ce24eb7	2018-03-05 07:25:41.839804-06	2	[22284] Door 343A	[4] DLarrabee	[21062] a	\N	\N
a7b4cc81-ed8e-47cd-8c11-2ff6184801f0	2018-03-05 07:25:41.848805-06	2	[22285] IC 343A	[4] DLarrabee	[21062] a	\N	\N
66ea0491-1d1d-4d3f-9a39-7916bf8d5e9a	2018-03-05 07:25:41.854806-06	2	[22286] IC 343A-outB	[4] DLarrabee	[21062] a	\N	\N
722dde32-1db0-44f0-8990-c626019d2d21	2018-03-05 07:25:41.859806-06	2	[22287] 344	[4] DLarrabee	[21062] a	\N	\N
7e8edc09-500c-4895-a52e-276053e89714	2018-03-05 07:25:41.877808-06	2	[22288] Door 344A	[4] DLarrabee	[21062] a	\N	\N
5233efdd-71bb-4661-b39e-312a4d87e1af	2018-03-05 07:25:41.884809-06	2	[22289] IC 344A	[4] DLarrabee	[21062] a	\N	\N
5719f23c-331c-41d8-9562-dc65ccf80d86	2018-03-05 07:25:41.892809-06	2	[22290] IC 344A-outB	[4] DLarrabee	[21062] a	\N	\N
ebc070a5-7e24-4463-9add-7e062199976e	2018-03-05 07:25:41.90281-06	2	[22242] 346	[4] DLarrabee	[21062] a	\N	\N
d854bc37-6d6e-4ac1-9b48-15b2065a381f	2018-03-05 07:25:41.923813-06	2	[22243] Door 346A	[4] DLarrabee	[21062] a	\N	\N
45424da6-5a94-44a9-9f2b-568a7bd915df	2018-03-05 07:25:41.931813-06	2	[22244] IC 346A	[4] DLarrabee	[21062] a	\N	\N
a26cb882-bc60-4b5d-9e78-ee750b7da149	2018-03-05 07:25:41.936814-06	2	[22245] IC 346A-outB	[4] DLarrabee	[21062] a	\N	\N
f3be9d8d-7c0c-41df-8f54-8605758010b7	2018-03-05 07:25:41.942814-06	2	[22246] 347	[4] DLarrabee	[21062] a	\N	\N
68c71e6a-6cdc-45eb-b043-0cfdc08fe2a0	2018-03-05 07:25:41.963817-06	2	[22247] Door 347A	[4] DLarrabee	[21062] a	\N	\N
dbe7b44d-31f6-4fb4-99e6-af68d784dd55	2018-03-05 07:25:41.971817-06	2	[22248] IC 347A	[4] DLarrabee	[21062] a	\N	\N
f47949cc-9fc4-4390-9e42-2eb73a509458	2018-03-05 07:25:41.980818-06	2	[22249] IC 347A-outB	[4] DLarrabee	[21062] a	\N	\N
db810dd6-4cb8-44b3-9eb6-f7e27a079fad	2018-03-05 07:25:41.986819-06	2	[22250] 348	[4] DLarrabee	[21062] a	\N	\N
1bff3fd4-5a68-429f-8883-cff496a18f34	2018-03-05 07:25:42.009821-06	2	[22251] Door 348A	[4] DLarrabee	[21062] a	\N	\N
7c817a6a-800d-4bf8-b364-27651e649785	2018-03-05 07:25:42.015822-06	2	[22252] IC 348A	[4] DLarrabee	[21062] a	\N	\N
66326026-a6b1-46aa-97ca-d8376c752353	2018-03-05 07:25:42.021822-06	2	[22253] IC 348A-outB	[4] DLarrabee	[21062] a	\N	\N
ad2bbabb-da69-496e-b4d7-c1bdbbb2f9f3	2018-03-05 07:25:42.026823-06	2	[22254] 349	[4] DLarrabee	[21062] a	\N	\N
a2a2071d-25df-4eac-b926-bf5b738eab24	2018-03-05 07:25:42.043825-06	2	[22255] Door 349A	[4] DLarrabee	[21062] a	\N	\N
ba9dac8a-0e48-4956-9663-8479c4594ff4	2018-03-05 07:25:42.050825-06	2	[22256] IC 349A	[4] DLarrabee	[21062] a	\N	\N
e73ed299-02bd-4db7-a944-39a09977202f	2018-03-05 07:25:42.056826-06	2	[22291] IC 349A-outB	[4] DLarrabee	[21062] a	\N	\N
174fb9e0-2606-49eb-981a-822e27aec9e1	2018-03-05 07:25:42.060826-06	2	[22293] 351	[4] DLarrabee	[21062] a	\N	\N
a21bc67f-9977-4815-a3c8-a4bb286495fe	2018-03-05 07:25:42.081828-06	2	[22294] Door 351A	[4] DLarrabee	[21062] a	\N	\N
aa33c9c0-af16-4fbb-a934-59788367ccea	2018-03-05 07:25:42.09883-06	2	[22295] Door 351B	[4] DLarrabee	[21062] a	\N	\N
9e622835-01b2-406e-9d4d-4f0fed6fcfe6	2018-03-05 07:25:42.104831-06	2	[22297] IC 351A	[4] DLarrabee	[21062] a	\N	\N
0fab0233-dbe9-4a92-bd03-cadfd354756b	2018-03-05 07:25:42.109831-06	2	[22301] IC 351A-outB	[4] DLarrabee	[21062] a	\N	\N
d571844b-c516-4fac-a39e-8e67c3a4fb2b	2018-03-05 07:25:42.117832-06	2	[22302] IC 351B	[4] DLarrabee	[21062] a	\N	\N
fd1759a2-373b-423e-aadc-2e84ff1304bd	2018-03-05 07:25:42.123833-06	2	[22303] IC 351B-outB	[4] DLarrabee	[21062] a	\N	\N
a822b1e7-70af-41b4-9ae9-3ce1ed0b7bac	2018-03-05 07:25:42.128833-06	2	[22374] 351A 	[4] DLarrabee	[21062] a	\N	\N
6d446019-10e4-406b-bee3-9835908310af	2018-03-05 07:25:42.132833-06	2	[22375] 351B	[4] DLarrabee	[21062] a	\N	\N
f23e10e3-7803-429f-ab38-66eebb112224	2018-03-05 07:25:42.136834-06	2	[22376] 351A+B IC-IN	[4] DLarrabee	[21062] a	\N	\N
e27d7efb-ee46-4261-a350-a0d42f044967	2018-03-05 07:25:42.140834-06	2	[22377] 351A+B IC-OUT	[4] DLarrabee	[21062] a	\N	\N
6c11612e-cbfe-404a-add4-9121684e081e	2018-03-05 07:25:42.145835-06	2	[22420] 352	[4] DLarrabee	[21062] a	\N	\N
5ad68d44-f1a8-4147-9063-e0052b72d676	2018-03-05 07:25:42.161836-06	2	[22257] Door 352A	[4] DLarrabee	[21062] a	\N	\N
3e0a5eb7-ed24-4ae6-a72c-912bcfaf27f6	2018-03-05 07:25:42.168837-06	2	[22349] IC 352A	[4] DLarrabee	[21062] a	\N	\N
ce1836aa-77c1-4e19-84b7-66e0026407e1	2018-03-05 07:25:42.174838-06	2	[22350] IC 352A-outB	[4] DLarrabee	[21062] a	\N	\N
ce21435f-4f9f-492d-bc2e-6937be5f028c	2018-03-05 07:25:42.179838-06	2	[22421] 378	[4] DLarrabee	[21062] a	\N	\N
17d9712b-a951-4d2f-ba73-aa7510071f43	2018-03-05 07:25:42.19584-06	2	[22274] Door 378	[4] DLarrabee	[21062] a	\N	\N
1a07d939-f5ed-432a-be8f-8ff22638f558	2018-03-05 07:25:42.203841-06	2	[22372] IC 378-InB	[4] DLarrabee	[21062] a	\N	\N
06e2e150-fb36-465b-ac01-356d2a94387c	2018-03-05 07:25:42.209841-06	2	[22373] IC 378-OutB	[4] DLarrabee	[21062] a	\N	\N
25c2fa84-9db0-42e3-bf27-57636fec7403	2018-03-05 07:27:21.922811-06	2	[22312] C Video Display	[4] DLarrabee	[21062] a	\N	\N
8ced1434-3122-49f9-88ae-0844714e85c1	2018-03-05 07:29:08.569475-06	2	[22539] Area D Right	[4] DLarrabee	[21062] a	\N	\N
82fc4060-7f40-4b71-b162-297e8a65ece7	2018-03-05 07:29:08.582476-06	2	[22540] Fill.png	[4] DLarrabee	[21062] a	\N	\N
75e2dfa0-2780-4edd-b187-0bfd1b5eb868	2018-03-05 07:29:08.588477-06	2	[22541] Alarm Box	[4] DLarrabee	[21062] a	\N	\N
2f8ef2ce-3c8d-48e5-95c3-93f8df985634	2018-03-05 07:29:08.593477-06	2	[22542] PODs 3X Drop sd.png	[4] DLarrabee	[21062] a	\N	\N
74a6851d-69ac-4cab-b2ef-6b2875e07936	2018-03-05 07:29:08.61648-06	2	[22543] Door 405A	[4] DLarrabee	[21062] a	\N	\N
38189975-3a1a-48e6-8cec-4fe9f63a5a6c	2018-03-05 07:29:08.638482-06	2	[22544] Door 414A	[4] DLarrabee	[21062] a	\N	\N
c26b9ce6-2bf6-4783-8db7-64216c4477d8	2018-03-05 07:29:08.656484-06	2	[22545] Door 414B	[4] DLarrabee	[21062] a	\N	\N
6a787853-47e9-4b68-8959-5e840b064008	2018-03-05 07:29:08.672485-06	2	[22546] Door 422A	[4] DLarrabee	[21062] a	\N	\N
6b599883-fdfa-47ab-a3b3-0458a5cbd410	2018-03-05 07:29:08.696488-06	2	[22547] Door 422B	[4] DLarrabee	[21062] a	\N	\N
277257b5-21da-47d0-b360-e755aed2ab79	2018-03-05 07:29:08.71449-06	2	[22548] Door 438A	[4] DLarrabee	[21062] a	\N	\N
23daabd9-fbde-4d67-932a-9984d8b2ee4d	2018-03-05 07:29:08.744493-06	2	[22549] Door 439A	[4] DLarrabee	[21062] a	\N	\N
42729e4d-9606-4a1a-9b14-1014c0a9f7a9	2018-03-05 07:29:08.769495-06	2	[22550] Door 443A	[4] DLarrabee	[21062] a	\N	\N
7985f947-d5f4-461f-bdc4-1d6d420427b3	2018-03-05 07:29:08.787497-06	2	[22551] Door 443B	[4] DLarrabee	[21062] a	\N	\N
b01ad381-ee52-4881-88e6-d337a0829238	2018-03-05 07:29:08.806499-06	2	[22552] Door 444A	[4] DLarrabee	[21062] a	\N	\N
e7d8cfe0-6bc7-4480-b5bc-d151c1323a90	2018-03-05 07:29:08.836502-06	2	[22553] Door 444B	[4] DLarrabee	[21062] a	\N	\N
95fe0146-edec-492e-926a-924725559c89	2018-03-05 07:29:08.854504-06	2	[22554] Door 447A	[4] DLarrabee	[21062] a	\N	\N
364ff522-2d96-4855-826c-d8efd826dadb	2018-03-05 07:29:08.878506-06	2	[22555] Door 447B	[4] DLarrabee	[21062] a	\N	\N
26c3f96d-6287-4f2f-a18e-e766d8788fbc	2018-03-05 07:29:08.903508-06	2	[22556] Door 448A	[4] DLarrabee	[21062] a	\N	\N
08890f0a-a2bd-48f4-8ac0-8ec0948f779e	2018-03-05 07:29:08.92151-06	2	[22557] Door 455A	[4] DLarrabee	[21062] a	\N	\N
0cf5e763-5c69-4b83-b239-847e01ed868f	2018-03-05 07:29:08.938512-06	2	[22558] Door 455B	[4] DLarrabee	[21062] a	\N	\N
14aaab08-7e64-45aa-9391-755f4ce3cc44	2018-03-05 07:29:08.959514-06	2	[22559] Door 455D	[4] DLarrabee	[21062] a	\N	\N
945320b5-b478-4ca7-b92b-32263f31c71d	2018-03-05 07:29:08.978516-06	2	[22560] Door 429A	[4] DLarrabee	[21062] a	\N	\N
7f87cd82-d7a2-4c40-9968-203f8e86db9e	2018-03-05 07:29:08.999518-06	2	[22561] Door 429B	[4] DLarrabee	[21062] a	\N	\N
63e1d39c-98d1-4867-8503-4b42c290b4ad	2018-03-05 07:29:09.01752-06	2	[22562] Door 429C	[4] DLarrabee	[21062] a	\N	\N
df30e194-39a4-4ac1-9adf-20b7a4189c2b	2018-03-05 07:29:09.037522-06	2	[22563] Door 456	[4] DLarrabee	[21062] a	\N	\N
e18004d4-722e-4a44-ac83-e9e64397ce34	2018-03-05 07:29:09.056524-06	2	[22564] Door 461	[4] DLarrabee	[21062] a	\N	\N
15ce93f2-3742-41c1-97fc-b74b531b2256	2018-03-05 07:29:09.074526-06	2	[22565] Door 414A	[4] DLarrabee	[21062] a	\N	\N
afaa9588-9c6f-4473-b073-8c8b3de87776	2018-03-05 07:29:09.094528-06	2	[22566] Door 414B	[4] DLarrabee	[21062] a	\N	\N
173a571e-3ace-4f73-8a8d-53e4dbd36d70	2018-03-05 07:29:09.099528-06	2	[22567] Cameras	[4] DLarrabee	[21062] a	\N	\N
d852adbe-e806-4ad7-aa0a-8cd528b45905	2018-03-05 07:29:09.104529-06	2	[22611] D 44 WAITING 382 	[4] DLarrabee	[21062] a	\N	\N
a3feb18d-b6d6-43f9-9110-783de5f83c7f	2018-03-05 07:29:09.109529-06	2	[22612] D 45 WAITING 382 	[4] DLarrabee	[21062] a	\N	\N
58b93f93-f899-4d48-b8c1-82266cf53a8b	2018-03-05 07:29:09.113529-06	2	[22613] D 46 WAITING 382 	[4] DLarrabee	[21062] a	\N	\N
a85887ba-3f79-427f-af93-8e67c09c2654	2018-03-05 07:29:09.12153-06	2	[22614] D 47 WAITING 382 	[4] DLarrabee	[21062] a	\N	\N
d2364d55-4094-494f-b970-3512c4aaed01	2018-03-05 07:29:09.126531-06	2	[22615] D 48 VENDING 492	[4] DLarrabee	[21062] a	\N	\N
233190e6-b73e-4819-81e9-91e1af939775	2018-03-05 07:29:09.131531-06	2	[22616] D 49 CORRIDOR 484 	[4] DLarrabee	[21062] a	\N	\N
81e2ea18-538a-48b2-9acf-fff9b74ff612	2018-03-05 07:29:09.137532-06	2	[22617] D 50 CORRIDOR 484	[4] DLarrabee	[21062] a	\N	\N
c4439c72-fd32-4ce0-b469-e32b89e02f95	2018-03-05 07:29:09.142532-06	2	[22618] D 51 CORRIDOR 484 	[4] DLarrabee	[21062] a	\N	\N
4b356352-6ec5-4c42-9acd-d001eb46490a	2018-03-05 07:29:09.147533-06	2	[22619] D 52 CORRIDOR 484 	[4] DLarrabee	[21062] a	\N	\N
31d8c68d-4eca-4386-849a-e9171bcad2a8	2018-03-05 07:29:09.156534-06	2	[22620] D 53 CORRIDOR 484 	[4] DLarrabee	[21062] a	\N	\N
cc29ff6a-9c9d-44c1-890d-b44750d1394e	2018-03-05 07:29:09.162534-06	2	[22621] D 54 CORRIDOR 484 	[4] DLarrabee	[21062] a	\N	\N
6dc6f7b7-c249-4735-9ba1-5aa242f951b3	2018-03-05 07:29:09.167535-06	2	[22622] D 55 INTERVIEW 466 	[4] DLarrabee	[21062] a	\N	\N
c2aef9e9-cd93-4ae9-bee8-ee1443b378bd	2018-03-05 07:29:09.172535-06	2	[22623] D 56 MEETING 467	[4] DLarrabee	[21062] a	\N	\N
3511f47c-e245-4cd0-9551-b785892d9158	2018-03-05 07:29:09.177536-06	2	[22624] D 57 CORRIDOR 484 	[4] DLarrabee	[21062] a	\N	\N
04b00ef3-a351-4824-97ae-9f5f70b140ec	2018-03-05 07:29:09.182536-06	2	[22625] D58 VISITING ROOM 445	[4] DLarrabee	[21062] a	\N	\N
8baee3c8-5592-4bec-ad87-66c5beb6162a	2018-03-05 07:29:09.187537-06	2	[22626] D59 MEDS STORAGE 401	[4] DLarrabee	[21062] a	\N	\N
e8e81227-e7fe-4828-b574-55645cdc5c37	2018-03-05 07:29:09.195538-06	2	[22627] None	[4] DLarrabee	[21062] a	\N	\N
1d255670-526d-4942-a901-7833fddbbab3	2018-03-05 07:29:09.199538-06	2	[22628] Nav Tool	[4] DLarrabee	[21062] a	\N	\N
54084c2d-70ce-4953-b5ec-9b0560057fca	2018-03-05 07:29:09.203538-06	2	[22629] New Shared Screen Object (link)	[4] DLarrabee	[21062] a	\N	\N
2b447cf8-24af-4d14-b4ba-787ace06c6ce	2018-03-05 07:29:09.208539-06	2	[22630] Main Button Tool	[4] DLarrabee	[21062] a	\N	\N
31940a6a-7f81-46de-a049-92e70e62d5e8	2018-03-05 07:29:09.213539-06	2	[22631] View IC Control	[4] DLarrabee	[21062] a	\N	\N
74d7f1ce-02d9-4d25-849b-7937607e8551	2018-03-05 07:29:09.21854-06	2	[22632] Interlock Control	[4] DLarrabee	[21062] a	\N	\N
4cd80e94-3c95-4342-b3cd-e87115e37877	2018-03-05 07:29:09.22254-06	2	[22633] Reports	[4] DLarrabee	[21062] a	\N	\N
2c10e34f-2693-4f2d-b907-b6cd5726f5a0	2018-03-05 07:29:09.228541-06	2	[22634] Group Release	[4] DLarrabee	[21062] a	\N	\N
3997b98c-f8f5-4e0f-8509-c3e2c408c13f	2018-03-05 07:29:09.233541-06	2	[22635] Video Frame	[4] DLarrabee	[21062] a	\N	\N
f4e4953f-a72c-4463-ba1b-6c718bc28f80	2018-03-05 07:29:09.242542-06	2	[22636] D Video Display	[4] DLarrabee	[21062] a	\N	\N
e71d0101-8636-4d6f-ab3a-614c8a291c28	2018-03-05 07:29:09.247543-06	2	[22637] Camera Label Frame	[4] DLarrabee	[21062] a	\N	\N
3e68869b-00c0-454c-86e6-b6d1cca80fbd	2018-03-05 07:29:09.253543-06	2	[22638] IC 448-InB	[4] DLarrabee	[21062] a	\N	\N
32a73265-0850-4d1b-9eed-9bd0b12aea71	2018-03-05 07:29:09.257544-06	2	[22395] 202 Copy	[4] DLarrabee	[21062] a	\N	\N
e691935f-c7d9-4d39-a176-cacff30adc21	2018-03-05 07:31:26.726289-06	2	[22636] D Video Display	[4] DLarrabee	[21062] a	\N	\N
44836b73-6b9f-4e48-95b7-6dae3c10d0c7	2018-03-05 07:32:10.383655-06	2	[21732] DW Spectrum NVR	[4] DLarrabee	[21062] a	\N	\N
0d2c87cf-d793-4b68-abc9-399798d778d2	2018-03-05 07:37:09.730586-06	2	[22136] C Video Display	[4] DLarrabee	[21062] a	\N	\N
df9b8ada-ab38-4bba-b007-e692e15617f1	2018-03-05 07:37:28.702483-06	2	[22312] C Video Display	[4] DLarrabee	[21062] a	\N	\N
ee465c6b-f659-4758-b641-6ee87f21bb9c	2018-03-05 07:37:56.598273-06	2	[22534] D Video Display	[4] DLarrabee	[21062] a	\N	\N
5185cfbf-7503-4d73-81be-69de65931ff8	2018-03-05 07:38:14.47206-06	2	[22636] D Video Display	[4] DLarrabee	[21062] a	\N	\N
9a756942-027e-4b7b-82f8-276360eca65d	2018-03-05 08:47:57.98937-06	2	[22465] Cameras	[4] DLarrabee	[21062] a	\N	\N
0704ccf0-77bd-49c5-8ee1-28acdfe46c49	2018-03-05 08:52:59.637532-06	2	[22084] Door 324OHDW OPEN/CLOSE	[4] DLarrabee	[21062] a	\N	\N
51bbd5b9-6724-47ed-afdf-322394bfdc8e	2018-03-05 08:58:41.25969-06	1	[22399] New Computer	[4] DLarrabee	[21062] a	\N	\N
81593a6d-74da-4018-9868-50ba711994f0	2018-03-05 08:58:55.86015-06	2	[22399] W7_IS_40_PC	[4] DLarrabee	[21062] a	\N	\N
9e91439a-66f8-4c4b-aadf-198a7b9a11e2	2018-03-05 08:59:41.028667-06	2	[22084] Door 324OHDW OPEN/CLOSE	[4] DLarrabee	[21062] a	\N	\N
7c5d657b-938a-4364-a6de-f5750383e951	2018-03-05 09:07:20.033563-06	2	[22441] Door 405A	[4] DLarrabee	[21062] a	\N	\N
64a67205-99af-4d00-b12a-53aab81037f6	2018-03-05 09:07:55.040063-06	2	[22442] Door 414A	[4] DLarrabee	[21062] a	\N	\N
e6790347-4cca-4572-b9f3-0c32f4d33988	2018-03-05 09:08:31.435702-06	2	[22443] Door 414B	[4] DLarrabee	[21062] a	\N	\N
c39b03a3-f15e-4223-a1f6-28310f3c524c	2018-03-05 09:09:02.892847-06	2	[22444] Door 422A	[4] DLarrabee	[21062] a	\N	\N
482aca35-969d-4a40-8311-985af7a42a44	2018-03-05 09:09:37.11727-06	2	[1072] DPIS-422B	[4] DLarrabee	[21062] a	\N	\N
ff5de084-f0dd-4d01-b3ac-c4ab47c247db	2018-03-05 09:10:03.503908-06	2	[22445] Door 422B	[4] DLarrabee	[21062] a	\N	\N
ee55c4ac-6f7e-46cb-8e83-59f05799dc38	2018-03-05 09:12:55.170073-06	2	[22458] Door 429A	[4] DLarrabee	[21062] a	\N	\N
6a3b90d7-274e-49d6-8a53-3e77b09fc556	2018-03-05 09:14:35.237079-06	2	[22459] Door 429B	[4] DLarrabee	[21062] a	\N	\N
bfd23233-c71c-4ab5-8063-3cd0b89e07c4	2018-03-05 09:15:17.308285-06	2	[22458] Door 429A	[4] DLarrabee	[21062] a	\N	\N
bc1103fe-eb51-4b65-ae65-e553fb8f33c8	2018-03-05 09:28:07.488296-06	2	[22459] Door 429B	[4] DLarrabee	[21062] a	\N	\N
a394724d-8461-4730-9f59-499a6a04cda0	2018-03-05 09:28:56.867233-06	2	[22460] Door 429C	[4] DLarrabee	[21062] a	\N	\N
ab37027e-9b09-4a15-b838-c9f00d08aadd	2018-03-05 09:30:27.228268-06	2	[22446] Door 438A	[4] DLarrabee	[21062] a	\N	\N
c52f4fa7-cb86-4694-a37b-8b3c9f4d7a95	2018-03-05 09:31:08.438389-06	2	[22447] Door 439A	[4] DLarrabee	[21062] a	\N	\N
09e922cc-574b-4255-ac56-893298e97109	2018-03-05 09:31:53.604905-06	2	[22448] Door 443A	[4] DLarrabee	[21062] a	\N	\N
0c21ff16-d718-4c34-919e-09db011b73a1	2018-03-05 09:32:33.538898-06	2	[22449] Door 443B	[4] DLarrabee	[21062] a	\N	\N
bc18030b-8ec3-4e14-bd76-dc0881eb9fdc	2018-03-05 09:33:10.681612-06	2	[22450] Door 444A	[4] DLarrabee	[21062] a	\N	\N
65de41fb-d06b-4eec-ae99-15ad35edc962	2018-03-05 09:33:51.301673-06	2	[22451] Door 444B	[4] DLarrabee	[21062] a	\N	\N
0bafcec2-ba6c-4f59-bb7e-cd1413b27950	2018-03-05 09:34:22.855829-06	2	[22452] Door 447A	[4] DLarrabee	[21062] a	\N	\N
eff3e874-8610-4f35-b927-7e2394408d38	2018-03-05 09:34:57.246267-06	2	[22453] Door 447B	[4] DLarrabee	[21062] a	\N	\N
f1fcd3a4-0a08-440b-81b7-b448fb87108a	2018-03-05 09:36:25.660108-06	2	[22454] Door 448A	[4] DLarrabee	[21062] a	\N	\N
0fd81a6e-f23b-45ef-86fb-b517b9dd83f6	2018-03-05 09:37:11.952737-06	2	[22455] Door 455A	[4] DLarrabee	[21062] a	\N	\N
426c26d4-df8d-4434-8bfc-540ac3ee4662	2018-03-05 09:37:48.5884-06	2	[22456] Door 455B	[4] DLarrabee	[21062] a	\N	\N
5c17fd9b-1f45-4039-829a-fa237d68ac1c	2018-03-05 09:38:34.309971-06	2	[22457] Door 455D	[4] DLarrabee	[21062] a	\N	\N
1730d2a3-ee6a-4c92-9afb-be0f98a80524	2018-03-05 09:42:02.958834-06	2	[21336] Door 514	[4] DLarrabee	[21062] a	\N	\N
07bbff3a-49ec-4ab4-98e1-b5ff2df321b8	2018-03-05 09:42:59.875525-06	2	[21337] Door 529	[4] DLarrabee	[21062] a	\N	\N
24175c8a-72ce-473c-87fe-3e69ca4c8b2f	2018-03-05 09:48:12.110746-06	2	[21337] Door 529	[4] DLarrabee	[21062] a	\N	\N
50d69d4a-768b-4b6c-83d2-f914ca4b0776	2018-03-05 09:48:21.181653-06	2	[21336] Door 514	[4] DLarrabee	[21062] a	\N	\N
\.


SET search_path = core, pg_catalog;

--
-- Name: AccessEntry_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AccessEntry"
    ADD CONSTRAINT "AccessEntry_pkey" PRIMARY KEY (id);


--
-- Name: AccessSet_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AccessSet"
    ADD CONSTRAINT "AccessSet_pkey" PRIMARY KEY (id);


--
-- Name: AccessSetsToAccessEntries_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AccessSetsToAccessEntries"
    ADD CONSTRAINT "AccessSetsToAccessEntries_pkey" PRIMARY KEY (access_set_id, access_entry_id);


--
-- Name: AccessSetsToTokens_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AccessSetsToTokens"
    ADD CONSTRAINT "AccessSetsToTokens_pkey" PRIMARY KEY (access_set_id, token_id);


--
-- Name: AlterTableInformation_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AlterTableInformation"
    ADD CONSTRAINT "AlterTableInformation_pkey" PRIMARY KEY (id);


--
-- Name: BlobType_abbrev_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "BlobType"
    ADD CONSTRAINT "BlobType_abbrev_key" UNIQUE (abbrev);


--
-- Name: BlobType_mime_type_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "BlobType"
    ADD CONSTRAINT "BlobType_mime_type_key" UNIQUE (mime_type);


--
-- Name: BlobType_name_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "BlobType"
    ADD CONSTRAINT "BlobType_name_key" UNIQUE (name);


--
-- Name: BlobType_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "BlobType"
    ADD CONSTRAINT "BlobType_pkey" PRIMARY KEY (id);

ALTER TABLE "BlobType" CLUSTER ON "BlobType_pkey";


--
-- Name: Card_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Card"
    ADD CONSTRAINT "Card_pkey" PRIMARY KEY (token_id);


--
-- Name: Parameter_name_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Parameter"
    ADD CONSTRAINT "Parameter_name_key" UNIQUE (name);


--
-- Name: Parameter_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Parameter"
    ADD CONSTRAINT "Parameter_pkey" PRIMARY KEY (id);


--
-- Name: Personnel_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_pkey" PRIMARY KEY (id);


--
-- Name: Reader_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Reader"
    ADD CONSTRAINT "Reader_pkey" PRIMARY KEY (id);


--
-- Name: ReadersToAccessEntries_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "ReadersToAccessEntries"
    ADD CONSTRAINT "ReadersToAccessEntries_pkey" PRIMARY KEY (reader_id, access_entry_id);


--
-- Name: RfidTag_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "RfidTag"
    ADD CONSTRAINT "RfidTag_pkey" PRIMARY KEY (token_id);


--
-- Name: RfidTag_tag_number_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "RfidTag"
    ADD CONSTRAINT "RfidTag_tag_number_key" UNIQUE (tag_number);


--
-- Name: ScheduledEvent_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "ScheduledEvent"
    ADD CONSTRAINT "ScheduledEvent_pkey" PRIMARY KEY (id);


--
-- Name: SystemInformationItem_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "SystemInformationItem"
    ADD CONSTRAINT "SystemInformationItem_pkey" PRIMARY KEY (sysinfo_id, item_id);


--
-- Name: SystemInformation_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "SystemInformation"
    ADD CONSTRAINT "SystemInformation_pkey" PRIMARY KEY (id);


--
-- Name: TokenType_name_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "TokenType"
    ADD CONSTRAINT "TokenType_name_key" UNIQUE (name);


--
-- Name: TokenType_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "TokenType"
    ADD CONSTRAINT "TokenType_pkey" PRIMARY KEY (id);

ALTER TABLE "TokenType" CLUSTER ON "TokenType_pkey";


--
-- Name: TokenType_table_name_key; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "TokenType"
    ADD CONSTRAINT "TokenType_table_name_key" UNIQUE (table_name);


--
-- Name: Token_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Token"
    ADD CONSTRAINT "Token_pkey" PRIMARY KEY (id);


--
-- Name: Vehicle_pkey; Type: CONSTRAINT; Schema: core; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Vehicle"
    ADD CONSTRAINT "Vehicle_pkey" PRIMARY KEY (id);


SET search_path = extra, pg_catalog;

--
-- Name: AccessSet_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "AccessSet"
    ADD CONSTRAINT "AccessSet_pkey" PRIMARY KEY (id);


--
-- Name: Blob_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "Blob"
    ADD CONSTRAINT "Blob_pkey" PRIMARY KEY (id);


--
-- Name: Card_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "Card"
    ADD CONSTRAINT "Card_pkey" PRIMARY KEY (token_id);


--
-- Name: Notes_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "Notes"
    ADD CONSTRAINT "Notes_pkey" PRIMARY KEY (id);


--
-- Name: Personnel_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_pkey" PRIMARY KEY (id);


--
-- Name: Vehicle_pkey; Type: CONSTRAINT; Schema: extra; Owner: extra; Tablespace: 
--

ALTER TABLE ONLY "Vehicle"
    ADD CONSTRAINT "Vehicle_pkey" PRIMARY KEY (id);


SET search_path = history, pg_catalog;

--
-- Name: Activity_Statistics_pkey; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Activity_Statistics"
    ADD CONSTRAINT "Activity_Statistics_pkey" PRIMARY KEY (id);


--
-- Name: Activity_pkey; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "Activity"
    ADD CONSTRAINT "Activity_pkey" PRIMARY KEY (id);


--
-- Name: ChangeType_name_key; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "ChangeType"
    ADD CONSTRAINT "ChangeType_name_key" UNIQUE (name);


--
-- Name: ChangeType_pkey; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "ChangeType"
    ADD CONSTRAINT "ChangeType_pkey" PRIMARY KEY (id);


--
-- Name: EventType_name_key; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "EventType"
    ADD CONSTRAINT "EventType_name_key" UNIQUE (name);


--
-- Name: EventType_pkey; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "EventType"
    ADD CONSTRAINT "EventType_pkey" PRIMARY KEY (id);


--
-- Name: ProjectChange_pkey; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "ProjectChange"
    ADD CONSTRAINT "ProjectChange_pkey" PRIMARY KEY (id);


--
-- Name: pk_history.AccutechTagChange; Type: CONSTRAINT; Schema: history; Owner: core; Tablespace: 
--

ALTER TABLE ONLY "AccutechTagChange"
    ADD CONSTRAINT "pk_history.AccutechTagChange" PRIMARY KEY (id);


SET search_path = core, pg_catalog;

--
-- Name: AccessSetsToAccessEntries_access_entry_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "AccessSetsToAccessEntries_access_entry_id_idx" ON "AccessSetsToAccessEntries" USING btree (access_entry_id);


--
-- Name: AccessSetsToAccessEntries_access_set_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "AccessSetsToAccessEntries_access_set_id_idx" ON "AccessSetsToAccessEntries" USING btree (access_set_id);


--
-- Name: AccessSetsToTokens_access_set_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "AccessSetsToTokens_access_set_id_idx" ON "AccessSetsToTokens" USING btree (access_set_id);


--
-- Name: AccessSetsToTokens_token_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "AccessSetsToTokens_token_id_idx" ON "AccessSetsToTokens" USING btree (token_id);


--
-- Name: Card_unique_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE UNIQUE INDEX "Card_unique_idx" ON "Card" USING btree (card_number, site_code, card_format) WHERE (deleted IS NULL);


--
-- Name: Personnel_existing_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE UNIQUE INDEX "Personnel_existing_idx" ON "Personnel" USING btree (id) WHERE (deleted IS NULL);


--
-- Name: ReadersToAccessEntries_access_entry_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "ReadersToAccessEntries_access_entry_id_idx" ON "ReadersToAccessEntries" USING btree (access_entry_id);


--
-- Name: ReadersToAccessEntries_reader_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "ReadersToAccessEntries_reader_id_idx" ON "ReadersToAccessEntries" USING btree (reader_id);


--
-- Name: Token_existing_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE UNIQUE INDEX "Token_existing_idx" ON "Token" USING btree (id) WHERE (deleted IS NULL);


--
-- Name: Token_personnel_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "Token_personnel_id_idx" ON "Token" USING btree (personnel_id) WHERE (deleted IS NULL);


--
-- Name: Token_type_id_idx; Type: INDEX; Schema: core; Owner: core; Tablespace: 
--

CREATE INDEX "Token_type_id_idx" ON "Token" USING btree (type_id);


SET search_path = extra, pg_catalog;

--
-- Name: AccessSet_notes_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "AccessSet_notes_id_idx" ON "AccessSet" USING btree (notes_id);


--
-- Name: Blob_blob_type_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Blob_blob_type_id_idx" ON "Blob" USING btree (type_id);


--
-- Name: Personnel_fingerprint_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Personnel_fingerprint_id_idx" ON "Personnel" USING btree (fingerprint_id);


--
-- Name: Personnel_notes_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Personnel_notes_id_idx" ON "Personnel" USING btree (notes_id);


--
-- Name: Personnel_photo_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Personnel_photo_id_idx" ON "Personnel" USING btree (photo_id);


--
-- Name: Personnel_signature_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Personnel_signature_id_idx" ON "Personnel" USING btree (signature_id);


--
-- Name: Vehicle_notes_id_idx; Type: INDEX; Schema: extra; Owner: extra; Tablespace: 
--

CREATE INDEX "Vehicle_notes_id_idx" ON "Vehicle" USING btree (notes_id);


SET search_path = history, pg_catalog;

--
-- Name: Activity_event_type_id_idx; Type: INDEX; Schema: history; Owner: core; Tablespace: 
--

CREATE INDEX "Activity_event_type_id_idx" ON "Activity" USING btree (event_type_id);


--
-- Name: Activity_time_idx; Type: INDEX; Schema: history; Owner: core; Tablespace: 
--

CREATE INDEX "Activity_time_idx" ON "Activity" USING btree ("time");


--
-- Name: ProjectChange_change_type_id_idx; Type: INDEX; Schema: history; Owner: core; Tablespace: 
--

CREATE INDEX "ProjectChange_change_type_id_idx" ON "ProjectChange" USING btree (change_type_id);


--
-- Name: ProjectChange_time_idx; Type: INDEX; Schema: history; Owner: core; Tablespace: 
--

CREATE INDEX "ProjectChange_time_idx" ON "ProjectChange" USING btree ("time");


SET search_path = core, pg_catalog;

--
-- Name: AllPersonnel_trigger_delete; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "AllPersonnel_trigger_delete" INSTEAD OF DELETE ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoDelete"();


--
-- Name: AllPersonnel_trigger_insert; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "AllPersonnel_trigger_insert" INSTEAD OF INSERT ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoInsert"();


--
-- Name: AllPersonnel_trigger_update; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "AllPersonnel_trigger_update" INSTEAD OF UPDATE ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoUpdate"();


--
-- Name: CardToken_trigger_delete; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "CardToken_trigger_delete" INSTEAD OF DELETE ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoDelete"();


--
-- Name: CardToken_trigger_insert; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "CardToken_trigger_insert" INSTEAD OF INSERT ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoInsert"();


--
-- Name: CardToken_trigger_update; Type: TRIGGER; Schema: core; Owner: core
--

CREATE TRIGGER "CardToken_trigger_update" INSTEAD OF UPDATE ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoUpdate"();


SET search_path = extra, pg_catalog;

--
-- Name: AllAccessSet_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllAccessSet_trigger_delete" INSTEAD OF DELETE ON "AllAccessSet" FOR EACH ROW EXECUTE PROCEDURE "AllAccessSet_DoDelete"();


--
-- Name: AllAccessSet_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllAccessSet_trigger_insert" INSTEAD OF INSERT ON "AllAccessSet" FOR EACH ROW EXECUTE PROCEDURE "AllAccessSet_DoInsert"();


--
-- Name: AllAccessSet_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllAccessSet_trigger_update" INSTEAD OF UPDATE ON "AllAccessSet" FOR EACH ROW EXECUTE PROCEDURE "AllAccessSet_DoUpdate"();


--
-- Name: AllPersonnel_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllPersonnel_trigger_delete" INSTEAD OF DELETE ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoDelete"();


--
-- Name: AllPersonnel_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllPersonnel_trigger_insert" INSTEAD OF INSERT ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoInsert"();


--
-- Name: AllPersonnel_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllPersonnel_trigger_update" INSTEAD OF UPDATE ON "AllPersonnel" FOR EACH ROW EXECUTE PROCEDURE "AllPersonnel_DoUpdate"();


--
-- Name: AllVehicle_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllVehicle_trigger_delete" INSTEAD OF DELETE ON "AllVehicle" FOR EACH ROW EXECUTE PROCEDURE "AllVehicle_DoDelete"();


--
-- Name: AllVehicle_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllVehicle_trigger_insert" INSTEAD OF INSERT ON "AllVehicle" FOR EACH ROW EXECUTE PROCEDURE "AllVehicle_DoInsert"();


--
-- Name: AllVehicle_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "AllVehicle_trigger_update" INSTEAD OF UPDATE ON "AllVehicle" FOR EACH ROW EXECUTE PROCEDURE "AllVehicle_DoUpdate"();


--
-- Name: CardToken_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "CardToken_trigger_delete" INSTEAD OF DELETE ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoDelete"();


--
-- Name: CardToken_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "CardToken_trigger_insert" INSTEAD OF INSERT ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoInsert"();


--
-- Name: CardToken_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "CardToken_trigger_update" INSTEAD OF UPDATE ON "CardToken" FOR EACH ROW EXECUTE PROCEDURE "CardToken_DoUpdate"();


--
-- Name: MultiCard_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "MultiCard_trigger_delete" INSTEAD OF DELETE ON "MultiCard" FOR EACH ROW EXECUTE PROCEDURE "MultiCard_DoDelete"();


--
-- Name: MultiCard_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "MultiCard_trigger_insert" INSTEAD OF INSERT ON "MultiCard" FOR EACH ROW EXECUTE PROCEDURE "MultiCard_DoInsert"();


--
-- Name: MultiCard_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "MultiCard_trigger_update" INSTEAD OF UPDATE ON "MultiCard" FOR EACH ROW EXECUTE PROCEDURE "MultiCard_DoUpdate"();


--
-- Name: SingleCard_trigger_delete; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "SingleCard_trigger_delete" INSTEAD OF DELETE ON "SingleCard" FOR EACH ROW EXECUTE PROCEDURE "SingleCard_DoDelete"();


--
-- Name: SingleCard_trigger_insert; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "SingleCard_trigger_insert" INSTEAD OF INSERT ON "SingleCard" FOR EACH ROW EXECUTE PROCEDURE "SingleCard_DoInsert"();


--
-- Name: SingleCard_trigger_update; Type: TRIGGER; Schema: extra; Owner: extra
--

CREATE TRIGGER "SingleCard_trigger_update" INSTEAD OF UPDATE ON "SingleCard" FOR EACH ROW EXECUTE PROCEDURE "SingleCard_DoUpdate"();


SET search_path = history, pg_catalog;

--
-- Name: Activity_trigger_insert; Type: TRIGGER; Schema: history; Owner: core
--

CREATE TRIGGER "Activity_trigger_insert" AFTER INSERT ON "Activity" FOR EACH ROW EXECUTE PROCEDURE "Activity_Insert_Statistics"();


SET search_path = core, pg_catalog;

--
-- Name: AccessSetsToAccessEntries_access_entry_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AccessSetsToAccessEntries"
    ADD CONSTRAINT "AccessSetsToAccessEntries_access_entry_id_fkey" FOREIGN KEY (access_entry_id) REFERENCES "AccessEntry"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: AccessSetsToAccessEntries_access_set_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AccessSetsToAccessEntries"
    ADD CONSTRAINT "AccessSetsToAccessEntries_access_set_id_fkey" FOREIGN KEY (access_set_id) REFERENCES "AccessSet"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: AccessSetsToTokens_access_set_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AccessSetsToTokens"
    ADD CONSTRAINT "AccessSetsToTokens_access_set_id_fkey" FOREIGN KEY (access_set_id) REFERENCES "AccessSet"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: AccessSetsToTokens_token_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "AccessSetsToTokens"
    ADD CONSTRAINT "AccessSetsToTokens_token_id_fkey" FOREIGN KEY (token_id) REFERENCES "Token"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: Card_token_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "Card"
    ADD CONSTRAINT "Card_token_id_fkey" FOREIGN KEY (token_id) REFERENCES "Token"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: ReadersToAccessEntries_access_entry_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "ReadersToAccessEntries"
    ADD CONSTRAINT "ReadersToAccessEntries_access_entry_id_fkey" FOREIGN KEY (access_entry_id) REFERENCES "AccessEntry"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: ReadersToAccessEntries_reader_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "ReadersToAccessEntries"
    ADD CONSTRAINT "ReadersToAccessEntries_reader_id_fkey" FOREIGN KEY (reader_id) REFERENCES "Reader"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: RfidTag_token_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "RfidTag"
    ADD CONSTRAINT "RfidTag_token_id_fkey" FOREIGN KEY (token_id) REFERENCES "Token"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: SystemInformationItem_sysinfo_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "SystemInformationItem"
    ADD CONSTRAINT "SystemInformationItem_sysinfo_id_fkey" FOREIGN KEY (sysinfo_id) REFERENCES "SystemInformation"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: Token_personnel_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "Token"
    ADD CONSTRAINT "Token_personnel_id_fkey" FOREIGN KEY (personnel_id) REFERENCES "Personnel"(id) ON UPDATE CASCADE DEFERRABLE INITIALLY DEFERRED;


--
-- Name: Token_type_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "Token"
    ADD CONSTRAINT "Token_type_id_fkey" FOREIGN KEY (type_id) REFERENCES "TokenType"(id);


--
-- Name: Vehicle_personnel_id_fkey; Type: FK CONSTRAINT; Schema: core; Owner: core
--

ALTER TABLE ONLY "Vehicle"
    ADD CONSTRAINT "Vehicle_personnel_id_fkey" FOREIGN KEY (personnel_id) REFERENCES "Personnel"(id) ON UPDATE CASCADE ON DELETE CASCADE;


SET search_path = extra, pg_catalog;

--
-- Name: AccessSet_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "AccessSet"
    ADD CONSTRAINT "AccessSet_id_fkey" FOREIGN KEY (id) REFERENCES core."AccessSet"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: AccessSet_notes_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "AccessSet"
    ADD CONSTRAINT "AccessSet_notes_id_fkey" FOREIGN KEY (notes_id) REFERENCES "Notes"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Blob_blob_type_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Blob"
    ADD CONSTRAINT "Blob_blob_type_id_fkey" FOREIGN KEY (type_id) REFERENCES core."BlobType"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Card_token_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Card"
    ADD CONSTRAINT "Card_token_id_fkey" FOREIGN KEY (token_id) REFERENCES core."Card"(token_id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: Personnel_fingerprint_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_fingerprint_id_fkey" FOREIGN KEY (fingerprint_id) REFERENCES "Blob"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Personnel_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_id_fkey" FOREIGN KEY (id) REFERENCES core."Personnel"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: Personnel_notes_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_notes_id_fkey" FOREIGN KEY (notes_id) REFERENCES "Notes"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Personnel_photo_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_photo_id_fkey" FOREIGN KEY (photo_id) REFERENCES "Blob"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Personnel_signature_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Personnel"
    ADD CONSTRAINT "Personnel_signature_id_fkey" FOREIGN KEY (signature_id) REFERENCES "Blob"(id) ON UPDATE CASCADE ON DELETE SET NULL;


--
-- Name: Vehicle_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Vehicle"
    ADD CONSTRAINT "Vehicle_id_fkey" FOREIGN KEY (id) REFERENCES core."Vehicle"(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- Name: Vehicle_notes_id_fkey; Type: FK CONSTRAINT; Schema: extra; Owner: extra
--

ALTER TABLE ONLY "Vehicle"
    ADD CONSTRAINT "Vehicle_notes_id_fkey" FOREIGN KEY (notes_id) REFERENCES "Notes"(id) ON UPDATE CASCADE ON DELETE SET NULL;


SET search_path = history, pg_catalog;

--
-- Name: Activity_event_type_id_fkey; Type: FK CONSTRAINT; Schema: history; Owner: core
--

ALTER TABLE ONLY "Activity"
    ADD CONSTRAINT "Activity_event_type_id_fkey" FOREIGN KEY (event_type_id) REFERENCES "EventType"(id);


--
-- Name: ProjectChange_change_type_id_fkey; Type: FK CONSTRAINT; Schema: history; Owner: core
--

ALTER TABLE ONLY "ProjectChange"
    ADD CONSTRAINT "ProjectChange_change_type_id_fkey" FOREIGN KEY (change_type_id) REFERENCES "ChangeType"(id);


--
-- Name: core; Type: ACL; Schema: -; Owner: core
--

REVOKE ALL ON SCHEMA core FROM PUBLIC;
REVOKE ALL ON SCHEMA core FROM core;
GRANT ALL ON SCHEMA core TO core;
GRANT USAGE ON SCHEMA core TO extra WITH GRANT OPTION;


--
-- Name: extra; Type: ACL; Schema: -; Owner: extra
--

REVOKE ALL ON SCHEMA extra FROM PUBLIC;
REVOKE ALL ON SCHEMA extra FROM extra;
GRANT ALL ON SCHEMA extra TO extra;
GRANT ALL ON SCHEMA extra TO core WITH GRANT OPTION;


--
-- Name: history; Type: ACL; Schema: -; Owner: core
--

REVOKE ALL ON SCHEMA history FROM PUBLIC;
REVOKE ALL ON SCHEMA history FROM core;
GRANT ALL ON SCHEMA history TO core;


--
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM postgres;
GRANT ALL ON SCHEMA public TO postgres;
GRANT ALL ON SCHEMA public TO PUBLIC;


SET search_path = core, pg_catalog;

--
-- Name: AllPersonnel_DoDelete(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "AllPersonnel_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllPersonnel_DoDelete"() FROM core;
GRANT ALL ON FUNCTION "AllPersonnel_DoDelete"() TO core;
GRANT ALL ON FUNCTION "AllPersonnel_DoDelete"() TO extra;


--
-- Name: AllPersonnel_DoInsert(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "AllPersonnel_DoInsert"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllPersonnel_DoInsert"() FROM core;
GRANT ALL ON FUNCTION "AllPersonnel_DoInsert"() TO core;
GRANT ALL ON FUNCTION "AllPersonnel_DoInsert"() TO extra;


--
-- Name: AllPersonnel_DoUpdate(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "AllPersonnel_DoUpdate"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllPersonnel_DoUpdate"() FROM core;
GRANT ALL ON FUNCTION "AllPersonnel_DoUpdate"() TO core;
GRANT ALL ON FUNCTION "AllPersonnel_DoUpdate"() TO extra;


--
-- Name: CanSwitchToSingleId(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "CanSwitchToSingleId"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CanSwitchToSingleId"() FROM core;
GRANT ALL ON FUNCTION "CanSwitchToSingleId"() TO core;
GRANT ALL ON FUNCTION "CanSwitchToSingleId"() TO extra;


--
-- Name: CardToken_DoDelete(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "CardToken_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoDelete"() FROM core;
GRANT ALL ON FUNCTION "CardToken_DoDelete"() TO core;


--
-- Name: CardToken_DoInsert(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "CardToken_DoInsert"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoInsert"() FROM core;
GRANT ALL ON FUNCTION "CardToken_DoInsert"() TO core;
GRANT ALL ON FUNCTION "CardToken_DoInsert"() TO extra;


--
-- Name: CardToken_DoUpdate(); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "CardToken_DoUpdate"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoUpdate"() FROM core;
GRANT ALL ON FUNCTION "CardToken_DoUpdate"() TO core;
GRANT ALL ON FUNCTION "CardToken_DoUpdate"() TO extra;


--
-- Name: Personnel_Delete(uuid, character varying); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "Personnel_Delete"(personnel_id uuid, username character varying) FROM PUBLIC;
REVOKE ALL ON FUNCTION "Personnel_Delete"(personnel_id uuid, username character varying) FROM core;
GRANT ALL ON FUNCTION "Personnel_Delete"(personnel_id uuid, username character varying) TO core;
GRANT ALL ON FUNCTION "Personnel_Delete"(personnel_id uuid, username character varying) TO extra;


--
-- Name: Token_Delete(uuid, character varying); Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON FUNCTION "Token_Delete"(token_id uuid, username character varying) FROM PUBLIC;
REVOKE ALL ON FUNCTION "Token_Delete"(token_id uuid, username character varying) FROM core;
GRANT ALL ON FUNCTION "Token_Delete"(token_id uuid, username character varying) TO core;
GRANT ALL ON FUNCTION "Token_Delete"(token_id uuid, username character varying) TO extra;


SET search_path = extra, pg_catalog;

--
-- Name: AllAccessSet_DoDelete(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "AllAccessSet_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllAccessSet_DoDelete"() FROM extra;
GRANT ALL ON FUNCTION "AllAccessSet_DoDelete"() TO extra;
GRANT ALL ON FUNCTION "AllAccessSet_DoDelete"() TO core;


--
-- Name: AllVehicle_DoDelete(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "AllVehicle_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllVehicle_DoDelete"() FROM extra;
GRANT ALL ON FUNCTION "AllVehicle_DoDelete"() TO extra;
GRANT ALL ON FUNCTION "AllVehicle_DoDelete"() TO core;


--
-- Name: AllVehicle_DoInsert(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "AllVehicle_DoInsert"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllVehicle_DoInsert"() FROM extra;
GRANT ALL ON FUNCTION "AllVehicle_DoInsert"() TO extra;
GRANT ALL ON FUNCTION "AllVehicle_DoInsert"() TO PUBLIC;
GRANT ALL ON FUNCTION "AllVehicle_DoInsert"() TO core;


--
-- Name: AllVehicle_DoUpdate(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "AllVehicle_DoUpdate"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "AllVehicle_DoUpdate"() FROM extra;
GRANT ALL ON FUNCTION "AllVehicle_DoUpdate"() TO extra;
GRANT ALL ON FUNCTION "AllVehicle_DoUpdate"() TO PUBLIC;
GRANT ALL ON FUNCTION "AllVehicle_DoUpdate"() TO core;


--
-- Name: CardToken_DoDelete(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "CardToken_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoDelete"() FROM extra;
GRANT ALL ON FUNCTION "CardToken_DoDelete"() TO extra;
GRANT ALL ON FUNCTION "CardToken_DoDelete"() TO core;


--
-- Name: CardToken_DoInsert(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "CardToken_DoInsert"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoInsert"() FROM extra;
GRANT ALL ON FUNCTION "CardToken_DoInsert"() TO extra;
GRANT ALL ON FUNCTION "CardToken_DoInsert"() TO core;


--
-- Name: CardToken_DoUpdate(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "CardToken_DoUpdate"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "CardToken_DoUpdate"() FROM extra;
GRANT ALL ON FUNCTION "CardToken_DoUpdate"() TO extra;
GRANT ALL ON FUNCTION "CardToken_DoUpdate"() TO core;


--
-- Name: MultiCard_DoDelete(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "MultiCard_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "MultiCard_DoDelete"() FROM extra;
GRANT ALL ON FUNCTION "MultiCard_DoDelete"() TO extra;
GRANT ALL ON FUNCTION "MultiCard_DoDelete"() TO core;


--
-- Name: MultiCard_DoInsert(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "MultiCard_DoInsert"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "MultiCard_DoInsert"() FROM extra;
GRANT ALL ON FUNCTION "MultiCard_DoInsert"() TO extra;
GRANT ALL ON FUNCTION "MultiCard_DoInsert"() TO core;


--
-- Name: MultiCard_DoUpdate(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "MultiCard_DoUpdate"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "MultiCard_DoUpdate"() FROM extra;
GRANT ALL ON FUNCTION "MultiCard_DoUpdate"() TO extra;
GRANT ALL ON FUNCTION "MultiCard_DoUpdate"() TO core;


--
-- Name: SingleCard_DoDelete(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "SingleCard_DoDelete"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "SingleCard_DoDelete"() FROM extra;
GRANT ALL ON FUNCTION "SingleCard_DoDelete"() TO extra;
GRANT ALL ON FUNCTION "SingleCard_DoDelete"() TO core;


--
-- Name: SingleCard_DoInsert(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "SingleCard_DoInsert"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "SingleCard_DoInsert"() FROM extra;
GRANT ALL ON FUNCTION "SingleCard_DoInsert"() TO extra;
GRANT ALL ON FUNCTION "SingleCard_DoInsert"() TO core;


--
-- Name: SingleCard_DoUpdate(); Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON FUNCTION "SingleCard_DoUpdate"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "SingleCard_DoUpdate"() FROM extra;
GRANT ALL ON FUNCTION "SingleCard_DoUpdate"() TO extra;
GRANT ALL ON FUNCTION "SingleCard_DoUpdate"() TO core;


SET search_path = history, pg_catalog;

--
-- Name: Activity_Insert_Statistics(); Type: ACL; Schema: history; Owner: core
--

REVOKE ALL ON FUNCTION "Activity_Insert_Statistics"() FROM PUBLIC;
REVOKE ALL ON FUNCTION "Activity_Insert_Statistics"() FROM core;
GRANT ALL ON FUNCTION "Activity_Insert_Statistics"() TO core;
GRANT ALL ON FUNCTION "Activity_Insert_Statistics"() TO extra;


SET search_path = core, pg_catalog;

--
-- Name: AccessEntry; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "AccessEntry" FROM PUBLIC;
REVOKE ALL ON TABLE "AccessEntry" FROM core;
GRANT ALL ON TABLE "AccessEntry" TO core;


--
-- Name: AccessSet; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "AccessSet" FROM PUBLIC;
REVOKE ALL ON TABLE "AccessSet" FROM core;
GRANT ALL ON TABLE "AccessSet" TO core;
GRANT SELECT,INSERT,REFERENCES,DELETE,TRIGGER,UPDATE ON TABLE "AccessSet" TO extra WITH GRANT OPTION;


--
-- Name: AccessSetsToAccessEntries; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "AccessSetsToAccessEntries" FROM PUBLIC;
REVOKE ALL ON TABLE "AccessSetsToAccessEntries" FROM core;
GRANT ALL ON TABLE "AccessSetsToAccessEntries" TO core;


--
-- Name: AccessSetsToTokens; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "AccessSetsToTokens" FROM PUBLIC;
REVOKE ALL ON TABLE "AccessSetsToTokens" FROM core;
GRANT ALL ON TABLE "AccessSetsToTokens" TO core;


--
-- Name: Personnel; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL ON TABLE "Personnel" FROM core;
GRANT ALL ON TABLE "Personnel" TO core;


--
-- Name: Personnel.id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(id) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(id) ON TABLE "Personnel" FROM core;
GRANT SELECT(id),REFERENCES(id) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.name_last; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(name_last) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(name_last) ON TABLE "Personnel" FROM core;
GRANT SELECT(name_last) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.name_first; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(name_first) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(name_first) ON TABLE "Personnel" FROM core;
GRANT SELECT(name_first) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.user_level; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(user_level) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(user_level) ON TABLE "Personnel" FROM core;
GRANT SELECT(user_level) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.days_to_log; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(days_to_log) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(days_to_log) ON TABLE "Personnel" FROM core;
GRANT SELECT(days_to_log) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.apb_type_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(apb_type_id) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(apb_type_id) ON TABLE "Personnel" FROM core;
GRANT SELECT(apb_type_id) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.apb_zone_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(apb_zone_id) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(apb_zone_id) ON TABLE "Personnel" FROM core;
GRANT SELECT(apb_zone_id) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.apb_violations; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(apb_violations) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(apb_violations) ON TABLE "Personnel" FROM core;
GRANT SELECT(apb_violations) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.created; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(created) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(created) ON TABLE "Personnel" FROM core;
GRANT SELECT(created) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.created_by; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(created_by) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(created_by) ON TABLE "Personnel" FROM core;
GRANT SELECT(created_by) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.updated; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(updated) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(updated) ON TABLE "Personnel" FROM core;
GRANT SELECT(updated) ON TABLE "Personnel" TO extra;


--
-- Name: Personnel.updated_by; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(updated_by) ON TABLE "Personnel" FROM PUBLIC;
REVOKE ALL(updated_by) ON TABLE "Personnel" FROM core;
GRANT SELECT(updated_by) ON TABLE "Personnel" TO extra;


--
-- Name: AllPersonnel; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "AllPersonnel" FROM PUBLIC;
REVOKE ALL ON TABLE "AllPersonnel" FROM core;
GRANT ALL ON TABLE "AllPersonnel" TO core;
GRANT SELECT,INSERT,REFERENCES,DELETE,UPDATE ON TABLE "AllPersonnel" TO extra WITH GRANT OPTION;


--
-- Name: BlobType; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "BlobType" FROM PUBLIC;
REVOKE ALL ON TABLE "BlobType" FROM core;
GRANT ALL ON TABLE "BlobType" TO core;
GRANT SELECT,REFERENCES ON TABLE "BlobType" TO extra WITH GRANT OPTION;


--
-- Name: Card; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "Card" FROM PUBLIC;
REVOKE ALL ON TABLE "Card" FROM core;
GRANT ALL ON TABLE "Card" TO core;


--
-- Name: Card.token_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(token_id) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(token_id) ON TABLE "Card" FROM core;
GRANT SELECT(token_id),REFERENCES(token_id) ON TABLE "Card" TO extra;


--
-- Name: Card.card_number; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(card_number) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(card_number) ON TABLE "Card" FROM core;
GRANT SELECT(card_number) ON TABLE "Card" TO extra;


--
-- Name: Card.site_code; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(site_code) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(site_code) ON TABLE "Card" FROM core;
GRANT SELECT(site_code) ON TABLE "Card" TO extra;


--
-- Name: Card.card_format; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(card_format) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(card_format) ON TABLE "Card" FROM core;
GRANT SELECT(card_format) ON TABLE "Card" TO extra;


--
-- Name: Card.card_type; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(card_type) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(card_type) ON TABLE "Card" FROM core;
GRANT SELECT(card_type) ON TABLE "Card" TO extra;


--
-- Name: Card.pin_number; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(pin_number) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(pin_number) ON TABLE "Card" FROM core;
GRANT SELECT(pin_number) ON TABLE "Card" TO extra;


--
-- Name: Card.card_valid; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(card_valid) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(card_valid) ON TABLE "Card" FROM core;
GRANT SELECT(card_valid) ON TABLE "Card" TO extra;


--
-- Name: Card.activate_date; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(activate_date) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(activate_date) ON TABLE "Card" FROM core;
GRANT SELECT(activate_date) ON TABLE "Card" TO extra;


--
-- Name: Card.deactivate_date; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(deactivate_date) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(deactivate_date) ON TABLE "Card" FROM core;
GRANT SELECT(deactivate_date) ON TABLE "Card" TO extra;


--
-- Name: Card.secondary_expiration_date; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(secondary_expiration_date) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(secondary_expiration_date) ON TABLE "Card" FROM core;
GRANT SELECT(secondary_expiration_date) ON TABLE "Card" TO extra;


--
-- Name: Card.expire_days; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(expire_days) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(expire_days) ON TABLE "Card" FROM core;
GRANT SELECT(expire_days) ON TABLE "Card" TO extra;


--
-- Name: Card.action_point_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(action_point_id) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(action_point_id) ON TABLE "Card" FROM core;
GRANT SELECT(action_point_id) ON TABLE "Card" TO extra;


--
-- Name: Card.threat_level; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(threat_level) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(threat_level) ON TABLE "Card" FROM core;
GRANT SELECT(threat_level) ON TABLE "Card" TO extra;


--
-- Name: Card.auto_disable; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(auto_disable) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(auto_disable) ON TABLE "Card" FROM core;
GRANT SELECT(auto_disable) ON TABLE "Card" TO extra;


--
-- Name: Card.grant_long_access_time; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(grant_long_access_time) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(grant_long_access_time) ON TABLE "Card" FROM core;
GRANT SELECT(grant_long_access_time) ON TABLE "Card" TO extra;


--
-- Name: Card.escort_visitor_capable; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(escort_visitor_capable) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(escort_visitor_capable) ON TABLE "Card" FROM core;
GRANT SELECT(escort_visitor_capable) ON TABLE "Card" TO extra;


--
-- Name: Card.access_cost_override_capable; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(access_cost_override_capable) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(access_cost_override_capable) ON TABLE "Card" FROM core;
GRANT SELECT(access_cost_override_capable) ON TABLE "Card" TO extra;


--
-- Name: Card.event_lock_override_capable; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(event_lock_override_capable) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(event_lock_override_capable) ON TABLE "Card" FROM core;
GRANT SELECT(event_lock_override_capable) ON TABLE "Card" TO extra;


--
-- Name: Card.building_passback_exemption; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(building_passback_exemption) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(building_passback_exemption) ON TABLE "Card" FROM core;
GRANT SELECT(building_passback_exemption) ON TABLE "Card" TO extra;


--
-- Name: Card.parking_passback_exemption; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(parking_passback_exemption) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(parking_passback_exemption) ON TABLE "Card" FROM core;
GRANT SELECT(parking_passback_exemption) ON TABLE "Card" TO extra;


--
-- Name: Card.card_holder_groups; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(card_holder_groups) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(card_holder_groups) ON TABLE "Card" FROM core;
GRANT SELECT(card_holder_groups) ON TABLE "Card" TO extra;


--
-- Name: Card.activation_group; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(activation_group) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(activation_group) ON TABLE "Card" FROM core;
GRANT SELECT(activation_group) ON TABLE "Card" TO extra;


--
-- Name: Card.on_access_output; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(on_access_output) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(on_access_output) ON TABLE "Card" FROM core;
GRANT SELECT(on_access_output) ON TABLE "Card" TO extra;


--
-- Name: Card.compass_command_group; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(compass_command_group) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(compass_command_group) ON TABLE "Card" FROM core;
GRANT SELECT(compass_command_group) ON TABLE "Card" TO extra;


--
-- Name: Card.low_battery; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(low_battery) ON TABLE "Card" FROM PUBLIC;
REVOKE ALL(low_battery) ON TABLE "Card" FROM core;
GRANT REFERENCES(low_battery) ON TABLE "Card" TO extra;


--
-- Name: Token; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "Token" FROM PUBLIC;
REVOKE ALL ON TABLE "Token" FROM core;
GRANT ALL ON TABLE "Token" TO core;


--
-- Name: Token.id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(id) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(id) ON TABLE "Token" FROM core;
GRANT SELECT(id),REFERENCES(id) ON TABLE "Token" TO extra;


--
-- Name: Token.user_level; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(user_level) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(user_level) ON TABLE "Token" FROM core;
GRANT SELECT(user_level) ON TABLE "Token" TO extra;


--
-- Name: Token.personnel_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(personnel_id) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(personnel_id) ON TABLE "Token" FROM core;
GRANT SELECT(personnel_id) ON TABLE "Token" TO extra;


--
-- Name: Token.badge_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(badge_id) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(badge_id) ON TABLE "Token" FROM core;
GRANT SELECT(badge_id) ON TABLE "Token" TO extra;


--
-- Name: Token.lost; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(lost) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(lost) ON TABLE "Token" FROM core;
GRANT SELECT(lost) ON TABLE "Token" TO extra;


--
-- Name: Token.last_read; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(last_read) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(last_read) ON TABLE "Token" FROM core;
GRANT SELECT(last_read) ON TABLE "Token" TO extra;


--
-- Name: Token.last_reader; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(last_reader) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(last_reader) ON TABLE "Token" FROM core;
GRANT SELECT(last_reader) ON TABLE "Token" TO extra;


--
-- Name: Token.last_read_status; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(last_read_status) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(last_read_status) ON TABLE "Token" FROM core;
GRANT SELECT(last_read_status) ON TABLE "Token" TO extra;


--
-- Name: Token.created; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(created) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(created) ON TABLE "Token" FROM core;
GRANT SELECT(created) ON TABLE "Token" TO extra;


--
-- Name: Token.created_by; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(created_by) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(created_by) ON TABLE "Token" FROM core;
GRANT SELECT(created_by) ON TABLE "Token" TO extra;


--
-- Name: Token.updated; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(updated) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(updated) ON TABLE "Token" FROM core;
GRANT SELECT(updated) ON TABLE "Token" TO extra;


--
-- Name: Token.updated_by; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(updated_by) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(updated_by) ON TABLE "Token" FROM core;
GRANT SELECT(updated_by) ON TABLE "Token" TO extra;


--
-- Name: Token.download_required; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(download_required) ON TABLE "Token" FROM PUBLIC;
REVOKE ALL(download_required) ON TABLE "Token" FROM core;
GRANT SELECT(download_required) ON TABLE "Token" TO extra WITH GRANT OPTION;


--
-- Name: CardDownload; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "CardDownload" FROM PUBLIC;
REVOKE ALL ON TABLE "CardDownload" FROM core;
GRANT ALL ON TABLE "CardDownload" TO core;


--
-- Name: CardToken; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "CardToken" FROM PUBLIC;
REVOKE ALL ON TABLE "CardToken" FROM core;
GRANT ALL ON TABLE "CardToken" TO core;
GRANT SELECT,INSERT,REFERENCES,DELETE,UPDATE ON TABLE "CardToken" TO extra WITH GRANT OPTION;


--
-- Name: PersonnelTokenCounts; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "PersonnelTokenCounts" FROM PUBLIC;
REVOKE ALL ON TABLE "PersonnelTokenCounts" FROM core;
GRANT ALL ON TABLE "PersonnelTokenCounts" TO core;
GRANT SELECT,INSERT,REFERENCES,DELETE,UPDATE ON TABLE "PersonnelTokenCounts" TO extra WITH GRANT OPTION;


--
-- Name: PersonnelWithSingleCard; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "PersonnelWithSingleCard" FROM PUBLIC;
REVOKE ALL ON TABLE "PersonnelWithSingleCard" FROM core;
GRANT ALL ON TABLE "PersonnelWithSingleCard" TO core;
GRANT SELECT,INSERT,REFERENCES,DELETE,UPDATE ON TABLE "PersonnelWithSingleCard" TO extra WITH GRANT OPTION;


--
-- Name: RfidTag; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "RfidTag" FROM PUBLIC;
REVOKE ALL ON TABLE "RfidTag" FROM core;
GRANT ALL ON TABLE "RfidTag" TO core;


--
-- Name: RfidTag.token_id; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(token_id) ON TABLE "RfidTag" FROM PUBLIC;
REVOKE ALL(token_id) ON TABLE "RfidTag" FROM core;
GRANT SELECT(token_id),REFERENCES(token_id) ON TABLE "RfidTag" TO extra;


--
-- Name: RfidTag.tag_number; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL(tag_number) ON TABLE "RfidTag" FROM PUBLIC;
REVOKE ALL(tag_number) ON TABLE "RfidTag" FROM core;
GRANT SELECT(tag_number) ON TABLE "RfidTag" TO extra;


--
-- Name: TokenType; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "TokenType" FROM PUBLIC;
REVOKE ALL ON TABLE "TokenType" FROM core;
GRANT ALL ON TABLE "TokenType" TO core;
GRANT SELECT,REFERENCES ON TABLE "TokenType" TO extra WITH GRANT OPTION;


--
-- Name: TokenType_id_seq; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON SEQUENCE "TokenType_id_seq" FROM PUBLIC;
REVOKE ALL ON SEQUENCE "TokenType_id_seq" FROM core;
GRANT ALL ON SEQUENCE "TokenType_id_seq" TO core;


--
-- Name: Vehicle; Type: ACL; Schema: core; Owner: core
--

REVOKE ALL ON TABLE "Vehicle" FROM PUBLIC;
REVOKE ALL ON TABLE "Vehicle" FROM core;
GRANT ALL ON TABLE "Vehicle" TO core;
GRANT SELECT,INSERT,REFERENCES,DELETE,UPDATE ON TABLE "Vehicle" TO extra WITH GRANT OPTION;


SET search_path = extra, pg_catalog;

--
-- Name: Vehicle; Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON TABLE "Vehicle" FROM PUBLIC;
REVOKE ALL ON TABLE "Vehicle" FROM extra;
GRANT ALL ON TABLE "Vehicle" TO extra;
GRANT ALL ON TABLE "Vehicle" TO core;


--
-- Name: AllVehicle; Type: ACL; Schema: extra; Owner: extra
--

REVOKE ALL ON TABLE "AllVehicle" FROM PUBLIC;
REVOKE ALL ON TABLE "AllVehicle" FROM extra;
GRANT ALL ON TABLE "AllVehicle" TO extra;
GRANT ALL ON TABLE "AllVehicle" TO core;


--
-- PostgreSQL database dump complete
--

